(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8528,        312]*)
(*NotebookOutlinePosition[      9213,        335]*)
(*  CellTagsIndexPosition[      9169,        331]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ViewPointSelect` Installation", "Section"],

Cell[CellGroupData[{

Cell["About", "Subsection"],

Cell[TextData[{
  "The realization of three-dimensional graphics in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " doesn't support free rotation and high quality rendering the picture \
simultaneously. One has to change either manually the option ",
  StyleBox["ViewPoint", "MR"],
  " and repeat rendering the graphics or to use the package ",
  StyleBox["RealTime3D`", "MR"],
  " which supports library OpenGL and has some limitations. The package ",
  StyleBox["ViewPointSelect", "MR"],
  "` combines these two alternatives. It provides an easy way to choose \
interactively view point of 3D graphics in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and redraw the result by standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions. The package supports graphical objects ",
  StyleBox["SurfaceGraphics", "MR"],
  " and ",
  StyleBox["Graphics3D", "MR"],
  " and functions ",
  StyleBox["Plot3D", "MR"],
  " and ",
  StyleBox["ListPlot3D", "MR"],
  ", ",
  StyleBox["ParametricPlot3D,", "MR"],
  " etc."
}], "Text"],

Cell["\[Copyright] Yuri E. Kandrashkin, 2006", "Text",
  TextAlignment->Right]
}, Open  ]],

Cell[CellGroupData[{

Cell["Loading", "Subsection"],

Cell[TextData[{
  "If the folder ",
  StyleBox["ViewPointSelect", "MR"],
  " is placed in one of the directories for automatic search for packages, it \
can be loaded as"
}], "Text"],

Cell[BoxData[
    \(<< \ ViewPointSelect`\)], "Input"],

Cell["\<\
The execution of the following line returns the list of such directories:\
\>", "Text"],

Cell[BoxData[
    \($Path // ColumnForm\)], "Input"],

Cell[TextData[{
  "If the folder with the package is in such a place (for example in \
directory ",
  StyleBox["Applications", "MR"],
  ") the execution of menu command ",
  StyleBox["Help \[RightTriangle] Rebuild Help Index", "SR"],
  " adds the function ",
  StyleBox["ViewPointSelect", "MR"],
  " in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ",
  StyleBox["HelpBrowser", "SR"],
  "."
}], "Text"],

Cell[TextData[{
  "Another way to load the package ",
  StyleBox["ViewPointSelect", "MR"],
  " is using the menu ",
  StyleBox["Input \[RightTriangle] Get File Path ...", "SR"],
  " and select the file ",
  StyleBox["init.m", "MR"],
  " in the folder ",
  StyleBox["ViewPointSelect", "MR"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Installation", "Subsection"],

Cell[CellGroupData[{

Cell["Copy files to a selected directory", "SubsubsectionIcon"],

Cell[TextData[{
  "Unpack and copy the directory ",
  StyleBox["ViewPointSelect", "MR"],
  " into ",
  StyleBox["Applications", "MR"],
  " subdirectory of your ",
  StyleBox["$BaseDirectory", "MR"],
  " or ",
  StyleBox["$UserBaseDirectory", "MR"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rebuild Help Index", "SubsubsectionIcon"],

Cell[TextData[{
  "Execute the menu command ",
  StyleBox["Help \[RightTriangle] Rebuild Help Index", "SR"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Adding keyboard shortcut", "SubsubsectionIcon"],

Cell[TextData[{
  "The package provides limited support to use the function ",
  StyleBox["ViewPointSelect", "MR"],
  " directly from menu or by keyboard shortcut. To activate this property one \
has to change the file ",
  StyleBox["MenuSetup.tr", "MR"],
  ". "
}], "Text"],

Cell["\<\
To get path to this file evaluate next cell (for OS Windows):\
\>", "Text"],

Cell[BoxData[
    \(ToFileName[{$TopDirectory, "\<SystemFiles\>", "\<FrontEnd\>", \
"\<TextResources\>", "\<Windows\>"}]\)], "Input"],

Cell[TextData[{
  "Create the subdirectories in the same order in your base directory and \
copy the file ",
  StyleBox["MenuSetup.tr", "MR"],
  " there. Insert the following lines after the description of standard ",
  StyleBox["ViewPoint selector", "MR"],
  " ",
  StyleBox["Item[\"&3D ViewPoint Selector...\",...]", "MR"],
  ":"
}], "Text"],

Cell[TextData[StyleBox["Item[\"&3D ViewPoint Select\", \
KernelExecute[ToExpression[\"ViewPointSelectDialog[]\"]],\n  \
MenuKey[\"v\",Modifiers->{Control,Command}], MenuEvaluator->Automatic],", \
"MR"]], "Text",
  CellFrame->True],

Cell[TextData[{
  "After saving the file ",
  StyleBox["MenuSetup.tr", "MR"],
  " restart ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", select function producing 3D graphic (like ",
  StyleBox["Plot3D", "MR"],
  " and ",
  StyleBox["ListPlot3D", "MR"],
  ", ",
  StyleBox["ParametricPlot3D,", "MR"],
  " etc. ) or place coursor just after it and apply  the menu command or the \
key combination (\[ControlKey]",
  StyleBox["\[KeyBar]", "KeyboardChars"],
  "\[AltKey]\[LeftModified]v\[RightModified] for Windows). This will launch \
",
  StyleBox["ViewPointSelect", "MR"],
  " with selected expression. Note, this property of ",
  StyleBox["ViewPointSelect", "MR"],
  " doesn't work on cells with format type ",
  StyleBox["InputForm", "SR"],
  "."
}], "Text"],

Cell[TextData[{
  "The chosen keyboard shortcut uses the command key which used to activate \
the menu. Thus the better solution is removing the shortcut key combination \
of standard ",
  StyleBox["ViewPoint selector", "SR"],
  " and using it for ",
  StyleBox["ViewPointSelect", "MR"],
  ":"
}], "Text"],

Cell[TextData[{
  StyleBox["Item[\"&3D ViewPoint Select\", \
KernelExecute[ToExpression[\"ViewPointSelectDialog[]\"]],\n", "MR"],
  StyleBox["  MenuKey[\"v\",Modifiers->{Control,Shift}], \
MenuEvaluator->Automatic],", "MR"]
}], "Text",
  CellFrame->True]
}, Open  ]],

Cell[CellGroupData[{

Cell["Loading the package", "SubsubsectionIcon"],

Cell["Load the package as", "Text"],

Cell[BoxData[
    \(Needs[ViewPointSelect`]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Make the autoloading package", "SubsubsectionIcon"],

Cell[TextData[{
  "To load the package with the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " kernel save",
  " in the directory ",
  StyleBox["Kernel", "MR"],
  " of your ",
  StyleBox["$BaseDirectory", "MR"],
  " or ",
  StyleBox["$UserBaseDirectory", "MR"],
  " the file ",
  StyleBox["init.m", "MR"],
  " with the following line (or add this line if the file ",
  StyleBox["init.m", "MR"],
  " already exists):"
}], "Text"],

Cell[TextData[{
  StyleBox["\tNeeds[\"", "MR"],
  StyleBox["ViewPointSelect", "MR"],
  StyleBox["`\"]", "MR"]
}], "Text",
  CellFrame->True],

Cell[TextData[{
  " Another option is to save the file in the folder ",
  StyleBox["Autoload", "MR"],
  ". "
}], "Text"],

Cell[TextData[{
  "This allows the package to load with the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " kernel. "
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 971}},
WindowSize->{496, 740},
WindowMargins->{{448, Automatic}, {Automatic, 101}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 48, 0, 65, "Section"],

Cell[CellGroupData[{
Cell[1849, 57, 27, 0, 39, "Subsection"],
Cell[1879, 59, 1063, 29, 161, "Text"],
Cell[2945, 90, 78, 1, 25, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3060, 96, 29, 0, 39, "Subsection"],
Cell[3092, 98, 182, 5, 42, "Text"],
Cell[3277, 105, 54, 1, 29, "Input"],
Cell[3334, 108, 97, 2, 25, "Text"],
Cell[3434, 112, 52, 1, 29, "Input"],
Cell[3489, 115, 415, 14, 59, "Text"],
Cell[3907, 131, 308, 10, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4252, 146, 34, 0, 39, "Subsection"],

Cell[CellGroupData[{
Cell[4311, 150, 63, 0, 25, "SubsubsectionIcon"],
Cell[4377, 152, 266, 10, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4680, 167, 47, 0, 25, "SubsubsectionIcon"],
Cell[4730, 169, 119, 3, 25, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4886, 177, 53, 0, 25, "SubsubsectionIcon"],
Cell[4942, 179, 274, 7, 59, "Text"],
Cell[5219, 188, 85, 2, 70, "Text"],
Cell[5307, 192, 133, 2, 70, "Input"],
Cell[5443, 196, 343, 9, 70, "Text"],
Cell[5789, 207, 230, 4, 70, "Text"],
Cell[6022, 213, 773, 23, 70, "Text"],
Cell[6798, 238, 305, 8, 70, "Text"],
Cell[7106, 248, 254, 6, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7397, 259, 48, 0, 70, "SubsubsectionIcon"],
Cell[7448, 261, 35, 0, 70, "Text"],
Cell[7486, 263, 56, 1, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7579, 269, 57, 0, 70, "SubsubsectionIcon"],
Cell[7639, 271, 440, 16, 70, "Text"],
Cell[8082, 289, 140, 5, 70, "Text"],
Cell[8225, 296, 120, 4, 70, "Text"],
Cell[8348, 302, 140, 5, 70, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

