(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    314599,       5788]*)
(*NotebookOutlinePosition[    315284,       5811]*)
(*  CellTagsIndexPosition[    315240,       5807]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["ViewPointSelect Guide", "Section"],

Cell[CellGroupData[{

Cell["About", "Subsection"],

Cell[TextData[{
  "The realization of three-dimensional graphics in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " doesn't support free rotation and high quality rendering the picture \
simultaneously. One has to change either manually the option ",
  StyleBox["ViewPoint", "MR"],
  " and repeat rendering the graphics or to use the package ",
  StyleBox["RealTime3D`", "MR"],
  " which supports library OpenGL and has some limitations. The package ",
  StyleBox["ViewPointSelect", "MR"],
  "` combines these two alternatives. It provides an easy way to choose \
interactively view point of 3D graphics in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and redraw the result by standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions. The package supports graphical objects ",
  StyleBox["SurfaceGraphics", "MR"],
  " and ",
  StyleBox["Graphics3D", "MR"],
  " and functions ",
  StyleBox["Plot3D", "MR"],
  " and ",
  StyleBox["ListPlot3D", "MR"],
  ", ",
  StyleBox["ParametricPlot3D,", "MR"],
  " etc."
}], "Text"],

Cell["\[Copyright] Yuri E. Kandrashkin, 2006", "Text",
  TextAlignment->Right]
}, Open  ]],

Cell[CellGroupData[{

Cell["Credits", "Subsection"],

Cell["\<\
This package was greatly improved based on the comments by David Park and \
Ingolf Dahl.\
\>", "Text"],

Cell[TextData[{
  "The package uses the algorithm of intercommunications between the ",
  StyleBox["Kernel", "MR"],
  " and ",
  StyleBox["FrontEnd", "MR"],
  " ",
  StyleBox["initially", "MR"],
  " realized in the package ",
  StyleBox["Replot", "MR"],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Highlights", "Subsection"],

Cell[TextData[{
  "\[FilledSmallSquare] Interactive selection of ",
  StyleBox["ViewPoint", "MR"],
  " of the chosen 3D graphics by real time rotation\n\[FilledSmallSquare] \
Support graphics objects ",
  StyleBox["SurfaceGraphics", "MR"],
  " and ",
  StyleBox["Graphics3D\n", "MR"],
  "\[FilledSmallSquare] User exandable list of supported plot functions\n\
\[FilledSmallSquare] Toggle to copy the picked value of ",
  StyleBox["ViewPoint", "MR"],
  " to clipboard\n\[FilledSmallSquare] Selection of ",
  StyleBox["ViewPoint", "MR"],
  " on the stage of the editing by menu or keyboard shortcut command "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ViewPointSelect as a function", "Subsection"],

Cell[TextData[{
  "In the following it is assumed that the package is intalled as it \
described in the file ",
  StyleBox["Intallation.nb", "MR"],
  "."
}], "Text"],

Cell["This loads the package if it has not been loaded", "Text"],

Cell[BoxData[
    \(Needs["\<ViewPointSelect`\>"]\)], "Input"],

Cell[TextData[{
  "The main function of the the package is ",
  StyleBox["ViewPointSelect", "MR"],
  ". The following gives the information:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?\ ViewPointSelect\)\)], "Input"],

Cell[BoxData[
    \("ViewPointSelect` provides interactive selection of option ViewPoint \
based on real time rotations. It supports objects SurfaceGraphics and \
Graphics3D generated by functions like Plot3D, ListPlot3D, ParametricPlot3D, \
etc.\n The delay before interactive window closes equal approximately 60 \
seconds. \n Example: Plot3D[Sin[x y], {x,0,1},{y,0,1}]//ViewPointSelect\n \
This function can be used also directly via menu command or by keyboard \
shortcut Ctrl-Command(Alt)-v. \n To activate it select the plot function \
(e.g. Plot3D[...]) or place coursor at the end of expression and press \
keyboard shortcut."\)], "Print"]
}, Open  ]],

Cell[TextData[{
  "Execution of an example opens a new notebook ",
  StyleBox["ViewPointSelect Window", "MR"],
  " with 3D graphics. Choose a new ",
  StyleBox["ViewPoint", "MR"],
  " by dragging any point within the graphics. "
}], "Text"],

Cell[BoxData[
    \(Plot3D[Sin[x\ y], {x, 0, 1}, {y, 0, 1}] // ViewPointSelect\)], "Input"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006<0001YR000`400?l0
0000o`00003o00<001BI000CS0004h`0o`004hb:000CS00000@001J^000N
X0007Z0001jQ5@007Z0:000NXA<001jP50007J0:000NX0X001fP2P007Z4:
000MX0X001jQ2P007Z0:000MX@T001jP50007Z4D000MX@X001jP2P007J4D
000NXA<001jP2P007Z4D000NX0X001jQ:0007Z0:000MX@T001jP:0007Z40
10007Z0001jS000NX@006i/1000CS00000D001W?00Paf@0=AmX045CO00Y9
f@0:00A1f0X003kM7@00?M`:000ng0X003gM5000?M`:000mg@X003kL2P00
?]dD000mg0T003kM2P00?M`:000ng@X003gL5000?MdD000mg0X003gM2P00
?M`9000ng0X003gM5000?M`:000mgA@003gL2P00?Md:000ng0X003gM2@00
?M`:000mg@X003gL5000?Md01000?M`003O@000/_0007Z<1000CS00000D0
01W?00Paf@0BD^D05V[^00QEg@0:00M?j_l004SaNP00B?400`00?M`002fn
000MX001000CS00000@001W?00Paf@0FJ^h025GMo`3ooomd0?oooa40k>WH
00<004Sa000mg0007J000@004h`00005000Ic`08<MT05V[^00QEg@2/Z9T0
o`3/jMQb0>cYf0030?ooo`3/jMP0k>WH00@0k>WH0P3oool20>cYf080oooo
0P3/jMP20?ooo`040>cYf000B?4003gL000MX04001><00001@006Ll0237I
01IZkP08EMd0[:RI0?l0k>WHLP3/jMP00`3oool0k>WH0>cYf0030>cYf00?
0;RdX`2h]J40oooo0>cYf02h]:<0^;FQ0?ooo`3/jMP0^;BS0;ReX@3oool0
k>WH0018l@00?M`001fP004001><00001@006Ll0237I01IZkP08EMd0[:RI
0?l0k>WHLP3/jMP00`3oool0k>WH0>cYf0030>cYf0060;RdX`2h]:40k>WH
0>cYf02h]:<0^;BQ0P3/jMP01`2h]:<0^;BQ0>cYf03/jMP004Sa000mg000
7J000@004h`00005000Ic`08<MT05V[^00QEg@2/Z9T0o`3/jMQb0>cYf003
0?ooo`3/jMP0k>WH00l0k>WH00<004Sa000mg0007J000@004h`00005000I
c`08<MT05V[^00QEg@2/Z9T0o`3/jMQb0>cYf0030?ooo`3/jMP0k>WH00P0
k>WH0P3oool20>cYf080oooo00@0k>WH0018l@00?M`001fP0@004h`00005
000Ic`08<MT05V[^00QEg@2/Z9T0o`3/jMQb0>cYf0030?ooo`3/jMP0k>WH
00L0k>WH00/0^;BS0;ReX@3oool0k>WH0;RdX`2h]J40oooo0>cYf000B?40
03gL000MX001000CS00000D001W?00Paf@0FJ^h025GM0:bXV@3o0>cYf780
k>WH00<0oooo0>cYf03/jMP01`3/jMP01P2h]:<0^;BQ0>cYf03/jMP0^;BS
0;RdX@80k>WH00<004Sa000mg0007J000@004h`00005000Ic`08<MT05V[^
00QEg@2/Z9T0o`3/jMQb0>cYf0030?ooo`3/jMP0k>WH00l0k>WH00<004Sa
000mg0007J000@004h`00005000Ic`08<MT05V[^00QEg@2/Z9T0o`3/jMQb
0>cYf0030?ooo`3/jMP0k>WH00`0k>WH0P3oool0103/jMP004Sa000mg000
7J01000CS00000D001W?00Paf@0FJ^h025GM0:bXV@3o0>cYf780k>WH00<0
oooo0>cYf03/jMP02`3/jMP01`2h]:<0^;FQ0?ooo`3/jMP004Sa000mg000
7J000@004h`00005000Ic`08<MT05V[^00QEg@2/Z9T0o`3/jMQb0>cYf003
0?ooo`3/jMP0k>WH00/0k>WH00L0^;BS0;RdX@3/jMP0k>WH0018l@00?M`0
01fP004001><00001@006Ll0237I01IZkP08EMd0[:RI0?l0k>WHLP3/jMP0
0`3oool0k>WH0>cYf00?0>cYf0030018l@00?M`001fP004001><00001@00
6Ll0237I01IZkP08EMd0[:RI0?l0k>WHLP3/jMP00`3oool0k>WH0>cYf00?
0>cYf0030018l@00?M`001jP004001><00001@006Ll0237I01IZkP08EMd0
[:RI0?l0k>WHLP3/jMP00`3oool0k>WH0>cYf00?0>cYf0030018l@00?M`0
01jP004001><00001@006Ll0237I01IZkP08EMd0[:RI0?l0k>WHLP3/jMP0
0`3oool0k>WH0>cYf00?0>cYf0030018l@00?M`001jP004001><00001000
6Ll0237I01IZkP08EMgo0:bXVG<0[:RI00<0oooo0>cYf03/jMP03`3/jMP0
0`00B?4003gL000NX001000CS00000@001W?00Paf@0FJ^h025GMo`3ooomd
0?ooo`060>k]i@3clnh0emO80<c<^P39bKH0aLFa1P34a:l02034a;00a/Jc
0=3@_`3emO40k>cU0018l@00?M`001jP0@004h`00004000Ic`08<MT05V[^
00QEgOl0ooooM03oool00`3^kND0h^;G0?ooo`0<0?ooo`050=[Jc@3/k>D0
04Sa000mg0007Z000@004h`00004000Ic`08<MT05V[^00QEgOl0ooooM03o
ool0103^kND0oooo0?;bk@3UiM/30>KVg0040>KVg@3Vi]`0i^KL0>KVg080
iNGK00L0hn?H0?7aj`3oool0d];10018l@00?M`001jP004001><00001000
6Ll0237I01IZkP08EMgo0?ooog@0oooo00D0k^gU0?ooo`3Rh]L0j^[R0>_[
h`020>c/i080jn_S00/0j^[R0>WYh03Xj=l0inON0>KVg@3ShmP0oooo0<c<
^P00B?4003gL000NX001000CS00000@001W?00Paf@0FJ^h025GMo`3ooomd
0?ooo`040>k]i@3oool0iNGK0>c/i0@0kNgV00`0k>cU0>_[h`3[jn<0j^[R
0>WYh03Wimh0i>CI0?ooo`3<c;T004Sa000mg0007Z01000CS00000@001W?
00Paf@0FJ^h025GMo`3ooomd0?ooo`040>k]i@3oool0iNGK0>g]iP@0k^kW
00`0bLW20>c/i03[jn<0j^[R0>WYh03Xj=l0iNGK0?ooo`3<c;T004Sa000m
g0007Z01000CS00000@001W?00Paf@0FJ^h025GMo`3ooomd0?ooo`040>k]
i@3oool0i^KL0>k^i`<0knoY0`39bL830>[ZhP070>WYh03Vi]`0oooo0<c<
^@00B?4003gL000NX001000CS00000@001W?00Paf@0FJ^h025GMo`3ooomd
0?ooo`030>k]i@3oool0i^KM00<0knoY1@39bL820>_[h`070>[ZhP3Vi]`0
oooo0<c<^@00B?4003gL000NX001000CS00000@001W?00Lbf@0FJ^h025GM
o`3ooomd0?ooo`030>k]i@3oool0inON0080l?3Z0`39bL80303]kNH0bLW2
0<W9`P39bL80jn_S0>[ZhP3Vi]d0oooo0<c<^P00B?4003kL000MX@4001><
000010006Ll01c;I01IZkP08EMdA0?ooo`062_ooobkooomRooooQooooiOo
oonLoooo;9goool/`_ooo`:Moooo00FPooooYoooojgooonQoooo:_ooo`1C
0?ooo`062_ooobkooomRooooQooooiOooonLoooo89gooolO`_ooo`:Moooo
00FPooooYoooojgooonQoooo:_ooo`0:0?ooo`062_ooobkooomRooooQooo
oiOooonLoooo89gooolO`_ooo`:Moooo00FPooooYoooojgooonQoooo:_oo
o`080?ooo`040>k]i@3oool0j>SO0?3`jP<0bLW20P3]kNH02`3[jn<0bLW2
0<W9`P39bL80jn_S0>OWgP3oool0c<bj0018l@00?]`001fQ004001><0000
10006Ll01c;I01IZkP08EMdA0?ooo`042?_knU3in??IP9b`nbEGQ5go03ad
00Cm5TenjVj>YkCjn_FBooooD`3oool010SknoY@nOScfH2L/?/UEhA4o`0l
M004oAI=O^Y^SZNdn_[eT_ooo`X0oooo00@8no_jD?WhlmV0W;3k9EN4A?l0
?7@01?dFCGkZKXjW]?[jmI;oool80?ooo`030>k]i@3oool0j^[R0080lO7[
00@0bLW20?3`jP3`l>X0k>cU0P3/k>@02@39bL80k>cT0>_[h`3Wimh0oooo
0<g=_000B?4003kL000MX@01000CS00000@001W?00Lbf@0FJ^h025GM4@3o
ool011CgmO?SJ8VTodYaTonS[[AKomK@a@06omG@a?oEcl?o/KNfodQ^T>Q/
SJImooooD`3oool011CgmO?SJ8VTodYaTonS[[A2omK@a@06omG@a?oEcl?o
/KNfodQ^T>Q/SJImoooo2P3oool011CgmO?SJ8VTodYaTonS[[A2omK@a@06
omG@a?oEcl?o/KNfodQ^T>Q/SJImoooo203oool00`3^kND0oooo0>[ZhP02
0?7ak0050?7aj`3`l>X0l?3Z0?3`jP3/k>D0103/k>@01P3Wimh0oooo0<o?
_P00B?4003kL000MX@4001><000010006Ll01c;I01IZkP08EMdA0?ooo`06
6oCbkodFCGko_lO:on;Oe_oPg]CohMkEFOoRgmH01_oQg]GogmcBom_GcOnf
_Kgm5TenFOoooe<0oooo00HKm?;_oAI=O_noal[oh]oFon3Ne?oQg]E0on;O
eP06on7NeOoOg=;ofmO=okJm_OdFCGiIoooo2P3oool01Q_dl^om5Tenoko7
b_oRgmKoh=kDon7NeD3oh]oF00KohMkEomoLd_oKelgo][fmoAI=OUWoool8
0?ooo`060>k]i@3oool0k>cU0??ckP3bl^d0lO7[0`3`l>X02`3]kNH0k>cU
0>c/i@3/k>D0k>cT0>OWgP3oool0dm?20018l@00?]`001fQ004001><0000
10006Ll01c;I01IZkP08EMdA0?ooo`037O?ak_l0?7Cok>_V00;ojn_U00?o
k>_Uonc[i_o/jnH0Eoo/jnH01_o[jnGojNSQonCRf_oPgMCo03ad?ooooe<0
oooo00<Mlo7^o`0lM?o/jnH00_o[jnD00oo/jnGok>_Vonc[iP0nonc[iP06
on_[iOoYj>7oi>;Jon3Me?l0?7@ooooo2P3oool00agclNko03adonc[iP02
on_[i@03onc[iOo/jnKok>_V03kok>_V00Kojn_UonWXhOoTh][oh=gDo`0l
M3ooool80?ooo`090>k]i@3oool0k^kW0?Gel@3dm?00l_;]0?7ak03alN/0
l?3Z0080knoY00T0k^kW0>g]iP3/k>@0i^KM0?ooo`3Hf<T004Sa000ng000
7J400@004h`00004000Ic`07<]T05V[^00QEgA40oooo00<Mlo7^o`0lM?o`
l>/0GOo`l>X01Oo_k^Soj^SQonCRfOl0?7@hoooo05<0oooo00<Mlo7^o`0l
M?o`l>/0A?o`l>X01Oo_k^Soj^SQonCRfOl0?7@hoooo00X0oooo00<Mlo7^
o`0lM?o`l>/0A?o`l>X01Oo_k^Soj^SQonCRfOl0?7@hoooo00P0oooo00L0
k^gU0?ooo`3alN/0moOc0?Gel@3clnh0l_;]0080lO7/00/0lO7[0?3`jP3_
knT0k^kW0>c/i03Vi]d0oooo0=oOdP00B?4003kL000MX@01000CS00000@0
01W?00Lbf@0FJ^h025GM4@3oool011gclNko03adoo7ak?oalNaLoo3`j`05
ono_jOo[j^?oiN;Ko`0lM3Ooool0D`3oool011gclNko03adoo7ak?oalNa3
oo3`j`05ono_jOo[j^?oiN;Ko`0lM3Ooool02P3oool011gclNko03adoo7a
k?oalNa3oo3`j`05ono_jOo[j^?oiN;Ko`0lM3Ooool0203oool0203^kND0
oooo0?Ogm03alN/0k^kW0>c/i@3[jn<0j^[R0P3Xj=l20>OWgP080>KVg@3T
i=T0lo?^0?ooo`3UiM/004Sa000ng0007J41000CS00000@001W?00Lbf@0F
J^h025GM4@3oool011gclNko03adoo;bkOobl^dBoo7ak00300000?oalNco
lO7/00;olO7/1@000003oo7ak0@000000ooalN`00`00003olO7/00000003
oo7ak0<000001OoalN`3000000?olO7/1@0000001OoalN`0000000000000
003olO7/00<000000ooalN`3000000oolO7/00Gol?3[onc[i?oVhmco03ad
=oooo`1C0?ooo`047O?ak_l0?7Col_;]oo;bkAgolO7/0`000002oo7ak080
000000ColO7/00000000000000006ooalN`01Oo`l>_ok>_TonKSg?l0?7@g
oooo00X0oooo00@Mlo7^o`0lM?obl^gol_;]3ooalN`3000000ColO7/2000
00001?oalN`00000000000000002oo7ak0<000001?oalN`4000000;olO7/
1@00000=oo7ak005oo3`joo/jnCoi^?Lo`0lM3Ooool0203oool00`3^kND0
o?cj0?ooo`0=0?ooo`040>c/i@00B?4003kL000MX@4001><000010006Ll0
1c;I01IZkP08EMdA0?ooo`047O?ak_l0?7Col_;^oo;bkQ;olO7]00<00000
oo7akOoalNd01?oalNd00`00003olO7]oo7ak@02oo7ak@0300000?oalNgo
lO7]00ColO7]00D00000oo7ak@00003olO7]00000003oo7ak@0300000?oa
lNgolO7]00?olO7]00D00000oo7akOoalNgolO7]00000004oo7ak@030000
0?oalNgolO7]00;olO7]00D00000oo7akOoalNgolO7]00000003oo7ak@05
00000?oalNgolO7]oo7ak@0000003_oalNd01Oo`l>cok>_UonKSgOl0?7@g
oooo05<0oooo00@Mlo7^o`0lM?obl^kol_;^7?oalNd01@00003olO7]oo7a
kOoalNd0000000;olO7]00@00000oo7akOoalNd000007?oalNd01Oo`l>co
k>_UonKSgOl0?7@goooo00X0oooo00@Mlo7^o`0lM?obl^kol_;^3_oalNd0
1@00003olO7]oo7akOoalNd0000000;olO7]00D00000oo7akOoalNgolO7]
00000002oo7ak@0500000?oalNgolO7]oo7ak@0000000_oalNd01@00003o
lO7]oo7akOoalNd0000000;olO7]00<00000oo7akOoalNd01_oalNd00`00
003olO7]oo7ak@0=oo7ak@05oo3`k?o/jnGoi^?Mo`0lM3Ooool0203oool0
0`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL000MX@4001><0000
10006Ll01c;I01IZkP08EMdA0?ooo`047O?ak_l0?7Com?C_ooCdka7olo?^
00<00000oo?ckP0000001Ooclnh00`00003olo?^oo?ckP02oo?ckP030000
0?oclnkolo?^00Colo?^00D00000oo?ckP00003olo?^00000003oo?ckP03
00000?oclnkolo?^00?olo?^00D00000oo?ck_oclnkolo?^00000004oo?c
kP0300000?oclnkolo?^00;olo?^00D00000oo?ck_oclnkolo?^00000003
oo?ckP0300000?oclnkolo?^013olo?^00Gol_;]onk]i_oXiMko03ad=ooo
o`1C0?ooo`047O?ak_l0?7Com?C_ooCdkacolo?^00D00000oo?ck_oclnko
lo?^00000002oo?ckP0300000?oclnh0000001golo?^00Gol_;]onk]i_oX
iMko03ad=oooo`0:0?ooo`047O?ak_l0?7Com?C_ooCdk`kolo?^00<00000
oo?ck_oclnh01?oclnh01@00003olo?^oo?ck_oclnh0000000;olo?^00D0
0000oo?ck_oclnkolo?^00000002oo?ckP0300000?oclnkolo?^00Colo?^
00<00000oo?ck_oclnh01_oclnh00`00003olo?^oo?ckP0=oo?ckP05oo;b
kOo^kNKoj>GNo`0lM3Ooool0203oool00`3_kn`0o_kk0?knn`0=0?knn`04
0>o_k000B?4003kL000MX@4001><000010006Ll01c;I01IZkP08EMdA0?oo
o`047O?ak_l0?7ComOGaooGelA7om?C`00<00000ooCdl00000001Oodm?00
0`00003om?C`ooCdl002ooCdl0D000000_odm?001@00003om?C`00000?od
m?00000000?om?C`0`000003ooCdl00500000?odm?3om?C`ooCdl0000000
1?odm?000`00003om?C`ooCdl002ooCdl00500000?odm?3om?C`ooCdl000
00000oodm?000`00003om?C`ooCdl00@ooCdl005oo?ckoo_k^SojNKPo`0l
M3Ooool0D`3oool011gclNko03adooGelOoemO4LooCdl00500000?odm?3o
m?C`ooCdl00000000_odm?03000001gom?C`00Golo?_ono^j?oYi^3o03ad
=oooo`0:0?ooo`047O?ak_l0?7ComOGaooGel@kom?C`00<00000ooCdl?od
m?001Oodm?04000000;om?C`00D00000ooCdl?odm?3om?C`00000002ooCd
l00300000?odm?3om?C`00Com?C`1@000004ooCdl00300000?odm?3om?C`
00gom?C`00Golo?_ono^j?oYi^3o03ad=oooo`080?ooo`030>o_k03no_/0
o_kk00d0o_kk00@0kno/0018l@00?]`001fQ0@004h`00004000Ic`07<]T0
5V[^00QEgA40oooo00@Mlo7^o`0lM?ofm_?om_Kc4Oofm_800`00003om_Kb
00000005ooKflP0300000?ofm_;om_Kb00;om_Kb00D00000ooKfl_ofm_;o
m_Kb00000002ooKflP0500000?ofm_;om_KbooKflP0000000oofm_801000
003om_KbooKflP000002ooKflP0500000?ofm_;om_KbooKflP0000001?of
m_800`00003om_KbooKflP02ooKflP8000000_ofm_801@00003om_KbooKf
l_ofm_80000001;om_Kb00GomOGaoo7`j_o[j>7o03ad=oooo`1C0?ooo`04
7O?ak_l0?7Com_KcooKflacom_Kb00D00000ooKfl_ofm_;om_Kb00000002
ooKflP0400000?ofm_;om_Kb000001com_Kb00GomOGaoo7`j_o[j>7o03ad
=oooo`0:0?ooo`047O?ak_l0?7Com_KcooKfl`kom_Kb00<00000ooKfl_of
m_801?ofm_801@00003om_KbooKfl_ofm_80000000;om_Kb0P000002ooKf
lP0400000?ofm_;om_Kb000000?om_Kb00@00000ooKfl_ofm_8000000oof
m_800`00003om_KbooKflP02ooKflP0300000?ofm_;om_Kb00gom_Kb00Go
mOGaoo7`j_o[j>7o03ad=oooo`080?ooo`030>o_k03no_/0o_kk00d0o_kk
00@0kno/0018l@00?]`001fQ0@004h`00004000Ic`08<MT05V[^00QEgA40
oooo00@Mlo7^o`0lM?ofm_Com_Kd4?ofm_<01@00003om_KcooKfloofm_<0
000000;om_Kc0`000005ooKfl`<000000_ofm_<300000004ooKfl`000000
0000000000;om_Kc00@00000ooKfloofm_<000000oofm_<3000000?om_Kc
0`000003ooKfl`80000000?om_Kc0000000000000oofm_<5000000oom_Kc
00GomOGboo7`joo[j>;o03ad=oooo`1C0?ooo`047O?ak_l0?7Com_KdooKf
m1com_Kc00D00000ooKfloofm_?om_Kc00000002ooKfl`0300000?ofm_<0
0000008000006oofm_<01OoemO;olO3[on_Xh_l0?7@goooo00X0oooo00@M
lo7^o`0lM?ofm_Com_Kd3_ofm_<00`00003om_KcooKfl`05ooKfl`<00000
0_ofm_<200000003ooKfl`000000000000Com_Kc10000003ooKfl`<00000
1Oofm_<00`00003om_KcooKfl`0=ooKfl`05ooGel_oal>_ojnSRo`0lM3Oo
ool0203oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000N
X04001><000010006Ll0237I01IZkP08EMdA0?ooo`037O?ak_l0?7Con?Sg
017on?Sf00D00000ooShm_ohn?Kon?Sf0000000HooShmP0400000?ohn?Ko
n?Sf000001Son?Sf00<00000ooShm_ohn?H04?ohn?H01OogmoGolo7^ongZ
i_l0?7@goooo05<0oooo00<Mlo7^o`0lM?ohn?L07Oohn?H01@00003on?Sf
ooShm_ohn?H0000000;on?Sf00<00000ooShm_ohn?H07Oohn?H01OogmoGo
lo7^ongZi_l0?7@goooo00X0oooo00<Mlo7^o`0lM?ohn?L03oohn?H01@00
003on?SfooShm_ohn?H00000023on?Sf00<00000ooShm_ohn?H03Oohn?H0
1OogmoGolo7^ongZi_l0?7@goooo00P0oooo00<0kno/0?knn`3no_/03@3n
o_/0103_kn`004Sa000mg0007Z01000CS00000@001W?00Paf@0FJ^h025GM
4@3oool00agclNko03adoo[jnP0@oo[jn@<0000000Con_[i000000000000
00000oojn_T00`00003on_[ioo[jn@0@oo[jn@@000003?ojn_T00`00003o
n_[ioo[jn@0Moo[jn@05oo[jn?oem?;ol>kZo`0lM3Goool0D`3oool00agc
lNko03adoo[jnP0Noo[jn@<000000_ojn_T2000001oon_[i00Gon_[hooGd
l_o`k^[o03ad=Oooo`0:0?ooo`037O?ak_l0?7Con_[j013on_[i1000000O
oo[jn@8000003oojn_T01Oojn_SomOCboo3^j_l0?7@eoooo00P0oooo00<0
kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z01000CS00000@0
01W?00Paf@0FJ^h025GM4@3oool01Aobl>co03adoogmo?omoOcoo?cl05co
o?ck00Cono_jooKdl_l0?7@/ooooD`3oool01Aobl>co03adoogmo?omoOco
o?cl04?oo?ck00Cono_jooKdl_l0?7@/oooo2P3oool01Aobl>co03adoogm
o?omoOcoo?cl04?oo?ck00Cono_jooKdl_l0?7@/oooo203oool00`3_kn`0
o_kk0?knn`0=0?knn`040>o_k000B?4003gL000NX04001><000010006Ll0
237I01IZkP08EMdA0?ooo`037O?ak_/UEhCo_lkL05koo_kn00Coo_kmoko>
fo/UEh@<ooooD`3oool00agclNkk9EN4oko>g015ooknoP04ooknoOnoc]_k
9EN43?ooo`X0oooo00<Mlo7^nbEGQ?noc]`0AOono_h01?ono_go_lkKnbEG
Q0coool80?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`0
01jP0@004h`00004000Ic`08<MT05V[^00QEgA40oooo00@Mlo7^eWfI[_mE
OJ;o`<oMGOooool01?oEgnSoEGfReGjI[`Klo?]C0?ooo`047O?ak]ImVJko
EGfRol3?gDCooooo00CoeMoXoeEmX]EnVJl6o?ck2P3oool011gclNkFOIV^
oeEmX_o0cme4ooooo`04omGOj?mEOJ;EOYV_1_cln`P0oooo00<0kno/0?kn
n`3no_/03@3no_/0103_kn`004Sa000mg0007Z01000CS00000@001W?00Pa
f@0FJ^h025GM4@3oool011Oelo5Ql^oXeWfI[_/UEhAMo`0lM004oAI=O^=Y
RZALm?;[3?[ime<0oooo00@GmO?aHO;_j=ImVJkk9EN4A?l0?7@01?dFCGkS
JHZTG?Cbj`cjnOL:0?ooo`045oGclF7bknSFOIV^nbEGQ4Co03ad00Cm5Ten
hfV:Y5cdl^/<n_Wg203oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000
B?4003gL000NX04001><000010006Ll0237I01IZkP08EMdA0?ooo`031_cl
naOelo4Ol_3/02lQlNo[;33[j>838O7_j`047o;`k1gclNhGmO?a1_clne<0
oooo00<6o?ck5oGclAobl>`08b7akn/O<>_XhP<QlNo[00@Ol_3/7O?akQOe
lo46o?ck2P3oool00`Klo?/GmO?a7o;`k00S8O7_jal`jnSR0b7akn/011ob
l>`Mlo7^5oGcl@Klo?/80?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/
0018l@00?M`001jP0@004h`00004000Ic`08<MT05V[^00QEgOl0ooooM03o
ool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000NX04001><
000010006Ll0237I01IZkP08EMgo0?ooog@0oooo00<0kno/0?knn`3no_/0
3@3no_/0103_kn`004Sa000mg0007Z01000CS00000@001W?00Paf@0FJ^h0
25GMo`3ooomd0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00
?M`001jP0@004h`00004000Ic`08<MT05V[^00QEgOl0ooooM03oool00`3_
kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000NX04001><00001000
6Ll01c7H01IZkP08EMgo0?ooog@0oooo00<0kno/0?knn`3no_/03@3no_/0
103_kn`004Sa000mg0007Z41000CS00000@001W?00Laf00FJ^h025GMo`3o
oomd0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001jQ
0@004h`00004000Ic`07<MP05V[^00QEgOl0ooooM03oool00`3_kn`0o_kk
0?knn`0=0?knn`040>o_k000B?4003gL000NX@4001><000010006Ll01c7H
01IZkP08EMgo0?ooog@0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`0
04Sa000mg0007Z41000CS00000@001W?00Laf00FJ^h025GMo`3ooomd0?oo
o`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001jQ0@004h`0
0004000Ic`07<MP05V[^00QEg@X0ooooo`00001P000000X0oooo00<0kno/
0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z41000CS00000@001W?
00Laf00FJ^h025GMo`3ooomd0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0
kno/0018l@00?M`001jQ0@004h`00004000Ic`07<MP05V[^00QEgOl0oooo
M03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000NX@40
01><000010006Ll01c7H01IZkP08EMgo0?ooog@0oooo00<0kno/0?knn`3n
o_/03@3no_/0103_kn`004Sa000mg0007Z41000CS00000@001W?00Laf00F
J^h025GMQ`3oool00`15CYT0oooo0?ooo`3Y0?ooo`030>o_k03no_/0o_kk
00d0o_kk00@0kno/0018l@00?M`001jQ0@004h`00004000Ic`07<MP05V[^
00QEgHL0oooo00<0ADjI0?ooo`3oool0j@3oool00`3_kn`0o_kk0?knn`0=
0?knn`040>o_k000B?4003gL000NX@4001><000010006Ll01c7H01IZkP08
EMd>0?ooo`<0ADjI0P3oool304E>V@<0oooo0`15CYT40?ooo`0404E>V@3o
ool0oooo04E>V@80oooo00@0ADjI0?ooo`15CYT0ADjI0`3oool304E>V@04
0?ooo`15CYT0ADjI04E>V@<0oooo0`15CYT40?ooo`80ADjI0P3oool204E>
V@H0oooo00D0ADjI0?ooo`3oool0oooo04E>V@020?ooo`80ADjI0P3oool2
04E>V@030?ooo`15CYT0ADjI0080ADjI00<0oooo04E>V@15CYT00P3oool3
04E>V@@0oooo0P15CYT01@3oool0ADjI0?ooo`3oool0ADjI0080oooo0`15
CYT60?ooo`<0ADjI0P3oool00`15CYT0oooo0?ooo`0404E>V@040?ooo`15
CYT0ADjI04E>V@80oooo00H0ADjI0?ooo`3oool0ADjI0?ooo`15CYT20?oo
o`80ADjI0P3oool304E>VMP0oooo00<0kno/0?knn`3no_/03@3no_/0103_
kn`004Sa000mg0007Z41000CS00000@001W?00Laf00FJ^h025GM3@3oool0
1@15CYT0oooo0?ooo`3oool0ADjI00@0oooo00<0ADjI0?ooo`15CYT01`3o
ool01P15CYT0oooo04E>V@3oool0ADjI0?ooo`80ADjI0P3oool00`15CYT0
oooo04E>V@020?ooo`0304E>V@3oool0oooo0080oooo00<0ADjI0?ooo`15
CYT01`3oool01015CYT0oooo0?ooo`15CYT20?ooo`0304E>V@3oool0oooo
00<0oooo00L0ADjI0?ooo`3oool0oooo04E>V@3oool0ADjI0080oooo00<0
ADjI0?ooo`15CYT00P3oool01P15CYT0oooo0?ooo`15CYT0oooo04E>V@80
oooo00<0ADjI0?ooo`3oool01@3oool01015CYT0oooo0?ooo`15CYT20?oo
o`0304E>V@3oool0ADjI00P0oooo00L0ADjI0?ooo`3oool0oooo04E>V@3o
ool0ADjI0080oooo00H0ADjI0?ooo`3oool0ADjI0?ooo`15CYT20?ooo`03
04E>V@3oool0ADjI0080oooo00D0ADjI0?ooo`15CYT0oooo04E>V@020?oo
o`0304E>V@3oool0oooo0080oooo00<0ADjI0?ooo`3oool0e@3oool00`3_
kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000NX@4001><00001000
6Ll0237I01IZkP08EMd=0?ooo`0504E>V@3oool0oooo0?ooo`15CYT00P3o
ool204E>V@80oooo1015CYT40?ooo`0604E>V@3oool0ADjI0?ooo`15CYT0
oooo0P15CYT20?ooo`0304E>V@3oool0ADjI0080oooo00<0ADjI0?ooo`3o
ool00P15CYT20?ooo`@0ADjI103oool01015CYT0oooo0?ooo`15CYT20?oo
o`0304E>V@3oool0oooo00<0oooo00@0ADjI0?ooo`3oool0ADjI0P3oool0
1P15CYT0oooo0?ooo`15CYT0oooo04E>V@<0oooo0`15CYT0103oool0ADjI
0?ooo`3oool404E>V@@0oooo00@0ADjI0?ooo`3oool0ADjI0P3oool00`15
CYT0oooo04E>V@0304E>V@D0oooo00L0ADjI0?ooo`3oool0oooo04E>V@3o
ool0ADjI00<0oooo0`15CYT01`3oool0ADjI0?ooo`3oool0ADjI0?ooo`15
CYT00P3oool01@15CYT0oooo04E>V@3oool0ADjI00D0oooo0P15CYWH0?oo
o`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]d001fP0@004h`0
0004000Ic`08<MT05V[^00QEg@d0oooo00L0ADjI0?ooo`3oool0oooo04E>
V@3oool0ADjI00@0oooo00@0ADjI0?ooo`3oool0ADjI103oool01P15CYT0
oooo04E>V@3oool0ADjI0?ooo`80ADjI0P3oool00`15CYT0oooo04E>V@02
0?ooo`0304E>V@3oool0ADjI00@0oooo00@0ADjI0?ooo`3oool0ADjI103o
ool01015CYT0oooo0?ooo`15CYT20?ooo`0304E>V@3oool0oooo00<0oooo
1015CYT20?ooo`0604E>V@3oool0oooo04E>V@3oool0ADjI1@3oool00`15
CYT0oooo04E>V@020?ooo`0404E>V@3oool0oooo04E>V@@0oooo00@0ADjI
0?ooo`3oool0ADjI0P3oool00`15CYT0oooo04E>V@020?ooo`0304E>V@3o
ool0oooo00<0oooo00<0ADjI0?ooo`3oool00P15CYT00`3oool0ADjI0?oo
o`040?ooo`0304E>V@3oool0ADjI0080oooo00<0ADjI0?ooo`15CYT00P3o
ool01@15CYT0oooo04E>V@3oool0ADjI0080oooo00<0ADjI0?ooo`15CYT0
fP3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kM000MX040
01><000010006Ll0237I01IZkP08EMd=0?ooo`0504E>V@3oool0oooo0?oo
o`15CYT00P3oool304E>V@80oooo0P15CYT50?ooo`80ADjI0`3oool204E>
V@030?ooo`15CYT0ADjI0080oooo00@0ADjI0?ooo`3oool0ADjI0P3oool3
04E>V@80oooo0P15CYT40?ooo`<0ADjI0P3oool204E>V@H0oooo00D0ADjI
0?ooo`3oool0oooo04E>V@020?ooo`80ADjI00D0oooo04E>V@15CYT0ADjI
0?ooo`0704E>V@80oooo0P15CYT40?ooo`<0ADjI00@0oooo04E>V@15CYT0
ADjI0`3oool204E>V@H0oooo00<0ADjI0?ooo`3oool00`3oool704E>V@04
0?ooo`15CYT0ADjI04E>V@80oooo0`15CYT20?ooo`0304E>V@3oool0oooo
0080ADjI0`3oool304E>VML0oooo00<0kno/0?knn`3no_/03@3no_/0103_
kn`004Sa000ng@007J01000CS00000@001W?00Paf@0FJ^h025GM3@3oool0
1@15CYT0oooo0?ooo`3oool0ADjI00h0oooo0P15CYT30?ooo`80ADjI5`3o
ool00`15CYT0oooo0?ooo`090?ooo`0504E>V@3oool0oooo0?ooo`15CYT0
1P3oool00`15CYT0oooo0?ooo`050?ooo`0304E>V@3oool0oooo00P0oooo
00@0ADjI0?ooo`3oool0ADjI3@3oool01@15CYT0oooo0?ooo`3oool0ADjI
00h0oooo00<0ADjI0?ooo`3oool0i03oool00`3_kn`0o_kk0?knn`0=0?kn
n`040>o_k000B?4003kM000MX04001><000010006Ll0237I01IZkP08EMd=
0?ooo`0504E>V@3oool0oooo0?ooo`15CYT03P3oool00`15CYT0oooo0?oo
o`030?ooo`0304E>V@3oool0oooo0240oooo1015CYTM0?ooo`0304E>V@3o
ool0oooo00`0oooo0`15CYT?0?ooo`0304E>V@3oool0oooo0080oooo00<0
ADjI0?ooo`3oool0g`3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000
B?4003kM000MX04001><000010006Ll0237I01IZkP08EMgo0?ooog@0oooo
00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng@007J01000CS000
00@001W?00Paf@0FJ^h025GMo`3ooomd0?ooo`030>o_k03no_/0o_kk00d0
o_kk00@0kno/0018l@00?]d001fP0@004h`00004000Ic`08<MT05V[^00QE
gOl0ooooM03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kM
000MX04001><000010006Ll0237I01IZkP08EMgo0?ooog@0oooo00<0kno/
0?knn`3no_/03@3no_/0103_kn`004Sa000ng@007J01000CS00000@001W?
00Paf@0FJ^h025GMo`3ooomd0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0
kno/0018l@00?]d001fP0@004h`00004000Ic`08<MT05V[^00QEgOl0oooo
M03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kM000MX040
01><000010006Ll0237I01IZkP08EMgo0?ooog@0oooo00<0kno/0?knn`3n
o_/03@3no_/0103_kn`004Sa000ng@007J01000CS00000@001W?00Laf@0F
J^h025GMo`3ooomd0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018
l@00?]d001jQ0@004h`00004000Ic`07<MT05V[^00QEgOl0ooooM03oool0
0`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kM000NX@4001><0000
10006Ll01c7I01IZkP08EMgo0?ooog@0oooo00<0kno/0?knn`3no_/03@3n
o_/0103_kn`004Sa000ng@007Z41000CS00000@001W?00Laf@0FJ^h025GM
o`3ooomd0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]d0
01jQ0@004h`00004000Ic`07<MT05V[^00QEgOl0ooooM03oool00`3_kn`0
o_kk0?knn`0=0?knn`040>o_k000B?4003kM000NX@4001><000010006Ll0
1c7I01IZkP08EMgo0?ooog@0oooo00<0kno/0?knn`3no_/03@3no_/0103_
kn`004Sa000ng@007Z41000CS00000@001W?00Laf@0FJ^h025GMo`3ooomd
0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]d001jQ0@00
4h`00004000Ic`07<MT05V[^00QEgOl0ooooM03oool00`3_kn`0o_kk0?kn
n`0=0?knn`040>o_k000B?4003kM000NX@4001><000010006Ll01c7I01IZ
kP08EMgo0?ooog@0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa
000ng@007Z41000CS00000@001W?00Laf@0FJ^h025GMo`3ooomd0?ooo`03
0>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]d001jQ0@004h`00004
000Ic`07<MT05V[^00QEgOl0ooooM03oool00`3_kn`0o_kk0?knn`0=0?kn
n`040>o_k000B?4003kM000NX@4001><000010006Ll01c7I01IZkP08EMgo
0?ooog@0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng@00
7Z41000CS00000@001W?00Laf@0FJ^h025GMo`3ooomd0?ooo`030>o_k03n
o_/0o_kk00d0o_kk00@0kno/0018l@00?]d001jQ0@004h`00004000Ic`07
<MT05V[^00QEgOl0ooooM03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_
k000B?4003kL000NX04001><000010006Ll01c7I01IZkP08EMgo0?ooog@0
oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng0007Z01000C
S00000@001W?00Laf@0FJ^h025GMo`3ooomd0?ooo`030>o_k03no_/0o_kk
00d0o_kk00@0kno/0018l@00?]`001jP0@004h`00004000Ic`07<MT05V[^
00QEgOl0ooooM03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?40
03kL000NX04001><000010006Ll01c7I01IZkP08EMgo0?ooog@0oooo00<0
kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng0007Z01000CS00000@0
01W?00Laf@0FJ^h025GMo`3ooomd0?ooo`030>o_k03no_/0o_kk00d0o_kk
00@0kno/0018l@00?]`001jP0@004h`00004000Ic`07<MT05V[^00QEgOl0
ooooM03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL000N
X04001><000010006Ll01c7I01IZkP08EMgo0?ooog@0oooo00<0kno/0?kn
n`3no_/03@3no_/0103_kn`004Sa000ng0007Z01000CS00000@001W?00La
f@0FJ^h025GMo`3ooomd0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/
0018l@00?]`001jP0@004h`00004000Ic`07<MT05V[^00QEgOl0ooooM03o
ool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL000NX04001><
000010006Ll01c7I01IZkP08EMgo0?ooog@0oooo00<0kno/0?knn`3no_/0
3@3no_/0103_kn`004Sa000ng0007Z01000CS00000@001W?00Laf@0FJ^h0
25GMo`3ooomd0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00
?]`001jP0@004h`00004000Ic`07<MT05V[^00QEgOl0ooooM03oool00`3_
kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gM000NX04001><00001000
6Ll01c7I01IZkP08EMgo0?ooog@0oooo00<0kno/0?knn`3no_/03@3no_/0
103_kn`004Sa000mg@007Z01000CS00000@001W?00Laf@0FJ^h025GMj@3o
ool00`000000oooo0?ooo`270?ooo`030>o_k03no_/0o_kk00d0o_kk00@0
kno/0018l@00?Md001jP0@004h`00004000Ic`07<MT05V[^00QEgNL0oooo
0P0000000`3oool000000?ooo`270?ooo`030>o_k03no_/0o_kk00d0o_kk
00@0kno/0018l@00?Md001jP0@004h`00004000Ic`07<MT05V[^00QEgN@0
oooo0`0000030?ooo`800000Q`3oool00`3_kn`0o_kk0?knn`0=0?knn`04
0>o_k000B?4003gM000NX04001><000010006Ll01c7I01IZkP08EMgQ0?oo
o`<000001P3oool2000008L0oooo00<0kno/0?knn`3no_/03@3no_/0103_
kn`004Sa000mg@007Z01000CS00000@001W?00Laf@0FJ^h025GMg`3oool2
000000T0oooo00<000000?ooo`000000QP3oool00`3_kn`0o_kk0?knn`0=
0?knn`040>o_k000B?4003gM000NX04001><000010006Ll01c7I01IZkP08
EMgL0?ooo`<000002`3oool010000000oooo0?ooo`0000250?ooo`030>o_
k03no_/0o_kk00d0o_kk00@0kno/0018l@00?Md001jP0@004h`00004000I
c`07<MT05V[^00QEgMT0oooo0`00000>0?ooo`040000003oool0oooo0000
08D0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg@007Z01
000CS00000@001W?00Laf@0FJ^h025GMe`3oool200000140oooo00D00000
0?ooo`3oool0oooo000000240?ooo`030>o_k03no_/0o_kk00d0o_kk00@0
kno/0018l@00?Md001jP0@004h`00004000Ic`07<MT05V[^00QEgM@0oooo
0`00000C0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
P@3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gM000NX040
01><000010006Ll01c7I01IZkP08EMgB0?ooo`8000005P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0840oooo00<0kno/0?knn`3n
o_/03@3no_/0103_kn`004Sa000mg@007Z01000CS00000@001W?00Laf@0F
J^h025GMc`3oool3000001P0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`200?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018
l@00?Md001jP0@004h`00004000Ic`07<MT05V[^00QEgL`0oooo0`00000K
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0O`3oool0
0`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gM000MX04001><0000
10006Ll01c7I01IZkP08EMg:0?ooo`8000006@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0O`3o
ool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gM000MX04001><
000010006Ll01c7I01IZkP08EMg70?ooo`<00000603oool4000000@0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1n0?ooo`030>o_
k03no_/0o_kk00d0o_kk00@0kno/0018l@00?Md001fP0@004h`00004000I
c`07<MT05V[^00QEgL@0oooo0`00000I0?ooo`800000102eKG`01@000000
oooo0?ooo`3oool0000000P0oooo00<000000?ooo`3oool0O@3oool00`3_
kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gM000MX04001><00001000
6Ll01c7I01IZkP08EMg20?ooo`8000006@3oool3000000H0]Fel00D00000
0?ooo`3oool0oooo000000080?ooo`030000003oool0oooo07d0oooo00<0
kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg@007J01000CS00000@0
01W?00Laf@0FJ^h025GM_`3oool3000001P0oooo0`0000000`2fL7l00000
0;E]O0070;E]O0050000003oool0oooo0?ooo`000000203oool00`000000
oooo0?ooo`1l0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00
?Md001fP0@004h`00004000Ic`07<MT05V[^00QEgKd0oooo0P00000I0?oo
o`8000001@2fL7l00`000000]Fel0;E]O0050;E]O0050000003oool0oooo
0?ooo`000000203oool00`000000oooo0?ooo`1l0?ooo`030>o_k03no_/0
o_kk00d0o_kk00@0kno/0018l@00?Md001fP0@004h`00004000Ic`07<MT0
5V[^00QEgKX0oooo0`00000H0?ooo`<000001`2fL7l00`000000]Fel0;E]
O0060;E]O0040000003oool0oooo000000T0oooo00<000000?ooo`3oool0
N`3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gM000MX040
01><000010006Ll01c7I01IZkP08EMfg0?ooo`<00000603oool300000080
]g:200<000000;I`O`2fL7l01P2fL7l00`000000]Fel0;E]O0050;E]O004
0000003oool0oooo000000X0oooo00<000000?ooo`3oool0NP3oool00`3_
kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gM000MX04001><00001000
6Ll01c7I01IZkP08EMfe0?ooo`8000006@3oool2000000H0]g:200<00000
0;I`O`2fL7l01@2fL7l00`000000]Fel0;E]O0050;E]O0040000003oool0
oooo000000X0oooo00<000000?ooo`3oool0NP3oool00`3_kn`0o_kk0?kn
n`0=0?knn`040>o_k000B?4003gM000MX04001><000010006Ll01c7I01IZ
kP08EMfb0?ooo`<00000603oool4000000L0]g:200<000000;I`O`2fL7l0
1P2fL7l010000000]Fel0;E]O02eKG`3000000040;9[O0000000oooo0000
00/0oooo00<000000?ooo`3oool0N@3oool00`3_kn`0o_kk0?knn`0=0?kn
n`040>o_k000B?4003gM000MX04001><000010006Ll01c7I01IZkP08EMf_
0?ooo`<00000603oool3000000@0^7F500<000000;MbPP2gLX801@2gLX80
0`000000]W1o0;I`O`050;I`O`@00000102bJg`00`000000oooo0000000<
0?ooo`030000003oool0oooo07P0oooo00<0kno/0?knn`3no_/03@3no_/0
103_kn`004Sa000mg@007J01000CS00000@001W?00Laf@0FJ^h025GM[@3o
ool2000001T0oooo0P0000070;QeQ@030000002gLX80]g:200D0]g:200<0
00000;I`O`2fL7l00`2fL7l4000000L0/V]l0P00000<0?ooo`030000003o
ool0oooo07P0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000m
g0007Z41000CS00000@001W?00Laf@0FJ^h025GMZP3oool3000001P0oooo
0`0000000`2iN8P000000;QeQ@070;QeQ@030000002gLX80]g:200D0]g:2
00<000000;I`O`0000000P0000030;=^O`030000002bJg`0/V]l00D0/V]l
0P00000=0?ooo`030000003oool0oooo07L0oooo00<0kno/0?knn`3no_/0
3@3no_/0103_kn`004Sa000mg0007Z41000CS00000@001W?00Laf@0FJ^h0
25GMZ03oool2000001P0oooo0`0000050;UhR0030000002hMHD0^7F500D0
^7F500<000000;MbPP2gLX80102gLX83000000H0/fio00<000000;9[O02b
Jg`01P2bJg`00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo07H0
oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z41000C
S00000@001W?00Laf@0FJ^h025GMY@3oool3000001P0oooo0`0000070;Uh
R0030000002hMHD0^7F500H0^7F500<000000;MbPP2gLX800`0000020;A`
PP030000002cKWl0/fio00D0/fio00<000000;9[O02bJg`01@2bJg`00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo07H0oooo00<0kno/0?kn
n`3no_/03@3no_/0103_kn`004Sa000mg0007Z41000CS00000@001W?00La
f@0FJ^h025GMXP3oool3000001P0oooo0`0000030;YjS0030000002iN8P0
^GR800D0^GR800<000000;QeQ@2hMHD01@2hMHD3000000D0]72200<00000
0;=^O`2cKWl01@2cKWl00`000000/V]l0;9[O0050;9[O08000003P3oool0
0`000000oooo0?ooo`1e0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/
0018l@00?M`001jQ0@004h`00004000Ic`07<MT05V[^00QEgJ00oooo0P00
000H0?ooo`<000001P2jNX`00`000000^GR80;UhR0050;UhR0030000002h
MHD0^7F500<0^7F5100000070;A`PP030000002cKWl0/fio00D0/fio00<0
00000;9[O02bJg`00`2bJg`3000000l0oooo00<000000?ooo`3oool0M03o
ool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000NX@4001><
000010006Ll01c7I01IZkP08EMfM0?ooo`<000005`3oool300000080^gf?
00<000000;YjS02jNX`01@2jNX`00`000000^GR80;UhR0050;UhR0030000
002hMHD00000008000000`2eLhD00`000000]7220;A`PP050;A`PP030000
002cKWl0/fio00D0/fio00<000000;9[O02bJg`00`000000102`JG`00000
0;1YO000000>0?ooo`030000003oool0oooo07@0oooo00<0kno/0?knn`3n
o_/03@3no_/0103_kn`004Sa000mg0007Z41000CS00000@001W?00Laf@0F
J^h025GMV`3oool2000001P0oooo0P0000050;]mS`030000002jNX`0^WZ<
00D0^WZ<00<000000;UhR02iN8P0102iN8P3000000L0]G>500<000000;A`
PP2dL8801@2dL8800`000000/fio0;=^O`030;=^O`@00000102`JG`00`00
0000/6Ul0000000?0?ooo`030000003oool0oooo07<0oooo00<0kno/0?kn
n`3no_/03@3no_/0103_kn`004Sa000mg0007Z41000CS00000@001W?00La
f@0FJ^h025GMV03oool3000001L0oooo100000070;]mS`030000002jNX`0
^WZ<00D0^WZ<00<000000;UhR02iN8P00`0000020;IeR0030000002eLhD0
]G>500D0]G>500<000000;A`PP2dL8801@2dL8800`000000/fio0;=^O`03
00000080/Fao00<000000;1YO02`JG`00`2`JG`00`000000/6Ul0000000@
0?ooo`030000003oool0oooo0780oooo00<0kno/0?knn`3no_/03@3no_/0
103_kn`004Sa000mg0007Z41000CS00000@001W?00Laf@0FJ^h025GMU@3o
ool3000001L0oooo0`0000030;]oTP030000002kOHl0^gf?00D0^gf?00<0
00000;YjS02jNX`01@2jNX`3000000D0]WF800<000000;EcQ@2eLhD01P2e
LhD00`000000]7220;A`PP040;A`PP<000001P2aK7l00`000000/6Ul0;1Y
O0020;1YO0040000002`JG`0/6Ul000000l0oooo00<000000?ooo`3oool0
LP3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000NX@40
01><000010006Ll01c7I01IZkP08EMfC0?ooo`800000603oool2000000L0
^gnB00<000000;]mS`2kOHl01@2kOHl010000000^WZ<0;YjS02jNX`30000
00030;MhS0000000]WF800H0]WF800<000000;EcQ@2eLhD01@2eLhD01000
0000]7220;A`PP2dL883000000030;9^PP000000/Fao00H0/Fao00<00000
0;1YO02`JG`00`2`JG`00`000000/6Ul0000000@0?ooo`030000003oool0
oooo0740oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg000
7Z41000CS00000@001W?00Laf@0FJ^h025GMT03oool3000001L0oooo0`00
00000`2lPYD000000;]oTP060;]oTP030000002kOHl0^gf?00D0^gf?00@0
00000;YjS00000000000102gN8`00`000000]WF80;IeR0050;IeR0030000
002eLhD0]G>500H0]G>50`0000050;9^PP030000002aK7l0/Fao00D0/Fao
00<000000;1YO02`JG`00P2`JG`010000000/6Ul0;1YO000000@0?ooo`03
0000003oool0oooo0700oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`0
04Sa000mg0007Z41000CS00000@001W?00Laf@0FJ^h025GMS@3oool30000
01L0oooo0`0000050;b2U@030000002kOi80^gnB00D0^gnB00<000000;]m
S`2kOHl00`2kOHl3000000L0]gR<00<000000;IeR02fMHP01@2fMHP00`00
0000]G>50;EcQ@020;EcQ@@000001`2bKX800`000000/Fao0;5/O`050;5/
O`030000002`JG`0/6Ul0080/6Ul00@000000;1YO00000000000403oool0
0`000000oooo0?ooo`1`0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/
0018l@00?M`001jQ0@004h`00004000Ic`08<MT05V[^00QEgH/0oooo0P00
000H0?ooo`80000000<0_HFI0000002lPYD01P2lPYD00`000000^gnB0;]o
TP050;]oTP030000002kOHl00000008000000`2hNhl00`000000]gR<0;Mh
S0050;MhS0030000002fMHP0]WF800D0]WF8100000040;9aQ@030000002b
KX80/Vj200D0/Vj200<000000;5/O`2aK7l01@2aK7l00`000000/6Ul0;1Y
O00300000080[FMl00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`1_0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001jQ
0@004h`00004000Ic`08<MT05V[^00QEgHP0oooo0`00000G0?ooo`<00000
0`2mQIT00`000000_8:E0;b2U@050;b2U@030000002kOi80^gnB00@0^gnB
0`0000060;QkS`030000002gN8`0]gR<00D0]gR<00<000000;IeR02fMHP0
0`2fMHP3000000L0/W6500<000000;9^PP2bKX801@2bKX800`000000/Fao
0;5/O`050;5/O`<0000000<0[FMl0000002]Ig`00P2]Ig`00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo06l0oooo00<0kno/0?knn`3no_/0
3@3no_/0103_kn`004Sa000mg0007Z41000CS00000@001W?00Paf@0FJ^h0
25GMQP3oool2000001L0oooo0`0000070;f5V@030000002lPYD0_8:E00D0
_8:E00<000000;]oTP2kOi800`0000020;UmTP030000002hNhl0^7^?00D0
^7^?00<000000;MhS02gN8`01@2gN8`00`000000]WF800000002000000<0
/g>900<000000;9aQ@2bLHD01@2bLHD00`000000/Vj20;9^PP050;9^PP03
0000002aK7l0/Fao00@0000000D0[VYo0000002]Ig`0[FMl000000040:eW
O0030000003oool0oooo00h0oooo00<000000?ooo`3oool0KP3oool00`3_
kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000NX@4001><00001000
6Ll0237I01IZkP08EMf30?ooo`<000005`3oool2000000<0_XNL00<00000
0;f5V@2mQIT0102mQIT00`000000_8:E0;b2U@050;b2U@<000001@2iOI80
0`000000^7^?0;QkS`050;QkS`030000002gN8`0]gR<00@0]gR<0`000006
0;=cR@030000002bLHD0/W6500D0/W6500<000000;9^PP2bKX801@2bKX83
000000D0[VYo00@000000:eWO02]Ig`00000102]Ig`00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo06d0oooo00<0kno/0?knn`3no_/03@3n
o_/0103_kn`004Sa000mg0007Z41000CS00000@001W?00Paf@0FJ^h025GM
P03oool3000001L0oooo0`0000050;j7W0030000002mQIT0_HFI00D0_HFI
00@000000;b2U@2lPYD0_8:E0`0000000`2iP9D000000;UmTP060;UmTP03
0000002hNhl0^7^?00D0^7^?00<000000;MhS02gN8`00`0000020;AfS003
0000002cLhT0/g>900D0/g>900<000000;9aQ@2bLHD01@2bLHD010000000
/Vj20;9^PP2bKX83000000030:m/PP000000[VYo00H0[VYo00<000000:eW
O00000001@2]Ig`00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
06d0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z41
000CS00000@001W?00Paf@0FJ^h025GMOP3oool2000001L0oooo0`000000
0`2oRYl000000;j7W0060;j7W0030000002mQIT0_HFI00D0_HFI0`000005
0;V0U@030000002iOI80^GfB00@0^GfB00<000000;QkS`2hNhl01@2hNhl3
000000D0]7J<00<000000;=cR@2cLhT01@2cLhT00`000000/W650;9aQ@05
0;9aQ@@00000102_K8800`000000[VYo0:iZO`050:iZO`030000002]Ig`0
000000D0[FMl00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`1/
0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001jQ0@00
4h`00004000Ic`08<MT05V[^00QEgG/0oooo0`00000G0?ooo`8000001@2o
RYl00`000000_XNL0;j7W0040;j7W0030000002mQIT0_HFI00<0_HFI0`00
00070;V0U@030000002iOI80^GfB00D0^GfB00@000000;QkS`2hNhl0^7^?
0`0000000`2eN8l000000;AfS0060;AfS0030000002cLhT0/g>900D0/g>9
00@000000;9aQ@2bLHD0/W650`0000000`2`KhH000000:m/PP050:m/PP03
0000002^JWl0[VYo00D0[VYo00<000000:eWO00000001P2]Ig`00`000000
oooo0?ooo`0?0?ooo`030000003oool0oooo06/0oooo00<0kno/0?knn`3n
o_/03@3no_/0103_kn`004Sa000mg0007Z41000CS00000@001W?00Paf@0F
J^h025GMN03oool3000001L0oooo0`0000070;n:W`030000002nQi`0_XNL
00D0_XNL00<000000;f5V@0000000P0000030;Z2V@030000002iP9D0^H2E
00D0^H2E00<000000;UmTP2iOI801@2iOI83000000@0]GR?00<000000;Af
S02dMX`01@2dMX`00`000000/g>90;=cR@050;=cR@@00000102`KhH00`00
0000[fb20:m/PP050:m/PP030000002^JWl0[VYo00D0[VYo0P0000020:eW
O0D000004@3oool00`000000oooo0?ooo`1[0?ooo`030>o_k03no_/0o_kk
00d0o_kk00@0kno/0018l@00?M`001jQ0@004h`00004000Ic`08<MT05V[^
00QEgGH0oooo0P00000G0?ooo`<000000`30SJ800`000000_hZO0;n:W`05
0;n:W`030000002nQi`0_XNL00<0_XNL0`0000070;Z2V@030000002iP9D0
^H2E00@0^H2E00@000000;UmTP2iOI80^GfB1@0000070;EhS`030000002d
MX`0]7J<00D0]7J<00<000000;=cR@2cLhT00P2cLhT4000000L0/6n600<0
00000:m/PP2_K880102_K8800`000000[VYo0:iZO`050:iZO`@00000102[
IWd00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo06X0oooo00<0
kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z41000CS00000@0
01W?00Paf@0FJ^h025GML`3oool3000001L0oooo0P0000070<2=XP030000
002oRYl0_hZO00D0_hZO00<000000;j7W00000000P0000020;^5W0030000
002jPYT0^X:I00D0^X:I00<000000;V0U@2iP9D01@2iP9D3000000D0]W^B
00<000000;EhS`2eN8l01@2eN8l00`000000]7J<0;AfS0040;AfS0D00000
0`2`LHT00`000000/6n60;1_QP050;1_QP030000002_K880[fb200D0[fb2
00@000000:iZO`2^JWl0[VYo1@0000070:]VO@030000003oool0oooo0100
oooo00<000000?ooo`3oool0J@3oool00`3_kn`0o_kk0?knn`0=0?knn`04
0>o_k000B?4003gL000NX@4001><000010006Ll0237I01IZkP08EMea0?oo
o`8000005`3oool300000080`HnV00<000000<2=XP30SJ801030SJ800`00
0000_hZO0;n:W`040;n:W`<000001P2kQI`00`000000^X:I0;Z2V@050;Z2
V@040000002iP9D0^H2E0;V0U@<0000000<0]WjE0000002fNi801@2fNi80
0`000000]GR?0;EhS`050;EhS`030000002dMX`0]7J<0080]7J<10000007
0;1aR@030000002`KhH0/6n600D0/6n600<000000:m/PP2_K880102_K884
000000@0ZfR000<000000:]VO@2[IWd01@2[IWd00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo06T0oooo00<0kno/0?knn`3no_/03@3no_/0
103_kn`004Sa000mg0007Z41000CS00000@001W?00Paf@0FJ^h025GMKP3o
ool3000001H0oooo0`0000050<6?YP0300000030SJ80`8fR00D0`8fR00<0
00000;n:W`2oRYl00`0000020;b8W`030000002kQI`0^hFL00D0^hFL00<0
00000;Z2V@2jPYT0102jPYT4000000@0]WjE00<000000;IkTP2fNi801@2f
Ni800`000000]GR?0;EhS`050;EhS`@000000`2aM8`00`000000/7690;1a
R@050;1aR@030000002`KhH0/6n600D0/6n600@000000:m/PP2_K880[fb2
0`0000000`2/JX<000000:]XP0050:]XP08000001`2[IWd00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo06P0oooo00<0kno/0?knn`3no_/0
3@3no_/0103_kn`004Sa000mg0007Z41000CS00000@001W?00Paf@0FJ^h0
25GMJ`3oool3000001L0oooo0P0000000`31TZT000000<6?YP060<6?YP03
00000030SJ80`8fR00@0`8fR0`0000060;b8W`030000002kQI`0^hFL00@0
^hFL00<000000;Z2V@2jPYT00P2jPYT4000000L0]WjE00<000000;IkTP2f
Ni80102fNi800`000000]GR?0;EhS`020;EhS`@000001`2aM8`00`000000
/7690;1aR@050;1aR@030000002`KhH0/6n600@0/6n6100000040:aZP`03
0000002[J800ZfR000@0ZfR00P0000070:]VO@030000003oool0oooo0140
oooo00<000000?ooo`3oool0I`3oool00`3_kn`0o_kk0?knn`0=0?knn`04
0>o_k000B?4003kM000MX@4001><000010006Ll0237I01IZkP08EMeY0?oo
o`8000005`3oool3000000@0`I:Y00<000000<6?YP31SjH01@31SjH01000
0000`8fR0<2=XP30SJ82000000030;b:XP000000_8RO00H0_8RO00<00000
0;^5W02kQI`01@2kQI`4000000@0]h2I00<000000;InU@2fOYD0102fOYD0
0`000000]W^B0;IkTP050;IkTP@00000102bMXl00`000000/GB<0;5dS004
0;5dS0030000002`LHT0/76900D0/76900@000000;1_QP2`KhH0/6n60`00
00000`2]KHH000000:aZP`060:aZP`030000002[J800ZfR000@0ZfR00P00
00070:]VO@030000003oool0oooo0100oooo00<000000?ooo`3oool0I`3o
ool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kM000MX@4001><
000010006Ll0237I01IZkP08EMeV0?ooo`<000005P3oool4000000L0`I:Y
00<000000<6?YP31SjH01031SjH4000000@0_8ZR00<000000;b8W`2lR9l0
1@2lR9l00`000000^hFL0;^5W0020;^5W0@000001P2gP9T00`000000]WjE
0;InU@050;InU@030000002fNi80]W^B0080]W^B100000060;9fS`030000
002aM8`0/GB<00D0/GB<00<000000;1aR@2`LHT0102`LHT4000000D0[Ff6
00<000000:aZP`2/JX<0102/JX<00`000000ZfR00:]XP0040:]XP0800000
102[IWd4000001<0oooo00<000000?ooo`3oool0IP3oool00`3_kn`0o_kk
0?knn`0=0?knn`040>o_k000B?4003kM000MX@4001><000010006Ll0237I
01IZkP08EMeS0?ooo`<000005P3oool3000000@0`YF/00<000000<6BZ@31
TZT01031TZT00`000000`HnV0<6?YP020<6?YP@000001`2lRZ800`000000
_8RO0;b8W`040;b8W`030000002kQI`00000008000000`2hPi`00`000000
]h2I0;N0V@050;N0V@030000002fOYD0]WjE00@0]WjE1@0000030;=iTP03
0000002bMXl0/WJ?00D0/WJ?00<000000;5dS02aM8`01@2aM8`00`000000
/76900000003000000030:i_R@000000[Ff600H0[Ff600<000000:aZP`2/
JX<01@2/JX<00`000000ZfR00:]XP0030:]XP0030000002[J800000000<0
0000102XI7d00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo06D0
oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng@007J41000C
S00000@001W?00Paf@0FJ^h025GMH@3oool2000001L0oooo0`0000060<:E
[00300000031TZT0`I:Y00D0`I:Y100000040;f=YP030000002lRZ80_8ZR
00D0_8ZR00<000000;b8W`2lR9l00P2lR9l3000000L0^8>L00<000000;N0
V@2gP9T0102gP9T00`000000]WjE0;InU@020;InU@@000001`2cNI800`00
0000/WJ?0;9fS`040;9fS`030000002aM8`0/GB<00@0/GB<0`0000060:i_
R@030000002]KHH0[Ff600D0[Ff600<000000:aZP`2/JX<0102/JX<01000
0000ZfR00:]XP02[J805000000L0Z6Am00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`1U0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/
0018l@00?]d001fQ0@004h`00004000Ic`08<MT05V[^00QEgEh0oooo0`00
000F0?ooo`<000000P33Ujl00`000000`YF/0<:E[0050<:E[00300000031
TZT0`I:Y0080`I:Y100000070;f=YP030000002lRZ80_8ZR00@0_8ZR00<0
00000;b8W`0000000P0000030;R5W`030000002hPi`0^8>L00@0^8>L00<0
00000;N0V@2gP9T01@2gP9T4000000@0/g^E00<000000;=iTP2cNI80102c
NI800`000000/WJ?0;9fS`050;9fS`030000002aM8`0000000<000000P2^
LX`00`000000[Vn90:i_R@040:i_R@030000002]KHH0[Ff600D0[Ff600<0
00000:aZP`2/JX<0102/JX<400000080ZFJ000@000000:UVP02YIX000000
1`2XI7d00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo06@0oooo
00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng@007J41000CS000
00@001W?00Paf@0FJ^h025GMG03oool2000001H0oooo0`0000060<>G[`03
00000032UJ`0`YF/00D0`YF/100000040;j@Z@030000002mSJH0_HfV00@0
_HfV00<000000;b:XP2lRZ800`2lRZ83000000H0^8FO00<000000;R3W02h
Pi`01@2hPi`010000000]h2I0;N0V@2gP9T5000000H0/g^E00<000000;=i
TP2cNI801@2cNI800`000000/WJ?0;9fS`030;9fS`<000001P2^LX`00`00
0000[Vn90:i_R@050:i_R@030000002]KHH0[Ff600D0[Ff600<000000:aZ
P`0000000`0000000`2ZJH<000000:UVP0030:UVP0040000002YIX00ZFJ0
000000L0Z6Am00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1S
0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]d001fQ0@00
4h`00004000Ic`08<MT05V[^00QEgET0oooo0`00000F0?ooo`8000000P33
V[<00`000000`iN_0<>G[`050<>G[`0300000032UJ`0`YF/0080`YF/1000
00060;j@Z@030000002mSJH0_HfV00D0_HfV00<000000;b:XP0000000P00
00030;V8XP030000002hQIl0^8FO00@0^8FO00<000000;R3W02hPi`01@2h
Pi`3000000@0]7jI00<000000;=kU@2cNiD01@2cNiD00`000000/gVB0;=i
TP040;=iTP030000002bMXl0000000<000000P2_M8l00`000000[W:<0:ib
S0050:ibS0030000002^KhT0[Vn900@0[Vn900<000000:e]QP2]KHH00`2]
KHH4000000H0ZVV300D000000:UVP02YIX00ZFJ0000000030:UVP0030000
002XI7d0Z6Am00@0Z6Am00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`1S0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]d0
01fQ0@004h`00004000Ic`08<MT05V[^00QEgEH0oooo0`00000F0?ooo`<0
00001@33V[<00`000000`iN_0<>G[`050<>G[`0400000032UJ`000000000
00<0_Y:/00<000000;j@Z@2nT:T01@2nT:T00`000000_HfV0;f=YP030;f=
YP<000001P2iR:800`000000^8FO0;R5W`050;R5W`040000002hPi`0^8>L
0;R3W0@000001`2dOYT00`000000/g^E0;=kU@040;=kU@030000002cNI80
/gVB0080/gVB100000070:mdS`030000002^LX`0[W:<00@0[W:<00<00000
0:i_R@2^KhT01@2^KhT5000000<0ZV^600<000000:YYP`2ZJH<0102ZJH<0
1@000000ZFJ00:UVP02YIX00000000<0ZFJ000<000000:QTO@2XI7d01@2X
I7d00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0680oooo00<0
kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng@007J41000CS00000@0
01W?00Paf@0FJ^h025GME03oool2000001H0oooo0`0000000`34W;H00000
0<>J/`060<>J/`0300000033Ujl0`iN_00<0`iN_0`0000060;jB[0030000
002nT:T0_Y2Y00D0_Y2Y00<000000;f=YP0000000P0000020;Z;Y@030000
002iR:80^HRR00D0^HRR00<000000;R5W`2hQIl0102hQIl4000000@0]H6L
00<000000;AnV@2dOYT01@2dOYT00`000000/g^E0;=kU@040;=kU@@00000
102`Mi800`000000[gB?0:mdS`040:mdS`030000002^LX`0[W:<00D0[W:<
00<000000:i_R@2^KhT00P2^KhT3000000L0ZV^600<000000:YYP`2ZJH<0
1@2ZJH<010000000ZFJ00:UVP00000040:UVP0040000002XI7d0Z6Am0:QT
O@@000005@3oool00`000000oooo0?ooo`1Q0?ooo`030>o_k03no_/0o_kk
00d0o_kk00@0kno/0018l@00?]d001fQ0@004h`00004000Ic`08<MT05V[^
00QEgE40oooo0`00000F0?ooo`8000001@34W;H00`000000`iZc0<>J/`05
0<>J/`0300000033Ujl00000008000000P2oUJl00`000000_Y:/0;jB[005
0;jB[0030000002nT:T0_Y2Y0080_Y2Y100000060;Z;Y@030000002iR:80
^HRR00D0^HRR00<000000;R5W`2hQIl00`0000000`2ePil000000;F1W006
0;F1W0030000002dOYT0]7jI00@0]7jI00@000000;=kU@2cNiD0/g^E1@00
00060;1gTP030000002_M8l0[gB?00D0[gB?00<000000:ibS02^LX`0102^
LX`5000000<0Zff900<000000:Y[QP2ZJhH01@2ZJhH00`000000ZVV30:YY
P`040:YYP`040000002YIX00ZFJ0000000@0ZFJ0100000040:ISOP030000
003oool0oooo0180oooo00<000000?ooo`3oool0H@3oool00`3_kn`0o_kk
0?knn`0=0?knn`040>o_k000B?4003kM000MX@4001><000010006Ll0237I
01IZkP08EMe>0?ooo`<000005P3oool4000000L0a9bf00<000000<>J/`33
V[<00`33V[<3000000H0_iF_00<000000;jB[02nTZ`01@2nTZ`4000000<0
^XfY00<000000;Z;Y@2jRjD01@2jRjD00`000000^HRR0;V8XP040;V8XP<0
00001@2ePil00`000000]H6L0;F1W0040;F1W0030000002dOYT0]7jI00D0
]7jI0`0000040;1iU@030000002`Mi80/7NB00D0/7NB00<000000:mdS`2_
M8l0102_M8l010000000[W:<0:ibS02^LX`5000000H0Zff900<000000:Y[
QP2ZJhH01@2ZJhH00`000000ZVV30:YYP`050:YYP`030000002YIX000000
00@0000000<0YVF10000002VHgh01@2VHgh00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo0600oooo00<0kno/0?knn`3no_/03@3no_/0103_
kn`004Sa000ng@007J41000CS00000@001W?00Paf@0FJ^h025GMC03oool2
000001H0oooo0`0000040<BO^@0300000034W;H0a9bf00D0a9bf00<00000
0<>J/`0000000P0000020;nG/`030000002oUJl0_iF_00D0_iF_00<00000
0;jB[02nTZ`00P2nTZ`4000000H0^XfY00<000000;Z;Y@2jRjD01@2jRjD0
0`000000^HRR0;V8XP03000000030;J6XP000000]H>O00D0]H>O00<00000
0;F1W02ePI`01@2ePI`00`000000]7jI0;AnV@05000000L0/7VE00<00000
0;1gTP2`Mi80102`Mi800`000000[gB?0:mdS`040:mdS`@00000102/L8`0
0`000000Zff90:]]R@050:]]R@030000002ZJhH0ZV^600D0ZV^600<00000
0:YYP`2ZJH<00P2ZJH<5000000D0YVF100<000000:ISOP2VHgh01@2VHgh0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0600oooo00<0kno/
0?knn`3no_/03@3no_/0103_kn`004Sa000ng@007J41000CS00000@001W?
00Paf@0FJ^h025GMB@3oool3000001H0oooo0`0000070<BO^@0300000034
W;H0a9bf00<0a9bf0`0000060;nG/`030000002oUJl0_iF_00D0_iF_1000
00030;^@[0030000002jSJT0^XfY00D0^XfY00<000000;Z;Y@2jRjD00`2j
RjD4000000D0]XJR00<000000;F3W`2ePil0102ePil00`000000]H6L0;F1
W0030;F1W0@000001@2aO9T00`000000/7VE0;1iU@040;1iU@030000002`
Mi80/7NB00D0/7NB00<000000:mdS`0000000`0000000`2/LXl000000:a`
S0060:a`S0030000002[KHT0Zff900@0Zff900<000000:Y[QP2ZJhH01@2Z
JhH5000000<0YfN30P0000050:IUP@030000002VHgh0YV=n00D0YV=n00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`1O0?ooo`030>o_k03n
o_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@004h`00004000Ic`08
<MT05V[^00QEgDL0oooo0P00000F0?ooo`<000000`35XKd00`000000a9ni
0<BO^@050<BO^@0300000034W;H00000008000000P30V[H00`000000_iNc
0;nG/`050;nG/`030000002oUJl0_iF_0080_iF_100000060;^@[0030000
002jSJT0^XfY00D0^XfY00<000000;Z;Y@0000000P0000020;N8Y@030000
002fQZ80]XJR00@0]XJR00<000000;F3W`2ePil01@2ePil00`000000]H6L
0000000200000080/WjL00<000000;5lV@2aO9T01@2aO9T00`000000/7VE
0;1iU@040;1iU@030000002`Mi80/7NB0080/7NB100000060:abS`030000
002/L8`0[72<00@0[72<00<000000:]]R@2[KHT01@2[KHT010000000ZV^6
0:Y[QP2ZJhH5000000H0YfN30P0000060:IUP@030000002VHgh0YV=n00D0
YV=n00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1N0?ooo`03
0>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@004h`00004
000Ic`08<MT05V[^00QEgD@0oooo0`00000E0?ooo`<000001`35XKd00`00
0000a9ni0<BO^@040<BO^@8000001P30V[H00`000000_iNc0;nG/`050;nG
/`@000000`2kTZl00`000000^i2/0;^@[0050;^@[0030000002jSJT0^XfY
00<0^XfY0`0000060;N8Y@030000002fQZ80]XJR00@0]XJR00<000000;F3
W`2ePil00P2ePil4000000H0/WjL00<000000;5lV@2aO9T0102aO9T00`00
0000/7VE0;1iU@050;1iU@@000000`2]MI800`000000[7:?0:abS`040:ab
S`030000002/L8`0[72<00D0[72<00<000000:]]R@2[KHT00`2[KHT50000
00@0Z6V600<000000:MWP`2WIh<01@2WIh<00`000000YVF10:IUP@040:IU
P@030000002VHgh0YV=n00D0YV=n00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`1N0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018
l@00?]`001jQ0@004h`00004000Ic`08<MT05V[^00QEgD80oooo0P00000F
0?ooo`8000000`35Y<400`000000aJ6m0<FQ_@050<FQ_@0300000034WkT0
a9ni00<000000P30W;T00`000000`9Zf0<2J]P040<2J]P030000002oUk<0
_iNc0080_iNc100000060;^B[`030000002kT:`0^i2/00D0^i2/1@000002
0;N;Z@030000002gR:D0]hRU00@0]hRU00<000000;J6XP2fQZ801@2fQZ84
000000<0/X6O00<000000;9nW02bOY`0102bOY`00`000000/GbI0;5lV@05
0;5lV@030000002`NID0/7VE00D000001`2]MI800`000000[7:?0:abS`04
0:abS`030000002/L8`0[72<00D0[72<1@0000020:Q[R@030000002XJHH0
Z6V600D0Z6V600<000000:MWP`2WIh<0102WIh<00`000000YVF10:IUP@05
0:IUP@040000002VHgh0YV=n0:ISOPD000005@3oool00`000000oooo0?oo
o`1M0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ
0@004h`00004000Ic`08<MT05V[^00QEgD40oooo0P00000D0?ooo`<00000
1P35Y<400`000000aJ6m0<FQ_@040<FQ_@<000001P30W;T00`000000`9Zf
0<2J]P040<2J]P@00000102lUK800`000000^i:_0;^B[`040;^B[`030000
002kT:`0^i2/0080^i2/0`0000070;N;Z@030000002gR:D0]hRU00@0]hRU
00@000000;J6XP2fQZ80]XJR100000070;:1W`030000002bOY`0/WjL00@0
/WjL00<000000;5lV@2aO9T00`2aO9T4000000D0[WNE00<000000:eeTP2]
MI80102]MI800`000000[7:?0:abS`050:abS`040000002/L8`0[72<0:a`
S0@000001`2XJhT00`000000Z6V60:QYQP040:QYQP030000002WIh<0YfN3
00D0YfN300<000000:IUP@2VIH400`2VIH45000000@0Y65n00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`1L0?ooo`030>o_k03no_/0o_kk
00d0o_kk00@0kno/0018l@00?]`001jQ0@004h`00004000Ic`08<MT05V[^
00QEgD40oooo00@000000?ooo`00000000003`3oool300000080aJK50P00
00060<FT`@0300000035XKd0aJ6m00<000000P31Wkd00`000000`9bi0<2L
^@050<2L^@0400000030V[H0`9Zf0<2J]P@000001P2lUK800`000000^i:_
0;^B[`050;^B[`@000000`2hSJ`00`000000]h^Y0;N;Z@040;N;Z@030000
002gR:D0]hRU00D0]hRU0`0000040;>3XP030000002bPIl0/X6O00@0/X6O
00<000000;9nW02bOY`01@2bOY`500000080[WZH00<000000:igU@2^MiD0
102^MiD00`000000[GFB0:eeTP050:eeTP030000002/LXl0[7:?00@0[7:?
100000040:U^S0030000002XJhT0Z6^900@0Z6^900<000000:QYQP2XJHH0
1@2XJHH00`000000YfN30:MWP`040:MWP`H000000P2THh400`000000Y65n
0:AQOP050:AQOP030000003oool0oooo01<0oooo00<000000?ooo`3oool0
G03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL000NX@40
01><000010006Ll0237I01IZkP08EMe10?ooo`050000003oool0oooo0?oo
o`000000303oool2000000L0aJK500<000000<FT`@35Y<400`35Y<430000
00H0`Inm00<000000<2L^@30W;T01030W;T4000000@0_9Nf00<000000;bE
/P2lUK80102lUK8010000000^i:_0;^B[`2kTZl5000000H0^8f/00<00000
0;N;Z@2gRjT0102gRjT00`000000]hRU0;N8Y@04000000030;>6Y@000000
/h>R00D0/h>R00<000000;:1W`2bPIl0102bPIl010000000/WjL0;9nW02b
OY`4000000L0[WZH00<000000:igU@2^MiD0102^MiD00`000000[GFB0:ee
TP040:eeTP030000002/LXl0000000@0000000<0ZW2?0000002YKX`01@2Y
KX`00`000000Z6^90:Q[R@050:Q[R@030000002XJHH0Z6V600@0Z6V600@0
00000:MWP`2WIh<0YfN31@0000060:ASP@030000002THGh0Y65n00D0Y65n
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1K0?ooo`030>o_
k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@004h`00004000I
c`08<MT05V[^00QEgD40oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`060?ooo`<000000P35Z<P00`000000aJK50<FVa@050<FVa@03
00000035Y<400000008000000P31XL400`000000`Inm0<6O_@050<6O_@04
00000030W;T0`9bi0<2L^@@000001`2lUkH00`000000_9Fb0;bE/P040;bE
/P<00000102hT:l00`000000^8f/0;R=[0050;R=[0030000002gRjT0]h^Y
0080]h^Y100000050;>6Y@030000002cPj80/h>R00@0/h>R00<000000;:1
W`2bPIl0102bPIl4000000@0[gbL00<000000:ijV02^NYP0102^NYP00`00
0000[WNE0:igU@050:igU@040000002]MI80[GFB0:eeTP@000001P2ZL8l0
0`000000ZFj<0:U^S0050:U^S0030000002XJhT0Z6^900@0Z6^900<00000
0:QYQP2XJHH00`2XJHH7000000030:EUQ0000000000000L0Y6>100<00000
0:AQOP2THGh0102THGh00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo05X0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng000
7Z41000CS00000@001W?00Paf@0FJ^h025GM@@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00<0oooo0P0000060<FXb00300000035
Y/D0aJK500<0aJK50`0000060<6Q`@0300000031Wkd0`Inm00D0`Inm0`00
00040;fJ^@030000002lUkH0_9Nf00D0_9Nf00<000000;bE/P2lUK800`00
00000`2hT[8000000;R@[`050;R@[`030000002hSJ`0^8f/00@0^8f/00<0
00000;N;Z@0000000P0000030;B8Z0030000002cQZD0/hJU00@0/hJU00<0
00000;>3XP2cPj80102cPj800`000000/X6O00000003000000030:moW`00
0000[gbL00H0[gbL00<000000:ijV02^NYP0102^NYP00`000000[WNE0:ig
U@040:igU@@000000`2ZLi800`000000ZW2?0:Y`S`050:Y`S`030000002Y
KX`0ZFj<00@0ZFj<00<000000:Q[R@2XJhT01@2XJhT5000000040:EXQ`00
00000000000000D0YFF40P0000060:ASP@030000002THGh0Y65n00D0Y65n
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1J0?ooo`030>o_
k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@004h`00004000I
c`08<MT05V[^00QEgD40oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`030?ooo`0300000035Z<P0aJS800D0aJS800<000000<FVa@00
00000P0000030<6Ta@0300000031XL40`J7100@0`J7100@000000<6O_@31
Wkd0`Inm0`0000000`2mW;d000000;fJ^@050;fJ^@030000002lUkH0_9Nf
00<0_9Nf100000050;RB/P030000002hT:l0^92_00@0^92_00@000000;R=
[02hSJ`0^8f/100000060;B8Z0030000002cQZD0/hJU00D0/hJU00@00000
0;>3XP2cPj80/h>R100000060:moW`030000002_O9`0[gbL00@0[gbL00<0
00000:ijV02^NYP0102^NYP00`000000[WNE00000004000000030:]eU@00
0000ZW>B00D0ZW>B00<000000:Y`S`2ZL8l0102ZL8l00`000000ZFj<0:U^
S0050:U^S0030000002XJhT0000000D000000P2UJ8L300000080YFR700<0
00000:EUQ02UIH@0102UIH@00`000000Y6>10:ASP@050:ASP@030000002T
HGh0Y65n00@0Y65n00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`1I0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ
0@004h`00004000Ic`08<MT05V[^00QEgD00oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`030?ooo`0300000035Z<P0aJS800@0aJS8
0P0000070<6Ta@0300000031XL40`J7100@0`J710`0000050;fL_@030000
002mV[T0_IZi00@0_IZi00<000000;bG]P0000000P0000020;VE]P030000
002hT[80^9:b00D0^9:b00<000000;R@[`2hT:l0102hT:l3000000@0]8^/
00<000000;B8Z02dR:P0102dR:P00`000000/hJU0;>6Y@040;>6Y@@00000
102`PJ800`000000[gnO0:moW`040:moW`030000002_O9`0[gbL00@0[gbL
00@000000:ijV02^NYP0[WZH100000060:]eU@030000002ZLi80ZW>B00D0
ZW>B00<000000:Y`S`2ZL8l0102ZL8l00`000000ZFj<0:U^S0020:U^S0@0
00001@2VJXT3000000D0YFR700<000000:EUQ02UIH@0102UIH@2000000H0
Y6>100<000000:AQOP2THGh01P00000G0?ooo`030000003oool0oooo05P0
oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng0007Z41000C
S00000@001W?00Paf@0FJ^h025GM@03oool00`000000oooo0?ooo`070?oo
o`800000103oool2000000040<FXb0000000000000000080`JG700<00000
0<6Ta@31Y<D01@31Y<D00`000000`J7100000003000000030;fO`@000000
_Ibm00H0_Ibm00<000000;fJ^@2mV[T00P2mV[T3000000H0^IFf00<00000
0;RB/P2hT[80102hT[800`000000^92_0;R@[`04000000030;F>[`000000
]8^/00D0]8^/00<000000;B8Z02dR:P0102dR:P00`000000/hJU0;>6Y@05
000000H0/86R00<000000:moW`2_Oil0102_Oil00`000000[gbL0:mlW004
0:mlW0@00000102[MiP00`000000ZgFE0:]eU@040:]eU@030000002ZLi80
ZW>B00@0ZW>B00<000000:Y`S`2ZL8l0102ZL8l5000000<0YVb<00<00000
0:IZR@2VJXT00`0000000`2VJXT000000:EXQ`060:EXQ`030000002UIH@0
YFF400@0YFF400<000000:ASP@2THh400P2THh45000000D0XF1o00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`1H0?ooo`030>o_k03no_/0
o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@004h`00004000Ic`08<MT0
5V[^00QEgD00oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`030?ooo`0300000031YLL0`JG700@0`JG700<000000<6Ta@31Y<D00`31
Y<D3000000H0_Io100<000000;fL_@2mW;d01@2mW;d4000000<0^INi00<0
00000;VE]P2iUKH0102iUKH00`000000^9:b0;RB/P020;RB/P@000001@2e
SZl00`000000]8^/0;B;[0050;B;[0030000002dR:P0]8RX0080]8RX1000
00050;24Y@030000002`PJ80/86R00@0/86R00<000000:moW`2_Oil0102_
Oil6000000030:ajW0000000ZgNH00D0ZgNH00<000000:]eU@2[MID01@2[
MID00`000000ZW>B0:YcTP040:YcTPH0000000<0Yfj?0000002VK8`01@2V
K8`3000000D0YVZ900<000000:EXQ`2UJ8L0102UJ8L00`000000YFF40:EU
Q0030:EUQ0H000000`2RHX800`000000XF1o0:5PO`050:5PO`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0E`3oool00`3_kn`0o_kk0?kn
n`0=0?knn`040>o_k000B?4003kL000NX@4001><000010006Ll0237I01IZ
kP08EMe00?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
0`3oool00`000000`JG70<6Ua`040<6Ua`0300000031Y<D0000000800000
0`2mXLD00`000000_Io10;fO`@040;fO`@040000002mW;d0_Ibm0;fL_@<0
000000<0^IZm0000002iUkT01@2iUkT00`000000^IFf0;VE]P040;VE]P@0
00000`2eT;800`000000]Hj_0;F>[`040;F>[`030000002dRj`0]8^/00@0
]8^/1@0000020;66Z0030000002`Q:D0/8BU00D0/8BU00<000000;21XP2`
PJ80102`PJ800`000000[gnO0:moW`05000000H0[7ZL00<000000:]gV02[
MiP0102[MiP00`000000ZgFE0:]eU@040:]eU@030000002ZLi80ZW>B00D0
00001`2WKXl00`000000YVb<0:I/S003000000030:I/S0000000YVZ900D0
YVZ900<000000:EXQ`2UJ8L01@2UJ8L500000080XVB40P0000060:9RPP03
0000002QH7l0XF1o00@0XF1o00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`1F0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00
?]`001jQ0@004h`00004000Ic`08<MT05V[^00QEgD00oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`030?ooo`0300000031YLL0`JG7
0080`JG7100000060;fQa@030000002mWl40_Io100@0_Io10`0000050;VJ
_@030000002iUkT0^INi00@0^INi00<000000;VE]P2iUKH01@0000060;F@
/P030000002eSZl0]Hj_00@0]Hj_00<000000;B;[02dRj`01@0000060;66
Z0030000002`Q:D0/8BU00@0/8BU00<000000;21XP2`PJ800`2`PJ840000
00@0[7bO00<000000:ajW02/NY`0102/NY`00`000000ZgNH0:]gV0050:]g
V0040000002[MID0ZgFE0:]eU@D000001@2WL9800`000000Yfj?0:M^S`04
0:M^S`<00000102VK8`00`000000YVZ90:IZR@050:IZR@030000002UJ8L0
000000D000001`2RI8@00`000000XV:20:9RPP040:9RPP030000002QH7l0
XF1o00D0XF1o00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`1F
0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@00
4h`00004000Ic`08<MT05V[^00QEgD00oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`030?ooo`@00000102mXlL00`000000_J750;fQ
a@040;fQa@030000002mWl40000000<0000000<0^Ic00000002iV[d01@2i
V[d00`000000^INi0;VG^@040;VG^@<000001@2eTkD00`000000]I2b0;F@
/P040;F@/P030000002eSZl0]Hj_0080]Hj_100000050;69Z`030000002a
QZP0/HJX00@0/HJX00<000000;24Y@2`Q:D0102`Q:D500000080[GnR00<0
00000:alW`2/O9l0102/O9l00`000000[7ZL0:ajW0040:ajW0030000002[
MiP0ZgNH00@0ZgNH100000030:QcU@030000002WL980Yg2B00@0Yg2B00@0
00000:M^S`2WKXl0Yfj?0`0000000`2WKXl000000:I/S0050:I/S0030000
002VJXT0YVZ900H000001P2SIXL00`000000XVB40:9TQ0040:9TQ0800000
1P2RHX800`000000XF1o0:5PO`040:5PO`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0E@3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_
k000B?4003kL000NX@4001><000010006Ll0237I01IZkP08EMdo0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool00`3oool00`000000
_J?70;fSa`050;fSa`030000002mXLD0_J750080_J750`0000060;VL`003
0000002iV[d0^IZm00@0^IZm00<000000;VG^@0000000`0000020;JE^@03
0000002eTkD0]I>e00@0]I>e00<000000;F@/P2eT;80102eT;84000000<0
/X^_00<000000;69Z`2aRJ/0102aRJ/00`000000/HJX0;66Z0040;66Z003
0000002`Q:D0000000<0000000<0[H6U0000002]Oj801@2]Oj800`000000
[7bO0:alW`040:alW`030000002/NY`0[7ZL00@0[7ZL1P0000000`2XMIP0
00000:QcU@050:QcU@030000002WL980Yg2B00@0Yg2B0`0000040:M^S`03
0000002VK8`0YVb<0080YVb<1@0000050:=XRP030000002SIXL0XfJ700@0
XfJ700<000000:9TQ02RI8@01@2RI8@2000000D0XV:200<000000:5PO`2Q
H7l0102QH7l2000001P0oooo00<000000?ooo`3oool0E03oool00`3_kn`0
o_kk0?knn`0=0?knn`040>o_k000B?4003kL000NX@4001><000010006Ll0
237I01IZkP08EMdo0?ooo`030000003oool0oooo00l0oooo0P0000040?oo
o`8000001P2mXlL4000000<0^Io400<000000;VL`02iW<00102iW<001000
0000^IZm0;VJ_@2iV[d4000000H0]YFi00<000000;FC]@2eTkD0102eTkD0
0`000000]I2b0;F@/P05000000H0/X^_00<000000;69Z`2aRJ/0102aRJ/0
0`000000/HJX0;66Z0020;66Z0@000001@2]PJD00`000000[GnR0:eoXP04
0:eoXP030000002/O9l0[7bO00@0[7bO00<000000:ajW02/NY`01@000006
0:QeV0030000002XLiD0Z7>E00D0Z7>E00<000000:M`TP2WL9800`000000
0`2WL98000000:M^S`040:M^S`D000000`2TJXd00`000000XfR:0:=XRP04
0:=XRP030000002SIXL0XfJ700D0XfJ700<000000:9TQ02RI8@0102RI8@0
0`000000XV:2000000050:9RPPH0000000<0Wen00000003oool05`3oool0
0`000000oooo0?ooo`1D0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/
0018l@00?]`001jQ0@004h`00004000Ic`08<MT05V[^00QEgCl0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`030?ooo`040000002m
XlL0_J?70;fSa`@000001P2iWl@00`000000^Ic00;VL`0040;VL`0<00000
102fUk`00`000000]YFi0;JE^@040;JE^@030000002eTkD0]I>e0080]I>e
100000050;:>/P030000002bRjl0/X^_00@0/X^_00<000000;69Z`2aRJ/0
0`2aRJ/5000000<0[XBX00<000000:f1Y@2]PJD0102]PJD00`000000[GnR
0:eoXP040:eoXP040000002/O9l0[7bO0:alW`D000001@2YN9/00`000000
Z7FH0:QeV0040:QeV0030000002XLiD0Z7>E00@0Z7>E0`0000040:M`TPH0
000000<0Y6b?0000002TJXd01P2TJXd00`000000XfR:0:=XRP040:=XRP03
0000002SIXL0XfJ700@0XfJ700<000000:9TQ02RI8@01@2RI8@8000000L0
Wen000<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1C0?ooo`03
0>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@004h`00004
000Ic`08<MT05V[^00QEgCl0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`030?ooo`<00000102iX<L00`000000^Io40;VOa0040;VO
a0030000002iW<00000000<0000000<0]Y[00000002fUk`01@2fUk`00`00
0000]YFi0;JE^@040;JE^@@000000`2bT;D00`000000/Xjb0;:>/P040;:>
/P030000002bRjl0/X^_00@0/X^_1@0000020:j6Z`030000002^Q:P0[XBX
00@0[XBX00<000000:f1Y@2]PJD0102]PJD00`000000[GnR0:eoXP020:eo
XPD00000102YNYh00`000000ZGRK0:UhV`040:UhV`030000002XMIP0Z7FH
00@0Z7FH00<000000:QcU@2XLiD00`0000000`2XLiD00000000000040000
00030:E_TP000000Y6b?00D0Y6b?00<000000:AZS@2TJXd0102TJXd00`00
0000XfR:0:=XRP040:=XRP030000002SIXL0XfJ700D0XfJ700<000000:9T
Q00000001@0000000`2PHH8000000:1QPP040:1QPP030000002OGh00Wen0
00@0Wen000<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1C0?oo
o`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@004h`0
0004000Ic`08<MT05V[^00QEgCl0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`030?ooo`030000002iX<L0^J3700@0^J3700@00000
0;VOa02iWl@0^Io4100000060;JJ`0030000002fUk`0]YNl00@0]YNl00<0
00000;JE^@0000000`0000000`2bT[P000000;:@]@050;:@]@030000002b
S[80/Xjb00@0/Xjb00<000000;:;[`0000001@0000060:j6Z`030000002^
Q:P0[XBX00@0[XBX00<000000:f1Y@2]PJD00`2]PJD500000080ZWbR00<0
00000:UjWP2YNYh0102YNYh00`000000ZGRK0:UhV`040:UhV`030000002X
MIP0Z7FH00<0Z7FH2@0000060:E_TP030000002TK8l0Y6b?00@0Y6b?00<0
00000:AZS@2TJXd01@2TJXd00`000000XfR:0:=XRP040:=XRP030000002S
IXL0XfJ700H000001P2PHhD00`000000X662000000040:1QPP030000002O
Gh00Wen000D0Wen000<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`1B0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ
0@004h`00004000Ic`08<MT05V[^00QEgCl0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`030?ooo`030000002iX<L0^J3700@0^J37
100000030;JLa0030000002fV/00]Y[000@0]Y[000@000000;JG_02fUk`0
]YNl100000060;:B^0030000002bT;D0/Y2e00@0/Y2e00@000000;:>/P2b
S[80/Xjb100000060:j9[P030000002^QZ/0[XJ[00@0[XJ[00<000000:j4
Z02^Q:P00`2^Q:P00`000000[H6U00000003000000030:YoY@000000ZWbR
00D0ZWbR00<000000:UjWP2YNYh0102YNYh00`000000ZGRK0:UhV`040:Uh
V`030000002XMIP0000000D000001P2ULID00`000000YFnB0:E_TP040:E_
TP030000002TK8l0Y6b?00@0Y6b?00<000000:AZS@2TJXd0102TJXd01000
0000XfR:0:=XRP2SJ8X6000000D0X6B700<000000:1SQ@2PHhD0102PHhD0
10000000X6620:1QPP0000030:1QPP030000002OGh00Wen000D0Wen000<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`1A0?ooo`030>o_k03n
o_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@004h`00004000Ic`08
<MT05V[^00QEgCh0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`030?ooo`030000002iX<L0000000<0000000<0]Yg60000002fW<@0
1@2fW<@00`000000]Y[00;JJ`0030;JJ`0@00000102bUK`00`000000/Y:h
0;:B^0040;:B^0030000002bT;D0/Y2e00<0/Y2e100000040:n;/P030000
002^RJh0[XV^00<0[XV^00<000000:j6Z`2^QZ/0102^QZ/00`000000[XBX
0:j4Z005000000H0ZWnU00<000000:YlXP2ZO:80102ZO:800`000000ZGZN
0:UjWP040:UjWP030000002YN9/0ZGRK00H000001@2VLiP00`000000YG6E
0:EaU@030:EaU@030000002UKi80YFnB00D0YFnB00<000000:A/S`2TK8l0
102TK8l00`000000Y6Z=0:AZS@07000000@0XFJ:00<000000:1TQ`2PI8L0
102PI8L00`000000X6>50:1SQ@050:1SQ@030000002PHH80000000@0X662
00<0000009mOP02OGh00102OGh000`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo0540oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa
000ng0007Z41000CS00000@001W?00Paf@0FJ^h025GM?P3oool00`000000
oooo0?ooo`0G0?ooo`800000103oool00`000000]Yg60;JMaP040;JMaP03
0000002fW<@0]Yc400@0]Yc41@0000020;>G_`030000002bUK`0/YFl00@0
/YFl00<000000;:B^02bT[P0102bT[P500000080[hje00<000000:n;/P2_
Rk80102_Rk800`000000[XV^0:j9[P030:j9[P040000002^QZ/0[XJ[0:j6
Z`D000001@2[PJP00`000000ZWnU0:YoY@040:YoY@030000002ZO:80ZWbR
00<0ZWbR00<000000:UjWP2YNYh00P2YNYh700000080YWFK00<000000:Ic
V02VLiP0102VLiP00`000000YG6E0:EaU@040:EaU@030000002UKi80YFnB
00@0YFnB00@000000:A/S`2TK8l0Y6b?1P0000040:5XS@030000002QIXX0
XFJ:00@0XFJ:00<000000:1TQ`2PI8L01@2PI8L00`000000X6>50:1SQ@04
0:1SQ@040000002PHH80X662000000<0X66200@0000009mOP02OGh00Wen0
1@00000I0?ooo`030000003oool0oooo0500oooo00<0kno/0?knn`3no_/0
3@3no_/0103_kn`004Sa000ng0007Z41000CS00000@001W?00Paf@0FJ^h0
25GM?P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0080
oooo0P0000050;JMaP80000000<0]Yc40000000000000`0000060;>G_`03
0000002bUK`0/YFl00@0/YFl00<000000;:B^00000000`0000000`2_T;P0
00000:n>]@050:n>]@030000002_Rk80[h^b00<0[h^b00<000000:j9[P2^
RJh00P2^RJh5000000@0ZhB[00<000000:^1Z02[PJP0102[PJP00`000000
ZWnU0:YoY@030:YoY@030000002ZO:80ZWbR00<0ZWbR1@000000102VN9h0
00000000000000060:IeV`030000002VLiP0YW>H00@0YW>H00<000000:Ea
U@2ULID0102ULID010000000YFnB0:E_TP2UKi86000000@0XV^@00<00000
0:5XS@2QJ8d0102QJ8d00`000000XFJ:0:5VRP040:5VRP030000002PI8L0
X6B700@0X6B700<000000:1SQ@2PHhD01@2PHhD00`000000X6620:1QPP07
000000@0WEj100<000000?ooo`3oool0603oool00`000000oooo0?ooo`1?
0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@00
4h`00004000Ic`08<MT05V[^00QEgCh0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`030?ooo`040000002fWLH0]Yg60;JMaP@00000
1@2cV/<00`000000/iNo0;>G_`040;>G_`040000002bUK`0/YFl0;:E_0@0
00001P2_T;P00`000000[hje0:n>]@030:n>]@030000002_Rk80[h^b00<0
[h^b1@0000030:^6[P030000002[Q:/0ZhB[00@0ZhB[00<000000:^1Z02[
PJP00`2[PJP00`000000ZWnU0:YoY@030:YoY@H000000P2WNZ44000000<0
YWRN00<000000:IeV`2VMI/00`2VMI/00`000000YW>H0:IcV0040:IcV003
0000002ULID0YG6E0080YG6E1P0000030:9]TP030000002RJi00XV^@00@0
XV^@00<000000:5XS@2QJ8d0102QJ8d00`000000XFJ:0:5VRP050:5VRP03
0000002PI8L0X6B700@0X6B700<000000:1SQ@2PHhD01`0000001@2MH8<0
000009ePP`2MH8<0000000L0WEj100<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`1?0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018
l@00?]`001jQ0@004h`00004000Ic`08<MT05V[^00QEgCh0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`030?ooo`<00000102cVlD0
0`000000/i[30;>J``030;>J``8000000`2cUkl5000000@0[i:k00<00000
0:n@^02_T;P0102_T;P00`000000[hje0:n>]@030:n>]@D000000P2[RK40
0`000000ZhJ^0:^6[P040:^6[P030000002[Q:/0ZhB[00<0ZhB[00<00000
0:^1Z02[PJP0102[PJP500000080YgbT00@000000:MjX@2WNZ40YgZQ1000
00050:IhWP030000002VMI/0YWFK00@0YWFK00<000000:IcV02VLiP00P2V
LiP6000000<0XVnE00<000000:9]TP2RKI80102RKI800`000000XV^@0:9[
T0040:9[T0030000002QJ8d0XFR=00@0XFR=00<000000:5VRP2QIXX0102Q
IXX00`000000X6B70:1TQ`07000000D0WV6600@0000009ePP`2MH8<00000
0`2MH8<00`000000WEj109eNP@0409eNP@030000003oool0oooo01P0oooo
00<000000?ooo`3oool0CP3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_
k000B?4003kL000NX@4001><000010006Ll0237I01IZkP08EMdn0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool00`3oool00`000000
/i_50;>Ka@040;>Ka@030000002cV/<0/i[300<0/i[3100000030:nE_`03
0000002_T[/0[i:k00@0[i:k00<000000:n@^02_T;P0102_T;P500000003
0:b;]0000000ZhVa00D0ZhVa00<000000:^6[P2[QZh0102[QZh00`000000
ZhB[0:^4Z`030:^4Z`H0000000<0YgnW0000002WO:@01@2WO:@3000000<0
YgZQ00<000000:IhWP2VN9h0102VN9h00`000000YWFK0:IeV`020:IeV`H0
00000`2SLIP00`000000XVnE0:9_U@030:9_U@030000002RKI80XVfB00@0
XVfB00<000000:9[T02RJi00102RJi000`000000XFR=0:5XS@040:5XS@03
0000002QIXX0XFJ:00L000001@2NHhP00`000000WV6609iQQP0409iQQP05
0000002MH8<0WF2309ePP`0000000P2MH8<00`000000WEj109eNP@0509eN
P@030000003oool0oooo01P0oooo00<000000?ooo`3oool0C@3oool00`3_
kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL000NX@4001><00001000
6Ll0237I01IZkP08EMdm0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool00`3oool00`000000/i_50;>Ka@040;>Ka@D000000P2_Ul<0
0`000000[iFo0:nE_`030:nE_`030000002_T[/0[i:k00@0[i:k00<00000
0:n@^00000000`0000000`2/SKP000000:b;]0040:b;]0030000002[RK40
ZhVa00@0ZhVa00<000000:^6[P2[QZh00`2[QZh6000000030:R1Z`000000
YgnW00D0YgnW00<000000:MlY02WO:@0100000060:MjX@040000002VN9h0
YWRN0:IhWPL000000P2SLi/00`000000Xg6H0:=aV0040:=aV0030000002R
KiD0XVnE00@0XVnE00<000000:9]TP2RKI80102RKI800`000000XV^@0:9[
T0040:9[T0030000002QJ8d0000000H000001@2NIH/00`000000WV>809iS
R00409iSR0030000002NHHH0WV6600D0WV6600D0000009ePP`2MH8<0WF23
0000000209ePP`030000002MGX40WEj100@0WEj100<000000?ooo`3oool0
603oool00`000000oooo0?ooo`1=0?ooo`030>o_k03no_/0o_kk00d0o_kk
00@0kno/0018l@00?]`001jQ0@004h`00004000Ic`08<MT05V[^00QEgCd0
oooo00<000000?ooo`3oool07`3oool2000000@0oooo00<000000;>Ka@00
00001@0000060:nG``030000002_UKl0[iFo00<0[iFo00<000000:nB^`2_
T[/01@0000050:b=^0030000002/Rk@0[8^d00@0[8^d00<000000:^9/@2[
RK40102[RK47000000H0Z86[00<000000:MoY`2WOjL00`2WOjL3000000@0
YgbT00@000000:MjX@2WNZ40YgZQ1P0000030:=fWP030000002SLi/0Xg>K
00@0Xg>K00<000000:=aV02SLIP0102SLIP00`000000XVnE0:9_U@040:9_
U@030000002RKI80XVfB00@0XVfB2000000609mWS@030000002NIH/0WVF;
00@0WVF;00<0000009iSR02NHhP0102NHhP00`000000WV6609iQQP0409iQ
QP030000002MH8<0WF230080WF2300<0000009ePP`0000001@2MGX430000
01X0oooo00<000000?ooo`3oool0C03oool00`3_kn`0o_kk0?knn`0=0?kn
n`040>o_k000B?4003kL000NX@4001><000010006Ll0237I01IZkP08EMdm
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool00P3oool2
000000D0[iS500<000000:nG``2_Ul<0102_Ul<00`000000[iFo0:nE_`05
000000D0[92k00<000000:b=^02/SKP00`2/SKP00`000000[8^d0:b;]004
0:b;]0L000001P2XQ:h00`000000Z86[0:R1Z`030:R1Z`030000002WOjL0
YgnW00<0000000<0YgnW0000002WO:@00P2WO:@6000000<0Y7RQ00<00000
0:=fWP2SMYh0102SMYh00`000000Xg>K0:=cV`040:=cV`030000002SLIP0
Xg6H00<0Xg6H00<000000:9_U@2RKiD0102RKiD8000000H0WfV@00<00000
09mWS@2OIhd0102OIhd00`000000WVF;09iUR`0409iUR`030000002NHhP0
WV>800@0WV>800<0000009iQQP2NHHH01@2NHHH010000000WF2309ePP`2M
H8<800000080Vef200<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`1;0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ
0@004h`00004000Ic`08<MT05V[^00QEgCd0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`030?ooo`030000002_V<D0[iS500<0[iS5
00@000000:nG``2_Ul<0[iO31@0000040:bB_P030000002/T;/0[92k00@0
[92k00<000000:b=^02/SKP00`2/SKP8000000D0Z8Ja00<000000:R4[P2X
Q:h0102XQ:h00`000000Z86[0:R1Z`020:R1Z`<000000P2WOjL6000000<0
Y7ZT00<000000:AhX@2TN:40102TN:400`000000XgJN0:=fWP040:=fWP03
0000002SLi/0Xg>K00<0Xg>K00<000000:=aV02SLIP0102SLIP8000000H0
Wf^C00<0000009mYT02OJI00102OJI000`000000WfN=09mWS@0409mWS@03
0000002NIH/0WVF;00@0WVF;00<0000009iSR02NHhP0102NHhP010000000
WV6609iQQP2NHHH70000000409aOQ0000000W5n4000000L0Vef200<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`1;0?ooo`030>o_k03no_/0
o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@004h`00004000Ic`08<MT0
5V[^00QEgCd0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?oo
o`030?ooo`040000002_V<D0[iS50:nHa@D00000102/UL800`000000[9:n
0:bB_P030:bB_P030000002/T;/0[92k00@0[92k1`0000060:R8]0030000
002XQ[40Z8Ja00<0Z8Ja00<000000:R4[P2XQ:h0102XQ:h9000000@0Y7bW
00<000000:AjY02TNZ@00`2TNZ@00`000000Y7RQ0:AhX@040:AhX@030000
002SMYh0XgJN00<0XgJN00<000000:=cV`2SLi/00`2SLi/7000000030:1_
V0000000X6fE00@0X6fE00<0000009m[T`2OJi<0102OJi<00`000000WfV@
09mYT00409mYT0030000002OIhd0WfN=00@0WfN=00<0000009iUR`2NIH/0
102NIH/00`000000WV>809iSR008000000@0W62600<0000009aOQ02LGh@0
0P2LGh@00`000000W5n40000000609]MPP030000003oool0oooo01T0oooo
00<000000?ooo`3oool0BP3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_
k000B?4003kL000NX@4001><000010006Ll0237I01IZkP08EMdm0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool00`3oool3000000<0
[9K400<000000:bE`P2/UL80102/UL800`000000[9:n0:bB_P030:bB_PP0
00001@2YRkL00`000000Z8Rd0:R8]0030:R8]0030000002XQ[40Z8Ja00@0
Z8Ja00<000000:R4[P0000001@0000050:EoZP030000002TO:L0Y7bW00<0
Y7bW00<000000:AjY02TNZ@0102TNZ@00`000000Y7RQ0:AhX@030:AhX@04
0000002SMYh0XgJN0:=fWPP000000P2PLI/00`000000X6nH0:1_V0030:1_
V0030000002PKID0X6fE00@0X6fE00<0000009m[T`2OJi<0102OJi<00`00
0000WfV@09mYT00409mYT0030000002OIhd0WfN=00@0WfN=2@00000509aR
R@030000002LH8H0W62600@0W62600<0000009aOQ02LGh@00`2LGh@20000
00L0Vef200<000000?ooo`3oool06@3oool00`000000oooo0?ooo`190?oo
o`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@004h`0
0004000Ic`08<MT05V[^00QEgC`0oooo00<000000?ooo`3oool09P3oool0
0`000000oooo0?ooo`030?ooo`030000002/U/@0[9K400<0[9K40P000005
0:bE`PL000001P2YSKX00`000000ZH^g0:V;]`030:V;]`030000002XR;@0
Z8Rd00<0Z8Rd00<000000:R6/@0000001`0000030:F1[@030000002UOjX0
YGnZ00@0YGnZ00<000000:AlY`2TO:L00`2TO:L00`000000Y7ZT0:AjY004
0:AjY0030000002TN:40000000H00000102QLih00`000000X76K0:1aV`03
0:1aV`030000002PKiP0X6nH00@0X6nH00<000000:1]U@2PKID0102PKID0
0`000000Wf^C09m[T`0309m[T`030000002OJI00WfV@00<0WfV@2@000006
09aTR`030000002LHXT0W6:900@0W6:900<0000009aPQP2LH8H01@2LH8H0
0`000000W5n409aOQ00209aOQ0030000002LGh@0000000H0Vef200<00000
0?ooo`3oool06@3oool00`000000oooo0?ooo`190?ooo`030>o_k03no_/0
o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@004h`00004000Ic`08<MT0
5V[^00QEgC`0oooo00<000000?ooo`3oool09`3oool2000000@0oooo00<0
00000:bFa02/U/@0102/U/@7000000D0ZI2n00<000000:V=^P2YSKX0102Y
SKX00`000000ZH^g0:V;]`030:V;]`L0000000@0YHB`0000000000000000
0P2UQ;000`000000YH6]0:F1[@030:F1[@030000002UOjX0YGnZ00<0YGnZ
00<000000:AlY`2TO:L0102TO:L8000000D0XGJQ00<000000:5cWP2QLih0
0`2QLih00`000000X76K0:1aV`040:1aV`030000002PKiP0X6nH00@0X6nH
00<000000:1]U@2PKID00`2PKID010000000Wf^C09m[T`2OJi<800000080
WFN@00<0000009aUS@2LIHd0102LIHd00`000000W6B;09aTR`0409aTR`03
0000002LHXT0W6:900@0W6:900<0000009aPQP2LH8H0102LH8H00`000000
W5n409aOQ00309aOQ08000001`2KGH800`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo04P0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`0
04Sa000ng0007Z41000CS00000@001W?00Paf@0FJ^h025GM?03oool00`00
0000oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo1P0000000`2Y
Tl<000000:VB`@040:VB`@030000002YT;h0ZI2n00<0ZI2n00<000000:V=
^P2YSKX00`2YSKX6000000030:F8]`000000YHJc0080YHJc0`0000050:F4
/0030000002UPJd0YH6]00@0YH6]00<000000:EoZP2UOjX00P2UOjX90000
00D0XGRT00<000000:5fX@2QMZ400`2QMZ400`000000XG>N0:5cWP040:5c
WP030000002PLI/0X76K00@0X76K00<000000:1_V02PKiP00`2PKiP:0000
00@0WFVC00<0000009eWT02MIi000`2MIi000`000000W6F=09aUS@0409aU
S@030000002LI8/0W6B;00@0W6B;00<0000009aRR@2LHXT0102LHXT00`00
0000W62609aPQP0509aPQP030000002LGh@0W5n400<0W5n42@00000L0?oo
o`030000003oool0oooo04L0oooo00<0kno/0?knn`3no_/03@3no_/0103_
kn`004Sa000ng0007Z41000CS00000@001W?00Paf@0FJ^h025GM?03oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0080oooo0P000005
0:VC``030000002YT/40ZI;100<0ZI;100<000000:V@_P2YT;h00P2YT;h6
000000030:F;^P000000YHRg00D0YHRg0`0000030:F6/`030000002UQ;00
YHB`00<0YHB`00@000000:F1[@2UPJd0YH6]1`0000020:9lZP030000002Q
NZL0XGZW00<0XGZW00<000000:5hY02QN:@0102QN:@00`000000XGJQ0:5f
X@030:5fX@030000002QLih0XG>N00@0XG>N00<000000:1aV`2PLI/00P2P
LI/9000000D0WF^E00<0000009eYT`2MJI<0102MJI<00`000000WFN@09eW
T00409eWT0030000002LIHd0W6F=00@0W6F=00<0000009aTR`2LI8/0102L
I8/00`000000W6:909aRR@0409aRR@030000002LH8H0W62600X0000000<0
VUj50000002JGH<01P2JGH<00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo04L0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000n
g0007Z41000CS00000@001W?00Paf@0FJ^h025GM?03oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo00<0oooo00<000000:VC``2YTl<0
0`2YTl<00`000000ZI;10:VB`@0700000080YXfm00<000000:F;^P2URkX0
0`2URkX00`000000YHRg0:F8]`03000000030:F8]`000000YHJc00@0YHJc
2@0000030:9o[@030000002RO:X0XWbZ00@0XWbZ00<000000:5jY`2QNZL0
0`2QNZL00`000000XGRT0:5hY0030:5hY0030000002QMZ40XGJQ00@0XGJQ
00<000000:5cWP0000002000000209e_V`030000002MKIP0WFfH00<0WFfH
00<0000009e[U@2MJiD0102MJiD00`000000WFVC09eYT`0409eYT`030000
002MIi00WFN@00@0WFN@00<0000009aUS@2LIHd00`2LIHd00`000000W6B;
09aTR`0409aTR`X000001@2JGhL00`000000VUj509YNQ@0309YNQ@800000
1P2JGH<00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04H0oooo
00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng0007Z41000CS000
00@001W?00Paf@0FJ^h025GM?03oool00`000000oooo0?ooo`0/0?ooo`03
0000003oool0oooo00<0oooo00<000000:VC``0000001@0000040:J?`@03
0000002VSKd0YXfm00<0YXfm00<000000:F;^P2URkX00P2URkX3000000@0
YHRg200000050::1/0030000002ROjd0XWn]00<0XWn]00<000000:9lZP2R
O:X00`2RO:X00`000000XGZW0:5jY`040:5jY`030000002QN:@0XGRT0080
XGRT2@00000509iaWP030000002MKi/0WFnK00<0WFnK00<0000009e]V02M
KIP0102MKIP00`000000WF^E09e[U@0409e[U@030000002MJI<0WFVC00<0
WFVC00<0000009eWT02MIi00102MIi0010000000W6F=09aUS@2LIHd;0000
00H0VV6900<0000009YOQ`2JGhL0102JGhL00`000000VUj509YNQ@0409YN
Q@030000002JGH<0VUf300@0VUf300<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`160?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018
l@00?]`001jQ0@004h`00004000Ic`08<MT05V[^00QEgC/0oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`030?ooo`030000002VT<80
YY3200<0YY3200<000000:J?`@2VSl400`2VSl400`000000YXfm0:J=_@03
0:J=_@/0000000<0XXJf0000002RPk<01@2RPk<00`000000XX6`0::1/003
0::1/0030000002ROjd0XWn]00<0XWn]00<000000:9lZP2RO:X00`2RO:X0
0`000000XGZW0:5jY`0800000080WWJS00<0000009icX@2NLj400`2NLj40
0`000000WW6N09iaWP0409iaWP030000002MKi/0WFnK00<0WFnK00<00000
09e]V02MKIP0102MKIP00`000000WF^E09e[U@0309e[U@030000002MJI<0
WFVC00@0WFVC2P00000409YTSP030000002JHX/0VV:;00<0VV:;00<00000
09YQR@2JHHT0102JHHT00`000000VUn709YOQ`0509YOQ`030000002JGXD0
VUj500@0VUj500<0000009YMP`2JGH<0102JGH<00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo04D0oooo00<0kno/0?knn`3no_/03@3no_/0
103_kn`004Sa000ng0007Z41000CS00000@001W?00Paf@0FJ^h025GM>`3o
ool00`000000oooo0?ooo`0_0?ooo`800000103oool00`000000YY320:J@
`P030:J@`P030000002VSl40YXo100<0YXo1200000040::8^@030000002R
Q[H0XXJf00<0XXJf00<000000::3/`2RPk<00`2RPk<00`000000XX6`0::1
/0040::1/0030000002ROjd0XWn]0080XWn]2@00000409ihYP030000002N
MZ<0WWJS00@0WWJS00<0000009icX@2NLj400`2NLj400`000000WW6N09ia
WP0309iaWP030000002MKi/0WFnK00@0WFnK00<0000009e]V02MKIP00`2M
KIP00`000000WF^E09e[U@0:0000000309YWT`000000VVJ@00@0VVJ@00<0
000009YTSP2JI8h0102JI8h00`000000VV:;09YRR`0409YRR`030000002J
HHT0VV6900@0VV6900<0000009YOQ`2JGhL0102JGhL00`000000VUj509YN
Q@0409YNQ@8000001@2JGH<00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo04@0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000n
g0007Z41000CS00000@001W?00Paf@0FJ^h025GM>`3oool00`000000oooo
0?ooo`0a0?ooo`030000003oool0oooo0080oooo00@000000:J@`P2VT<80
YY322P0000040:::_0030000002RR;T0XXRi00<0XXRi00<000000::6]P2R
Q[H00`2RQ[H00`000000XX>c0::3/`030::3/`030000002RPK00000000P0
00000P2OO:`00`000000WWZY09ijZ@0309ijZ@030000002NN:H0WWRV00<0
WWRV00<0000009ifX`2NMZ<00`2NMZ<00`000000WW>Q09icX@0409icX@03
0000002NLIh0WW6N00<0WW6N00@0000009e_V`2MKi/0WFnK2`00000409YY
U@030000002JIi<0VVNC00@0VVNC00<0000009YVT02JIY00102JIY000`00
0000VVB>09YTSP0409YTSP030000002JHX/0VV:;00@0VV:;00<0000009YQ
R@2JHHT00`2JHHT00`000000VUn709YOQ`0509YOQ`030000002JGXD0VUj5
00<0VUj52@00000L0?ooo`030000003oool0oooo04@0oooo00<0kno/0?kn
n`3no_/03@3no_/0103_kn`004Sa000ng0007Z41000CS00000@001W?00Pa
f@0FJ^h025GM>`3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0
oooo0080oooo0`0000030::>`@@000000P2RSL000`000000XXZl0:::_003
0:::_0030000002RR;T0XXRi00<0XXRi00<000000::6]P2RQ[H02P000005
09mo[`030000002OO:`0Wgb/00<0Wgb/00<0000009ijZ@2NNZT0102NNZT0
0`000000WWRV09ihYP0309ihYP030000002NMZ<0WWJS00<0WWJS00<00000
09icX@2NLj400P2NLj4;000000<0VffK00<0000009][V02KJiP0102KJiP0
0`000000VVVE09YYU@0309YYU@030000002JIi<0VVNC00@0VVNC00<00000
09YVT02JIY000`2JIY000`000000VVB>09YTSP0409YTSP030000002JHX/0
VV:;00@0VV:;00<0000009YQR@2JHHT0102JHHT=0000000309QNQP000000
000000D0V5f400<000000?ooo`3oool06`3oool00`000000oooo0?ooo`13
0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@00
4h`00004000Ic`08<MT05V[^00QEgC/0oooo00<000000?ooo`3oool0<`3o
ool00`000000oooo0?ooo`020?ooo`80000000<0XXk10000000000000`00
00040::=`0030000002RR[`0XXZl0080XXZl2@00000409n3]@030000002O
PK80Wh6b00<0Wh6b00<0000009mo[`2OOjl00`2OOjl00`000000Wgb/09ml
[00309ml[0030000002NNZT0WWZY00<0WWZY00<0000009ihYP2NN:H00`2N
N:H;00000080Vg6P00<0000009]_W@2KKid00`2KKid00`000000VffK09]]
V`0409]]V`030000002KJiP0Vf^H00<0Vf^H00<0000009YYU@2JJID0102J
JID00`000000VVNC09YWT`0309YWT`030000002JIY00VVJ@00@0VVJ@00<0
000009YTSP2JI8h0102JI8h00`000000VV:;09YRR`0<000000H0V5n800<0
000009QNQP2HGXH0102HGXH2000000D0V5f400<000000?ooo`3oool06`3o
ool00`000000oooo0?ooo`120?ooo`030>o_k03no_/0o_kk00d0o_kk00@0
kno/0018l@00?]`001jQ0@004h`00004000Ic`08<MT05V[^00QEgC/0oooo
00<000000?ooo`3oool0=03oool010000000oooo0?ooo`3oool3000000D0
XXk12@00000209n8_0030000002OQKP0WhFh00<0WhFh00<0000009n3]@2O
PkD00`2OPkD00`000000Wh6b09n1/P0309n1/P030000002OOjl0Wgn_00<0
Wgn_00<0000009ml[02OO:`00`2OO:`;0000000309]eYP000000Vg>S00@0
Vg>S00<0000009]aX02KLJ00102KLJ000`000000VfnM09]_W@0309]_W@03
0000002KKI/0VffK00<0VffK00<0000009][V02KJiP0102KJiP00`000000
VVVE09YYU@0309YYU@030000002JIi<0VVNC00@0VVNC00<0000009YVT02J
IY003@00000409QQS0030000002HH8X0V62:00@0V62:00<0000009QOR02H
GhP0102HGhP00`000000V5j609QNQP0409QNQP030000002HGH@0000000@0
V5f400<000000?ooo`3oool06`3oool00`000000oooo0?ooo`120?ooo`03
0>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@004h`00004
000Ic`08<MT05V[^00QEgC/0oooo00<000000?ooo`3oool0=@3oool30000
00<0oooo1@0000000`2ORl40000009n:_`0309n:_`030000002OR;`0WhRl
00<0WhRl00<0000009n5^02OQKP00`2OQKP00`000000Wh>e09n3]@0309n3
]@030000002OPK80Wh6b00<0Wh6b2`0000000`2LNZ`0000009]hZ@0409]h
Z@030000002KMJH0VgFV00<0VgFV00<0000009]cX`2KLj<00`2KLj<00`00
0000Vg6P09]aX00309]aX0030000002KKid0VfnM00@0VfnM00<0000009]]
V`2KKI/00`2KKI/00`000000Vf^H09][V00309][V0030000002JJID0VVVE
00d00000102HI9400`000000V6>>09QSSP0409QSSP030000002HHH`0V66<
00@0V66<00<0000009QPRP2HH8X0102HH8X00`000000V5n809QOR00409QO
R0030000002HGXH0V5j600@0V5j60P00000509QMQ0030000003oool0oooo
01L0oooo0`0000000`3oool000000?ooo`120?ooo`030>o_k03no_/0o_kk
00d0o_kk00@0kno/0018l@00?]`001jQ0@004h`00004000Ic`08<MT05V[^
00QEgCX0oooo00<000000?ooo`3oool0<`3oool300000080oooo00<00000
0?ooo`3oool00P3oool00`000000Wh_109n;`@0309n;`@030000002OR[l0
WhZo0080WhZo0P00000409n8_0030000002OQKP0WhFh0080WhFh30000000
0`2LO[80000009al[`0409al[`030000002LNZ`0W7Z/00<0W7Z/00<00000
09]hZ@2KN:T00`2KN:T00`000000VgFV09]eYP0309]eYP030000002KLj<0
Vg>S00<0Vg>S00<0000009]aX02KLJ000`2KLJ000`000000VfnM09]_W@03
09]_W@030000002KKI/0000000`00000102HJ9D00`000000V6JC09QVT`04
09QVT`030000002HI940V6BA00@0V6BA00<0000009QSSP2HHhh00`2HHhh0
0`000000V66<09QQS00409QQS0030000002HH8X0V62:00@0V62:00<00000
09QOR02HGhP0102HGhP00`000000V5j609QNQP0409QNQP030000002HGH@0
000000@0V5f400<000000?ooo`3oool04`3oool4000000@0oooo00<00000
0?ooo`3oool0@@3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?40
03kL000NX@4001><000010006Ll0237I01IZkP08EMdj0?ooo`030000003o
ool0oooo0300oooo0`0000060?ooo`030000003oool0oooo0080oooo00<0
000009n;`@2ORl400`2ORl400`000000WhZo09n:_`0<00000080W8>h00<0
000009b1]@2LPKD00`2LPKD00`000000W7jb09an/P0309an/P030000002L
O:l0W7b_0080W7b_00<0000009aj[02LNZ`00`2LNZ`00`000000VgRY09]h
Z@0309]hZ@030000002KMJH0VgFV00<0VgFV00<0000009]cX`2KLj<00P2K
Lj<?000000D0V6^K00<0000009QYV02HJIP0102HJIP00`000000V6RE09QX
U@0309QXU@030000002HIY<0V6JC00@0V6JC00<0000009QTT@2HI9400`2H
I9400`000000V6>>09QSSP0409QSSP030000002HHH`0V66<00@0V66<00<0
000009QPRP2HH8X0102HH8X00`000000V5n809QOR00409QOR0040000002H
GXH0V5j609QNQP/00000403oool4000000P0oooo00<000000?ooo`3oool0
@@3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL000NX@40
01><000010006Ll0237I01IZkP08EMdj0?ooo`030000003oool0oooo02`0
oooo1000000:0?ooo`030000003oool0oooo0080oooo2000000409b7_P03
0000002LQK/0W8Fk0080W8Fk00<0000009b3^02LPkP00`2LPkP00`000000
W86e09b1]@0309b1]@030000002LO[80W7jb0080W7jb00<0000009al[`2L
O:l00`2LO:l00`000000W7Z/09aj[00309aj[10000000P2HLJ<00`000000
V6nP09Q_X00309Q_X0030000002HKId0V6fM00@0V6fM00<0000009Q[V`2H
Ji/00`2HJi/00`000000V6VH09QYV00309QYV0030000002HJ9D0V6RE00@0
V6RE00<0000009QVT`2HIY<00`2HIY<00`000000V6BA09QTT@0409QTT@03
0000002HHhh0V6>>00<0V6>>00<0000009QQS02HHH`0102HHH`010000000
V62:09QPRP2HH8X>000000<0UUf700@0000009MLQ@2GG8D000000`2GG8D0
0`000000oooo0?ooo`0;0?ooo`<00000303oool00`000000oooo0?ooo`11
0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@00
4h`00004000Ic`08<MT05V[^00QEgCX0oooo00<000000?ooo`3oool0:@3o
ool3000000l0oooo00<000000?ooo`3oool00P3oool2000000@0W8W000<0
000009b7_P2LQkh00`2LQkh00`000000W8Fk09b5^`0209b5^`030000002L
PkP0W8>h00<0W8>h00<0000009b1]@2LPKD00`2LPKD00`000000W7jb0000
000?000000D0V7FX00<0000009QcYP2HLjH00`2HLjH00`000000V76S09Qa
X`0309QaX`030000002HKj00V6nP00<0V6nP00<0000009Q]W@2HKId00`2H
KId00`000000V6^K09Q[V`0409Q[V`030000002HJIP0V6VH00<0V6VH00<0
000009QXU@2HJ9D00`2HJ9D00`000000V6JC09QVT`0409QVT`030000002H
I940V6BA00<0V6BA4@00000409IOR`030000002FGXT0UUj900@0UUj900<0
000009IMQ`2FGHL0102FGHL00`000000Ueb50000000409MLQ@030000003o
ool0oooo00H0oooo1000000?0?ooo`030000003oool0oooo0440oooo00<0
kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng0007Z41000CS00000@0
01W?00Paf@0FJ^h025GM>P3oool00`000000oooo0?ooo`0V0?ooo`<00000
4`3oool00`000000oooo0?ooo`030?ooo`030000002LRL00W8W00080W8W0
00<0000009b7_P2LQkh00`2LQkhB000000@0VGba00<0000009Qj[P2HNZh0
0`2HNZh00`000000V7N[09QgZ`0309QgZ`030000002HMJP0V7FX00<0V7FX
00<0000009QcYP2HLjH00`2HLjH00`000000V76S09QaX`0309QaX`030000
002HKj00V6nP00<0V6nP00<0000009Q]W@2HKId00`2HKId00`000000V6^K
09Q[V`0309Q[V`030000002HJIP0V6VH00@0V6VH00<0000009QXU@000000
4@00000609IRS`030000002FH8d0UV2=00<0UV2=00<0000009IOR`2FGh/0
102FGh/00`000000UUj909INR@0409INR@030000002FGHL0UUf700@0UUf7
00@0000009MLQ@2GG8D000000`2GG8D00`000000oooo0?ooo`030?ooo`<0
00004`3oool00`000000oooo0?ooo`110?ooo`030>o_k03no_/0o_kk00d0
o_kk00@0kno/0018l@00?]`001jQ0@004h`00004000Ic`08<MT05V[^00QE
gCX0oooo00<000000?ooo`3oool08`3oool3000001L0oooo0P0000040?oo
o``00000102IP[X00`000000VH2g09V0]`0309V0]`030000002IO[@0VGjd
0080VGjd00<0000009Ul/@2IO;400`2IO;400`000000V7Z^09Qj[P0309Qj
[P030000002HMj/0V7N[00<0V7N[00<0000009QeZ02HMJP00`2HMJP00`00
0000V7>V09QcYP0209QcYP030000002HLJ<0V76S00<0V76S00<0000009Q_
X02HKj000`2HKj0E000000D0UFJE00<0000009ITT`2FI9<00`2FI9<00`00
0000UV>A09IST@0409IST@030000002FHXl0UV:?00<0UV:?00<0000009IP
S@2FH8d0102FH8d00`000000UUn;09IOR`0409IOR`030000002FGXT0UUj9
00@0UUj900<0000009IMQ`2FGHL0102FGHL010000000Ueb509MLQ@000003
09MLQ@D000005P3oool00`000000oooo0?ooo`110?ooo`030>o_k03no_/0
o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@004h`00004000Ic`08<MT0
5V[^00QEgCT0oooo00<000000?ooo`3oool08@3oool3000001`0oooo00<0
00000?ooo`3oool00P3oool00`000000VHJo09V6_`0209V6_`030000002I
QKd0VHFm00<0VHFm00<0000009V2^P2IP[X00P2IP[X00`000000VH2g09V0
]`0309V0]`030000002IO[@0VGjd0080VGjd00<0000009Ul/@2IO;400`2I
O;400`000000V7Z^09Qj[P0309Qj[P030000002HMj/0V7N[0080V7N[00<0
000009QeZ00000005P00000509E[W@030000002EJIX0UFVJ00<0UFVJ00<0
000009EXV02EJ9P0102EJ9P00`000000UFJE09EVU@0309EVU@030000002F
I9<0UVBC00@0UVBC00<0000009IST@2FHi400`2FHi400`000000UV:?09IR
S`0409IRS`030000002FH8d0UV2=00<0UV2=00<0000009IOR`2FGh/0102F
Gh/00`000000UUj909INR@0409INR@030000002FGHL0UUf700@0UUf700D0
000009MLQ@2GG8D0Ueb50000000209MLQ@030000003oool0oooo01T0oooo
00<000000?ooo`3oool0@03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_
k000B?4003kL000NX@4001><000010006Ll0237I01IZkP08EMdi0?ooo`03
0000003oool0oooo01h0oooo0`00000P0?ooo`030000003oool0oooo0080
oooo00<0000009V6_`2IQ[l00P2IQ[l00`000000VHFm09V5_@0309V5_@03
0000002IP[X0VH:j0080VH:j00@0000009V0]`2IP;L0VH2g6@00000509Ec
Z0030000002ELJD0UG6U00<0UG6U00<0000009E_XP2EKj800`2EKj800`00
0000UFfP09E]X00309E]X0030000002EJid0UF^M00<0UF^M00<0000009EY
VP2EJIX00`2EJIX00`000000UFRH09EXV00309EXV0030000002EIYD0UFJE
00@0UFJE00<0000009ITT`2FI9<00`2FI9<00`000000UV>A09IST@0409IS
T@030000002FHXl0UV:?00<0UV:?00<0000009IPS@2FH8d0102FH8d00`00
0000UUn;09IOR`0409IOR`030000002FGXT0UUj900<0UUj94000000J0?oo
o`030000003oool0oooo0400oooo00<0kno/0?knn`3no_/03@3no_/0103_
kn`004Sa000ng0007Z41000CS00000@001W?00Paf@0FJ^h025GM>@3oool0
0`000000oooo0?ooo`0K0?ooo`<00000903oool00`000000oooo0?ooo`02
0?oooa<000000`2EO[H00`000000UG^c09Ek/`0209Ek/`030000002ENK00
UGV`00<0UGV`00<0000009Eg[P2EMjh00P2EMjh00`000000UGF[09EeZ`03
09EeZ`030000002ELjP0UG>X00<0UG>X00<0000009EaY@2ELJD00`2ELJD0
0`000000UFnR09E_XP0309E_XP030000002EKJ00UFfP00<0UFfP00<00000
09E[W@2EJid00`2EJid00`000000UFVJ09EYVP0309EYVP030000002EJ9P0
UFRH00<0UFRH00<0000009EVU@2EIYD00`2EIYD00`000000UVBC09ITT`04
09ITT`030000002FHi40UV>A00<0UV>A00<0000009IRS`2FHXl00`2FHXlD
0000000309ENRP000000UEf800D0UEf800D0000009ILQ`2FG8L0UUb70000
000209ILQ`030000003oool0oooo01P0oooo00<000000?ooo`3oool0@03o
ool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL000NX@4001><
000010006Ll0237I01IZkP08EMdi0?ooo`030000003oool0oooo01P0oooo
0`00000X0?ooo`030000003oool0oooo0080oooo00<0000009F3_P2EPkh0
0`2EPkh00`000000UH:l09F2_00209F2_0030000002EP;T0UH2i0080UH2i
00<0000009En]P2EO[H00`2EO[H00`000000UG^c09Ek/`0209Ek/`030000
002ENK00UGV`00<0UGV`00<0000009Eg[P2EMjh00P2EMjh00`000000UGF[
09EeZ`0309EeZ`030000002ELjP0UG>X00<0UG>X00<0000009EaY@2ELJD0
0P2ELJD00`000000UFnR09E_XP0309E_XP030000002EKJ00UFfP00<0UFfP
00<0000009E[W@2EJid00`2EJid00`000000UFVJ09EYVP0309EYVP030000
002EJ9P0UFRH0080UFRH6P0000000`2DHHl0000009AOS@0509AOS@030000
002DGh/0U5n;00@0U5n;00<0000009ENRP2EGXX0102EGXX00`000000UEf8
09EMR00409EMR0050000002FG8L0UUb709ILQ`0000000P2FG8L00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo0400oooo00<0kno/0?knn`3n
o_/03@3no_/0103_kn`004Sa000ng0007Z41000CS00000@001W?00Paf@0F
J^h025GM>@3oool00`000000oooo0?ooo`0E0?ooo`<00000;03oool00`00
0000oooo0?ooo`020?ooo`800000102EPkh00`000000UH:l09F2_00209F2
_0030000002EP;T0UH2i0080UH2i00<0000009En]P2EO[H00`2EO[H00`00
0000UG^c09Ek/`0209Ek/`030000002ENK00UGV`00<0UGV`00<0000009Eg
[P2EMjh00P2EMjh00`000000UGF[09EeZ`0309EeZbL000000P2CIYP00`00
0000TfBF09=TUP0409=TUP030000002CHi<0Tf>C00<0Tf>C00<0000009=R
T@2CHY400`2CHY400`000000U66?09AQS`0409AQS`030000002DGhd0U5n=
00@0U5n=00<0000009AOR`2DGh/00`2DGh/00`000000UEj:09ENRP0409EN
RP030000002EGHP0UEf800@0UEf800<0000009ILQ`2FG8L00P2FG8L00`00
0000UUb70000000I0?ooo`030000003oool0oooo0400oooo00<0kno/0?kn
n`3no_/03@3no_/0103_kn`004Sa000ng0007Z41000CS00000@001W?00Pa
f@0FJ^h025GM>@3oool00`000000oooo0?ooo`0B0?ooo`<00000<03oool2
000000@0oooo:`000005099`Y`030000002BKjD0TVnU00<0TVnU00<00000
099]XP2BKJ800`2BKJ800`000000Tf^O09=[W`0309=[W`030000002CJId0
TfVM00<0TfVM00<0000009=WVP2CIiX00`2CIiX00`000000TfJH09=VV003
09=VV0030000002CI9H0TfBF00<0TfBF00<0000009=ST`2CHi<0102CHi<0
0`000000Tf:A09=RT@0309=RT@030000002DHHl0U66?00<0U66?00<00000
09AOS@2DGhd0102DGhd00`000000U5n;09AOR`0409AOR`030000002EGXX0
UEj:00@0UEj:00<0000009EMR02EGHP0102EGHP01@000000UUb709ILQ`2F
G8L000000080UUb700<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`100?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ
0@004h`00004000Ic`08<MT05V[^00QEgCP0oooo00<000000?ooo`3oool0
403oool3000003D0oooo00<000000?ooo`3oool00P3oool00`000000TX6m
09:1_@0209:1_@030000002BOk/0TWnk0080TWnk00<00000099m^@2BOKT0
0P2BOKT00`000000TW^f099k]P03099k]P030000002BNK<0TWVc0080TWVc
00<00000099g/02BMk000P2BMk000`000000TWF]099e[@03099e[@030000
002BLjX0TW>Z0080TW>Z00<00000099`Y`2BL:L00`2BL:L00`000000TVnU
099_Y@03099_Y@030000002BKJ80TVfR0080TVfR00<0000009=[W`2CJil0
0`2CJil00`000000TfVM09=YW@0309=YW@030000002CIiX0TfNJ00<0TfNJ
00<0000009=VV02CIYP0102CIYP00`000000TfBF09=TUP0309=TUP030000
002CHi<0Tf>C00<0Tf>C00<0000009=RT@2CHY40102CHY400`000000U66?
09AQS`0309AQS`030000002DGhd0U5n=00@0U5n=00<0000009AOR`2DGh/0
0`2DGh/00`000000UEj:09ENRP0409ENRP030000002EGHP0UEf800@0UEf8
00@0000009ILQ`2FG8L0UUb71000000H0?ooo`030000003oool0oooo0400
oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng0007Z41000C
S00000@001W?00Paf@0FJ^h025GM>03oool00`000000oooo0?ooo`0=0?oo
o`<00000>@3oool00`000000oooo0?ooo`020?ooo`030000002BPKd0TX6m
0080TX6m00<00000099o^`2BOk/00P2BOk/00`000000TWfi099m^@02099m
^@030000002BNkH0TW^f0080TW^f00<00000099i/`2BNK<00`2BNK<00`00
0000TWN`099g/002099g/0030000002BMJd0TWF]00<0TWF]00<00000099c
ZP2BLjX00P2BLjX00`000000TW2W099`Y`03099`Y`030000002BKjD0TVnU
0080TVnU00<00000099]XP2BKJ800`2BKJ800`000000Tf^O09=[W`0309=[
W`030000002CJId0TfVM00<0TfVM00<0000009=WVP2CIiX00`2CIiX00`00
0000TfJH09=VV00309=VV0030000002CI9H0TfBF00<0TfBF00<0000009=S
T`2CHi<0102CHi<00`000000Tf:A09=RT@0309=RT@030000002DHHl0U66?
00@0U66?00<0000009AOS@2DGhd00P2DGhdI00000080UEf800<0000009EM
R0000000603oool00`000000oooo0?ooo`0o0?ooo`030>o_k03no_/0o_kk
00d0o_kk00@0kno/0018l@00?]`001jQ0@004h`00004000Ic`08<MT05V[^
00QEgCP0oooo00<000000?ooo`3oool02P3oool3000003d0oooo00<00000
0?ooo`3oool00P3oooma00000080TUn>00<0000009=NS02CGX`00`2CGX`0
0`000000Tef;09=MR`0409=MR`030000002DGHX0U5f:00@0U5f:00<00000
09EMR02EGHP00`2EGHP2000001P0oooo00<000000?ooo`3oool0?`3oool0
0`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL000NX@4001><0000
10006Ll0237H01IZkP08EMdh0?ooo`030000003oool0oooo00L0oooo0`00
00110?ooo`030000003oool0oooo0080oooo00<0000008mn_02?O[`00P2?
O[`00`000000Sgfk08mm^`0208mm^`030000002?NkP0Sg^h0080Sg^h00<0
000008mh]@2?N;D00P2?N;D00`000000SgJb08mf/P0308mf/P030000002?
M:l0SgB_0080SgB_00<0000008mb[02?LZ`00P2?LZ`00`000000Sg2Z08m`
ZP0308m`ZP030000002?KZL0SfjW0080SfjW00<0000008m/Y02?K:@00`2?
K:@00`000000T6^R091[XP03091[XP030000002@JIl0T6VO0080T6VO00<0
0000091WW@2@Iid00`2@Iid00`000000T6JJ091VVP03091VVP030000002A
I9P0TFBH00<0TFBH00<00000095SUP2AHiH0102AHiH00`000000TF:C095R
T`03095RT`030000002AHI40TF6A00<0TF6A00<00000099PT02BH900102B
H9000`000000TUn>099OSP03099OSP030000002CGX`0Tej<00@0Tej<00<0
000009=MR`2CGH/0102CGH/00`000000U5f:09AMRP0409AMRP030000002E
GHP0UEf80080UEf800<0000009EMR00000005`3oool00`000000oooo0?oo
o`0o0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ
0@004h`00004000Ic`08<MP05V[^00QEgCP0oooo00<000000?ooo`3oool0
0`3oool4000004D0oooo00<000000?ooo`3oool00P3oool2000000<0Sgjl
00<0000008mm^`2?OK/00P2?OK/00`000000Sg^h08mk^00208mk^0030000
002?N;D0SgRe0080SgRe00<0000008mf/P2?M[800`2?M[800`000000SgB_
08md[`0208md[`030000002?LZ`0Sg:/0080Sg:/00<0000008m`ZP2?L:X0
0`2?L:X00`000000SfjW08m^Y`0208m^Y`030000002?K:@0SfbT00<0SfbT
00<00000091[XP2@Jj800P2@Jj800`000000T6VO091YW`03091YW`030000
002@Iid0T6NM00<0T6NM00<00000091VVP2@IYX00`2@IYX00`000000TFBH
095TV003095TV0030000002AHiH0TF>F00<0TF>F00<00000095RT`2AHY<0
0`2AHY<00`000000TF6A095QT@04095QT@030000002BH900TV2@00<0TV2@
00<00000099OSP2BGhh0102BGhh00`000000Tej<09=NS00409=NS0030000
002CGH/0Tef;00<0Tef;00<0000009AMRP2DGHX0102DGHX00`000000UEf8
09EMR00309EMR08000005`3oool00`000000oooo0?ooo`0o0?ooo`030>o_
k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@004h`00004000I
c`08<MP05V[^00QEgCP0oooo00<000000?ooo`3oool00`00001:0?ooo`80
0000103ooolD000000@0SgJb00<0000008md[`2?M:l00`2?M:l00`000000
Sg:/08mb[00208mb[0030000002?L:X0Sg2Z0080Sg2Z00<0000008m^Y`2?
KZL00`2?KZL00`000000SfbT08m/Y00208m/Y0030000002@Jj80T6^R00<0
T6^R00<00000091YW`2@JIl00`2@JIl00`000000T6NM091WW@03091WW@03
0000002@IYX0T6JJ00<0T6JJ00<00000095TV02AI9P00`2AI9P00`000000
TF>F095SUP03095SUP030000002AHY<0TF:C00<0TF:C00<00000095QT@2A
HI400`2AHI400`000000TV2@099PT004099PT0030000002BGhh0TUn>00<0
TUn>00<0000009=NS02CGX`0102CGX`00`000000Tef;09=MR`0409=MR`03
0000002DGHX0U5f:00@0U5f:00<0000009EMR02EGHP00`2EGHP2000001H0
oooo00<000000?ooo`3oool0?`3oool00`3_kn`0o_kk0?knn`0=0?knn`04
0>o_k000B?4003kL000NX@4001><000010006Ll0237H01IZkP08EMdg0?oo
o`@00000C`3oool00`000000oooo0?ooo`020?ooo`040000002<Nk/0S7^k
08ak^`8000000`2<N[X00`000000S7Rg08ah]`0208ah]`030000002<M[@0
S7Jd02D000000`2@Jj800`000000T6VO091YW`03091YW`030000002@Iid0
T6NM0080T6NM00<00000091VVP2@IYX00`2@IYX00`000000TFBH095TV003
095TV0030000002AHiH0TF>F00<0TF>F00<00000095RT`2AHY<0102AHY<0
0`000000TF6A095QT@03095QT@030000002BH900TV2@00<0TV2@00<00000
099OSP2BGhh0102BGhh00`000000Tej<09=NS00409=NS1D000005P3oool0
0`000000oooo0?ooo`0o0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/
0018l@00?]`001jQ0@004h`00004000Ic`08<MP05V[^00QEgCP0oooo00<0
00000?ooo`3oool0D03oool00`000000oooo0?ooo`020?ooo`030000002<
Nk/0S7^k0080S7^k00D0000008aj^P2<N[X0S7Zj0000000408ah]`030000
002<M[@0S7Jd0080S7Jd00<0000008ad/@2<M;400P2<M;400`000000S7:^
08ab[P0208ab[P030000002<L:`0S72/00<0S72/00<0000008a^Z@2<KZT0
0P2<KZT00`000000S6bV08a/YP0208a/YP030000002=JZ@0SFZT00<0SFZT
00<0000008eXX@000000@@000006099MS0030000002CGH/0Tef;00@0Tef;
00<0000009AMRP2DGHX00`2DGHX2000001D0oooo00<000000?ooo`3oool0
?`3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL000NX@40
01><000010006Ll0237H01IZkP08EMdi0?ooo`030000003oool0oooo0500
oooo00<000000?ooo`3oool00P3oool?000000@0S7Jd00<0000008ad/@2<
M;400P2<M;400`000000S7:^08ab[P0208ab[P030000002<L:`0S72/0080
S72/00<0000008a^Z@2<KZT00`2<KZT00`000000S6bV08a/YP0208a/YP03
0000002=JZ@0SFZT00<0SFZT00<0000008eXX@2=J:400P2=J:400`000000
SFNO08eWW`0308eWW`030000002=II`0SFFL00<0SFFL00<0000008iTVP2>
I9X00`2>I9X00`000000SV>H08iSV00308iSV0030000002?HYH0Sf:F00<0
Sf:F00<0000008mQU02?HI@00`2?HI@00`000000T62B091PTP03091PTP03
0000002@Gi00T5n@00@0T5n@00<00000095NS`2AGXl00`2AGXl00`000000
TEj=095NS@04095NS@030000002BGH`0TUf<00<0TUf<00<0000009=MR`2C
GH/0102CGH/00`000000U5f:09AMRP0409AMRP030000003oool0oooo01@0
oooo00<000000?ooo`3oool0?P3oool00`3_kn`0o_kk0?knn`0=0?knn`04
0>o_k000B?4003kL000NX@4001><000010006Ll0237H01IZkP08EMdj0?oo
o`800000D@3oool00`000000oooo0?ooo`020?ooo`0300000028NKX0R7Vj
0080R7Vj00@0000008Qh^@28N;T0R7Ri0P00000208Qe]Q<000000P2<L:`0
0`000000S6jY08a^Z@0308a^Z@030000002<K:H0S6bV0080S6bV00<00000
08eZY02=JZ@00P2=JZ@00`000000SFRQ08eXX@0308eXX@030000002=Iil0
SFNO00<0SFNO00<0000008eUW02=II`00P2=II`00`000000SVBJ08iTVP03
08iTVP030000002>HiP0SV>H00<0SV>H00<0000008mRUP2?HYH00`2?HYH0
0`000000Sf6D08mQU00308mQU0030000002@H980T62B00@0T62B00<00000
091OT02@Gi000`2@Gi000`000000TEj?095NS`04095NS`030000002AGXd0
TEj=00<0TEj=00<00000099MS02BGH`0102BGH`00`000000Tef;09=MR`04
09=MR`030000002DGHX0U5f:00@0U5f:00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0n0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/
0018l@00?]`001jQ0@004h`00004000Ic`08<MP05V[^00QEgC`0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`020?ooo`8000000`28
NKX00`000000R7Ri08Qh^@0208Qh^@0500000028MKH0R7Ff08Qe]P000000
1029Lk<00`000000RG6`08Ua/00208Ua/00300000029Kjh0RFn^0080RFn^
00<0000008U]Z`0000005000000408eXX@030000002=Iil0SFNO0080SFNO
00<0000008eUW02=II`00`2=II`00`000000SVBJ08iTVP0308iTVP030000
002>HiP0SV>H00<0SV>H00<0000008mRUP2?HYH00`2?HYH00`000000Sf6D
08mQU00308mQU0030000002@H980T62B00<0T62B00<00000091OT02@Gi00
102@Gi000`000000TEj?095NS`03095NS`030000002AGXd0TEj=00@0TEj=
00<00000099MS02BGH`00`2BGH`00`000000Tef;09=MR`0409=MR`030000
002DGHX0U5f:00@0U5f:0P00000D0?ooo`030000003oool0oooo03h0oooo
00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng0007Z41000CS000
00@001W?00Paf00FJ^h025GM?@3oool200000500oooo0P0000030?ooo`d0
000000<0R7Ff00000029Lk<00`29Lk<00`000000RG6`08Ua/00208Ua/003
00000029Kjh0RFn^0080RFn^00<0000008U]Z`29KJ/00P29KJ/00`000000
RF^X08U[Z00208U[Z00300000029JZH0RFZV0080RFZV00<0000008YXX`2:
J:<00`2:J:<Q00000080Sf:F00<0000008mQU02?HI@00`2?HI@00`000000
T62B091PTP03091PTP030000002@Gi00T5n@00<0T5n@00<00000095NS`2A
GXl0102AGXl00`000000TEj=095NS@03095NS@030000002BGH`0TUf<00@0
TUf<00@0000009=MR`2CGH/0Tef;2`00000D0?ooo`030000003oool0oooo
03h0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng0007Z41
000CS00000@001W?00Paf00FJ^h025GM?`3oool00`000000oooo0?ooo`1?
0?ooo`030000003oool0oooo0080oooo00D0000008Ef^@25M[T0QGJi0000
000408Ee^00300000025LkD0000000`000001029Kjh00`000000RFf[08U]
Z`0208U]Z`0300000029JjP0RF^X0080RF^X00<0000008UZYP29JZH00P29
JZH00`000000RVRS08YXX`0308YXX`030000002:IZ40RVJQ0080RVJQ00<0
000008]UWP2;IIh00`2;IIh00`000000RfBL08]TW00208]TW0030000002;
HYX0Rf:J00<0Rf:J00<0000008aQV02<HIP00`2<HIP010000000SF2F08eP
UP2=H9H]00000080TUj<00<0000009=NS02CGX`0102CGX`2000001<0oooo
00<000000?ooo`3oool0?P3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_
k000B?4003kL000NX@4001><000010006Ll0237H01IZkP08EMe00?ooo`03
0000003oool0oooo04l0oooo00<000000?ooo`3oool00P3oool5000000@0
QGFh00D0000008Ec]@25LkD0QG>e0000000408Ea/P0300000026Kk00QVn`
0080QVn`3@00000208U[Z00300000029JZH0RFZV0080RFZV00<0000008YX
X`2:J:<00P2:J:<00`000000RVJQ08YVX@0308YVX@030000002;IIh0RfFN
0080RfFN00<0000008]TW02;I9`00`2;I9`00`000000Rf:J08]RVP0308]R
VP030000002<HIP0S66H00<0S66H00<0000008ePUP2=H9H00`2=H9H00`00
0000SEnD08eOU00308eOU0030000002>Gi80SUnB00<0SUnB00<0000008mN
T@2?GY400`2?GY400`000000Sej?08mNS`0408mNS`030000002@GXh0T5j>
00<0T5j>00<00000095NS@2AGXd0102AGXd00`000000TUj<099NS004099N
S0030000002CGX`0Tej<00@0Tej<0P00000B0?ooo`030000003oool0oooo
03h0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng0007Z41
000CS00000@001W?00Paf00FJ^h025GM@@3oool200000500oooo00<00000
0?ooo`3oool00P3oool00`000000PW>h089c^0090000000308Ec]@000000
QG6b00<0QG6b00<0000008I_/026Kk000P26Kk000`000000QVf]08I][@02
08I][@0300000026JjX0QV^Z0080QV^Z00<0000008IYZ00000003P000004
08YVX@030000002;IIh0RfFN0080RfFN00<0000008]TW02;I9`00`2;I9`0
0`000000Rf:J08]RVP0308]RVP030000002<HIP0S66H0080S66H00<00000
08ePUP2=H9H00`2=H9H00`000000SEnD08eOU00308eOU0030000002>Gi80
SUnB00@0SUnB00<0000008mNT@2?GY400`2?GY400`000000Sej?08mNS`03
08mNS`030000002@GXh0T5j>00@0T5j>00<00000095NS@2AGXd0102AGXd0
0`000000TUj<099NS003099NS0030000002CGX`0Tej<00@0Tej<00<00000
0?ooo`0000004@3oool00`000000oooo0?ooo`0n0?ooo`030>o_k03no_/0
o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@004h`00004000Ic`08<MP0
5V[^00QEgD<0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`020?ooo`0500000022LkP0PW>h089c^00000001022L[L00`000000PW2d
0000000900000080QVn`00D0000008I][@26KJd0QVf]0000000408I[ZP03
00000026JJP0QVVX0080QVVX00<0000008MXY@27J:D00`27J:D00`000000
QfJS08MVX`0208MVXa@000000P2;HYX00`000000S66H08aQV00308aQV003
0000002=H9H0SF2F00<0SF2F00<0000008eOU02=Gi@00`2=Gi@00`000000
SUnB08iOTP0308iOTP030000002?GY40SejA00@0SejA00<0000008mNS`2?
GXl00`2?GXl00`000000T5j>091NSP03091NSP030000002AGXd0TEj=00@0
TEj=00<00000099NS02BGX`0102BGX`00`000000Tej<09=NS00409=NS080
00004P3oool00`000000oooo0?ooo`0m0?ooo`030>o_k03no_/0o_kk00d0
o_kk00@0kno/0018l@00?]`001jQ0@004h`00004000Ic`07<]T05V[^00QE
gD@0oooo0P00001?0?ooo`030000003oool0oooo0080oooo1P000003089b
]`0500000022L;@0PW2d089`]00000001022K[800`000000PVb_00000009
00000080QV^Z00<0000008IYZ026JJP00P26JJP00`000000QfRU08MXY@02
08MXY@0300000027IZ<0QfJS00<0QfJS00<0000008MTX027I:000P27I:00
0`000000R6>N08QSWP0308QSWP0300000029HY`0RF:L0080RF:L00<00000
08UQVP29HIX07@00000408mNT@030000002?GXl0Sej?00<0Sej?00<00000
091NSP2@GXh0102@GXh00`000000TEj=095NS@04095NS@030000002BGX`0
TUj<00<0TUj<00<0000009=NS02CGX`0102CGX`00`000000oooo0000000A
0?ooo`030000003oool0oooo03d0oooo00<0kno/0?knn`3no_/03@3no_/0
103_kn`004Sa000mg0007Z01000CS00000@001W?00Lbf@0FJ^h025GMAP3o
ool00`000000oooo0?ooo`1=0?ooo`8000000`3oool2000000<0Og6g2@00
0004089^/P0500000022K:l0PVb_089/[`0000001023JZ`00`000000PfVZ
0000000:00000080QfRU00<0000008MVX`27IZ<00P27IZ<00`000000QfBP
08MTX00308MTX00300000028Hih0R6>N0080R6>N00<0000008URW029HY`0
0`29HY`00`000000RF6J08UQVP0208UQVP030000002:H9P0RV2H00<0RV2H
00<0000008]OUP2;GiH00`2;GiH00`000000RenD08]OU00308]OU0030000
002<GY<0S5jC00<0S5jC00<0000008eNT@0000009P0000000`3oool00000
0?ooo`0?0?ooo`030000003oool0oooo03d0oooo00<0kno/0?knn`3no_/0
3@3no_/0103_kn`004Sa000mg0007Z01000CS00000@001W?00Lbf@0FJ^h0
25GMA`3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo0080
oooo00D0000007ma]`1oLKL0Og6g0000000307m`]P030000001oK[<0Ofjc
00P000000P22K:l00`000000PfZ/08=Z[00208=Z[00300000023JJX0PfVZ
0080PfVZ00<0000008=WY`23IjL00P23IjL00`000000Q6FU0000000;0000
000308MTX0000000R6>N00@0R6>N00<0000008URW029HY`00P29HY`00`00
0000RF6J08UQVP0308UQVP030000002:H9P0RV2H00<0RV2H00<0000008]O
UP2;GiH00`2;GiH00`000000RenD08]OU00308]OU0030000002<GY<0S5jC
00<0S5jC00<0000008eNT@2=GY400`2=GY400`000000SUj@08iNT00408iN
T0030000002?GXl0Sej?00<0Sej?00<00000091NSP2@GXh0102@GXh00`00
0000TUj>099NSP03099NSP030000002CGhd0Ten=00@0Ten=00@000000?oo
o`3oool000003`3oool00`000000oooo0?ooo`0m0?ooo`030>o_k03no_/0
o_kk00d0o_kk00@0kno/0018l@00?M`001jP0@004h`00004000Ic`07<]T0
5V[^00QEgDP0oooo0P00001?0?ooo`030000003oool0oooo0080oooo1`00
00000`1oL;H0000007m^/`0207m^/`030000001oK;40Ofba0080Ofba2P00
000408=YZP0300000023IjL0PfNW0080PfNW00<0000008AUY@24IJD00P24
IJD00`000000Q6BR08ATXP0208ATXP0300000025Hj00QF>P00h000001@29
HIX00`000000RV2H08YPV00308YPV0030000002;GiH0RenF0080RenF00<0
000008]OU02;Gi@00`2;Gi@00`000000S5jC08aNT`0408aNT`030000002=
GY40SEjA00<0SEjA00<0000008iNT02>GY000`2>GY000`000000Sej?08mN
S`0408mNS`030000002@GXh0T5j>00<0T5j>00<00000099NSP2BGXh0102B
GXh00`000000Ten=09=OS@0409=OS@030000003oool0000000l0oooo00<0
00000?ooo`3oool0?@3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000
B?4003gL000NX04001><000010006Ll01c;I01IZkP08EMe:0?ooo`030000
003oool0oooo04d0oooo00<000000?ooo`3oool00P3oool01P000000O6jf
07a^]P1lK[H0000007a]]@L00000101oK;401@000000OfZ^07mZ[P1oJZh0
000000<0P6R[2000000208=WY`0300000024IJD0Q6FU00<0Q6FU00<00000
08ATXP24I:800P24I:800`000000QF>P08ESX00208ESX00300000026HIh0
QV6N0080QV6N00<0000008IPW026H9`00P26H9`@00000080RenF00<00000
08]OU02;Gi@00`2;Gi@00`000000S5jC08aNT`0308aNT`030000002=GY40
SEjA00<0SEjA00<0000008iNT02>GY00102>GY000`000000Sej?08mNS`03
08mNS`030000002@GXh0T5j>00@0T5j>00<00000099NSP2BGXh00`2BGXh0
0`000000Ten=09=OS@0409=OS@040000003oool0oooo000000h0oooo00<0
00000?ooo`3oool0?@3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000
B?4003gL000NX04001><000010006Ll01c;I01IZkP08EMe;0?ooo`800000
CP3oool00`000000oooo0?ooo`020?ooo`<0000000<0O6jf0000001lKKD0
0P1lKKD00`000000O6^b07a[/P07000000<0OfZ^00<00000081XZ`20J:/0
0P20J:/01P000000P6JY081VZ@20IZT00000085UYPT000001024I:800`00
0000QF>P08ESX00308ESX00300000026HIh0QV6N0080QV6N00<0000008IP
W026H9`00`26H9`00`000000QenJ08MOVP0208MOVP0300000028GiP0R5nH
00<0R5nH00<0000008UNUP29GYH07000000608mNS`030000002@GXh0T5j>
00<0T5j>00<00000099NSP2BGXh0102BGXh00`000000Ten=09=OS@0409=O
S@040000003oool0oooo000000d0oooo00<000000?ooo`3oool0?@3oool0
0`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000NX04001><0000
10006Ll01c;I01IZkP08EMe=0?ooo`030000003oool0oooo04`0oooo00<0
00000?ooo`3oool00P3oool00`000000NVff00000006000000<0O6^b00<0
000007aY/01lJK000P1lJK0700000080P6R[00D00000081VZ@20IZT0P6JY
00000004085UYP0300000021Hj@0PF>T0080PF>T2`00000508IQWP030000
0026H9`0QV2L0080QV2L00<0000008MOVP27GiX00`27GiX00`000000R5nH
08QOV00208QOV00300000029GYH0REjF00<0REjF00<0000008YNU@2:GYD0
0`2:GYD00`000000RefC08]MT`0308]MT`030000002<GI80S5fB00@0S5fB
00<0000008eNT@2=GY400P2=GY4L000000<0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0l0?ooo`030>o_k03no_/0o_kk00d0o_kk
00@0kno/0018l@00?M`001jP0@004h`00004000Ic`07<]T05V[^00QEgDh0
oooo0P00001=0?ooo`8000000`3oool01@000000NVff07Y]]P1jKKH00000
0080NVbd1P00000407aY/0060000001lIjd0O6N]07aW[@000000OFJ[2000
0004085UYP0300000021Hj@0PF>T0080PF>T00<00000089RXP22HZ800P22
HZ8010000000PV6P089QX022HJ0:00000080QV2L00<0000008MOVP27GiX0
0P27GiX00`000000R5nH08QOV00308QOV00300000029GYH0REjF00<0REjF
00<0000008YNU@2:GYD00`2:GYD00`000000RefC08]MT`0308]MT`030000
002<GI80S5fB00<0S5fB00<0000008eNT@2=GY400`2=GY400`000000SUj@
08iNT00408iNT0030000002@GY00T5j@00<0T5j@00<00000095OT02AGi00
102AGi000`000000Tf2?09=PS`0409=PS`040000003oool0oooo000000d0
oooo00<000000?ooo`3oool0?03oool00`3_kn`0o_kk0?knn`0=0?knn`04
0>o_k000B?4003gL000NX04001><000010006Ll01c;I01IZkP08EMe@0?oo
o`030000003oool0oooo04`0oooo00@000000?ooo`3oool0oooo1@000003
07Y/]0040000001jJ[80NVZb07YZ/PD00000101lIjd01@000000OFJ[07eV
Z`1mIZ/0000000<0OFBX1`000004085SY00300000022HZ80PV:R0080PV:R
00<00000089QX022HJ000P22HJ000`000000Pf2M08=PW@0208=PW@030000
0024Gi`0Q5nL00d0000000<0R5nH00000029GYH01029GYH00`000000RUjE
08YNU@0208YNU@030000002;GI<0RefC00@0RefC00<0000008aMTP2<GI80
0`2<GI800`000000SEjA08eNT@0308eNT@030000002>GY00SUj@00<0SUj@
00<00000091NT02@GY00102@GY000`000000TEn@095OT003095OT0030000
002CH8l0Tf2?00@0Tf2?00D000000?ooo`3oool0oooo0000000<0?ooo`03
0000003oool0oooo03`0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`0
04Sa000mg0007Z01000CS00000@001W?00Lbf@0FJ^h025GMD@3oool00`00
0000oooo0?ooo`1<0?ooo`030000003oool0oooo00<000000P3oool50000
00<0NVZb00@0000007YX[`1jJ:l0NVR_1P00000307eVZ`030000001mI:P0
OFBX0080OFBX00<0000007iSYP1nHjH00P1nHjH800000003089RXP000000
PV6P00@0PV6P00<0000008=PW@23H9d00P23H9d00`000000Q5nL08AOW002
08AOW00300000025GYX0QEjJ00<0QEjJ00@0000008INV026GYP0QUjH3`00
000408]MT`030000002<GI80S5fB00<0S5fB00<0000008eNT@2=GY40102=
GY400`000000SUj@08iNT00308iNT0030000002@GY00T5j@00<0T5j@00<0
0000095OT02AGi00102AGi000`000000Tf2?09=PS`0409=PS`050000003o
ool0oooo0?ooo`0000002`3oool00`000000oooo0?ooo`0l0?ooo`030>o_
k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001jP0@004h`00004000I
c`07<]T05V[^00QEgE80oooo0P00001=0?ooo`8000002P3oool5000000<0
NVR_00<0000007]V[@1kIZd00P1kIZd6000000<0OFBX00D0000007iSYP1n
HjH0OV>V0000000407iQY0030000001oH:40Of2Q00P000001@23H9d00`00
0000Q5nL08AOW00208AOW00300000025GYX0QEjJ0080QEjJ00<0000008IN
V026GYP00`26GYP00`000000QefF08MMUP0308MMUP0300000028GID0R5fE
00<0R5fE7P0000000`2@GY000000095OT005095OT0030000002CH8l0Tf2?
00<0Tf2?00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo03`0oooo00<0kno/0?knn`3no_/03@3no_/0103_
kn`004Sa000mg0007Z01000CS00000@001W?00Lbf@0FJ^h025GME03oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0oooo00h0oooo1@000004
07]V[@040000001kI:X0NfBZ07]TZPP0000000<0OV>V0000001nHJ@00`1n
HJ@00`000000Of2Q07mPX@0207mPX@0300000020Gil0P5nO0080P5nO2@00
000208AOW00300000025GYX0QEjJ0080QEjJ00<0000008INV026GYP00`26
GYP00`000000QefF08MMUP0208MMUP0300000028GID0R5fE00<0R5fE00<0
000008YMU02:GI@00`2:GI@00`000000RefC08]MT`0308]MT`030000002<
GY80S5jB00@0S5jB00<0000008iNTP2>GY800`2>GY800`000000T5nA091O
T@02091OTA0000000`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo03`0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000m
g0007Z01000CS00000@001W?00Paf00FJ^h025GME@3oool2000004X0oooo
00<000000?ooo`3oool04`3oool6000000<0NfBZ00D0000007aSZ01lHjP0
O6>X0000000207aQY@H0000000<0OV6T0000001oH:400`1oH:400`000000
P5nO081OW`02081OW`0300000021GYd0PEjM0080PEjM00<00000089MV`22
GI/02P00000308INV00300000027GIH0QefF00<0QefF00<0000008QMU@28
GID00`28GID00`000000RUfD08YMU00308YMU0030000002;GI<0RefC00<0
RefC00<0000008aNTP2<GY800`2<GY800`000000SUjB08iNTP0408iNTP03
0000002@Gi40T5nA00<0T5nA00<00000095PT@2AH940102AH9400`000000
Tf:A09=RT@0309=RT@030000003oool0oooo0080oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`0l0?ooo`030>o_k03no_/0o_kk00d0
o_kk00@0kno/0018l@00?M`001jP0@004h`00004000Ic`08<MP05V[^00QE
gEL0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0I0?oo
o`D000000`1lHjP00`000000O66U07aQY@0207aQY@030000001mH:<0OF2S
00L000001020Gil00`000000PEjM085NW@03085NW@0300000022GI/0PUfK
0080PUfK00<0000008=MVP23GIX00P23GIX00`000000Q5fH0000000;0000
00@0R5fE00<0000008YMU02:GI@00P2:GI@00`000000RefC08]MT`0408]M
T`030000002<GY80S5jB00<0S5jB00<0000008iNTP2>GY800`2>GY800`00
0000T5nA091OT@04091OT@030000002AH940TF2A00<0TF2A00<0000009=R
T@2CHY40102CHY400`000000oooo0?ooo`020?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0?03oool00`3_kn`0o_kk0?knn`0=0?kn
n`040>o_k000B?4003gL000NX04001><000010006Ll0237H01IZkP08EMeH
0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool07P3oool5
000000@0O66U00D0000007ePX`1mH:<0OF2S0000000407iOX@L000000`21
GYd00`000000PUfK089MV`03089MV`0300000023GIX0PefJ0080PefJ00<0
000008AMV024GIP00`24GIP00`000000QEbG08ELU`0208ELU`0300000027
G9H00000010000001@2<GY800`000000SUjB08iNTP0408iNTP030000002@
Gi40T5nA00<0T5nA00<00000095PT@2AH940102AH9400`000000Tf:A09=R
T@0309=RT@030000003oool0oooo00<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0k0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0
kno/0018l@00?M`001jP0@004h`00004000Ic`08<MP05V[^00QEgET0oooo
0P0000160?ooo`030000003oool0oooo02<0oooo1P00000307ePX`030000
001nGj40OUnQ0080OUnQ00<0000007mNW`1oGYl00P1oGYl900000003089M
V`000000PefJ00@0PefJ00<0000008AMV024GIP00P24GIP00`000000QEbG
08ELU`0308ELU`0300000027G9H0QebF00<0QebF00<0000008QMU@28GID0
0`28GID00`000000RUfD08YMU00208YMU2800000103oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo03/0oooo00<0kno/0?knn`3no_/0
3@3no_/0103_kn`004Sa000mg0007Z01000CS00000@001W?00Paf00FJ^h0
25GMF`3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo02T0
oooo1P00000307iOX@030000001oGYl0OejO0080OejO00<00000081MW@20
GId00P20GId00`000000PEfK085MV`09000000@0Q5fH00<0000008ELU`25
G9L00`25G9L00`000000QebF08MLUP0208MLUP0300000028GID0R5fE00<0
R5fE00<0000008YMU02:GI@00`2:GI@00`000000S5jC08aNT`0308aNT`03
0000002=Gi<0SEnC00@0SEnC00<0000008mPT`2?H9<00`2?H9<00`000000
TF:C095RT`04095RT`030000002DHi@0U6>D00<0U6>D00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03/0
oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z01000C
S00000@001W?00Paf00FJ^h025GMG03oool2000004<0oooo00<000000?oo
o`3oool0;`3oool600000080OejO00<00000081MW@20GId00`20GId00`00
0000PEfK085MV`02085MV`0300000022G9X0PUbJ0080PUbJ3000000508ML
UP0300000028GID0R5fE00<0R5fE00<0000008YMU02:GI@00`2:GI@00`00
0000S5jC08aNT`0308aNT`030000002=Gi<0SEnC00<0SEnC00<0000008mP
T`2?H9<0102?H9<00`000000TF:C095RT`03095RT`030000002DHi@0U6>D
00@0U6>D00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo03/0oooo00<0kno/0?knn`3no_/03@3no_/0103_
kn`004Sa000mg0007Z01000CS00000@001W?00Paf00FJ^h025GMGP3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo03D0oooo1`000000
0`20GId00000085MV`03085MV`0300000022G9X0PUbJ00<0PUbJ00<00000
08=LV023G9P00P23G9P00`000000QEbG08ELU`0208ELU`d000001P2:GI@0
0`000000S5jC08aNT`0308aNT`030000002=Gi<0SEnC00<0SEnC00<00000
08mPT`2?H9<00`2?H9<00`000000TF:C095RT`04095RT`030000002DHi@0
U6>D00@0U6>D00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo03/0oooo00<0kno/0?knn`3no_/03@3no_/0
103_kn`004Sa000mg0007Z01000CS00000@001W?00Paf00FJ^h025GMG`3o
ool00`000000oooo0?ooo`0n0?ooo`030000003oool0oooo03d0oooo2000
0004089LVP0300000023G9P0PebH00<0PebH00<0000008ELU`25G9L00P25
G9L00`000000QUbF08ILUP0308ILUP0300000028GID0R5fE0080R5fE4P00
00000`2=Gi<0000008mPT`0508mPT`030000002AHY<0TF:C00<0TF:C00<0
000009ASU02DHi@0102DHi@00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0>`3oool00`3_kn`0o_kk0?kn
n`0=0?knn`040>o_k000B?4003gL000NX04001><000010006Ll0237H01IZ
kP08EMeP0?ooo`800000?P3oool00`000000oooo0?ooo`140?ooo`P00000
1023G9P00`000000QEbG08ELU`0208ELU`0300000026G9H0QUbF00<0QUbF
00<0000008QMU@28GID00`28GID00`000000RUfD08YMU00308YMU0030000
002;GY@0RejD00<0RejD00@0000008eOU02=Gi@0SEnD5`0000050?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0>`3oool00`3_kn`0
o_kk0?knn`0=0?knn`040>o_k000B?4003gL000NX04001><000010006Ll0
237H01IZkP08EMeR0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0C03oool800000080QEbG00<0000008ILUP26G9H00P26G9H00`00
0000R5fE08QMU@0308QMU@030000002:GI@0RUfD00<0RUfD00<0000008]N
U02;GY@00`2;GY@00`000000SEnD08eOU00408eOU0030000002?HI@0Sf6D
00<0Sf6D00<00000099RU02BHY@00`2BHY@00`000000U6BE09ATU@0409AT
U@030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0j0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018
l@00?M`001jP0@004h`00004000Ic`08<MP05V[^00QEgF<0oooo0P00000k
0?ooo`030000003oool0oooo05@0oooo2P00000408QMU@030000002:GI@0
RUfD00<0RUfD00<0000008]NU02;GY@00`2;GY@00`000000SEnD08eOU003
08eOU0030000002?HI@0Sf6D00@0Sf6D00<00000099RU02BHY@00`2BHY@0
0`000000U6BE09ATU@0409ATU@030000003oool0oooo00@0oooo00D00000
0?ooo`3oool0oooo0000000l0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0
kno/0018l@00?M`001jP0@004h`00004000Ic`08<MP05V[^00QEgFD0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1N0?ooo`h00000
0`2;GY@00`000000SEnD08eOU00308eOU0030000002?HI@0Sf6D00<0Sf6D
00<00000099RU02BHY@0102BHY@00`000000U6BE09ATU@0309ATU@030000
003oool0oooo00@0oooo00D000000?ooo`3oool0oooo0000000l0?ooo`03
0>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001jP0@004h`00004
000Ic`08<MP05V[^00QEgFH0oooo00<000000?ooo`3oool0=`3oool00`00
0000oooo0?ooo`1/0?oooah000001P3oool010000000oooo0?ooo`00000l
0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001jP0@00
4h`00004000Ic`07<]T05V[^00QEgFL0oooo0P00000g0?ooo`030000003o
ool0oooo0940oooo00<000000?ooo`000000?03oool00`3_kn`0o_kk0?kn
n`0=0?knn`040>o_k000B?4003gM000NX04001><000010006Ll01c;I01IZ
kP08EMeY0?ooo`030000003oool0oooo03@0oooo00<000000?ooo`3oool0
TP3oool2000003`0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa
000mg@007Z01000CS00000@001W?00Lbf@0FJ^h025GMJP3oool2000003@0
oooo00<000000?ooo`3oool0TP3oool2000003`0oooo00<0kno/0?knn`3n
o_/03@3no_/0103_kn`004Sa000mg@007Z01000CS00000@001W?00Lbf@0F
J^h025GMK03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo
09<0oooo0P00000k0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018
l@00?Md001jP0@004h`00004000Ic`07<]T05V[^00QEgFd0oooo0P00000a
0?ooo`030000003oool0oooo0940oooo0`00000l0?ooo`030>o_k03no_/0
o_kk00d0o_kk00@0kno/0018l@00?Md001jP0@004h`00004000Ic`07<]T0
5V[^00QEgFl0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`2=0?ooo`@00000?`3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000
B?4003gM000NX04001><000010006Ll01c;I01IZkP08EMe`0?ooo`030000
003oool0oooo02d0oooo00<000000?ooo`3oool0R@3oool4000004<0oooo
00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg@007Z01000CS000
00@001W?00Lbf@0FJ^h025GML@3oool2000002d0oooo00<000000?ooo`3o
ool0Q03oool5000004L0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`0
04Sa000mg@007Z01000CS00000@001W?00Lbf@0FJ^h025GML`3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo0800oooo1000001<0?oo
o`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?Md001jP0@004h`0
0004000Ic`07<]T05V[^00QEgG@0oooo0P00000Z0?ooo`030000003oool0
oooo07`0oooo1000001@0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/
0018l@00?Md001jP0@004h`00004000Ic`07<]T05V[^00QEgGH0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`1g0?ooo`D00000E03o
ool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gM000NX04001><
000010006Ll01c;I01IZkP08EMeg0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0L`3oool4000005T0oooo00<0kno/0?knn`3no_/0
3@3no_/0103_kn`004Sa000mg@007Z01000CS00000@001W?00Paf@0FJ^h0
25GMN03oool2000002H0oooo00<000000?ooo`3oool0K`3oool4000005d0
oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z01000C
S00000@001W?00Paf@0FJ^h025GMNP3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo06/0oooo1000001Q0?ooo`030>o_k03no_/0o_kk
00d0o_kk00@0kno/0018l@00?M`001jP0@004h`00004000Ic`08<MT05V[^
00QEgG/0oooo0P00000S0?ooo`030000003oool0oooo06H0oooo1@00001U
0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001jP0@00
4h`00004000Ic`08<MT05V[^00QEgGd0oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`1R0?ooo`@00000JP3oool00`3_kn`0o_kk0?kn
n`0=0?knn`040>o_k000B?4003gL000NX04001><000010006Ll0237I01IZ
kP08EMen0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
GP3oool4000006h0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa
000mg0007Z01000CS00000@001W?00Paf@0FJ^h025GMO`3oool2000001l0
oooo00<000000?ooo`3oool0F@3oool500000780oooo00<0kno/0?knn`3n
o_/03@3no_/0103_kn`004Sa000mg0007Z01000CS00000@001W?00Paf@0F
J^h025GMP@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo
05D0oooo1000001g0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018
l@00?M`001jP0@004h`00004000Ic`08<MT05V[^00QEgH80oooo0P00000L
0?ooo`030000003oool0oooo0540oooo1000001k0?ooo`030>o_k03no_/0
o_kk00d0o_kk00@0kno/0018l@00?M`001jP0@004h`00004000Ic`08<MT0
5V[^00QEgH@0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?oo
o`1<0?ooo`D00000O`3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000
B?4003gL000NX04001><000010006Ll0237I01IZkP08EMf50?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0B03oool4000008@0oooo
00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z01000CS000
00@001W?00Paf@0FJ^h025GMQP3oool2000001P0oooo00<000000?ooo`3o
ool0A03oool4000008P0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`0
04Sa000mg0007Z01000CS00000@001W?00Paf@0FJ^h025GMR03oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0440oooo1000002<0?oo
o`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001jP0@004h`0
0004000Ic`08<MT05V[^00QEgHT0oooo0P00000D0?ooo`030000003oool0
oooo03`0oooo1@00002@0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/
0018l@00?M`001jP0@004h`00004000Ic`08<MP05V[^00QEgH/0oooo00<0
00000?ooo`3oool04@3oool00`000000oooo0?ooo`0h0?ooo`@00000U@3o
ool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000MX04001><
000010006Ll0237H01IZkP08EMf<0?ooo`8000004@3oool00`000000oooo
0?ooo`0d0?ooo`@00000V@3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_
k000B?4003gL000MX04001><000010006Ll0237H01IZkP08EMf>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0;`3oool5000009d0
oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007J01000C
S00000@001W?00Paf00FJ^h025GMS`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo02/0oooo1000002R0?ooo`030>o_k03no_/0o_kk
00d0o_kk00@0kno/0018l@00?M`001fP0@004h`00004000Ic`08<MP05V[^
00QEgI00oooo0P00000=0?ooo`030000003oool0oooo02L0oooo1000002V
0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001fP0@00
4h`00004000Ic`08<MP05V[^00QEgI80oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`0S0?ooo`@00000ZP3oool00`3_kn`0o_kk0?kn
n`0=0?knn`040>o_k000B?4003gL000MX04001><000010006Ll0237H01IZ
kP08EMfC0?ooo`8000002P3oool00`000000oooo0?ooo`0N0?ooo`D00000
[P3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000MX040
01><000010006Ll0237H01IZkP08EMfE0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool06P3oool400000;<0oooo00<0kno/0?knn`3n
o_/03@3no_/0103_kn`004Sa000mg0007J01000CS00000@001W?00Paf00F
J^h025GMUP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
01H0oooo1000002g0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018
l@00?M`001fP0@004h`00004000Ic`08<MP05V[^00QEgIL0oooo0P000006
0?ooo`030000003oool0oooo0140oooo1@00002k0?ooo`030>o_k03no_/0
o_kk00d0o_kk00@0kno/0018l@00?M`001fP0@004h`00004000Ic`08<MP0
5V[^00QEgIT0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0=0?ooo`@00000`03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000
B?4003gL000MX04001><000010006Ll0237H01IZkP08EMfJ0?ooo`800000
0`3oool00`000000oooo0?ooo`090?ooo`@00000a03oool00`3_kn`0o_kk
0?knn`0=0?knn`040>o_k000B?4003gL000MX04001><000010006Ll01c7H
01IZkP08EMfL0?ooo`040000003oool0oooo000000L0oooo100000380?oo
o`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?Md001jQ0@004h`0
0004000Ic`07<MP05V[^00QEgId0oooo00<000000?ooo`0000000P3oool5
00000<`0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg@00
7Z41000CS00000@001W?00Laf00FJ^h025GMWP3oool400000=40oooo00<0
kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg@007Z41000CS00000@0
01W?00Laf00FJ^h025GMo`3ooomd0?ooo`030>o_k03no_/0o_kk00d0o_kk
00@0kno/0018l@00?Md001jQ0@004h`00004000Ic`07<MP05V[^00QEgOl0
ooooM03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gM000N
X@4001><000010006Ll01c7H01IZkP08EMgo0?ooog@0oooo00<0kno/0?kn
n`3no_/03@3no_/0103_kn`004Sa000mg@007Z41000CS00000@001W?00La
f00FJ^h025GMo`3ooomd0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/
0018l@00?Md001jQ0@004h`00004000Ic`07<MP05V[^00QEgOl0ooooM03o
ool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gM000NX@4001><
000010006Ll01c7H01IZkP08EMgo0?ooog@0oooo00<0kno/0?knn`3no_/0
3@3no_/0103_kn`004Sa000mg@007Z41000CS00000@001W?00Laf00FJ^h0
25GMo`3ooomd0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00
?Md001jQ0@004h`00004000Ic`07<MP05V[^00QEgOl0ooooM03oool00`3_
kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gM000NX@4001><00001000
6Ll01c7H01IZkP08EMgo0?ooog@0oooo00<0kno/0?knn`3no_/03@3no_/0
103_kn`004Sa000mg@007Z41000CS00000@001W?00Laf00FJ^h025GMo`3o
oomd0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?Md001jQ
0@004h`00004000Ic`08<MP05V[^00QEgOl0ooooM03oool00`3_kn`0o_kk
0?knn`0=0?knn`040>o_k000B?4003kL000MX@4001><000010006Ll0237H
01IZkP08EMgo0?ooog@0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`0
04Sa000ng0007J41000CS00000@001W?00Paf00FJ^h025GMo`3ooomd0?oo
o`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001fQ0@004h`0
0004000Ic`08<MP05V[^00QEgOl0ooooM03oool00`3_kn`0o_kk0?knn`0=
0?knn`040>o_k000B?4003kL000MX@4001><000010006Ll0237H01IZkP08
EMgo0?ooog@0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000n
g0007J41000CS00000@001W?00Paf00FJ^h025GMo`3ooomd0?ooo`030>o_
k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001fQ0@004h`00004000I
c`08<MP05V[^00QEgOl0ooooM03oool00`3_kn`0o_kk0?knn`0=0?knn`04
0>o_k000B?4003kL000MX@4001><000010006Ll0237H01IZkP08EMgo0?oo
og@0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng0007J41
000CS00000@001W?00Paf00FJ^h025GMo`3ooomd0?ooo`030>o_k03no_/0
o_kk00d0o_kk00@0kno/0018l@00?]`001fQ0@004h`00004000Ic`08<MP0
5V[^00QEgOl0ooooM03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000
B?4003kL000MX@4001><000010006Ll0237H01IZkP08EMgo0?ooog@0oooo
00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng0007J41000CS000
00@001W?00Paf00FJ^h025GMo`3ooomd0?ooo`030>o_k03no_/0o_kk00d0
o_kk00@0kno/0018l@00?]`001fQ0@004h`00004000Ic`07<MP05V[^00QE
gOl0ooooM03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL
000NX04001><000010006Ll01c7H01IZkP08EMgo0?ooog@0oooo00<0kno/
0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z01000CS00000@001W?
00Laf00FJ^h025GMo`3ooomd0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0
kno/0018l@00?M`001jP0@004h`00004000Ic`07<MP05V[^00QEgOl0oooo
M03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000NX040
01><000010006Ll01c7H01IZkP08EMgo0?ooog@0oooo00<0kno/0?knn`3n
o_/03@3no_/0103_kn`004Sa000mg0007Z01000CS00000@001W?00Laf00F
J^h025GMo`3ooomd0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018
l@00?M`001jP0@004h`00004000Ic`07<MP05V[^00QEgOl0ooooM03oool0
0`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000NX04001><0000
10006Ll01c7H01IZkP08EMgo0?ooog@0oooo00<0kno/0?knn`3no_/03@3n
o_/0103_kn`004Sa000mg0007Z01000CS00000@001W?00Laf00FJ^h025GM
o`3ooomd0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`0
01jP0@004h`00004000Ic`07<MP05V[^00QEgOl0ooooM03oool00`3_kn`0
o_kk0?knn`0=0?knn`040>o_k000B?4003gL000NX04001><000010006Ll0
1c7H01IZkP08EMgo0?ooog@0oooo00<0kno/0?knn`3no_/03@3no_/0103_
kn`004Sa000mg0007Z01000CS00000@001W?00Laf00FJ^h025GMo`3ooomd
0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001jP0@00
4h`00004000Ic`07<MP05V[^00QEgOl0ooooM03oool00`3_kn`0o_kk0?kn
n`0=0?knn`040>o_k000B?4003gL000NX04001><000010006Ll01c7H01IZ
kP08EMgo0?ooog@0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa
000mg0007Z01000CS00000@001W?00Laf00FJ^h025GMo`3ooomd0?ooo`03
0>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001jP0@004h`00004
000Ic`07<MP05V[^00QEgOl0ooooM03oool00`3_kn`0o_kk0?knn`0=0?kn
n`040>o_k000B?4003gL000NX04001><000010006Ll01c7H01IZkP08EMgo
0?ooog@0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg000
7Z01000CS00000@001W?00Laf00FJ^h025GMo`3ooomd0?ooo`030>o_k03n
o_/0o_kk00d0o_kk00@0kno/0018l@00?M`001jP0@004h`00004000Ic`07
<MP05V[^00QEgOl0ooooM03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_
k000B?4003gL000NX04001><000010006Ll01c7H01IZkP08EMgo0?ooog@0
oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z01000C
S00000@001W?00Laf00FJ^h025GMo`3ooomd0?ooo`030>o_k03no_/0o_kk
00d0o_kk00@0kno/0018l@00?M`001jP0@004h`00004000Ic`07<MP05V[^
00QEgOl0ooooM03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?40
03gL000NX04001><000010006Ll01c7H01IZkP08EMgo0?ooog@0oooo00<0
kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z01000CS00000@0
01W?00Laf00FJ^h025GMo`3ooomd0?ooo`030>o_k03no_/0o_kk00d0o_kk
00@0kno/0018l@00?M`001jP0@004h`00004000Ic`07<MP05V[^00QEgOl0
ooooM03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000N
X04001><000010006Ll0237I01IZkP08EMgo0?ooog@0oooo00<0kno/0?kn
n`3no_/03@3no_/0103_kn`004Sa000mg0007J01000CS00000@001W?00Pa
f@0FJ^h025GMo`3ooomd0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/
0018l@00?M`001fP0@004h`00004000Ic`08<MT05V[^00QEgOl0ooooM03o
ool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000MX04001><
000010006Ll0237I01IZkP08EMgo0?ooog@0oooo00<0kno/0?knn`3no_/0
3@3no_/0103_kn`004Sa000mg0007J01000CS00000@001W?00Paf@0FJ^h0
25GMo`3ooomd0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00
?M`001fP0@004h`00004000Ic`08<MT05V[^00QEgOl0ooooM03oool00`3_
kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000MX04001><00001000
6Ll0237I01IZkP08EMgo0?ooog@0oooo00<0kno/0?knn`3no_/03@3no_/0
103_kn`004Sa000mg0007J01000CS00000@001W?00Paf@0FJ^h025GMo`3o
oomd0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001fP
0@004h`00004000Ic`08<MT05V[^00QEgOl0ooooM03oool00`3_kn`0o_kk
0?knn`0=0?knn`040>o_k000B?4003gL000MX04001><000010006Ll0237I
01IZkP08EMgo0?ooog@0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`0
04Sa000mg0007J01000CS00000@001W?00Paf@0FJ^h025GMo`3ooomd0?oo
o`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001fP0@004h`0
0004000Ic`08<MT05V[^00QEgOl0ooooM03oool00`3_kn`0o_kk0?knn`0=
0?knn`040>o_k000B?4003gL000MX04001><000010006Ll0237I01IZkP08
EMgo0?ooog@0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000m
g0007J01000CS00000@001W?00TdfP0FJ^h025GMo`3ooomd0?ooo`030>o_
k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001fP0@004h`00004000I
c`09==X05V[^00QEgOl0ooooM03oool00`3_kn`0o_kk0?knn`0=0?knn`04
0>o_k000B?4003gL000MX04001><000010006Ll02CCJ01IZkP08EMgo0?oo
og@0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007J01
000CS00000@001W?00TdfP0FJ^h025GMo`3ooomd0?ooo`030>o_k03no_/0
o_kk00d0o_kk00@0kno/0018l@00?M`001fP0@004h`00004000Ic`09==X0
5V[^00QEgOl0ooooF`3ooolA000000P0oooo00<0kno/0?knn`3no_/03@3n
o_/0103_kn`004Sa000mg0007J01000CS00000@001W?00TdfP0FJ^h025GM
o`3ooomK0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
1P3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000MX040
01><000010006Ll02CCJ01IZkP08EMgK0?ooo`030000003oool0oooo00<0
oooo0P00001A0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`060?ooo`030>o_k03no_/0o_kk00d0
o_kk00@0kno/0018l@00?M`001fP0@004h`00004000Ic`09==X05V[^00QE
gM/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1>0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`060?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018
l@00?M`001fP0@004h`00004000Ic`09==X05V[^00QEgM00oooo0`000003
0?ooo`<000000P3oool4000000@0oooo00<000000?ooo`3oool01@3oool0
1@000000oooo0?ooo`3oool0000000<0oooo100000030?ooo`050000003o
ool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`<00000
0P3oool010000000oooo0?ooo`0000030?ooo`040000003oool000000000
00@0oooo0P0000020?ooo`<000001@3oool300000080oooo00@000000?oo
o`3oool000000P3oool400000080oooo100000030?ooo`<000000`3oool4
000000030?ooo`000000oooo00<0oooo100000050?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool01P3oool01P3^kND0lo?^0=OGb03<
c;X0bLVf0<G5/@H0a<B_00P0a<B`0<K6/`3@d;l0mOGa0>c/i@00B?4003gL
000MX04001><000010006Ll02CCJ01IZkP08EMg?0?ooo`070000003oool0
oooo0?ooo`000000oooo000000030?ooo`030000003oool0000000<0oooo
00H000000?ooo`3oool000000?ooo`0000060?ooo`050000003oool0oooo
0?ooo`0000000P3oool00`000000oooo0?ooo`050?ooo`050000003oool0
oooo0?ooo`0000000`3oool00`000000oooo0?ooo`030?ooo`070000003o
ool0oooo0?ooo`000000oooo000000020?ooo`070000003oool0oooo0?oo
o`000000oooo000000050?ooo`040000003oool0oooo000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`030000003oool000000080oooo
00@000000?ooo`3oool000000`3oool00`000000oooo000000030?ooo`03
0000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000
oooo000000030?ooo`050000003oool0oooo0?ooo`0000001@3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<0k^gU0>;R
e`3oool0303oool01@3Jf/d0k>cU0018l@00?M`001fP004001><00001000
6Ll02CCJ01IZkP08EMg?0?ooo`030000003oool0oooo00<0oooo00L00000
0?ooo`3oool0oooo0000003oool0000000<0oooo00H000000?ooo`3oool0
00000?ooo`0000050?ooo`030000003oool000000080oooo00<000000?oo
o`3oool01@0000020?ooo`070000003oool000000?ooo`000000oooo0000
00020?ooo`030000003oool0oooo00<0oooo00L000000?ooo`3oool0oooo
0000003oool000000080oooo00L000000?ooo`3oool0oooo0000003oool0
000000D0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?oo
o`3oool0000000D0oooo00@000000?ooo`3oool000000P3oool01`000000
oooo0?ooo`3oool000000?ooo`0000000`3oool00`000000oooo00000003
0?ooo`030000003oool0oooo00@0000000<0oooo0000003oool00P3oool0
1@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`060?ooo`040>k]i@3oool0l_;]0>GUf`<0i^KL
00@0i^KM0>KVg03Vi]`0i^KL0P3UiM/01`3ShmP0lO7[0?ooo`3Bd/4004Sa
000mg0007J000@004h`00004000Ic`09==X05V[^00QEgLl0oooo00<00000
0?ooo`3oool00`3oool01`000000oooo0?ooo`3oool000000?ooo`000000
0`3oool01P000000oooo0?ooo`000000oooo000000D0oooo00<000000?oo
o`0000000P3oool010000000oooo0?ooo`0000030?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000P3oool400000080oooo
00L000000?ooo`3oool0oooo0000003oool000000080oooo00L000000?oo
o`3oool0oooo0000003oool0000000D0oooo00@000000?ooo`3oool00000
0`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`00
00000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool00000
00<0oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo00000005
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool0
1@3^kND0oooo0>;Re`3Zj^80jn_S0080k>cT0P3[jn<02`3Zj^80jNWP0>SX
g`3Wimh0i^KM0>?Sf03oool0c<bj0018l@00?M`001fP004001><00001000
6Ll01cCJ01IZkP08EMg?0?ooo`030000003oool0oooo00@0oooo0`000002
0?ooo`@000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00L0
00000?ooo`3oool0oooo0000003oool0000000<0oooo0`0000020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000030?oo
o`030000003oool0oooo00<000000P3oool00`000000oooo0?ooo`040000
00040?ooo`0000000000000000<0oooo0`0000020?ooo`<000001@3oool3
00000080oooo00@000000?ooo`3oool000000P3oool400000080oooo1000
00030?ooo`<000000P3oool400000080oooo0`0000020?ooo`@000001@3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00@0
k^gU0?ooo`3UiM/0k>cT103]kNH0303/k>D0jn_S0>_[h`3Zj^80jNWP0>OW
gP3Ti=T0oooo0<c<^@00B?4003_J000QZ@4001><000010006Ll01cCJ01IZ
kP08EMg?0?ooo`050000003oool0oooo0?ooo`0000005@3oool01@000000
oooo0?ooo`3oool0000001@0oooo00D000000?ooo`3oool0oooo0000000@
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo01L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00H0oooo00@0k^gU0?ooo`3UiM/0kNgV103^k^L0303]kNH0k>cT0>_[
h`3Zj^80jNWP0>SXg`3UiM/0oooo0<c<^@00B?4003_J000QZ@4001><0000
10006Ll01cCJ01IZkP08EMg@0?ooo`<000005@3oool00`000000oooo0?oo
o`030?ooo`8000004P3oool4000000P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0oooo00@0
00000?ooo`3oool00000203oool00`000000oooo0?ooo`0G0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`060?ooo`070>k]i@3oool0i^KL0>k^i`3_knT0bLW20>o_j@020>k^
i`0;0>c/i03Zj^80bLW20>[ZhP3YjN00i^KL0?ooo`3<c;T004Sa000kfP00
8JT00@004h`00004000Ic`07==X05V[^00QEgOl0ooooF`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00@0k^gU0?ooo`3V
i]d0knoY0`39bL800`3_knT0k^kW0>c/i@030<W9`P070>[ZhP3Vi]`0oooo
0<c<^@00B?4003_J000QZ@01000CS00000@001W?00LdfP0FJ^h025GMo`3o
oomK0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3o
ool00`3^kND0oooo0>OWgP020?3`jP<0bLW200`0kNgV0<W9`P39bL80bLW2
0>_[h`3Zj^80i^KM0?ooo`3<c;X004Sa000kfP008JT1000CS00000@001W?
00LdfP0FJ^h025GMo`3ooomK0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool01P3oool0103^kND0oooo0>SXg`3`l>X20?7aj`D0bLW2
0`3[jn<01P3Wimh0oooo0<c<^P00B?4003_J000QZ@4001><000010006Ll0
1cCJ01IZkP08EMgo0?oooe/0oooo4@0000080?ooo`030>k]i@3oool0j^[R
0080lO7[0P3`l>X30<W9`P0:0>c/i03[jn<0k>cT0>_[h`3Wimh0oooo0<g=
_000B?4003_J000QZ@4001><000010006Ll01cCJ01IZkP08EMgo0?ooog@0
oooo00<0k^gU0?ooo`3Zj^800P3alN`01@3alN/0l?3Z0?3`jP39bL80k>cU
00@0k>cT00H0inON0?ooo`3?ckh004Sa000kfP008JT1000CS00000@001W?
00LdfP0FJ^h025GMo`3ooomd0?ooo`060>k]i@3oool0k>cU0??ckP3bl^d0
lO7[0`3`l>X02`3]kNH0k>cU0>c/i@3/k>D0k>cT0>OWgP3oool0dm?20018
l@00>mX0026Y004001><000010006Ll01cCJ01IZkP08EMgo0?ooog@0oooo
00T0k^gU0?ooo`3^k^L0mOGa0?Cdl03bl^d0lO7/0?7aj`3`l>X00P3_knT0
2@3^k^L0kNgV0>c/i03Vi]d0oooo0=SHb@00B?4003_J000QZ@01000CS000
00@001W?00LdfP0FJ^h025GMo`3ooomd0?ooo`070>k]i@3oool0lO7[0?Og
l`3emO40lo?^0?;bk@020?7ak00;0?7aj`3`l>X0knoY0>k^i`3/k>@0i^KM
0?ooo`3Ogm8004Sa000kfP008JT00@004h`00004000Ic`07==X05V[^00QE
gOl0ooooM03oool0203^kND0oooo0?Ogm03alN/0k^kW0>c/i@3[jn<0j^[R
0P3Xj=l20>OWgP080>KVg@3Ti=T0lo?^0?ooo`3UiM/004Sa000kfP008JT1
000CS00000@001W?00LdfP0FJ^h025GMool0001do`0000030>k]i@3lo?X0
oooo00d0oooo00@0k>cU0018l@00>mX0026Y0@004h`00004000Jc`00>n00
03_P001;h08004??00<00D??0054d001A=002@02AM030054d0800D??00<0
0DC@0053c`01@ll0L@01A=1_0013cg000D??7P00@ll00`00>n0002kL000b
`@01000ETP0000L001[?000kh000>n0004_P000mc000@ll00DC@00800TG@
0`00B]P3005=g003001@h000CN<0053R0080053R00<005?Q001@hP00D>80
0`00D>;P001=hfl004KP00<004_P001;h`00A^001P00A^000`00@m`0043L
0010g003000mg003000nfP00@=`003gL00<0043L00<003kJ0010g000?]X0
0P00>]T02000>=P003[I000ef000>=P003GH000kh000>>X003;10@004h/0
0005000Jc`00>n0004_[001=h`00E><00P00F>H01000F>/005c/001PkP00
Go8300=Ul@@00fSd00<00fSj005ZnP01J_X01001J_X00`00IOd00FCi005T
n@1_001PnFl0063lK`00H?T01`00G?T0063l001Ln@00FOP005[e001Hl`00
EoH00P00F?L01000EoH005Gd001Am000EO@2001Am0@005Gd00D0057`001<
k`00DO0005Gd001Am002001<l`H004O_0@00>>X1000b`@4001>;00001`00
6/l003_P001;j`00F>h005_b001HkP00Fo800P03H?400`03HOH00fSd00=X
nP0300IZn@<01Vcl1`03Jo/2009ZoW000fSj^000IOd00`l5I_^?IY_eoooo
o`0?ooooo`03knG]oHmVVoD?1FKk008006Gm00<?1FKkSfJKmOooool03ooo
ool01noUkOf?IYWc3`EQm`00H?T005ci3`ENmhmVU_<04?ooool02>oUk?b?
IY?a3`E?lP00C?<004O_0016jP00>>X003;10@004h/00007000Jc`00>n80
04_[001HkP00Fo800F3e00=QmP02009Un@0300=XnP06J_T01Vcl00801fom
0`07L_d400IaoP<00g;o0`03K_oo009ZoRT00V[n01F?Iikfom3JlOlXE/?o
3Cnfoa54_OlBAK_o54Fioa94^OlCAKco4dJmoa15__l=AL3o2TG1o`Q4`ol6
@L3o0co0o`4o`ol0>kko7djioloHkHmWW_H00P02J_h0<HmWW_Kod=[aobQF
`ol=?kKo4DBmoa95^olDAKWo4TBioa=5_?lCA[go44Fno`e5`?l:AL7o24C3
o`I1`?l3?l3o0Co3o`0k__lOC[WocmS]SfJKm@00IOd0063lSfJImOo^e]3o
]D@XojH[3On/<17oZc4BojTb5?nY<1;o[38Cojdb4on^<A3o/C0=ok8^2_nd
;@So/BX6ok4X0ond9`7o[R@0oj`l7ooZe<n?IY?a001Am000C?<004O_000h
jP00</400@004h/00004000Jc`00>n8004_[001HkP800F3e00@00f7f00=X
nP03J?X01Vcl0P07Kod200Mbo@H01gCn0P06LOh300=bog800fko^002J_h0
5NoUk_go:5kOoa=?golKEMoo8E[RobELhOlVGN3o95cQob=Nh_lQG^;o7UkR
oa]OiOlFG^Go4egVo`iKiOl9F>Ko15CVo`5>h_l0AM?o7djhooooo`02009Z
oP0aknG^oOlXG]oo4doOoa]EgolQF^;o9EcQobIMh?lTG>7o8ekRob5Nh_lN
G^;o6eoUoaINiOlCGNKo3U_Uo`UHi_l4E>Ko0DkRo`15dolOC[Sooooo001U
o@00H?c_iNgmole9:?o<>1?oc3hKolm48Oo?AbGocdLVolm69?o@Ab?odDHQ
om957_oEAA_oeD8FomI04ooE?@koeST9omDe1?oA<07o`RX0oj/l7oooool0
057d001<l`00Anl003SZ000b`@01000CR`0000/001[?000khP00Bn/005S^
005Pm@03HOH00VGi00=XnP03Jo/01Voj00M_o@0200IaoP0300Mbo@07M?h0
1gCn00<01gCn0P06LOh300=bo`@00fkoo`02J_hX009ZoP0Eooooool>D>go
75__obQSl?l_J?3o<f_aocA/lOlaK?;o<Fgbobi_l_lZL?;o9G3coam_lolI
KOCo4f[do`eVm?l7H??o0U[`o`1=h_l0>[Wooooo00800V[n01Goooooo`i@
kOlLFnoo:6?`obmXl?lcJo7o=6caoc5/l_laKO;o;VobobY`l_lUL??o7foc
oaU]m?lCJ_Co3FKdo`MPlol2F_3o04gRo`0j^Oooool00P00H?`05Ooooooo
f3L>om]37?oMC2SogU8_ommE<ooPEcCoh5Daon1F<OoQERkohUDZonAC9OoT
D1ooiD`IonE84ooU@`goi3h7on0h0_oA;`3oZR<0ooooo`02001<l`030017
k`00>>X003;1004001FB00002P007m8003_R001;j`00F>h005ob005Pm@02
IOWoYjNWoj>RXonRXZ82oj6QX@03oj2PX?nUWYGoZYb900;oWinO0_nPX:02
oj6QX@04ojNWY`03K_l00Fcn005/oP@00V[n00<01eSS00XHP`07F><01002
J_h200XHP`800V[n00D01eCN00T`Z00:68<02CVe00ESl`02009ZoP0700IP
k`0:68<01F?c009ZoP05Ho<02QR300IPk`02009ZoP802QR31`02J_h01008
CM<02QR300XHP`08DMT3009ZoP802QR30P02J_h200XHP`800V[n0P0:68<2
009ZoP0900MKi`0:68<02QR3009ZoP05Ho<02DG600XHP`09<:P0257I00<0
0V[n00D01eCN00T`Z00:68<02CVe00ESl`02009ZoP0900IMj`09<:P01eSS
009ZoP07E=h02C2X00XHP`09>KD01F?c00800V[n00D01eCN00Ti]@0:68<0
2CVe00ESl`02009ZoP0300MKi`0:68<02QR300L00V[n00L024gC00XHP`05
IOL00V[n00EUm`0:68<024gC00@00V[n0P0:68<2009ZoP802QR30P02J_h2
00XHP`<00V[n00<02DG600XHP`09>KD00P0:68<2009ZoP0400Q=d`0:68<0
2QR300QAf@<00V[n00L01V3_00XHP`05Ho<00V[n00ESl`0:68<01V3_04X0
0V[nB@00IOd05Ooooooo55KcobERm?laJoCo>G7docedmOlmM?Ko>gGeocUf
mOlgMoGo<WSfobahmolUMoOo7gKgoaUbmolAK_So2fSgo`EPm?l2DnKo0Cfn
ooooo`02001Uo@0aoooooolDE_?o9F;doc5[m?liLOCo?GCeocedm_lkMOGo
>GKeocMgmOlbN?Ko;7SgobEgmolOM_Oo6G;goa5^n?l;J?Oo1F3do`9Ci_l1
?Kkooooo001Po000G?Woooooomdl5?oPBbGohE@aon=K>OoTGSgoi5lmonAN
>ooUGSWoiEhgonIM<_oWFbcoj5LUonUD7ooYD1WojDXAonQ42ooT?@GoeS<2
ojlV0Oooool004cc0017k`00A^X003SZ000aaP01000ETP0000T002?F000k
h000BnL005S[001OlP01H?EU0S^Eoi^KVon/[:`00ooYjNT02ooZj^[ohlIj
omUj5?o/k>cokNg]onk^k_oaimGol?3`oo;bl_nSXj<00V[n00800F[j0P00
IOd01@01I?T0/m3m0?ooo`2e^]T024K:00<00FCi0P3oool04P0:68<00FCi
0;oAm@3hn?/0oooo0?7eo@20U=4024gE005Tn@2=^O`0oooo0868_`08CMD0
O:ok0?ooo`2AUlL024W@005Tn@80oooo00<02QR3005Tn@01I?T01001I?T0
1`3Ag_L0oooo0?ooo`38fOL02QR300Q=e@01I?T00P3oool01P0:68<00FCi
0?ooo`3oool02QR3005Tn@80oooo00<02QR3005Tn@2WbO`00P3oool08`01
I?T0O:ok0>;Yn@3oool0n?[n0<SKn`0:68<024W@005Tn@2odOD0n?Sk0?oo
o`3amOd0P9CA00Q=e@01I?T0Vl;l0?Sio02e^]T00FCi0;oAm@3hn?/0oooo
0?7eo@20U=4024gE005Tn@2odOD0lO;h0?ooo`3`m_h0P:3S00Q=e@01I?T0
YlWl0080oooo1`01I?T0203@h_d0oooo06if]@06E^<0JJ?k0?ooo`3Be>P0
2CNc0`01I?T20?ooo`0600XHP`01I?T0oooo0?ooo`0:68<00FCi0P3oool0
1P0:68<00FCi005Tn@3RjOT0oooo0?7eo@80oooo00<02QR3005Tn@3Ag_L0
0P3oool03038fOL02QR300Q=e@01I?T0SKWl0?ooo`21R;l024gE07b_n`3o
ool0TIO700Q9d4X00FCiB@00H?`01Ooooooo65WcobiXm?ljLOCo@WOe00L0
oooo00Wo:WchobAjn?lMMoSo5G?ho`i/n?l9HoCo1EKWo`8o_oooool00P00
H?`01Ooooooo65WcobiXm?ljLOCo@WOe00/0oooo01co3Vcho`USm?l5E^Oo
0Snoooooo`00G?T005WhoooooooN@1SohE4^on=L>_oTHT;omL6eoooooooV
ID?oiVE1onIT?OoWHSSoj60bonUL:_oZFBCoooooooNhXOoYB0koiD09omLf
1On`9`;ooooo0P00Anl00`00@NP003SZ000/b001000ETP0000@002?F000k
h000A^X0057[0P00Go801@01H?GoX:2Pon[Zj_oYjNWon^RY00;oj^[Z00Wo
n>DHoleW0?o]kNgok^k^ooJX<oofcXcol_;boo?clonSXj<00P02IOT2005T
n@80063i00@0fNOn0?ooo`3Jg>`02QR30`00H?T20?ooo`0700XHP`2me_d0
oooo0;o3g`2bcod0n?[n0<OLo@02001Pn@090=7Qo03oool0bLcS00T]YP37
g?d0oooo0=;Dj00:68<015_b0080oooo00<02QR3001Pn@00H?T00`00H?T0
2037g?d0oooo0:Z_e02bcod0oooo0<W<h`09;JH0063i0P3oool01P0:68<0
063i0?ooo`3oool02QR3001Pn@80oooo01<02QR3001Pn@3hn_h0oooo00XH
P`00H?T0d>7m0>WaoP00H?T0O:gk0?ooo`3Be>P02QR30;gFo@3oool0_l?O
0;;?o@3hn_h0amcm0080063i0100n?[n0?ooo`0:68<0_MKm0?ooo`2o`ml0
//om0?SjoP37g?d0063i0;gFo@3oool0_l?O001Pn@3Iioh0amcm0P00H?T0
0`3hn_h0oooo00XHP`07001Pn@090?7eoP3oool0ZZoD00Q7d02Wb?`0oooo
0?7bn00:68<015_b0080063i0P3oool01P0:68<0063i0?ooo`3oool02QR3
001Pn@80oooo00H02QR3001Pn@3@hOd0oooo0;Fjf@00H?T20?ooo`0B00XH
P`37g?d0oooo0:Z_e02bcod0oooo0<W<h`09;JH0063i0=7Qo03oool0bLcS
00T]YP37g?d0oooo0=;Dj00:68<015_bTP00H?T01Ooooooo7UgcocI^m?m2
M_GoBG_e00L0oooo00Wo;GggobEjn?lNMoSo5g?hoa5]mol=I_Co2eWWo`I1
`?ooool00P00H?T07?oooooo7UgcocI^m?m2M_GoBG_e0?oooom:O_OoB7kf
odEom_m1P?Ko>gofocEomol]OOOo9G[hoaign03ooooo4Fggo`eVm?l;FNOo
1T70ooooo`00F?<005GdoooooooOAAkohUPfonAR@_oUIdT3ooooo`05onIX
AOoWId7oif@konQR=OoZGRd00oooool02_oYBQ7oiT@=omLk2ona:`Kooooo
0017k`00A^X0047X000khP00</41000ETP0001H001oB000kh000A^@005GZ
001Lk000Go9E03nQohn?Son>SXkojNWYom5k0?o:<@3obWIEooog0?o[Z`3o
fiioonFPNOoG@P3ol_;boo?cloodm?CoY:BT0`03HOH3005Pm@<0oooo00@0
2QR300EGi`01H?D00F3e0P3oool00`0:68<0n?[n0?ooo`0500XHP`0606VQ
n@3oool0oooo0?Sio@0:68<0n?Wm0P3oool0101^M[D01dgG0?ooo`3oool3
00XHP`0;00Q3b005FN/00F3e0?SjoP3oool02QR3005Pm@3oool0n?Sk00XH
P`01H?D00P3oool01P0:68<00F3e0?ooo`3oool02QR3005Pm@80oooo00D0
2QR3005Pm@3oool0oooo00XHP`05005Pm@80oooo00<02BfU0?SjoP3oool0
1@0:68<01P01H?D0oooo0?ooo`0:68<0n?[n0?ooo`D02QR300<0n?[n0?oo
o`0:68<01@01H?D20?ooo`0300XHP`01H?D00F3e00@00F3e00H0JJ7i0?oo
o`3oool0dM_c00Te/@3@hOd20?ooo`0406if]@06D^0005[e001Jm@80oooo
00H02QR3001Jm@3oool0oooo00XHP`00F_D20?ooo`0600XHP`00F_D0n?[n
0?ooo`0:68<005[e0P3oool02@0:68<0n?[n0?ooo`0:68<005[e0?ooo`3h
n?/02QR306RMn@020?ooo`030?Sio@0:68<0n?Wm0080oooo00<0KWJe00M9
e`00F_D0T@00F_D01Ooooooo9F;cocecm?m8NoGoCX3f00L0oooo00Wo;Gcg
obIin?lPMoOo6G?goaI_molCJOCo45gXo`Y4_oooool00P00F_D05Ooooooo
9F;cocecm?m8NoGoCX3f0?oooom>POKoBh3fodMom_m2OoKo?7ofocIomol]
O?Oo9WWhob1gm`3ooooo5Vogoa=Ym?l@GNSo2TBoooooo`02001El@06oooo
oooPBbGohehmonEWB?oVK4koiVe@0oooool00ooWJ4;oifDlonQR=P03oooo
o`06onU@6OoXC1Koi4LComPo4?na;@[ooooo0P00@NP00`00>n8002kL000Z
]`01000ETP0000T001oB000mg000A^@005GU001Hj`00G>aN03bIoj>SXooW
i^H00_oZj^X03Ong303od7P0oooU0?okc03of8P0okm:0?ngA03o^U0jomVJ
HOomg03o^Jij00=QmP01H?D00P00F_D01`00Fo80S;Gi0?ooo`3Ri?00oooo
096Ga`07BMD00P00Fo820?ooo`0300XHP`3oool0oooo00@0oooo00/02BbT
0;gDn`3oool0d]S^0?ooo`3Bf>h0oooo0=;HkP3oool0_lSW00T/Y0040?oo
o`040=WVo020VM/02BbT00AGj`80oooo00H02QR3001KlP3oool0oooo00T/
Y000Fo820?ooo`0600XHP`00Fo80oooo0?ooo`0:68<005_b0P3oool01@0:
68<005_b0?ooo`3oool02QR300<005_b00D015O[0=7Kl`3oool0n?Sk00I>
g@060?ooo`0500T/Y000Fo80oooo0?ooo`0:68<01P3oool01009;:@0oooo
0?ooo`0:68<5001KlP80oooo00<02QR3001KlP00Fo801000Fo802P2Wa_X0
oooo0>;Tl03amOd02QR30?7eo@3Ri?00oooo0:Z_e008@l/2001KlP80oooo
00H02QR3001KlP3oool0oooo00XHP`00Fo820?ooo`0600XHP`00Fo80oooo
0?ooo`0:68<005_b0P3oool01@0:68<0oooo0?ooo`0:68<005_b0080oooo
00/02BbT0;gDn`3oool0d]S^0?ooo`3Bf>h0oooo0=;HkP3oool0_lSW00T/
Y019001KlTT005Sc01Goooooob]Vm?m4N?GoCWofoe:2m_mCPoKoDH;fodf1
mom8OoKo@gofocenm_leO?Ko;G[gobIgmolQM?Oo6g7goaQ^molHJ_Co5UoW
o`m7`?ooool00P00F?<07_oooooo:fKdodAhmOm>OoKoDX;f0?oooomAP_Ko
CH7godQom_m3OoKo?GkfocElm_l]N_Oo9WOgob5dm`3ooooo66kgoaQZm?lF
GnOo3dO0ooooo`00EO40057`oooooooQCb_oi6=4onI[C_oWKe;oifmConI^
D@?ooooo013oifDmooooooooooooo_GaonQD8OoXD1_oiddHonA:6?oG@QKo
/S4?ooooo`00@NP0043Q000kh000;]`002Zg0@005I80000G000Pb000>=P0
04KT001Ai@00F>/005c/001Pk_n6QhKo_XiFooWOB?oikT;ok;H0oo_@0?o`
^P3oj[00onVb0?oJR`3ociD0on:o0?ong`3om_3LojBUY@03H?400P00Fo82
001HkP060;gDnP3oool0ZZoD0?ooo`2o`ml02CNg0P00F>h20?ooo`0B00XH
P`3hn_h0oooo00XHP`07BMH0oooo0?Shn`08@/T0n?[m0?Shn`07A<h0n?[n
0?ooo`3hn?/01dC>0?SjoP3hnOd02QR30P3oool03P0:68<0J9cd0>W`o@3h
n_h0KWJe00Q2b@3hn_h0oooo00XHP`06C=X0oooo0?Shn`07A<h005S^0P3o
ool01P0:68<005S^0?ooo`3oool02QR300ABi080oooo00D023^n001HkP3o
ool0oooo00XHP`02001HkP0>06^Fj`3Ri_@0oooo0?ooo`2Y`_<005S^0?Sj
oP3oool02QR300M9eP3oool0n?Sk00Q2b@00F>h20?ooo`0@00XHP`3hn_h0
oooo00XHP`07BMH0oooo0?Shn`08@/T0l?Gn0?ooo`0:68<01dC>001HkP08
?/<01dOB001HkP80oooo00<02QR3001HkP00F>h01000F>h02P3@h?/0oooo
0:Z_e03oool0TIO70?ooo`2Z[m@0oooo0=;Dj009<Zh2001HkP80oooo00H0
2QR3001HkP3oool0oooo00XHP`04D^@20?ooo`0600Pk_P00F>h0n?[n0?oo
o`0:68<01dWF0P3oool04`0:68<0n?[n0?ooo`0:68<01TcJ0?ooo`3hn?/0
1dC>0?Sjo@3hn?/01dC>0?SjoP3oool0n?Sk00M4cP3hn_h0n?Wm00XHP`06
C=X0T@00F>h05Ooooooo<V_dod]mmOmDPoKoEXCgoeF3momBP_KoCH3fodQm
m_m2O?Ko?7[focAhm_l]M_Ko9W?gob5amolLKoKo76gfoaaZm?lLHNKo4TRo
ooooo`02001HkP0EoooooolbJoCoBggeoeB3m_mFQ?L0oooooe:2m_m=P?Ko
B7gfod9lm_llN_Ko=7Sfobefm_lVLoOo8G7g0?oooolLKOKo76[doaaQi_lB
B;oooooo0080057[00Soooooon9D<_oUJD_oig1DonMaE_oXL5GoifmBonI/
C@Gooooo00goieDVonMB8OoVCQcoiTdLon=<7?oFAQco/3<Booooo`00>n80
03_P000ef0008mH002Zg004001>;00005P008<P003SH0016i000DND005GZ
001Hjfd0=HOoU9BDoielB_o7LP3oij@0oooX0?o[]P3ojJX0onR/0?oCP@3o
^T`0on:j0?ojlWOom_KfooShn?nUY:D200=Mk009001Lk000F>/005S[0>W`
o@3oool023^l0?ooo`3Yk_T02QR3008005S[0P3oool04P0:68<0d>3k0?oo
o`2ea^h0WZC>0?ooo`3Ag?@0YlGh0?ooo`39c><015;R0<OJnP3oool0bLcS
00ABhP37f_X0oooo0:Z_e080oooo00`02QR3001Hj`1XW?<0oooo0=;Dj009
:j80am[j0?ooo`2Z_^/0WZC>0?ooo`38eO82001Hj`80oooo00X02QR3001H
j`3oool0oooo082Lg`2@WmD0oooo0>;Xm`04D^8005S[0P3oool200XHP`05
09Zmm`3hnO`0oooo0?7dn`2J_OL00P00F>/01P3@h?/0oooo0;G6kP2NY<h0
oooo0=7Lm08005S[0P3oool0400:68<0d>3k0?ooo`2ea^h0WZC>0?ooo`3A
g?@005S[0;gDn@3oool0b=Kd00Tb[@3Jg>`0_l[Y00I>f`00F>/20?ooo`80
2QR31@00F>/0303amOd0oooo00Pk_03oool0h^Sg0?ooo`08>k`0oooo0?7d
n`0:68<0157T001EjP80oooo00h02QR3001EjP3oool0oooo082Kg`2@WmD0
oooo0>;Wm`04Cn4005GZ0=3On`3oool0]L?Z00XHP`80oooo01<02QR30<OI
nP3oool0Z[g[09jTcP3oool0b=Gb0:O4m`3oool0bLcS00A?h@37fOX0oooo
0<W<h`04Cn40amWj0?ooo`2Z[m@02CFe094005GZ01GoooooocM^m?mAPOKo
EhGgoeV6momGQOOoDX7fodenm_m7NoKo@GWfoc]gmOldM?Go;7;fobI_m_lR
KOKo7V_foamZm_lQJ_?o8F;VoaI9__ooool00P00ENX08?oooooo=fkdoe61
m_mGQOOoFHKg0?oooomBPOKoCGkfodMkm_m1NOKo>gOeocAdmOl/L_Ko9Vof
ob9]mP3ooooo7f[fob5ZlolQH^Ko5TVnooooo`00DN/0057UoooooooSFCOo
ifeAonQbEooXLeWoig5GonI^D_oVJTgoiFM70oooool03_oUEbcoiE<VonE@
8_oUCAkoiDdOon9>8OoFBB7o[cDFooooo`00?M`003[I000ef000:M0002J/
0@004h/0000I000J_000=]80043L001@hP00F>H005WX001LjOnGUiOo]kNg
onc/k?oN]WkofHP0oo;40?o]/@3oj:X0omAe0?nnJ03oo=D0oo_ONOohm_7o
nOWiojFUY@03GN`005c/001Hj`02001Ij0070?ooo`3Ri?001dG?0>7[o03o
ool02QR300I;fP030?ooo`8005GZ0100d=ok0?ooo`3oool0d=ok001EjP3Y
l?d0oooo07bWm000ENX0O:Od0?ooo`1lYo@005GZ07bWm03oool0jO3m0P3o
ool0200:68<005GZ001EjP3oool0n?Sk00T`[@00ENX0d=ok0P3oool00`3@
go/005GZ001EjP030?ooo`8005GZ00L0oooo0=WUn`3hn_h0oooo0>7[o01l
Yo@005GZ00@0oooo00@005GZ0?3eo@3oool0d]CX1@00ENX0103@go/0oooo
0?ooo`3@go/3001EjP80oooo00<02QR3001EjP3@go/00P3oool02P3@go/0
05GZ001EjP00ENX0_M?i0?3eo@3oool0l?Gm09ZlmP00ENX40?ooo`D005GZ
00`0J9[b0?ooo`3Ri?001dG?0>7[o03oool0h^C`00M5c`3Qjo`0oooo06if
]@06BML30?ooo`8005GZ00H0oooo0=WUn`3hn_h0oooo0>7[o01lYo@3001E
jP030>7[o03oool0l?Gm0080oooo00<02QR3001EjP3@go/00P3oool03@3@
go/005GZ0>W`o@3oool0O:Od001EjP1lYo@0oooo07bWm000ENX0O:Od0?oo
o`3Yl?d0TP00ENX05Ooooooo?7;doeV7m_mMR_OoGHWgoeV6momCPOKoCWkf
odMjmOm1N?Go>WCeocAbmOl/KoGo9fceob=Zm_lPJOKo8VSeobEYl_lUH^Ko
6D^nooooo`02001EjP0EoooooollL_CoFHOfoef:momMROL0oooooe>1m_m>
O_KoAg[eod5hmOljM?Go=7;eoba_mOlWK?Go8f[f0?oooolRJ?Go9FWbobER
i_lIBkkooooo008004gS00Soooooon=M??oXM5Woj7MMonQfGOoWLUWoiVmC
onE[CPGooooo00goi54WonA?8ooSC23ohddRon5?9OoEBRGo[cLIooooo`00
>=P003GH000fdP00:M0002Zg004000im000060006[`003KB0010g000B]`0
057U001EiFD0=XcoVIVIojJWY_o]kNgoilZ:olMX0?ob^@3og8T0olYW0?nf
<@3o^e80ooo:0?oo_03onkT0ooNb0?o:Zf000eg/001Lj@8005WX00P0V[ge
0?ooo`2o`ml01T_F0;gCn03oool0WZC>00Q0``8005GU0P09=K8A001Ei@80
oooo00H02QR3001Ei@1nYNh0oooo0?7bn006BmH9001Ei@802CFb2@00END2
0?ooo`0900T`Z`00END0oooo0?ooo`0:68<014oL00E=f@09:Z0023fn00P0
05GU0P3oool00`0:68<005GU001Ei@0=001Ei@80oooo00<02C2[001Ei@00
END00`00END0302Wa?H0oooo0;o3g`06BmH0_M?h0?ooo`2o`ml01T_F0;gC
n03oool0ZZoD00Q0``8005GU0P09=K8=001Ei@80oooo00<02QR3001Ei@00
END0X@00END05OooooooAWWeof2<momRSOSoH8_goe^7momDP_OoCWcfodMh
m_m1M?Go>W7eocA^m?l]JoGo:6WeobAWmOlRI_Go9FOeobUXl_lYHnCo6d^m
ooooo`02001Ei@0Noooooom6NOGoH8cgof:=n?mPRoL0oooooeB2mom>O?Ko
AgSfod5dmOljLOGo=6kdobe[mOlXJOGo96Oe0?oooolUIoGo:FSbobUSi?lK
Bkgooooo001;h`00Bn3oooooonEUA_oXNV3oj7aRonQjH?oXM5_oifiD0ooo
ool04?oSG3[ooooooooooooooooohTdTon9;8_oRCBGoh50YomA<:On^>A_o
oooo000hf000=MP002W@000Pb0009Z`1000>O@0001H001Zl000fdP00@=`0
04[L001Dh`00END005WXoijNWOoShn?ok;9NomZH0?oBO03ogY<0omUl0?oH
N@3o]3@0oj060?o_VP3ooj`0oo[fk?okn?7o]ZR70`00FNP03@00F>H0d>3j
0?ooo`2NY<h0157O09Zlm03oool0d]CX00T`Z`00END0jO3l0>[]n009=K80
4@00END20?ooo`0500XHP`1^M[D0j^cf0?ooo`2L^O002@00END00`3Yl?`0
j^gh00Te/P09001Ei@0:0<OIn@3`mOd005GU001Ei@3Qjo/0oooo082Mh02@
Wm@0n?Sk0=[Rm@T005GU0P3oool00`09:Z0005GU001Ei@0=001Ei@030<OI
n@3`mOd005GU00D005GU0100d=oj0?ooo`2NY<h0157O09Zlm03oool0WZC>
00AAg`2J_?@0oooo0=;Dj009<:/005GU0>W`o03ZkOP02CFb3@00END20?oo
o`0300TZX000END005GU0:4005GU01GoooooodIimOmXT_SoJY?hofF?n?mN
ROOoEh?goe1nm_m:NOKo@gGeoceamOlfK_Co;f_eob]YmOlXIoGo9fKeobYX
mOl/JO;o:V;Toaa<_Oooool00P00END01OooooooAWWeofRBn?mZToSoIHoh
00/0oooo00go:VSeobaYl_lZH^Co74bmooooo`00CN<004_PoooooooUIDKo
jH5XonZ3J_oYOVGoj7MN00?ooooo00?oi653onAM?OoSF3H00oooool02ooR
CROohU0Zon1A;?oCCB[o[CTLooooo`00>=P003KB000Yd0008<P002J/0040
00im00005P006[`003O;000kdP00B]`005?Q001EiE@0?9_oSHf=ogmgKooP
V`3ol?3`onBmV?o/[@3ooml0ooo60?oZY`3o`V00om5e0?ohYbgono_koocl
o?nVYZH2001Ji`8005SV00L0l?Gm0?ooo`1XV^l005GU06RJk`3oool0l?Gm
008005GU0P3Yl?`B001Ei@<0oooo00<0n?[n0=WUn`2</_<02P00END20>W`
o0l005GU00@0d=oj0?SjoP3oool0fNGk2P00END00`3Qjo/0n?[n001Ei@0G
001Ei@0;0?3eo@3oool0J9[_001Ei@1XV^l0oooo06RJk`00END0J9[_0?oo
o`3`mOd00P00END20>W`o0h005GU00<0hN_k0?SjoP00END0FP00ENE9001A
i@0Eoooooom=O_KoKYOhog2In?mZToSoHXchoe^6momDP?OoCG_fodMgm_m0
L_Go>VoeocA]m?l`JoCo;FWdobaYmOl]JOGo;VWbobaSiOlMC;cooooo0080
057U00Goooooodenm_m^UoSoL9WhofZCn00;0?ooo`0<obeYmOl^JO;o;6?U
oae<_?ooool004gS001;h?ooooooiVY=on^7K_o[RW3ojX=Z0oooool01OoU
J4goi6A7onAO@?oSFc[ohUHd00?ooooo00GohU8]ommB;_oCCBco[CXMoooo
o`02000fdP03000/b0008<P002BV004000im00005P006:/00376000odP00
B]P0053P001Dhd@0@ZWoWYjNomGDe?o`l?3ol_;bonS;ZoohdP3om^B7oo?B
SOobXP3oklVAonO5X_oQP@3oo?cloogmoOnVYjL2001Ji`8005SVo`00ENDZ
001Ei@0EoooooomBP_KoNIohogbQn?maVOSoIi7hof2;momIQOOoDh7fodek
m_m6MoGo@G?eocY_m?lhK_Co=6cdoc9/m?laJoCo<6WaobaRi?lMC;cooooo
008005GU00Gooooooe:2m_miWoSoO:7hog6In00;0?ooo`0Loc5[m?l`JO7o
;6;Toae<_?ooool004gS001;h?ooooooifmBonbANOo/TgcojhYaooO<`_oo
ooooig9IonM]DooUJ4goi6A6onAO@OoSFc[oheThoooooooc^jgohUDaommC
<?oCCRco[CXMooooo`8003KB00<002c8000Pb0009Z`00@003Wd0000F000H
Z`00<LH003oB001:f000D>0005CS001Jion6QXKoU9BCoo;bl_oclo?oiZ@0
ooS][_ofm_Kolm^/onZG0?ojn_[ono_koo7J^ooi]Rooo_knojNWY`8005[W
0P00F>Ko001EiBX005GU01GooooooeR6m_n9Z_WoSJgiognSn?maVOSoJY?h
ofB>momNR_OoFHKgoeB2m_mAP?KoBgceodYlmOm4N?Go?gGeocYbm?ldK?;o
:V7SoaQ8^oooool00P00END0;?ooooooF8KfohVZnOn=[OWoOj?hog6In?mZ
ToSoI8kgoej:momIQ_OoE8;foe60m_m;O?GoBWceodAhmOloMOGo>W;docA/
l_lZHN?o64Rkooooo`00CN<004_PoooooooXM5SokYf9onnQSOo]UGoojhYa
onZ3J_oYOFCoj7QNonMcFOoWKeCoiVeAonEXBooUJ4[oi6=4onAP?ooSG3[o
h5Hdom9<:_n/=QSooooo0P00=]800`00;<P00238000V[001000>O@0001<0
01R[000b`@00?L`004OG001CfP00F]mH03^Eoj2PX?oQh>7olo?concWcoob
k=kom_KfooShn?oinOWoiX/0oo_knoolo?cooOgm00;oo_kn00?oYjNW001J
i`00F^L00`00F>I`001EiFl005CSB@00Dn405OooooooII3goiNdnOnJ]o[o
RJ[iogZPn?mbV_SoKIGhofRBn?mUSoOoHXkgof6=momMR_OoFHOfoe:3m_m<
O_Ko@gOeocM^l_lXGn?o5DJiooooo`02001Ch@0/oooooomUT?OoUkCioiZg
n_n9Z_WoNZ3hog:Jn?m]UOSoJ9;hofF?momRS_OoHHggoef:momIQoKoDX?f
odanm_m3MoGo=fkbobQOholEA[Wooooo001@h000Bn3oooooonUoIOo`ZIOo
lJbJonjMROo/TG[ojh]bonZ5KOoYPFSoj7iUonUlH_oYNf7oj7MMonQdFOoV
Ke;oiFY<onAS@ooQFCOodTXXojXc5Oooool2000gb`03000/b0008<P002BV
004000im000010006:/003;1000mc002AM02001CfP03001Jgon=SHgoZZZZ
00KoZZZZ00?o]:J>ojZZZ_nZZZX01?nZZZX2001Ji`<005SVg`00E>=9001C
h@0EoooooomfW?SoT:oioiBbnOn5YoSoMIchofjGn?mXT_OoIY3gof:>momO
S?OoGX_goeV8m_mFQOKoD8;fodUlmOloMOGo<V_bob=Lhol`G<G_iNck0080
05?Q01GoooooogJLn?n@[oWoU;;iohFWn?meW?SoKYOhofRBmomVT?OoHXkg
oen<momNRoOoFHSfoeJ5m_m@P_KoBGceocmemOlbJo;o8ecSoc1LaNoUk?/0
0P00D>006_ooooook8efonnST?o`YYCokYZ5on^=MOoZQfkojX5XonUoI_oY
O6;oj7UOonQiG_oXMEWoig9FonI^D?oUJ4Woi60oon1E<_o@AR?o]T/`knGZ
nP00=l/00376000/b0008[T002BV0@003Wd00004000TYP00</40047:005<
d08005?J00<005[O001Ji000G^L00P00H^T6005Uj`8006;Y00@00F7Z001N
j@00G^L005kW0`00F^L2001HiVl005GUK`00E>=9001Ch@09SfJCjOoLiOgo
Li[hof2<momEQ?KoCGkfodQjmOm2M_GoA7Se00;o?W?e0_lkLOD2oc=/m006
oc1Zm?lXI?Co7eg_ocAWh?oBfo:?IY?Y0P00Dn402HmVTnWog>Gmog>Jn?mP
S?OoEHCfodenm_m8N_Go@WKeodAhm@02ocicm@;o>g7e0_lcK?@04Ol`J_Co
:6CdoamMkoldIn3od]_bSfJCj@00D>80053PSfJAioojhMcojh]conUkH?oW
LEGoiVY=onEVB?oTHD;oi6=400;oi5ln0_oSG3/2on9F<`06on9C<?oPCBSo
g4DOom1C=?o_f=:?IXOO0P00<LH00`00</4002:i000TYP01000>O@000P00
</401000@LX00Dc@001CfP00DmX2001Jg`03001Ni`00H^T006;Y00@00FG[
1000Ind2005Uj`05001Rj@01HNX005kY001Nj@00G>T00P00F^Oo001HiRP0
05SV00<?1E[USfJFjnoUkO/04?ooool01hmVU^/?1E[U001HiP00F>H?1E[U
SfJFjnoUkO/04?ooool01hmVU>/?1EKS001Dh`00D>8?1E;PSfJAinoUk?/0
4?ooool01hmVQml?1C_<000gb`00<LH003;1000Z]`009Z`00@005J000003
000b`@00B]`004_=00<005?J0P00F]l01000G^L006;Y001Rj@01IN/3001W
k@@006Wb1000Ind01001IN/0063^001PkP00H>i`001Lk=l005cY1P00F^L0
0`00F>H005GU001Dh`02001Ch@80053P0P01CM`3001:g0@004[H0P00AmL2
0013d`05000odP00?L`003g<000mc000=l/00P00</41000EX00000<0oooo
0011bP00Bld01000F]l01000G^L006;Y005Uj`00Ind3009/l@T00fke00<0
0Vca00=Xm003J?@00P03J?Co00=UlE@00fGa0P03Hn`01@03HN/00F7Z009M
j@02GNT005[W008005SV0`00END3001Dh`8005?Q0P00D>000`01CM`004[L
001:f0020017e`04001:f000@m<003O;000HZ`40oooo0000103oool0047:
001@hP00DmX2005Uj`<006O]00D00Vca00=^m@03KoX01gCn001co@0200=b
o`0700MdoP00Lod01gCn00MdoP00Lod00g;o00MdoP02001co@0300MdoP06
LOh01g;m0=h00g;oK`01K?h01003L_l00Fcn001co@03L_l4001co@09005Z
nP02IOT00fSd00=Ul@01H?D005ob001Jm@00Go8005_b00800F3e00P005ob
001PkP00H>h0063^001Lk000H>h005ob001EjP8005S[0P00G>`00`00E><0
04?C000mg0010?ooo`000P3oool01@01C=000UgY00IWm002K?401gCn0080
4g[o0P0JP_l20269o`0302N=o`0[T?l0:i3o0080:i3o0`0aU?oo02^@oeD0
:i3o0`0WSOl202^@o`809hgo0`0SQOl00`0WSOl08HWo0269o`030269o`03
02>5o`0QROl08HWo00808HWo1@0JP_l301=jo`801fom00<005Sc000kdP3o
ool00@3oool000<0oooo0P01C=000`06Io@01g;m01=jo`0201Z2o`0402>5
o`0WSOl0<Hco036Do`80>Y7o0P0mUOl903nGog00?IGoK`0oUom`03fEo`D0
?iOo00D0?IGo03ZAo`0mUOl0>Y7o03fEo`0903ZAo`H0<Hco0P0SQOl0100C
N_l01Vcl000odP00<LH30?ooo`001@3oool00`00Bld00Dc@005<d0020017
e`<004[H00/0053P001Ch@00F^@005kW001Ji000G^L00F7Z001Nj@00F^L0
05cY001Nj@03001LjG0005S[K`00F>i_001Ij0@005S[00<005S^001Hj`00
F>/00`00F>/2001Aj`03001Ai@00DN/004_W0080057U00D004_W001Aj`00
Bn/004_W001;h`020016i006001;h`00BnL004_W001;j`00A^X003oB1@3o
ool00001\
\>"], "Text",
  ImageSize->{396, 422},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "There are three buttons to return to the initial notebook: \n",
  StyleBox["[ViewPoint]", "MR"],
  " \[Dash] returns the chosen ",
  StyleBox["ViewPoint", "MR"],
  "\n",
  StyleBox["[Ok]", "MR"],
  " \[Dash] plots the current version of the graphics\n",
  StyleBox["[Cancel]", "MR"],
  " \[Dash] plots graphics with default ",
  StyleBox["ViewPoint", "MR"],
  "."
}], "Text"],

Cell[TextData[{
  "It is important to mention that the function ",
  StyleBox["ViewPointSelect", "MR"],
  " is interactive and it interrupts temporally the computation. If there is \
no action (changes of position of graphics) within 60 seconds, it would \
automatically close the opened window and return the control to the main \
notebook."
}], "Text"],

Cell[TextData[{
  "There is special feature which allows copying the final version of ",
  StyleBox["ViewPoint", "MR"],
  " to the clipboard. The property is controlled by option ",
  StyleBox["CopyToClipboard", "MR"],
  ". To activate it press on the box in the upper-right corner of window. \
This action equivalent to evaluation of the expression:"
}], "Text"],

Cell[BoxData[
    \(SetOptions[ViewPointSelect, CopyToClipboard \[Rule] True]\)], "Input"],

Cell[TextData[{
  "This button has two values so to reactivate option ",
  StyleBox["CopyToClipboard", "MR"],
  " press on this box again."
}], "Text"],

Cell[TextData[{
  "The parameter ",
  StyleBox["$PlotFunctions", "MR"],
  " fixes the plot functions which can be used as arguments of ",
  StyleBox["ViewPointSelect", "MR"],
  ". "
}], "Text"],

Cell[BoxData[
    \($PlotFunctions\)], "Input"],

Cell[TextData[{
  "The expression ",
  StyleBox["Show[Graphics3D[...]]", "MR"],
  " is supported in addition to this list. ",
  StyleBox["$PlotFunctions", "MR"],
  " can be expanded. Next cell demonstartes how new function can be included \
and used:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Needs["\<Graphics`Graphics3D`\>"]\), "\n", 
    \(AppendTo[$PlotFunctions, BarChart3D]\), "\n", 
    \(BarChart3D[{{1, 2, 3}, {4, 5, 6}}] // 
      ViewPointSelect\), "\[IndentingNewLine]", 
    \($PlotFunctions = Most[$PlotFunctions]\)}], "Input"],

Cell[BoxData[
    \({Plot3D, ListPlot3D, ParametricPlot3D, BarChart3D}\)], "Output"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .98733 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0600159 1.12634 1.67482e-016 1.12634 [
[.54493 .00121 0 -6.97768 ]
[.54493 .00121 18 2.02232 ]
[.66341 .07712 0 -6.74638 ]
[.66341 .07712 6 2.25362 ]
[.77007 .14545 0 -6.55458 ]
[.77007 .14545 18 2.44542 ]
[.8666 .2073 0 -6.39295 ]
[.8666 .2073 6 2.60705 ]
[.95438 .26354 0 -6.2549 ]
[.95438 .26354 18 2.7451 ]
[.42002 .0417 -2.95274 -9 ]
[.42002 .0417 3.04726 0 ]
[.26331 .12912 -2.86588 -9 ]
[.26331 .12912 3.13412 0 ]
[.1251 .20622 -2.7916 -9 ]
[.1251 .20622 3.2084 0 ]
[.03758 .26851 -6 -6.42813 ]
[.03758 .26851 0 2.57187 ]
[.02199 .45531 -6 -6.11359 ]
[.02199 .45531 0 2.88641 ]
[.00536 .65521 -6 -5.78092 ]
[.00536 .65521 0 3.21908 ]
[-0.01242 .86964 -6 -5.42848 ]
[-0.01242 .86964 0 3.57152 ]
[ 0 0 0 0 ]
[ 1 .98733 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.52005 0 m
.94959 .27397 L
s
.5326 .008 m
.52643 .0114 L
s
[(0.5)] .54493 .00121 -1 .5506 Mshowa
.65081 .0834 m
.64452 .08655 L
s
[(1)] .66341 .07712 -1 .4992 Mshowa
.75727 .1513 m
.75086 .15423 L
s
[(1.5)] .77007 .14545 -1 .45657 Mshowa
.85362 .21276 m
.84714 .21549 L
s
[(2)] .8666 .2073 -1 .42066 Mshowa
.94126 .26866 m
.9347 .27122 L
s
[(2.5)] .95438 .26354 -1 .38998 Mshowa
.125 Mabswid
.55727 .02374 m
.55356 .02575 L
s
.58142 .03914 m
.57768 .04111 L
s
.60504 .05421 m
.6013 .05615 L
s
.62817 .06896 m
.62441 .07088 L
s
.67299 .09755 m
.66919 .0994 L
s
.6947 .1114 m
.6909 .11323 L
s
.71598 .12497 m
.71216 .12677 L
s
.73683 .13827 m
.733 .14005 L
s
.7773 .16408 m
.77344 .16581 L
s
.79694 .17661 m
.79307 .17831 L
s
.8162 .18889 m
.81232 .19057 L
s
.83509 .20094 m
.83121 .2026 L
s
.87181 .22436 m
.86791 .22598 L
s
.88966 .23575 m
.88575 .23734 L
s
.90718 .24692 m
.90326 .24849 L
s
.92437 .25789 m
.92045 .25944 L
s
.25 Mabswid
.52005 0 m
.05163 .26059 L
s
.4198 .05577 m
.41969 .06281 L
s
[(1)] .42002 .0417 -0.01575 1 Mshowa
.26268 .14318 m
.26237 .15021 L
s
[(2)] .26331 .12912 -0.04471 1 Mshowa
.12413 .22026 m
.12364 .22728 L
s
[(3)] .1251 .20622 -0.06947 1 Mshowa
.125 Mabswid
.38671 .07418 m
.38662 .0784 L
s
.35449 .09211 m
.35437 .09633 L
s
.3231 .10957 m
.32296 .11379 L
s
.29251 .12659 m
.29234 .13081 L
s
.2336 .15936 m
.23338 .16358 L
s
.20522 .17515 m
.20499 .17936 L
s
.17754 .19055 m
.17728 .19477 L
s
.15051 .20558 m
.15024 .2098 L
s
.45378 .03687 m
.45374 .04109 L
s
.4887 .01744 m
.48869 .02167 L
s
.09836 .2346 m
.09805 .23881 L
s
.07319 .2486 m
.07286 .25281 L
s
.25 Mabswid
.05163 .26059 m
0 .88911 L
s
.05053 .27406 m
.057 .27683 L
s
[(0)] .03758 .26851 1 .42847 Mshowa
.03525 .46006 m
.04187 .46244 L
s
[(2)] .02199 .45531 1 .35858 Mshowa
.0189 .65907 m
.02567 .66099 L
s
[(4)] .00536 .65521 1 .28465 Mshowa
.00137 .87248 m
.00826 .8739 L
s
[(6)] -0.01242 .86964 1 .20633 Mshowa
.125 Mabswid
.0468 .31941 m
.05071 .32102 L
s
.04301 .36552 m
.04694 .36706 L
s
.03916 .41239 m
.04311 .41388 L
s
.03126 .50854 m
.03526 .50991 L
s
.02721 .55786 m
.03123 .55915 L
s
.02309 .60802 m
.02713 .60925 L
s
.01463 .71101 m
.01871 .71209 L
s
.01029 .76388 m
.01439 .76489 L
s
.00587 .81769 m
.00999 .81862 L
s
.25 Mabswid
.52005 0 m
.52247 .74893 L
s
.52247 .74893 m
0 .88911 L
s
0 .88911 m
.05163 .26059 L
s
.05163 .26059 m
.52005 0 L
s
.94959 .27397 m
.49152 .45132 L
s
.49152 .45132 m
.49043 .98733 L
s
.49043 .98733 m
1 .89612 L
s
1 .89612 m
.94959 .27397 L
s
.52005 0 m
.52247 .74893 L
s
.52247 .74893 m
1 .89612 L
s
1 .89612 m
.94959 .27397 L
s
.94959 .27397 m
.52005 0 L
s
.05163 .26059 m
.49152 .45132 L
s
.49152 .45132 m
.49043 .98733 L
s
.49043 .98733 m
0 .88911 L
s
0 .88911 m
.05163 .26059 L
s
0 0 m
1 0 L
1 .98733 L
0 .98733 L
closepath
clip
newpath
.5 Mabswid
.621 .783 .959 r
.49197 .45562 m .29965 .37258 L .43156 .31304 L p F P
0 g
s
.621 .783 .959 r
.43156 .31304 m .62297 .40514 L .49197 .45562 L p F P
0 g
s
.866 .655 .615 r
.49096 .96952 m .49197 .45562 L .29965 .37258 L p F P
0 g
s
.515 .367 .618 r
.62297 .40514 m .49197 .45562 L .49096 .96952 L p F P
0 g
s
.515 .367 .618 r
.49096 .96952 m .63439 .94286 L .62297 .40514 L p F P
0 g
s
.882 .661 .599 r
.63439 .94286 m .62297 .40514 L .43156 .31304 L p F P
0 g
s
.621 .783 .959 r
.62297 .40514 m .43156 .31304 L .57894 .24651 L p F P
0 g
s
.621 .783 .959 r
.57894 .24651 m .76801 .34924 L .62297 .40514 L p F P
0 g
s
.882 .661 .599 r
.63233 .84623 m .62297 .40514 L .43156 .31304 L p F P
0 g
s
.515 .367 .618 r
.76801 .34924 m .62297 .40514 L .63233 .84623 L p F P
0 g
s
.866 .655 .615 r
.29965 .37258 m .27959 .92554 L .49096 .96952 L p F P
0 g
s
.473 .322 .596 r
.43156 .31304 m .29965 .37258 L .27959 .92554 L p F P
0 g
s
.621 .783 .959 r
.29965 .37258 m .0722 .27438 L .20307 .2031 L p F P
0 g
s
.621 .783 .959 r
.20307 .2031 m .43156 .31304 L .29965 .37258 L p F P
0 g
s
.866 .655 .615 r
.29009 .63607 m .29965 .37258 L .0722 .27438 L p F P
0 g
s
.473 .322 .596 r
.43156 .31304 m .29965 .37258 L .29009 .63607 L p F P
0 g
s
.445 .812 .995 r
.49096 .96952 m .27959 .92554 L .42407 .89359 L p F P
0 g
s
.445 .812 .995 r
.42407 .89359 m .63439 .94286 L .49096 .96952 L p F P
0 g
s
.515 .367 .618 r
.63233 .84623 m .78992 .81131 L .76801 .34924 L p F P
0 g
s
.9 .668 .578 r
.78992 .81131 m .76801 .34924 L .57894 .24651 L p F P
0 g
s
.621 .783 .959 r
.76801 .34924 m .57894 .24651 L .74468 .1717 L p F P
0 g
s
.621 .783 .959 r
.74468 .1717 m .92948 .287 L .76801 .34924 L p F P
0 g
s
.9 .668 .578 r
.78525 .71288 m .76801 .34924 L .57894 .24651 L p F P
0 g
s
.515 .367 .618 r
.92948 .287 m .76801 .34924 L .78525 .71288 L p F P
0 g
s
.882 .661 .599 r
.43156 .31304 m .42543 .78854 L .63233 .84623 L p F P
0 g
s
.882 .661 .599 r
.43156 .31304 m .42407 .89359 L .63439 .94286 L p F P
0 g
s
.495 .816 1 r
.63233 .84623 m .42543 .78854 L .58585 .74636 L p F P
0 g
s
.495 .816 1 r
.58585 .74636 m .78992 .81131 L .63233 .84623 L p F P
0 g
s
.866 .655 .615 r
.0722 .27438 m .05001 .55811 L .29009 .63607 L p F P
0 g
s
.564 .809 .991 r
.29009 .63607 m .05001 .55811 L .18663 .50111 L p F P
0 g
s
.473 .322 .596 r
.29009 .63607 m .428 .58888 L .43156 .31304 L p F P
0 g
s
.473 .322 .596 r
.27959 .92554 m .42407 .89359 L .43156 .31304 L p F P
0 g
s
.564 .809 .991 r
.18663 .50111 m .428 .58888 L .29009 .63607 L p F P
0 g
s
.473 .322 .596 r
.57894 .24651 m .43156 .31304 L .42543 .78854 L p F P
0 g
s
.882 .661 .599 r
.428 .58888 m .43156 .31304 L .20307 .2031 L p F P
0 g
s
.621 .783 .959 r
.43156 .31304 m .20307 .2031 L .35088 .1226 L p F P
0 g
s
.621 .783 .959 r
.35088 .1226 m .57894 .24651 L .43156 .31304 L p F P
0 g
s
.882 .661 .599 r
.42923 .49394 m .43156 .31304 L .20307 .2031 L p F P
0 g
s
.473 .322 .596 r
.57894 .24651 m .43156 .31304 L .42923 .49394 L p F P
0 g
s
.515 .367 .618 r
.78525 .71288 m .95891 .66837 L .92948 .287 L p F P
0 g
s
.921 .675 .548 r
.95891 .66837 m .92948 .287 L .74468 .1717 L p F P
0 g
s
.9 .668 .578 r
.57894 .24651 m .58437 .63923 L .78525 .71288 L p F P
0 g
s
.9 .668 .578 r
.57894 .24651 m .58585 .74636 L .78992 .81131 L p F P
0 g
s
.534 .814 .998 r
.78525 .71288 m .58437 .63923 L .76314 .58503 L p F P
0 g
s
.534 .814 .998 r
.76314 .58503 m .95891 .66837 L .78525 .71288 L p F P
0 g
s
.882 .661 .599 r
.20307 .2031 m .19231 .39821 L .42923 .49394 L p F P
0 g
s
.882 .661 .599 r
.20307 .2031 m .18663 .50111 L .428 .58888 L p F P
0 g
s
.587 .801 .981 r
.42923 .49394 m .19231 .39821 L .34505 .32773 L p F P
0 g
s
.473 .322 .596 r
.42923 .49394 m .58156 .43608 L .57894 .24651 L p F P
0 g
s
.473 .322 .596 r
.42543 .78854 m .58585 .74636 L .57894 .24651 L p F P
0 g
s
.587 .801 .981 r
.34505 .32773 m .58156 .43608 L .42923 .49394 L p F P
0 g
s
.409 .256 .56 r
.20307 .2031 m .0722 .27438 L .05001 .55811 L p F P
0 g
s
.473 .322 .596 r
.74468 .1717 m .57894 .24651 L .58437 .63923 L p F P
0 g
s
.9 .668 .578 r
.58156 .43608 m .57894 .24651 L .35088 .1226 L p F P
0 g
s
.621 .783 .959 r
.57894 .24651 m .35088 .1226 L .51912 .03097 L p F P
0 g
s
.621 .783 .959 r
.51912 .03097 m .74468 .1717 L .57894 .24651 L p F P
0 g
s
.9 .668 .578 r
.58023 .33969 m .57894 .24651 L .35088 .1226 L p F P
0 g
s
.473 .322 .596 r
.74468 .1717 m .57894 .24651 L .58023 .33969 L p F P
0 g
s
.9 .668 .578 r
.35088 .1226 m .34802 .22324 L .58023 .33969 L p F P
0 g
s
.9 .668 .578 r
.35088 .1226 m .34505 .32773 L .58156 .43608 L p F P
0 g
s
.606 .792 .97 r
.58023 .33969 m .34802 .22324 L .51944 .13686 L p F P
0 g
s
.473 .322 .596 r
.58023 .33969 m .74904 .26943 L .74468 .1717 L p F P
0 g
s
.473 .322 .596 r
.58437 .63923 m .76314 .58503 L .74468 .1717 L p F P
0 g
s
.606 .792 .97 r
.51944 .13686 m .74904 .26943 L .58023 .33969 L p F P
0 g
s
.409 .256 .56 r
.05001 .55811 m .18663 .50111 L .20307 .2031 L p F P
0 g
s
.921 .675 .548 r
.74468 .1717 m .76314 .58503 L .95891 .66837 L p F P
0 g
s
.409 .256 .56 r
.35088 .1226 m .20307 .2031 L .19231 .39821 L p F P
0 g
s
.921 .675 .548 r
.74904 .26943 m .74468 .1717 L .51912 .03097 L p F P
0 g
s
.409 .256 .56 r
.19231 .39821 m .34505 .32773 L .35088 .1226 L p F P
0 g
s
.921 .675 .548 r
.51912 .03097 m .51944 .13686 L .74904 .26943 L p F P
0 g
s
.409 .256 .56 r
.51912 .03097 m .35088 .1226 L .34802 .22324 L p F P
0 g
s
.409 .256 .56 r
.34802 .22324 m .51944 .13686 L .51912 .03097 L p F P
0 g
s
.25 Mabswid
.52005 0 m
.52247 .74893 L
s
.52247 .74893 m
0 .88911 L
s
0 .88911 m
.05163 .26059 L
s
.05163 .26059 m
.52005 0 L
s
.52005 0 m
.52247 .74893 L
s
.52247 .74893 m
1 .89612 L
s
1 .89612 m
.94959 .27397 L
s
.94959 .27397 m
.52005 0 L
s
.52005 0 m
.94959 .27397 L
s
.5326 .008 m
.52643 .0114 L
s
[(0.5)] .54493 .00121 -1 .5506 Mshowa
.65081 .0834 m
.64452 .08655 L
s
[(1)] .66341 .07712 -1 .4992 Mshowa
.75727 .1513 m
.75086 .15423 L
s
[(1.5)] .77007 .14545 -1 .45657 Mshowa
.85362 .21276 m
.84714 .21549 L
s
[(2)] .8666 .2073 -1 .42066 Mshowa
.94126 .26866 m
.9347 .27122 L
s
[(2.5)] .95438 .26354 -1 .38998 Mshowa
.125 Mabswid
.55727 .02374 m
.55356 .02575 L
s
.58142 .03914 m
.57768 .04111 L
s
.60504 .05421 m
.6013 .05615 L
s
.62817 .06896 m
.62441 .07088 L
s
.67299 .09755 m
.66919 .0994 L
s
.6947 .1114 m
.6909 .11323 L
s
.71598 .12497 m
.71216 .12677 L
s
.73683 .13827 m
.733 .14005 L
s
.7773 .16408 m
.77344 .16581 L
s
.79694 .17661 m
.79307 .17831 L
s
.8162 .18889 m
.81232 .19057 L
s
.83509 .20094 m
.83121 .2026 L
s
.87181 .22436 m
.86791 .22598 L
s
.88966 .23575 m
.88575 .23734 L
s
.90718 .24692 m
.90326 .24849 L
s
.92437 .25789 m
.92045 .25944 L
s
.25 Mabswid
.05163 .26059 m
0 .88911 L
s
.05053 .27406 m
.057 .27683 L
s
[(0)] .03758 .26851 1 .42847 Mshowa
.03525 .46006 m
.04187 .46244 L
s
[(2)] .02199 .45531 1 .35858 Mshowa
.0189 .65907 m
.02567 .66099 L
s
[(4)] .00536 .65521 1 .28465 Mshowa
.00137 .87248 m
.00826 .8739 L
s
[(6)] -0.01242 .86964 1 .20633 Mshowa
.125 Mabswid
.0468 .31941 m
.05071 .32102 L
s
.04301 .36552 m
.04694 .36706 L
s
.03916 .41239 m
.04311 .41388 L
s
.03126 .50854 m
.03526 .50991 L
s
.02721 .55786 m
.03123 .55915 L
s
.02309 .60802 m
.02713 .60925 L
s
.01463 .71101 m
.01871 .71209 L
s
.01029 .76388 m
.01439 .76489 L
s
.00587 .81769 m
.00999 .81862 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[5]:=",
  ImageSize->{271.625, 268.125},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004?000131000`40O003h00Oogoo47oo003oOol@
Ool00?mooa1oo`00ogoo47oo003oOol@Ool00?mooa1oo`00UWoo0P0017oo0P0017oo0P00Jgoo002E
Ool01000Oomoo`0027oo00@007ooOol006Yoo`00UGoo00@007ooOol000]oo`03001oogoo06Qoo`00
UGoo00@007ooOol000Uoo`8006]oo`00UGoo00@007ooOol000Uoo`03001oogoo06Yoo`00SGoo00<0
07ooOol01Woo0P002Woo0`00JWoo002;Ool5001oOol008Uoo`80009oo`03001oogoo008007eoo`00
LWoo1@0047oo0P0017oo00<007oo00000`00O7oo001dOol00`00Oomoo`0?Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool2001jOol007Aoo`03001oogoo00eoo`8000Moo`03001oogoo00Eoo`03001oogoo
07Moo`00M7oo00<007ooOol02goo0P0000=oo`00Ool01Woo00<007ooOol01Woo0P00Mgoo001dOol0
0`00Oomoo`09Ool2000;Ool00`00Oomoo`06Ool00`00Ool0001fOol007=oo`8000Uoo`8000eoo`03
001oogoo00Uoo`8007Aoo`00OGoo00<007ooOol02goo1@002goo00<007ooOol0LGoo001kOol2000<
Ool20002=A400`00M[5f/@02000:Ool2001aOol007Uoo`800003Ool007oo00Uoo`8000@e4@03001f
/GJa009f/@03001oogoo00Moo`04001oo`00001_Ool007Moo`8000aoo`8000He4@03001f/GJa00=f
/@8000]oo`03001oogoo06aoo`00MWoo00<007ooOol02goo00<003DA=A401SDA00<007JaM[401GJa
00<007ooOol02Goo0P00K7oo001dOol2000<Ool20009=A400`00M[5f/@06M[42000;Ool00`00Oomo
o`1YOol0079oo`<000]oo`8000/e4@03001f/GJa00Qf/@8000Qoo`04001oo`00000=Ool5001GOol0
071oo`80009oo`03001oogoo00Moo`8000de4@03001f/GJa00Yf/@03001oogoo00Uoo`03001oogoo
00aoo`03001oogoo05Moo`00KWoo0P0037oo0P003cDA00<007JaM[402gJa0P002Woo0P0037oo00<0
07ooOol0Egoo001]Ool00`00Oomoo`0;Ool00`00=A4e4@0?=A400`00M[5f/@0=M[400`00Oomoo`08
Ool3000:Ool00`00Oomoo`1GOol006]oo`8000aoo`80018e4@03001f/GJa00if/@8000]oo`03001o
ogoo00Moo`03001oogoo05Moo`00JGoo0`002goo0P0053DA00<007JaM[4047Ja0P002Woo0P001Woo
0P00FGoo001WOol2000<Ool2000F=A400`00M[5f/@0BM[400`00Oomoo`09Ool00`00Oomoo`1NOol0
06Ioo`03001oogoo00]oo`03000e4CDA01He4@03001f/GJa01=f/@8000Qoo`@005ioo`00I7oo0P00
37oo0P006CDA00<007JaM[405GJa00<007ooOol02Goo00<007ooOol0Fgoo001ROol2000<Ool2000K
=A400`00M[5f/@0FM[42000:Ool2001KOol004Yoo`@0019oo`800003Ool007oo00Uoo`8001de4@03
001f/GJa01Qf/@8000Yoo`8005Uoo`00BWoo00<007ooOol04Goo0P0037oo0P007cDA00<007JaM[40
6WJa00<007ooOol01Woo00@007ooOol005Qoo`00Bgoo00<007ooOol03goo00<007ooOol02goo00<0
03DA=A407cDA00<007JaM[406gJa0P002Woo0P00EWoo001<Ool00`00Oomoo`0<Ool2000<Ool2000R
=A400`00M[5f/@0MM[42000:Ool00`00Oomoo`1COol004Yoo`04001oogoo000;Ool3000;Ool2000T
=A400`00M[5f/@0OM[400`00Oomoo`07Ool3001COol004]oo`8000Yoo`8000aoo`8002He4@03001f
/GJa021f/@8000Yoo`03001oogoo051oo`00EWoo00<007ooOol02Woo0P00:3DA00<007JaM[408WJa
00<007ooOol027oo0P00D7oo001DOol2000<Ool00`00=A4e4@0X=A400`00M[5f/@0SM[42000:Ool2
001>Ool0059oo`8000aoo`<002Xe4@03001f/GJa02Ef/@8000Moo`04001oogoo000<Ool50002Ool2
0004Ool2000bOol0051oo`800003Ool007oo00Uoo`80008e4@03000e4CDA02Pe4@03001f/GJa02Mf
/@03001oogoo00Qoo`8000aoo`03001oogoo00Moo`04001oogoo000aOol004ioo`8000aoo`8000@e
4@03000e4CDA02Pe4@03001f/GJa02Qf/@8000Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001o
ogoo02moo`00CGoo00<007ooOol02Woo0P001SDA00<003DA=A409SDA1@00:WJa00<007ooOol01goo
0`002Goo00<007ooOol027oo0P00<Woo001;Ool2000;Ool20008=A400`00=A4e4@0T=A420002Ccl0
0`00Ccm??`02000YM[42000:Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0aOol004Uo
o`800003Ool007oo00Qoo`8000Xe4@03000e4CDA028e4@8000A??`03001??dlo009??`8002Uf/@80
00Uoo`8000Eoo`8000Yoo`<0035oo`00Agoo0P000goo00<007ooOol01Goo0P0033DA00<003DA=A40
83DA0P001Tlo00<004loCcl014lo00<007JaM[40:7Ja00<007ooOol027oo0P00@goo0016Ool00`00
Oomoo`09Ool2000>=A400`00=A4e4@0N=A420008Ccl00`00Ccm??`05Ccl2000YM[420006Ool20002
Ool00`00Oomoo`10Ool004Aoo`8000Yoo`80010e4@03000e4CDA01`e4@8000Y??`03001??dlo00M?
?`8002Uf/@03001oogoo00Qoo`80041oo`00@Woo0`002Woo00<003DA=A4043DA00<003DA=A406SDA
0P0034lo00<004loCcl02Dlo0P00:7Ja0P002Woo00<007ooOol0?Goo0010Ool2000;Ool2000C=A40
0`00=A4e4@0H=A42000>Ccl00`00Ccm??`0;Ccl00`00M[5f/@0WM[420007Ool01000Ool00000?Goo
000nOol2000;Ool2000E=A400`00=A4e4@0F=A42000@Ccl00`00Ccm??`0<Ccl2000YM[400`00Oomo
o`08Ool00`00Oomoo`0jOol002Qoo`8001=oo`03001oogoo00Uoo`8001He4@03000e4CDA01De4@80
019??`03001??dlo00i??`8002Mf/@<000Uoo`8003Yoo`009goo00@007ooOol0011oo`<000Uoo`80
01Pe4@03000e4CDA01<e4@8001A??`03001??dlo011??`03001f/GJa02Af/@04001f/GJa0008Ool0
1000Ool00000>7oo000YOol00`00Oomoo`0=Ool2000:Ool2000J=A400`00=A4e4@0A=A42000FCcl0
0`00Ccm??`0ACcl2000TM[401000M[5f/GJa0P002Woo00<007ooOol0=Goo000ZOol00`00Oomoo`0:
Ool2000:Ool2000L=A400`00=A4e4@0?=A42000HCcl00`00Ccm??`0CCcl2000RM[400`00M[5f/@03
M[420009Ool2000eOol002Moo`04001oogoo000;Ool00`00Oomoo`08Ool2000N=A400`00=A4e4@0=
=A42000JCcl00`00Ccm??`0ECcl2000PM[400`00M[5f/@05M[400`00Oomoo`06Ool3000<Ool4000T
Ool002Qoo`8000Yoo`<000Qoo`80020e4@03000e4CDA00/e4@8001a??`03001??dlo01M??`03001f
/GJa01ef/@03001f/GJa00If/@8000Uoo`8000Yoo`03001oogoo02Eoo`00<Woo0P002Goo0P008SDA
00<003DA=A402CDA0P007Tlo00<004loCcl064lo0P007GJa00<007JaM[4027Ja00<007ooOol027oo
00<007ooOol027oo00<007ooOol097oo000`Ool2000:Ool00`00=A4e4@0R=A400`00=A4e4@07=A42
000PCcl00`00Ccm??`0JCcl2000KM[400`00M[5f/@09M[420008Ool30009Ool00`00Oomoo`0SOol0
02ioo`8000Yoo`<002@e4@03000e4CDA00De4@80029??`03001??dlo01a??`8001Uf/@03001f/GJa
00]f/@03001oogoo00Qoo`8000Eoo`04001oogoo000TOol002eoo`03001oo`0000Qoo`80008e4@03
000e4CDA028e4@03000e4CDA00<e4@8002A??`03001??dlo01i??`03001f/GJa01If/@03001f/GJa
00af/@8000Yoo`03001oogoo00=oo`8002Eoo`00:goo0P002Goo0P0013DA00<003DA=A408SDA00@0
03DA=A4e4@8002I??`03001??dlo01m??`8001If/@03001f/GJa00if/@8000Moo`@002Yoo`00:Goo
0P002Goo0P001SDA00<003DA=A408SDA00@003DA000002Q??`03001??dlo025??`8001Af/@03001f
/GJa011f/@03001oogoo00Qoo`03001oogoo02Moo`009goo0P002Goo0P0023DA00<003DA=A408SDA
0P00:Tlo00<004loCcl08dlo0P004gJa00<007JaM[4047Ja0P002Goo0P009goo000VOol00`00Ool0
0008Ool00`00=A4e4@08=A400`00=A4e4@0R=A43000YCcl00`00Ccm??`0UCcl00`00M[5f/@0@M[40
0`00M[5f/@0BM[400`00Oomoo`06Ool3000VOol002Aoo`8000Uoo`8000/e4@03000e4CDA028e4@03
001b/W:b008002M??`03001??dlo02I??`80011f/@03001f/GJa01=f/@8000Uoo`8002Aoo`008Woo
0P002Goo0P003CDA00<003DA=A408SDA00<007:bL[800W:b0P009Dlo00<004loCcl0:4lo0P003WJa
00<007JaM[405GJa00<007ooOol027oo0P008Woo000POol30008Ool2000?=A400`00=A4e4@0R=A40
0`00L[9b/P04L[82000SCcl00`00Ccm??`0ZCcl00`00M[5f/@0;M[400`00M[5f/@0FM[420008Ool0
0`00Ool0000QOol001ioo`8000Uoo`80010e4@8002@e4@03001b/W:b00Ib/P80025??`03001??dlo
02]??`8000]f/@03001f/GJa01Qf/@03001oogoo00Qoo`8001moo`007Goo00<007ooOol01goo0P00
4SDA0P0093DA00<007:bL[8027:b0P007dlo00<004loCcl0;Dlo0P002GJa00<007JaM[406GJa0P00
2Woo00<007ooOol02Woo10000goo0P0017oo0P000goo000>Ool2000;Ool20009Ool00`00=A4e4@0B
=A42000T=A400`00L[9b/P0:L[82000MCcl00`00Ccm??`0_Ccl20007M[400`00M[5f/@0KM[420007
Ool01000Ool000002Woo00<007ooOol02Goo00@007ooOol0009oo`003Goo00@007ooOol000Qoo`<0
00Qoo`8001De4@03000e4CDA02<e4@03001b/W:b00ab/P8001]??`03001??dlo035??`03001f/GJa
00Af/@03001f/GJa01ef/@03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00]oo`40005oo`5o
o`003Goo00@007ooOol000Ioo`8000Uoo`8001Le4@03000e4CDA02<e4@03001b/W:b00ib/P8001U?
?`03001??dlo039??`8000Af/@03001f/GJa01if/@8000Uoo`8000Uoo`03001oogoo00Qoo`8000=o
o`003Goo00@007ooOol000Eoo`8000Qoo`8001Te4@03000e4CDA02<e4@03001b/W:b011b/P8001M?
?`03001??dlo03A??`80009f/@03001f/GJa021f/@03001oogoo00Eoo`03001oogoo008000Eoo`04
001oogoo0009Ool00`00Oomoo`02Ool000eoo`04001oogoo0005Ool01000Ool0000017oo0P006cDA
00<003DA=A408cDA00<007:bL[804W:b0P005Dlo00<004loCcl0=Tlo0`008gJa0P002Woo00<007oo
Ool00goo0P002Woo0`000Woo000>Ool20006Ool01000Oomoogoo10007CDA00<003DA=A408cDA00<0
07:bL[8057:b0P004dlo00<004loCcl0=dlo0P009GJa00<007ooOol027oo0P0057oo000FOol00`00
Oomoo`02Ool00`00=A4e4@0M=A400`00=A4e4@0S=A400`00L[9b/P0FL[82000ACcl00`00Ccm??`0e
Ccl200000ceC001f/@0UM[420006Ool200000goo0000000COol001Ioo`8000=oo`03000e4CDA01de
4@03000e4CDA02<e4@03001b/W:b01Qb/P8000m??`03001??dlo03=??`8000<mD`03001f/GJa02If
/@8000Eoo`800003Ool007oo019oo`005Woo00<007ooOol00Woo00<003DA=A407CDA00<003DA=A40
8cDA00<007:bL[806W:b0P003Dlo00<004loCcl0<4lo0`001CeC00<007JaM[40:7Ja00<007oo0000
0P000goo00<007ooOol04Goo000FOol00`00Oomoo`02Ool00`00=A4e4@0M=A400`00=A4e4@0S=A40
0`00L[9b/P0LL[82000;Ccl00`00Ccm??`0^Ccl20008?E<00`00M[5f/@0YM[420005Ool00`00Oomo
o`0AOol001Eoo`03001oogoo00=oo`03000e4CDA01de4@03000e4CDA02<e4@03001b/W:b01ib/P80
00U??`03001??dlo02]??`<000XmD`03001f/GJa02]f/@03001oogoo009oo`03001oogoo015oo`00
5Goo00<007ooOol00goo00<003DA=A407CDA00<003DA=A408cDA00<007:bL[8087:b0P001dlo00<0
04loCcl0:Dlo0P003CeC00<007JaM[40:gJa00<007ooOol00Woo00<007ooOol04Goo000EOol00`00
Oomoo`03Ool00`00=A4e4@0M=A400`00=A4e4@0S=A400`00L[9b/P0RL[820005Ccl00`00Ccm??`0W
Ccl2000??E<00`00M[5f/@0[M[400`00Oomoo`02Ool00`00Oomoo`0AOol001Eoo`03001oogoo009o
o`03000e4CDA01he4@03000e4CDA02<e4@03001b/W:b02Ab/P8000=??`03001??dlo02A??`<0014m
D`03001f/GJa02]f/@03001oogoo00=oo`03001oogoo011oo`005Goo00<007ooOol00Woo00<003DA
=A407SDA00<003DA=A408cDA00<007:bL[809W:b0P0000=??`00Ccl08dlo0P0053eC00<007JaM[40
:gJa00<007ooOol00goo00<007ooOol047oo000EOol00`00Oomoo`02Ool00`00=A4e4@0N=A400`00
=A4e4@0S=A400`00L[9b/P0XL[82000QCcl3000F?E<00`00M[5f/@0[M[400`00Oomoo`03Ool00`00
Oomoo`0@Ool001Eoo`03001oogoo009oo`03000e4CDA01he4@03000e4CDA02<e4@03001b/W:b02Ub
/P<001e??`8001TmD`03001f/GJa02]f/@03001oogoo00=oo`03001oogoo011oo`005Goo00<007oo
Ool00Woo00<003DA=A407CDA0P009CDA00<007:bL[80:G:b00<007:bL[800P006Dlo0P006ceC00<0
07JaM[40;7Ja00<007ooOol00Woo00<007ooOol047oo000EOol20003Ool00`00=A4e4@0M=A42000U
=A400`00L[9b/P0YL[800`00L[9b/P02L[82000DCcl3000M?E<00`00M[5f/@0/M[400`00Oomoo`02
Ool00`00Oomoo`0@Ool001Eoo`03001oogoo009oo`03000e4CDA01de4@8002De4@03001b/W:b02Ub
/P03001b/W:b00Ab/P80011??`80020mD`03001f/GJa02af/@03001oogoo009oo`03001oogoo011o
o`005Goo00<007ooOol00Woo00<003DA=A407CDA0P0093DA0`00:W:b00<007:bL[801W:b0P002dlo
0`008ceC00<007JaM[40:gJa00<007ooOol00Woo00<007ooOol047oo000EOol00`00Oomoo`02Ool0
0`00=A4e4@0M=A42000R=A420003Bcl2000XL[800`00L[9b/P08L[820007Ccl2000V?E<00`00M[5f
/@0[M[400`00Oomoo`02Ool00`00Oomoo`0@Ool001Aoo`03001oogoo00=oo`03000e4CDA01de4@80
020e4@8000M;?`8002Ib/P03001b/W:b00Yb/P8000=??`8002PmD`03001f/GJa02]f/@03001oogoo
009oo`03001oogoo011oo`0057oo00<007ooOol00goo00<003DA=A407CDA0P007SDA0P002d/o0P00
97:b00<007:bL[8037:b0`00:SeC00<007JaM[40:gJa00<007ooOol00Woo00<007ooOol047oo000D
Ool00`00Oomoo`03Ool00`00=A4e4@0M=A42000L=A42000?Bcl2000RL[800`00L[9b/P0=L[800`00
?E<mD`0Y?E<00`00M[5f/@0[M[400`00Oomoo`02Ool00`00Oomoo`0@Ool001Aoo`03001oogoo009o
o`03000e4CDA01he4@8001Xe4@8001=;?`80021b/P03001b/W:b00eb/P03000mDceC02TmD`03001f
/GJa02]f/@03001oogoo00=oo`03001oogoo00moo`0057oo00<007ooOol00Woo00<003DA=A407SDA
00<003DA=A405SDA0`005d/o0P007W:b00<007:bL[803G:b00<003eC?E<0:CeC00<007JaM[40:gJa
00<007ooOol00goo00<007ooOol03goo000DOol00`00Oomoo`02Ool00`00=A4e4@0N=A400`00=A4e
4@0D=A42000LBcl3000KL[800`00L[9b/P0=L[800`00?E<mD`0Y?E<00`00M[5f/@0[M[400`00Oomo
o`03Ool00`00Oomoo`0?Ool001Aoo`03001oogoo009oo`03000e4CDA01he4@03000e4CDA018e4@80
025;?`8001Ub/P03001b/W:b00eb/P03000mDceC02TmD`03001f/GJa02]f/@03001oogoo00=oo`03
001oogoo00moo`0057oo00<007ooOol00Woo00<003DA=A407SDA00<003DA=A4043DA0P009D/o0P00
5g:b00<007:bL[803G:b00<003eC?E<0:CeC00<007JaM[40:gJa00<007ooOol00goo00<007ooOol0
3goo000DOol20003Ool00`00=A4e4@0N=A400`00=A4e4@0>=A42000YBcl2000EL[800`00L[9b/P0=
L[800`00?E<mD`0Y?E<00`00M[5f/@0[M[400`00Oomoo`03Ool00`00Oomoo`0?Ool001Aoo`03001o
ogoo009oo`03000e4CDA01he4@03000e4CDA00`e4@8002e;?`8001=b/P03001b/W:b00eb/P03000m
DceC02TmD`03001f/GJa02af/@03001oogoo009oo`03001oogoo00moo`0057oo00<007ooOol00Woo
00<003DA=A407SDA00<003DA=A402CDA0`00<D/o0P004W:b00<007:bL[8037:b00<003eC?E<0:CeC
00<007JaM[40;7Ja00<007ooOol00Woo00<007ooOol03goo000DOol00`00Oomoo`02Ool00`00=A4e
4@0N=A400`00=A4e4@07=A42000fBcl2000@L[800`00L[9b/P0<L[800`00?E<mD`0Y?E<00`00M[5f
/@0/M[400`00Oomoo`02Ool00`00Oomoo`0?Ool001=oo`03001oogoo00=oo`03000e4CDA01he4@03
000e4CDA00De4@8003Y;?`<000eb/P03001b/W:b00ab/P03000mDceC02TmD`03001f/GJa02af/@03
001oogoo009oo`03001oogoo00moo`004goo00<007ooOol00goo00<003DA=A407SDA00<003DA=A40
0cDA0P00?d/o0P002g:b00<007:bL[8037:b00<003eC?E<0:CeC00<007JaM[40;7Ja00<007ooOol0
0Woo00<007ooOol03goo000COol00`00Oomoo`03Ool00`00=A4e4@0M=A420003=A420013Bcl20009
L[800`00L[9b/P0<L[800`00?E<mD`0Y?E<00`00M[5f/@0/M[400`00Oomoo`02Ool00`00Oomoo`0?
Ool001=oo`03001oogoo009oo`03000e4CDA01he4@800003=A40000004M;?`8000Mb/P03001b/W:b
00ab/P03000mDceC02TmD`03001f/GJa02af/@03001oogoo00=oo`03001oogoo00ioo`004goo00<0
07ooOol00Woo00<003DA=A407SDA0`00Bd/o0P001G:b00<007:bL[8037:b00<003eC?E<0:CeC00<0
07JaM[40;7Ja00<007ooOol00goo00<007ooOol03Woo000COol00`00Oomoo`02Ool00`00=A4e4@0N
=A400`00L[=b/`02001;Bcl20003L[800`00L[9b/P0<L[800`00?E<mD`0Y?E<00`00M[5f/@0/M[40
0`00Oomoo`03Ool00`00Oomoo`0>Ool001=oo`03001oogoo009oo`03000e4CDA01he4@03001b/g:c
009b/`<004Y;?`800003L[8007:b00eb/P03000mDceC02TmD`03001f/GJa02af/@03001oogoo00=o
o`03001oogoo00ioo`004goo00<007ooOol00Woo00<003DA=A407SDA00<007:cL[<01G:c0P00BT/o
0`003G:b00<003eC?E<0:CeC00<007JaM[40;7Ja00<007ooOol00goo00<007ooOol03Woo000COol2
0003Ool00`00=A4e4@0N=A400`00L[=b/`07L[<30018Bcl01000Bcl000002g:b00<003eC?E<0:CeC
00<007JaM[40;7Ja00<007ooOol00goo00<007ooOol03Woo000COol00`00Oomoo`02Ool00`00=A4e
4@0N=A400`00L[=b/`0:L[<20016Bcl01000Bcm;?d/o0P002G:b00<003eC?E<0:CeC00<007JaM[40
;7Ja00<007ooOol00goo00<007ooOol03Woo000COol00`00Oomoo`02Ool00`00=A4e4@0N=A400`00
L[=b/`0<L[<30013Bcl00`00Bcm;?`03Bcl20007L[800`00?E<mD`0Y?E<00`00M[5f/@0/M[400`00
Oomoo`03Ool00`00Oomoo`0>Ool001=oo`03001oogoo009oo`03000e4CDA01he4@03001b/g:c00mb
/`80045;?`03001;?d/o00E;?`8000Eb/P03000mDceC02TmD`03001f/GJa02ef/@03001oogoo009o
o`03001oogoo00ioo`004goo00<007ooOol00Woo00<003DA=A407SDA00<007:cL[<04G:c0`00?T/o
00<004/oBcl01d/o0P000g:b00<003eC?E<0:CeC00<007JaM[40;GJa00<007ooOol00Woo00<007oo
Ool03Woo000BOol00`00Oomoo`03Ool00`00=A4e4@0N=A400`00L[=b/`0DL[<2000lBcl00`00Bcm;
?`09Bcl200000g:b000mD`0[?E<00`00M[5f/@0/M[400`00Oomoo`02Ool00`00Oomoo`0>Ool000Uo
o`@000Eoo`03001oogoo00=oo`03000e4CDA01he4@03001b/g:c01Ib/`<003U;?`03001;?d/o00];
?`8002`mD`03001f/GJa02af/@03001oogoo009oo`03001oogoo00ioo`002Goo00<007ooOol01Woo
00<007ooOol00Woo00<003DA=A407cDA00<007:cL[<06G:c0P00=d/o00<004/oBcl024/o0`0000<m
D`00?E<0:ceC00<007JaM[40;7Ja00<007ooOol00goo00<007ooOol03Goo000:Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool00`00=A4e4@0O=A400`00L[=b/`0KL[<3000dBcl00`00Bcm;?`06Bcl20004
?E<00`00?E<mD`0Z?E<00`00M[5f/@0/M[400`00Oomoo`03Ool00`00Oomoo`0=Ool000]oo`03001o
ogoo00Aoo`03001oogoo009oo`03000e4CDA01le4@03001b/g:c01ib/`80039;?`03001;?d/o00=;
?`<000HmD`03000mDceC02XmD`03001f/GJa02af/@03001oogoo00=oo`03001oogoo00eoo`002Goo
00@007ooOol000Eoo`03001oogoo009oo`03000e4CDA01le4@03001b/g:c021b/`<002m;?`03001;
?d/o00<000TmD`03000mDceC02XmD`03001f/GJa02af/@03001oogoo00=oo`03001oogoo00eoo`00
2Woo0P001Woo00<007ooOol00Woo00<003DA=A407cDA00<007:cL[<08g:c0P00;D/o0`0033eC00<0
03eC?E<0:SeC00<007JaM[40;7Ja00<007ooOol00goo00<007ooOol03Goo000BOol20003Ool00`00
=A4e4@0O=A400`00L[=b/`0UL[<3000WBcl4000>?E<00`00?E<mD`0Z?E<00`00M[5f/@0/M[400`00
Oomoo`03Ool00`00Oomoo`0=Ool0019oo`03001oogoo009oo`03000e4CDA01he4@03001b/g:c02Ub
/`8002=;?`8000<mD`03000mDceC00`mD`03000mDceC02XmD`03001f/GJa02af/@03001oogoo00=o
o`03001oogoo00eoo`004Woo00<007ooOol00Woo00<003DA=A407SDA00<007:cL[<0:g:c0`007D/o
0`001CeC00<003eC?E<033eC00<003eC?E<0:SeC00<007JaM[40;7Ja00<007ooOol00goo00<007oo
Ool03Goo000BOol00`00Oomoo`02Ool00`00=A4e4@0N=A400`00L[=b/`0^L[<2000HBcl30008?E<0
0`00?E<mD`0<?E<00`00?E<mD`0Z?E<00`00M[5f/@0/M[400`00Oomoo`03Ool00`00Oomoo`0=Ool0
019oo`03001oogoo009oo`03000e4CDA01he4@03001b/g:c031b/`<0019;?`<000/mD`03000mDceC
00`mD`03000mDceC02XmD`03001f/GJa02af/@03001oogoo00=oo`03001oogoo00eoo`004Goo00<0
07ooOol00goo00<003DA=A407SDA00<007:cL[<0<g:c0P003D/o0`003SeC00<003eC?E<033eC00<0
03eC?E<0:SeC00<007JaM[40;GJa00<007ooOol00Woo00<007ooOol03Goo000AOol00`00Oomoo`03
Ool00`00=A4e4@0N=A400`00L[=b/`0eL[<30008Bcl2000A?E<00`00?E<mD`0<?E<00`00?E<mD`0Z
?E<00`00M[5f/@0]M[400`00Oomoo`02Ool00`00Oomoo`0=Ool0015oo`03001oogoo009oo`03000e
4CDA01le4@03001b/g:c03Qb/`8000=;?`<001<mD`03000mDceC00`mD`03000mDceC02XmD`03001f
/GJa02ef/@03001oogoo009oo`03001oogoo00eoo`004Goo00<007ooOol00Woo00<003DA=A407cDA
00<007:cL[<0>W:c0`005SeC00<003eC?E<033eC00<003eC?E<0:SeC00<007JaM[40;GJa00<007oo
Ool00goo00<007ooOol037oo000AOol00`00Oomoo`02Ool00`00=A4e4@0O=A400`00L[=b/`0kL[<0
0`00?E<mD`0E?E<00`00?E<mD`0<?E<00`00?E<mD`0Z?E<00`00M[5f/@0]M[400`00Oomoo`03Ool0
0`00Oomoo`0<Ool0015oo`03001oogoo009oo`03000e4CDA01he4@<003ab/`03000mDceC01DmD`03
000mDceC00`mD`03000mDceC02XmD`03001f/GJa02ef/@03001oogoo00=oo`03001oogoo00aoo`00
4Goo00<007ooOol00Woo00<003DA=A4073DA0P000d/o0`00>G:c00<003eC?E<05CeC00<003eC?E<0
33eC00<003eC?E<0:SeC00<007JaM[40;GJa00<007ooOol00goo00<007ooOol037oo000AOol20003
Ool00`00=A4e4@0J=A420008Bcl2000gL[<00`00?E<mD`0E?E<00`00?E<mD`0<?E<00`00?E<mD`0Z
?E<00`00M[5f/@0]M[400`00Oomoo`03Ool00`00Oomoo`0<Ool0015oo`03001oogoo009oo`03000e
4CDA01Le4@<000a;?`<003Ab/`03000mDceC01DmD`03000mDceC00`mD`03000mDceC02XmD`03001f
/GJa02ef/@03001oogoo00=oo`03001oogoo00aoo`004Goo00<007ooOol00Woo00<003DA=A405CDA
0P004T/o0`00<G:c00<003eC?E<05CeC00<003eC?E<033eC00<003eC?E<0:SeC00<007JaM[40;GJa
00<007ooOol00goo00<007ooOol037oo000AOol00`00Oomoo`02Ool00`00=A4e4@0C=A42000GBcl2
000_L[<00`00?E<mD`0E?E<00`00?E<mD`0<?E<00`00?E<mD`0Z?E<00`00M[5f/@0]M[400`00Oomo
o`03Ool00`00Oomoo`0<Ool0015oo`03001oogoo009oo`03000e4CDA010e4@<001];?`<002ab/`03
000mDceC01DmD`03000mDceC00`mD`03000mDceC02XmD`03001f/GJa02ef/@03001oogoo00=oo`03
001oogoo00aoo`0047oo00<007ooOol00goo00<003DA=A403SDA0P008D/o0`00:G:c00<003eC?E<0
5CeC00<003eC?E<033eC00<003eC?E<0:SeC00<007JaM[40;GJa00<007ooOol00goo00<007ooOol0
37oo000@Ool00`00Oomoo`03Ool00`00=A4e4@0<=A42000VBcl2000WL[<00`00?E<mD`0E?E<00`00
?E<mD`0<?E<00`00?E<mD`0Z?E<00`00M[5f/@0]M[400`00Oomoo`03Ool00`00Oomoo`0<Ool0011o
o`03001oogoo009oo`03000e4CDA00Xe4@<002Y;?`<002Ab/`03000mDceC01DmD`03000mDceC00`m
D`03000mDceC02/mD`03001f/GJa02ef/@03001oogoo009oo`03001oogoo00aoo`0047oo00<007oo
Ool00Woo00<003DA=A4023DA0P00<4/o0`008G:c00<003eC?E<05CeC00<003eC?E<033eC00<003eC
?E<0:ceC00<007JaM[40;GJa00<007ooOol00goo00<007ooOol02goo000@Ool00`00Oomoo`02Ool0
0`00=A4e4@06=A42000eBcl2000OL[<00`00?E<mD`0E?E<00`00?E<mD`0<?E<2000/?E<00`00M[5f
/@0]M[400`00Oomoo`03Ool00`00Oomoo`0;Ool0011oo`03001oogoo009oo`03000e4CDA00<e4@<0
03U;?`<001ab/`03000mDceC01DmD`03000mDceC00`mD`8002`mD`03001f/GJa02ef/@03001oogoo
00=oo`03001oogoo00]oo`0047oo00<007ooOol00Woo00@003DA=A4e4@8003m;?`<001Ub/`03000m
DceC01DmD`03000mDceC00`mD`8002`mD`03001f/GJa02ef/@03001oogoo00=oo`03001oogoo00]o
o`0047oo00<007ooOol00Woo00@003DA000004A;?`<001Ib/`03000mDceC01DmD`03000mDceC00`m
D`8002`mD`03001f/GJa02ef/@03001oogoo00=oo`03001oogoo00]oo`0047oo0P000goo0P00BD/o
0P0057:c00<003eC?E<05CeC00<003eC?E<033eC0P00;3eC00<007JaM[40;GJa00<007ooOol00goo
00<007ooOol02goo000@Ool00`00Oomoo`04Ool30018Bcl3000AL[<00`00?E<mD`0E?E<00`00?E<m
D`0<?E<2000/?E<00`00M[5f/@0]M[400`00Oomoo`03Ool00`00Oomoo`0;Ool0011oo`03001oogoo
00Moo`<004Q;?`<000ib/`03000mDceC01DmD`03000mDceC00`mD`8002`mD`03001f/GJa02ef/@03
001oogoo00=oo`03001oogoo00]oo`0047oo00<007ooOol02Woo0`00B4/o0P0037:c00<003eC?E<0
5CeC00<003eC?E<033eC0P00;3eC00<007JaM[40;GJa00<007ooOol00goo00<007ooOol02goo000?
Ool00`00Oomoo`0>Ool30017Bcl30009L[<00`00?E<mD`0E?E<00`00?E<mD`0<?E<2000/?E<00`00
M[5f/@0]M[400`00Oomoo`03Ool00`00Oomoo`0;Ool000moo`03001oogoo015oo`@004I;?`<000Ib
/`03000mDceC01DmD`03000mDceC00`mD`8002`mD`03001f/GJa02ef/@03001oogoo00=oo`03001o
ogoo00]oo`003goo00<007ooOol05Goo0`00AT/o0P0017:c00<003eC?E<05CeC00<003eC?E<033eC
0P00;3eC00<007JaM[40;GJa00<007ooOol00goo00<007ooOol02goo000?Ool00`00Oomoo`0HOol3
0015Bcl300000g:c000mD`0F?E<00`00?E<mD`0<?E<2000[?E<3000^M[400`00Oomoo`04Ool00`00
Oomoo`0:Ool000moo`03001oogoo01]oo`<004E;?`8001LmD`03000mDceC00`mD`8002LmD`@000=7
G`8002ef/@03001oogoo00=oo`03001oogoo00Yoo`003goo00<007ooOol07Woo0`00?d/o0`0000<m
D`00?E<05SeC00<003eC?E<033eC0P0093eC0`002DMO0P00:gJa00<007ooOol00goo00<007ooOol0
2Woo000?Ool00`00Oomoo`0QOol3000iBcl30004?E<00`00?E<mD`0E?E<00`00?E<mD`0<?E<2000P
?E<4000>Ael3000XM[400`00Oomoo`03Ool00`00Oomoo`0:Ool000moo`03001oogoo02Aoo`<003=;
?`<000LmD`03000mDceC01DmD`03000mDceC00`mD`8001dmD`<001E7G`8002If/@03001oogoo00=o
o`03001oogoo00Yoo`003goo00<007ooOol09goo0`00;D/o0`002SeC00<003eC?E<05CeC00<003eC
?E<033eC0P006CeC10006TMO0`008gJa00<007ooOol00goo00<007ooOol02Woo000?Ool2000[Ool3
000WBcl3000=?E<00`00?E<mD`0E?E<00`00?E<mD`0<?E<2000F?E<3000QAel2000QM[400`00Oomo
o`03Ool00`00Oomoo`0:Ool000moo`03001oogoo02eoo`<0029;?`80010mD`03000mDceC01DmD`03
000mDceC00`mD`8001<mD`<002I7G`8001mf/@03001oogoo00=oo`03001oogoo00Yoo`003goo00<0
07ooOol0<7oo10006d/o0`004SeC00<003eC?E<05CeC00<003eC?E<033eC0P003ceC1000:dMO0`00
77Ja00<007ooOol00goo00<007ooOol02Woo000?Ool00`00Oomoo`0dOol3000EBcl3000E?E<00`00
?E<mD`0E?E<00`00?E<mD`0<?E<2000<?E<3000bAel2000JM[400`00Oomoo`03Ool00`00Oomoo`0:
Ool000ioo`03001oogoo03Qoo`<000m;?`<001PmD`03000mDceC01DmD`03000mDceC00dmD`03000m
DceC00HmD`@003M7G`8001Qf/@03001oogoo00=oo`03001oogoo00Yoo`003Woo00<007ooOol0>goo
0`002D/o0`006ceC00<003eC?E<05CeC00<003eC?E<03CeC00<003eC?E<00ceC0`00?DMO0`005GJa
00<007ooOol00goo00<007ooOol02Woo000>Ool00`00Oomoo`0nOol30003Bcl3000N?E<00`00?E<m
D`0E?E<00`00?E<mD`0=?E<00`00?E<000030013Ael2000CM[400`00Oomoo`04Ool00`00Oomoo`09
Ool000ioo`03001oogoo045oo`<0024mD`03000mDceC01DmD`03000mDceC00dmD`8004U7G`<0011f
/@03001oogoo00Aoo`03001oogoo00Uoo`001goo0`0017oo00<007ooOol0@Woo00<003eC?E<083eC
00<003eC?E<05CeC00<003eC?E<03CeC00<007:b00000P00BDMO0P003WJa00<007ooOol017oo00<0
07ooOol02Goo0008Ool00`00Oomoo`03Ool00`00Oomoo`12Ool00`00?E<mD`0P?E<00`00?E<mD`0E
?E<00`00?E<mD`0=?E<00`00L[9b/P02L[820019Ael2000=M[400`00Oomoo`03Ool00`00Oomoo`09
Ool000Eoo`D000Aoo`03001oogoo045oo`03000mDceC024mD`03000mDceC01DmD`03000mDceC00dm
D`03001b/W:b00Ab/P<004Q7G`<000Yf/@03001oogoo00=oo`03001oogoo00Uoo`001Goo00@007oo
Ool000Eoo`03001oogoo045oo`03000mDceC024mD`03000mDceC01DmD`03000mDceC00dmD`03001b
/W:b00Mb/P<004Q7G`8000Qf/@03001oogoo00=oo`03001oogoo00Uoo`001Woo00<007oo000017oo
0P00@goo00<003eC?E<08CeC00<003eC?E<05CeC00<003eC?E<03CeC00<007:bL[802W:b0P00B4MO
0`001GJa00<007ooOol00goo00<007ooOol02Goo0007Ool20005Ool20012Ool00`00?E<mD`0Q?E<0
0`00?E<mD`0E?E<00`00?E<mD`0=?E<00`00L[9b/P0<L[830018Ael20003M[400`00Oomoo`03Ool0
0`00Oomoo`09Ool000ioo`03001oogoo045oo`03000mDceC024mD`03000mDceC01DmD`03000mDceC
00dmD`03001b/W:b00mb/P<004M7G`800003M[4007oo00Aoo`03001oogoo00Uoo`003Woo00<007oo
Ool0@Goo00<003eC?E<083eC00<003eC?E<05SeC00<003eC?E<03CeC00<007:bL[804W:b0P00AdMO
0P001Goo00<007ooOol02Goo000=Ool00`00Oomoo`12Ool00`00?E<mD`0P?E<00`00?E<mD`0F?E<0
0`00?E<mD`0=?E<00`00L[9b/P0DL[830010Ael40007Ool00`00Oomoo`09Ool000eoo`03001oogoo
049oo`03000mDceC020mD`03000mDceC01HmD`03000mDceC00dmD`03001b/W:b01Mb/P<003U7G`@0
00]oo`03001oogoo00Uoo`003Goo00<007ooOol0@Woo00<003eC?E<083eC00<003eC?E<05SeC00<0
03eC?E<03CeC00<007:bL[806W:b0P00<dMO100047oo00<007ooOol027oo000=Ool00`00Oomoo`12
Ool00`00?E<mD`0P?E<00`00?E<mD`0F?E<00`00?E<mD`0=?E<00`00L[9b/P0LL[83000/Ael4000D
Ool00`00Oomoo`08Ool000eoo`03001oogoo049oo`03000mDceC020mD`03000mDceC01HmD`03000m
DceC00dmD`03001b/W:b01mb/P<002E7G`@001Qoo`03001oogoo00Qoo`003Goo00<007ooOol0@Woo
00<003eC?E<083eC00<003eC?E<05SeC00<003eC?E<03CeC00<007:bL[808W:b0P007dMO100077oo
00<007ooOol027oo000=Ool00`00Oomoo`12Ool00`00?E<mD`0P?E<00`00?E<mD`0F?E<00`00?E<m
D`0=?E<00`00L[9b/P0TL[83000HAel4000POol00`00Oomoo`08Ool000eoo`03001oogoo049oo`03
000mDceC020mD`03000mDceC01HmD`03000mDceC00dmD`03001b/W:b02Mb/P<00157G`@002Aoo`03
001oogoo00Qoo`003Goo00<007ooOol0@Woo00<003eC?E<083eC00<003eC?E<05SeC00<003eC?E<0
3CeC00<007:bL[80:W:b0P002dMO1000:7oo00<007ooOol027oo000=Ool00`00Oomoo`12Ool00`00
?E<mD`0P?E<00`00?E<mD`0F?E<00`00?E<mD`0=?E<00`00L[9b/P0/L[830004Ael4000/Ool00`00
Oomoo`08Ool000aoo`8004Aoo`03000mDceC020mD`03000mDceC01HmD`03000mDceC00dmD`03001b
/W:b02mb/P@0031oo`03001oogoo00Qoo`003Goo00<007ooOol0@Woo00<003eC?E<083eC00<003eC
?E<05SeC00<003eC?E<03CeC00<007:bL[80<7:b00<007ooOol0<7oo00<007ooOol027oo000<Ool0
0`00Oomoo`13Ool00`00?E<mD`0P?E<00`00?E<mD`0F?E<00`00?E<mD`0=?E<00`00L[9b/P0`L[80
0`00Oomoo`0`Ool00`00Oomoo`08Ool000aoo`03001oogoo04=oo`03000mDceC020mD`03000mDceC
01HmD`03000mDceC00dmD`03001b/W:b031b/P03001oogoo031oo`03001oogoo00Qoo`0037oo00<0
07ooOol0@goo00<003eC?E<083eC00<003eC?E<05SeC00<003eC?E<03CeC00<007:bL[80<7:b00<0
07ooOol0<7oo00<007ooOol027oo000<Ool00`00Oomoo`13Ool00`00?E<mD`0P?E<00`00?E<mD`0F
?E<00`00?E<mD`0=?E<00`00L[9b/P0`L[800`00Oomoo`0aOol00`00Oomoo`07Ool000aoo`03001o
ogoo04=oo`03000mDceC020mD`03000mDceC01HmD`03000mDceC00dmD`03001b/W:b031b/P03001o
ogoo035oo`03001oogoo00Moo`0037oo00<007ooOol0@goo00<003eC?E<083eC00<003eC?E<05SeC
00<003eC?E<03CeC00<007:bL[80<7:b00<007ooOol0<Goo00<007ooOol01goo000<Ool00`00Oomo
o`13Ool00`00?E<mD`0P?E<00`00?E<mD`0F?E<00`00?E<mD`0=?E<00`00L[9b/P0`L[800`00Oomo
o`0aOol00`00Oomoo`07Ool000aoo`03001oogoo04=oo`03000mDceC020mD`03000mDceC01DmD`<0
00`mD`@0035b/P03001oogoo035oo`03001oogoo00Moo`0037oo00<007ooOol0@goo00<003eC?E<0
83eC00<003eC?E<04CeC10000ceC0`001CeC100013mO0`00;W:b00<007ooOol0<Goo00<007ooOol0
1goo000<Ool00`00Oomoo`13Ool00`00?E<mD`0P?E<00`00?E<mD`0=?E<4000:?E<5000;?el4000Z
L[800`00Oomoo`0aOol00`00Oomoo`07Ool000aoo`03001oogoo049oo`03000mDceC024mD`03000m
DceC00XmD`<000/mD`@000<oG`<000doG`<002Mb/P03001oogoo035oo`03001oogoo00Moo`002goo
0P00A7oo00<003eC?E<08CeC00<003eC?E<01SeC10002SeC10002SmO0`003CmO0`0097:b00<007oo
Ool0<Goo00<007ooOol01goo000<Ool00`00Oomoo`12Ool00`00?E<mD`0Q?E<00`00?E<mD`02?E<4
000:?E<4000A?el3000=?el3000RL[800`00Oomoo`0`Ool00`00Oomoo`07Ool000]oo`03001oogoo
04=oo`03000mDceC024mD`D000XmD`@001PoG`<000doG`@001ib/P03001oogoo031oo`03001oogoo
00Moo`002goo00<007ooOol0@goo00<003eC?E<07ceC0`002SeC10007cmO10003CmO0`006g:b00<0
07ooOol0<7oo00<007ooOol01goo000;Ool00`00Oomoo`13Ool00`00?E<mD`0K?E<40002?E<00`00
?E<mD`04?E<4000W?el3000=?el3000HL[800`00Oomoo`0aOol00`00Oomoo`06Ool000]oo`03001o
ogoo04=oo`03000mDceC01LmD`@000HmD`03000mDceC00@002hoG`<000doG`<001Eb/P03001oogoo
035oo`03001oogoo00Ioo`002goo00<007ooOol0@goo00<003eC?E<053eC0`002SeC0`00=CmO0`00
3CmO10004G:b00<007ooOol0<Goo00<007ooOol01Woo000;Ool00`00Oomoo`13Ool00`00?E<mD`0@
?E<4000=?E<00`00L[<00003000e?el3000>?el3000>L[800`00Oomoo`0aOol00`00Oomoo`06Ool0
00]oo`03001oogoo04=oo`03000mDceC00`mD`@0014mD`03001b/g:c00=b/`<003DoG`@000doG`<0
00]b/P03001oogoo035oo`03001oogoo00Ioo`002goo00<007ooOol0@goo00<003eC?E<02CeC0`00
5CeC00<007:cL[<01W:c1000=CmO0`003CmO0`0027:b00<007ooOol0<Goo00<007ooOol01Woo000;
Ool00`00Oomoo`13Ool00`00?E<mD`05?E<4000H?E<00`00L[=b/`0:L[<3000e?el3000=?el40004
L[800`00Oomoo`0aOol00`00Oomoo`06Ool000]oo`03001oogoo04=oo`04000mDceC?E<4000L?E<0
0`00L[=b/`0=L[<4000d?el3000>?el300000g:b001oo`0bOol00`00Oomoo`06Ool000]oo`03001o
ogoo04=oo`@0020mD`03001b/g:c015b/`<003@oG`<000doG`<003=oo`03001oogoo00Ioo`002goo
00<007ooOol0@7oo10008ceC00<007:cL[<057:c1000<cmO10001CmO1000=Woo00<007ooOol01Woo
000:Ool2000nOol40003Ool00`00?E<mD`0Q?E<00`00L[=b/`0HL[<4000c?el5000jOol00`00Oomo
o`06Ool000Yoo`03001oogoo03Uoo`@000Moo`03000mDceC024mD`03001b/g:c01ab/`<002`oG`@0
00=oo`<003Uoo`03001oogoo00Ioo`002Woo00<007ooOol0=Woo0`002goo00<003eC?E<08CeC00<0
07:cL[<07g:c100093mO10002Woo0`00=goo00<007ooOol01Goo000:Ool00`00Oomoo`0bOol4000>
Ool00`00?E<mD`0Q?E<00`00L[=b/`0SL[<3000L?el5000AOol4000cOol00`00Oomoo`05Ool000Yo
o`03001oogoo02ioo`@0019oo`03000mDceC024mD`03001b/g:c02Ib/`@001@oG`@001Yoo`<0031o
o`03001oogoo00Eoo`002Woo00<007ooOol0:goo0`005Woo00<003eC?E<08CeC00<007:cL[<0:W:c
0`0033mO1@008Goo0`00;Goo00<007ooOol01Goo000:Ool00`00Oomoo`0WOol4000IOol00`00?E<m
D`0Q?E<00`00L[=b/`0]L[<40004?el4000YOol3000ZOol00`00Oomoo`05Ool000Yoo`03001oogoo
02=oo`@001eoo`03000mDceC024mD`03001b/g:c035b/`@0031oo`<002Moo`03001oogoo00Eoo`00
2Woo00<007ooOol087oo0`008Goo00<003eC?E<08CeC00<007:cL[<0<W:c00<007ooOol0<goo1000
8goo00<007ooOol01Goo000:Ool00`00Oomoo`0LOol4000TOol00`00?E<mD`0Q?E<00`00L[=b/`0b
L[<00`00Oomoo`0gOol3000POol00`00Oomoo`05Ool00004Ool000000006Ool00`00Oomoo`0HOol4
000XOol00`00?E<mD`0Q?E<00`00L[=b/`0bL[<00`00Oomoo`0jOol3000MOol00`00Oomoo`05Ool0
0005Ool007ooOol00005Ool00`00Oomoo`0EOol3000/Ool00`00?E<mD`0Q?E<00`00L[=b/`0bL[<0
0`00Oomoo`0mOol3000JOol00`00Oomoo`05Ool00005Ool007ooOol00004Ool00`00Oomoo`0BOol4
000_Ool00`00?E<mD`0Q?E<00`00L[=b/`0bL[<00`00Oomoo`10Ool3000GOol00`00Oomoo`05Ool0
0004Ool000000005Ool00`00Oomoo`0>Ool4000bOol00`00?E<mD`0R?E<00`00L[=b/`0bL[<00`00
Oomoo`13Ool4000COol00`00Oomoo`05Ool0009oo`03001oogoo00Aoo`<000Yoo`@003Ioo`03000m
DceC028mD`03001b/g:c039b/`03001oogoo04Moo`<0015oo`03001oogoo00Aoo`000Woo0`0017oo
00<007ooOol01goo0`00>Woo00<003eC?E<08SeC00<007:cL[<0<W:c00<007ooOol0BWoo0`003Woo
00<007ooOol017oo0009Ool00`00Oomoo`03Ool4000mOol00`00?E<mD`0R?E<00`00L[=b/`0bL[<0
0`00Oomoo`1=Ool3000;Ool00`00Oomoo`04Ool000Uoo`03001oo`0000<0045oo`03000mDceC028m
D`03001b/g:c039b/`03001oogoo051oo`<000Qoo`03001oogoo00Aoo`002Goo0`00A7oo00<003eC
?E<08SeC00<007:cL[<0<W:c00<007ooOol0Dgoo100017oo00<007ooOol017oo000<Ool5000oOol0
0`00?E<mD`0P?E<5000bL[<00`00Oomoo`1GOol300000goo001oo`05Ool0015oo`D003Yoo`03000m
DceC01`mD`@000Dk?`@002ib/`03001oogoo05Uoo`<000Ioo`005Woo1@00=Goo00<003eC?E<05ceC
1@003C/o1000:W:c00<007ooOol0Dgoo1P002Goo000KOol5000`Ool00`00?E<mD`0B?E<5000F>cl4
000VL[<00`00Oomoo`1=Ool6000?Ool0021oo`D002]oo`03000mDceC00hmD`@001lk?`@0029b/`03
001oogoo04Qoo`D001Eoo`009Goo1@009Woo00<003eC?E<02CeC1@009c/o10007W:c00<007ooOol0
@Woo1P006Woo000ZOol5000QOol00`00?E<mD`04?E<5000`>cl4000JL[<00`00Oomoo`0lOol6000P
Ool002moo`D001aoo`03000mDceC00@003Tk?`@001Ib/`03001oogoo03Moo`D002Ioo`00=7oo1@00
5goo0`00@C/o10004W:c00<007ooOol0<Goo1P00:goo000iOol5000EOol40011>cl4000>L[<00`00
Oomoo`0[Ool6000aOol003ioo`D001Aoo`D0040k?`@000Yb/`03001oogoo02Ioo`D003Moo`00@goo
1@0057oo1000@3/o10001W:c00<007ooOol087oo1P00?7oo0018Ool5000COol5000o>cl40002L[<0
0`00Oomoo`0KOol50012Ool004eoo`D001=oo`@003lk?`<001Moo`H004Moo`00DWoo1@004Woo1@00
=C/o1@0057oo1P00CGoo001GOol5000BOol4000/>cl5000DOol5001COol005aoo`D0015oo`D0028k
?`D001=oo`H005Qoo`00HGoo1@004Goo100063/o1P004Woo1P00GWoo001VOol5000@Ool5000>>cl5
000COol5001TOol006]oo`D0011oo`@000Dk?`D0019oo`H006Uoo`00L7oo1@003goo1@004Goo1P00
Kgoo001eOol5000<Ool00`00Oomoo`0<Ool5001eOol007Yoo`D000Moo`03001oogoo00Ioo`H007Yo
o`00Ogoo1@000Woo00<007ooOol01P00P7oo0024Ool50026Ool00?mooa1oo`00ogoo47oo003oOol@
Ool00?mooa1oo`00\
\>"],
  ImageRangeCache->{{{0, 270.625}, {267.125, 0}} -> {0.0213702, -0.0381708, \
0.00348044, 0.00348044}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"],

Cell[BoxData[
    \({Plot3D, ListPlot3D, ParametricPlot3D}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In general the function ",
  StyleBox["ViewPointSelect", "MR"],
  " acts as any standard ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " function. Thus buttons ",
  StyleBox["[Ok]", "MR"],
  " and ",
  StyleBox["[Cancel]", "MR"],
  " return graphic objects and button ",
  StyleBox["[ViewPoint]", "MR"],
  " returns the value of option as typical output. Another example, if the \
option ",
  StyleBox["ViewPoint", "MR"],
  " is applied the resulting graphics would alwais use this value:"
}], "Text"],

Cell[BoxData[
    \(Plot3D[Sin[x\ y], {x, 0, 1}, {y, 0, 1}, ViewPoint \[Rule] {2, 0, 0}] // 
      ViewPointSelect\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Action via menu or keyboard shortcut command", "Subsection"],

Cell[TextData[{
  "The different approach is used if ",
  StyleBox["ViewPointSelect", "MR"],
  " is called via menu or keyboard shortcut command. In this case ",
  StyleBox["ViewPointSelect", "MR"],
  " doesn't generate an output cell but changes the input cell."
}], "Text"],

Cell[TextData[{
  "To launch ",
  StyleBox["ViewPointSelect", "MR"],
  " select a function producing 3D graphics (",
  StyleBox["Plot3D", "MR"],
  ", ",
  StyleBox["ListPlot3D", "MR"],
  ", ",
  StyleBox["ParametricPlot3D,", "MR"],
  " etc. ) or place coursor just after it and apply the menu command or the \
key combination (\[ControlKey]",
  StyleBox["\[KeyBar]", "KeyboardChars"],
  "\[AltKey]\[LeftModified]v\[RightModified] for Windows). (Note that this \
will work only if the cursor will remain in the same position of the editing \
notebook while the dialog window is open.) For example, if the cursor is \
placed at the end of the following expression:"
}], "Text"],

Cell[BoxData[
    \(ParametricPlot3D[{Cos[5  t], Sin[3  t], Sin[t]}, {t, 0, 
        2  \[Pi]}]\)], "Input"],

Cell["the described action opens the new window", "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006<0001YR000`400?l0
0000o`00003o00<001BI000CS0004h`0o`004hb:000CS00000@001J^000N
X0007Z0001jQ5@007Z0:000NXA<001jP50007J0:000NX0X001fP2P007Z4:
000MX0X001jQ2P007Z0:000MX@T001jP50007Z4D000MX@X001jP2P007J4D
000NXA<001jP2P007Z4D000NX0X001jQ:0007Z0:000MX@T001jP:0007Z40
10007Z0001jS000NX@006i/1000CS00000D001W?00Paf@0=AmX045CO00Y9
f@0:00A1f0X003kM7@00?M`:000ng0X003gM5000?M`:000mg@X003kL2P00
?]dD000mg0T003kM2P00?M`:000ng@X003gL5000?MdD000mg0X003gM2P00
?M`9000ng0X003gM5000?M`:000mgA@003gL2P00?Md:000ng0X003gM2@00
?M`:000mg@X003gL5000?Md01000?M`003O@000/_0007Z<1000CS00000D0
01W?00Paf@0BD^D05V[^00QEg@0:00M?j_l004SaNP00B?400`00?M`002fn
000MX001000CS00000@001W?00Paf@0FJ^h025GMo`3ooomd0?oooa40k>WH
00<004Sa000mg0007J000@004h`00005000Ic`08<MT05V[^00QEg@2/Z9T0
o`3/jMQb0>cYf0030?ooo`3/jMP0k>WH00@0k>WH0P3oool20>cYf080oooo
0P3/jMP20?ooo`040>cYf000B?4003gL000MX04001><00001@006Ll0237I
01IZkP08EMd0[:RI0?l0k>WHLP3/jMP00`3oool0k>WH0>cYf0030>cYf00?
0;RdX`2h]J40oooo0>cYf02h]:<0^;FQ0?ooo`3/jMP0^;BS0;ReX@3oool0
k>WH0018l@00?M`001fP004001><00001@006Ll0237I01IZkP08EMd0[:RI
0?l0k>WHLP3/jMP00`3oool0k>WH0>cYf0030>cYf0060;RdX`2h]:40k>WH
0>cYf02h]:<0^;BQ0P3/jMP01`2h]:<0^;BQ0>cYf03/jMP004Sa000mg000
7J000@004h`00005000Ic`08<MT05V[^00QEg@2/Z9T0o`3/jMQb0>cYf003
0?ooo`3/jMP0k>WH00l0k>WH00<004Sa000mg0007J000@004h`00005000I
c`08<MT05V[^00QEg@2/Z9T0o`3/jMQb0>cYf0030?ooo`3/jMP0k>WH00P0
k>WH0P3oool20>cYf080oooo00@0k>WH0018l@00?M`001fP0@004h`00005
000Ic`08<MT05V[^00QEg@2/Z9T0o`3/jMQb0>cYf0030?ooo`3/jMP0k>WH
00L0k>WH00/0^;BS0;ReX@3oool0k>WH0;RdX`2h]J40oooo0>cYf000B?40
03gL000MX001000CS00000D001W?00Paf@0FJ^h025GM0:bXV@3o0>cYf780
k>WH00<0oooo0>cYf03/jMP01`3/jMP01P2h]:<0^;BQ0>cYf03/jMP0^;BS
0;RdX@80k>WH00<004Sa000mg0007J000@004h`00005000Ic`08<MT05V[^
00QEg@2/Z9T0o`3/jMQb0>cYf0030?ooo`3/jMP0k>WH00l0k>WH00<004Sa
000mg0007J000@004h`00005000Ic`08<MT05V[^00QEg@2/Z9T0o`3/jMQb
0>cYf0030?ooo`3/jMP0k>WH00`0k>WH0P3oool0103/jMP004Sa000mg000
7J01000CS00000D001W?00Paf@0FJ^h025GM0:bXV@3o0>cYf780k>WH00<0
oooo0>cYf03/jMP02`3/jMP01`2h]:<0^;FQ0?ooo`3/jMP004Sa000mg000
7J000@004h`00005000Ic`08<MT05V[^00QEg@2/Z9T0o`3/jMQb0>cYf003
0?ooo`3/jMP0k>WH00/0k>WH00L0^;BS0;RdX@3/jMP0k>WH0018l@00?M`0
01fP004001><00001@006Ll0237I01IZkP08EMd0[:RI0?l0k>WHLP3/jMP0
0`3oool0k>WH0>cYf00?0>cYf0030018l@00?M`001fP004001><00001@00
6Ll0237I01IZkP08EMd0[:RI0?l0k>WHLP3/jMP00`3oool0k>WH0>cYf00?
0>cYf0030018l@00?M`001jP004001><00001@006Ll0237I01IZkP08EMd0
[:RI0?l0k>WHLP3/jMP00`3oool0k>WH0>cYf00?0>cYf0030018l@00?M`0
01jP004001><00001@006Ll0237I01IZkP08EMd0[:RI0?l0k>WHLP3/jMP0
0`3oool0k>WH0>cYf00?0>cYf0030018l@00?M`001jP004001><00001000
6Ll0237I01IZkP08EMgo0:bXVG<0[:RI00<0oooo0>cYf03/jMP03`3/jMP0
0`00B?4003gL000NX001000CS00000@001W?00Paf@0FJ^h025GMo`3ooomd
0?ooo`060>k]i@3clnh0emO80<c<^P39bKH0aLFa1P34a:l02034a;00a/Jc
0=3@_`3emO40k>cU0018l@00?M`001jP0@004h`00004000Ic`08<MT05V[^
00QEgOl0ooooM03oool00`3^kND0h^;G0?ooo`0<0?ooo`050=[Jc@3/k>D0
04Sa000mg0007Z000@004h`00004000Ic`08<MT05V[^00QEgOl0ooooM03o
ool0103^kND0oooo0?;bk@3UiM/30>KVg0040>KVg@3Vi]`0i^KL0>KVg080
iNGK00L0hn?H0?7aj`3oool0d];10018l@00?M`001jP004001><00001000
6Ll0237I01IZkP08EMgo0?ooog@0oooo00D0k^gU0?ooo`3Rh]L0j^[R0>_[
h`020>c/i080jn_S00/0j^[R0>WYh03Xj=l0inON0>KVg@3ShmP0oooo0<c<
^P00B?4003gL000NX001000CS00000@001W?00Paf@0FJ^h025GMo`3ooomd
0?ooo`040>k]i@3oool0iNGK0>c/i0@0kNgV00`0k>cU0>_[h`3[jn<0j^[R
0>WYh03Wimh0i>CI0?ooo`3<c;T004Sa000mg0007Z01000CS00000@001W?
00Paf@0FJ^h025GMo`3ooomd0?ooo`040>k]i@3oool0iNGK0>g]iP@0k^kW
00`0bLW20>c/i03[jn<0j^[R0>WYh03Xj=l0iNGK0?ooo`3<c;T004Sa000m
g0007Z01000CS00000@001W?00Paf@0FJ^h025GMo`3ooomd0?ooo`040>k]
i@3oool0i^KL0>k^i`<0knoY0`39bL830>[ZhP070>WYh03Vi]`0oooo0<c<
^@00B?4003gL000NX001000CS00000@001W?00Paf@0FJ^h025GMo`3ooomd
0?ooo`030>k]i@3oool0i^KM00<0knoY1@39bL820>_[h`070>[ZhP3Vi]`0
oooo0<c<^@00B?4003gL000NX001000CS00000@001W?00Lbf@0FJ^h025GM
o`3ooomd0?ooo`030>k]i@3oool0inON0080l?3Z0`39bL80303]kNH0bLW2
0<W9`P39bL80jn_S0>[ZhP3Vi]d0oooo0<c<^P00B?4003kL000MX@4001><
000010006Ll01c;I01IZkP08EMdA0?ooo`062_ooobkooomRooooQooooiOo
oonLoooo;9goool/`_ooo`:Moooo00FPooooYoooojgooonQoooo:_ooo`1C
0?ooo`062_ooobkooomRooooQooooiOooonLoooo89gooolO`_ooo`:Moooo
00FPooooYoooojgooonQoooo:_ooo`0:0?ooo`062_ooobkooomRooooQooo
oiOooonLoooo89gooolO`_ooo`:Moooo00FPooooYoooojgooonQoooo:_oo
o`080?ooo`040>k]i@3oool0j>SO0?3`jP<0bLW20P3]kNH02`3[jn<0bLW2
0<W9`P39bL80jn_S0>OWgP3oool0c<bj0018l@00?]`001fQ004001><0000
10006Ll01c;I01IZkP08EMdA0?ooo`042?_knU3in??IP9b`nbEGQ5go03ad
00Cm5TenjVj>YkCjn_FBooooD`3oool010SknoY@nOScfH2L/?/UEhA4o`0l
M004oAI=O^Y^SZNdn_[eT_ooo`X0oooo00@8no_jD?WhlmV0W;3k9EN4A?l0
?7@01?dFCGkZKXjW]?[jmI;oool80?ooo`030>k]i@3oool0j^[R0080lO7[
00@0bLW20?3`jP3`l>X0k>cU0P3/k>@02@39bL80k>cT0>_[h`3Wimh0oooo
0<g=_000B?4003kL000MX@01000CS00000@001W?00Lbf@0FJ^h025GM4@3o
ool011CgmO?SJ8VTodYaTonS[[AKomK@a@06omG@a?oEcl?o/KNfodQ^T>Q/
SJImooooD`3oool011CgmO?SJ8VTodYaTonS[[A2omK@a@06omG@a?oEcl?o
/KNfodQ^T>Q/SJImoooo2P3oool011CgmO?SJ8VTodYaTonS[[A2omK@a@06
omG@a?oEcl?o/KNfodQ^T>Q/SJImoooo203oool00`3^kND0oooo0>[ZhP02
0?7ak0050?7aj`3`l>X0l?3Z0?3`jP3/k>D0103/k>@01P3Wimh0oooo0<o?
_P00B?4003kL000MX@4001><000010006Ll01c;I01IZkP08EMdA0?ooo`06
6oCbkodFCGko_lO:on;Oe_oPg]CohMkEFOoRgmH01_oQg]GogmcBom_GcOnf
_Kgm5TenFOoooe<0oooo00HKm?;_oAI=O_noal[oh]oFon3Ne?oQg]E0on;O
eP06on7NeOoOg=;ofmO=okJm_OdFCGiIoooo2P3oool01Q_dl^om5Tenoko7
b_oRgmKoh=kDon7NeD3oh]oF00KohMkEomoLd_oKelgo][fmoAI=OUWoool8
0?ooo`060>k]i@3oool0k>cU0??ckP3bl^d0lO7[0`3`l>X02`3]kNH0k>cU
0>c/i@3/k>D0k>cT0>OWgP3oool0dm?20018l@00?]`001fQ004001><0000
10006Ll01c;I01IZkP08EMdA0?ooo`037O?ak_l0?7Cok>_V00;ojn_U00?o
k>_Uonc[i_o/jnH0Eoo/jnH01_o[jnGojNSQonCRf_oPgMCo03ad?ooooe<0
oooo00<Mlo7^o`0lM?o/jnH00_o[jnD00oo/jnGok>_Vonc[iP0nonc[iP06
on_[iOoYj>7oi>;Jon3Me?l0?7@ooooo2P3oool00agclNko03adonc[iP02
on_[i@03onc[iOo/jnKok>_V03kok>_V00Kojn_UonWXhOoTh][oh=gDo`0l
M3ooool80?ooo`090>k]i@3oool0k^kW0?Gel@3dm?00l_;]0?7ak03alN/0
l?3Z0080knoY00T0k^kW0>g]iP3/k>@0i^KM0?ooo`3Hf<T004Sa000ng000
7J400@004h`00004000Ic`07<]T05V[^00QEgA40oooo00<Mlo7^o`0lM?o`
l>/0;oo`l>X3000000Gol?3Z1000000Roo3`jP05ono^j?oZj>7oi>;Io`0l
M3Soool0D`3oool00agclNko03adoo3`j`14oo3`jP05ono^j?oZj>7oi>;I
o`0lM3Soool02P3oool00agclNko03adoo3`j`14oo3`jP05ono^j?oZj>7o
i>;Io`0lM3Soool0203oool01`3^kND0oooo0?7aj`3gmo<0mOGa0??ckP3b
l^d00P3alN`02`3alN/0l?3Z0>o_j@3^k^L0k>cT0>KVg@3oool0gmoB0018
l@00?]`001fQ004001><000010006Ll01c;I01IZkP08EMdA0?ooo`047O?a
k_l0?7ColO7/oo7ak2ool?3[00<00000oo3`joo`l>/01_o`l>/00`00003o
l?3[oo3`j`0Qoo3`j`05ono_jOo[j^?oiN;Ko`0lM3Ooool0D`3oool011gc
lNko03adoo7ak?oalNa3oo3`j`05ono_jOo[j^?oiN;Ko`0lM3Ooool02P3o
ool011gclNko03adoo7ak?oalNa3oo3`j`05ono_jOo[j^?oiN;Ko`0lM3Oo
ool0203oool0203^kND0oooo0?Ogm03alN/0k^kW0>c/i@3[jn<0j^[R0P3X
j=l20>OWgP080>KVg@3Ti=T0lo?^0?ooo`3UiM/004Sa000ng0007J41000C
S00000@001W?00Lbf@0FJ^h025GM4@3oool011gclNko03adoo;bkOobl^dR
oo7ak0<000001?oalN`3000000?olO7/10000005oo7ak00300000?oalNco
lO7/027olO7/00Gol?3[onc[i?oVhmco03ad=oooo`1C0?ooo`047O?ak_l0
?7Col_;]oo;bkAgolO7/0`000002oo7ak080000000ColO7/000000000000
00006ooalN`01Oo`l>_ok>_TonKSg?l0?7@goooo00X0oooo00@Mlo7^o`0l
M?obl^gol_;]3ooalN`3000000ColO7/200000001?oalN`0000000000000
0002oo7ak0<000001?oalN`4000000;olO7/1@00000=oo7ak005oo3`joo/
jnCoi^?Lo`0lM3Ooool0203oool00`3^kND0o?cj0?ooo`0=0?ooo`040>c/
i@00B?4003kL000MX@4001><000010006Ll01c;I01IZkP08EMdA0?ooo`04
7O?ak_l0?7Col_;^oo;bkR7olO7]00D00000oo7akOoalNgolO7]00000002
oo7ak@0500000?oalNgolO7]oo7ak@0000000_oalNd01@00003olO7]oo7a
kOoalNd0000000ColO7]0P00000Roo7ak@05oo3`k?o/jnGoi^?Mo`0lM3Oo
ool0D`3oool011gclNko03adoo;bk_obl^hLoo7ak@0500000?oalNgolO7]
oo7ak@0000000_oalNd01000003olO7]oo7ak@00000Loo7ak@05oo3`k?o/
jnGoi^?Mo`0lM3Ooool02P3oool011gclNko03adoo;bk_obl^h>oo7ak@05
00000?oalNgolO7]oo7ak@0000000_oalNd01@00003olO7]oo7akOoalNd0
000000;olO7]00D00000oo7akOoalNgolO7]00000002oo7ak@0500000?oa
lNgolO7]oo7ak@0000000_oalNd00`00003olO7]oo7ak@06oo7ak@030000
0?oalNgolO7]00golO7]00Gol?3/onc[iOoVhmgo03ad=oooo`080?ooo`03
0>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001fQ0@004h`00004
000Ic`07<]T05V[^00QEgA40oooo00@Mlo7^o`0lM?odm>oom?C_8Ooclnh0
0`00003olo?^oo?ckP04oo?ckP0500000?oclnkolo?^oo?ckP0000000_oc
lnh01@00003olo?^oo?ck_oclnh0000000?olo?^00<00000oo?ckP000000
8_oclnh01Oobl^gok^gVonSUg_l0?7@goooo05<0oooo00@Mlo7^o`0lM?od
m>oom?C_7?oclnh01@00003olo?^oo?ck_oclnh0000000;olo?^00<00000
oo?ckP0000007Ooclnh01Oobl^gok^gVonSUg_l0?7@goooo00X0oooo00@M
lo7^o`0lM?odm>oom?C_3_oclnh00`00003olo?^oo?ckP04oo?ckP050000
0?oclnkolo?^oo?ckP0000000_oclnh01@00003olo?^oo?ck_oclnh00000
00;olo?^00<00000oo?ck_oclnh01?oclnh00`00003olo?^oo?ckP06oo?c
kP0300000?oclnkolo?^00golo?^00Gol_;]onk]i_oXiMko03ad=oooo`08
0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001fQ0@00
4h`00004000Ic`07<]T05V[^00QEgA40oooo00@Mlo7^o`0lM?oemO7omOGa
8Oodm?000`00003om?C`ooCdl004ooCdl00500000?odm?3om?C`ooCdl000
00000_odm?001@00003om?C`ooCdl?odm?00000000?om?C`00@00000ooCd
l?odm?0000008Oodm?001OoclnooknkXonWVh?l0?7@goooo05<0oooo00@M
lo7^o`0lM?oemO7omOGa7?odm?001@00003om?C`ooCdl?odm?00000000;o
m?C`0`00000MooCdl005oo?ckoo_k^SojNKPo`0lM3Ooool02P3oool011gc
lNko03adooGelOoemO4>ooCdl00300000?odm?3om?C`00Gom?C`10000002
ooCdl00500000?odm?3om?C`ooCdl00000000_odm?000`00003om?C`ooCd
l004ooCdl0D000001?odm?000`00003om?C`ooCdl00=ooCdl005oo?ckoo_
k^SojNKPo`0lM3Ooool0203oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_
k000B?4003kL000MX@4001><000010006Ll01c;I01IZkP08EMdA0?ooo`04
7O?ak_l0?7Com_KcooKflb7om_Kb00<00000ooKfl_ofm_801?ofm_801@00
003om_KbooKfl_ofm_80000000;om_Kb0P000002ooKflP0400000?ofm_;o
m_Kb000000?om_Kb00<00000ooKfl_ofm_807oofm_801OoemO7olO3Zon_X
hOl0?7@goooo05<0oooo00@Mlo7^o`0lM?ofm_?om_Kc7?ofm_801@00003o
m_KbooKfl_ofm_80000000;om_Kb00@00000ooKfl_ofm_8000007?ofm_80
1OoemO7olO3Zon_XhOl0?7@goooo00X0oooo00@Mlo7^o`0lM?ofm_?om_Kc
3_ofm_800`00003om_KbooKflP04ooKflP0500000?ofm_;om_KbooKflP00
00000_ofm_82000000;om_Kb00@00000ooKfl_ofm_8000000oofm_801000
003om_KbooKflP000003ooKflP0300000?ofm_;om_Kb00;om_Kb00<00000
ooKfl_ofm_803Oofm_801OoemO7olO3Zon_XhOl0?7@goooo00P0oooo00<0
kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng0007J41000CS00000@0
01W?00Paf@0FJ^h025GM4@3oool011gclNko03adooKfm?ofm_@QooKfl`03
00000?ofm_?om_Kc00Gom_Kc0`000002ooKfl`80000000?om_Kc00000000
00000_ofm_<300000004ooKfl`00000000000000023om_Kc00GomOGboo7`
joo[j>;o03ad=oooo`1C0?ooo`047O?ak_l0?7Com_KdooKfm1com_Kc00D0
0000ooKfloofm_?om_Kc00000002ooKfl`0300000?ofm_<0000000800000
6oofm_<01OoemO;olO3[on_Xh_l0?7@goooo00X0oooo00@Mlo7^o`0lM?of
m_Com_Kd3_ofm_<00`00003om_KcooKfl`05ooKfl`<000000_ofm_<20000
0003ooKfl`000000000000Com_Kc10000003ooKfl`<000001Oofm_<00`00
003om_KcooKfl`0=ooKfl`05ooGel_oal>_ojnSRo`0lM3Ooool0203oool0
0`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000NX04001><0000
10006Ll0237I01IZkP08EMdA0?ooo`037O?ak_l0?7Con?Sg02;on?Sf00D0
0000ooShm_ohn?Kon?Sf0000000fooShmP05ooOgmOoclNkokN[Vo`0lM3Oo
ool0D`3oool00agclNko03adooShm`0MooShmP0500000?ohn?Kon?SfooSh
mP0000000_ohn?H00`00003on?SfooShmP0MooShmP05ooOgmOoclNkokN[V
o`0lM3Ooool02P3oool00agclNko03adooShm`0?ooShmP0500000?ohn?Ko
n?SfooShmP0000008?ohn?H00`00003on?SfooShmP0=ooShmP05ooOgmOoc
lNkokN[Vo`0lM3Ooool0203oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_
k000B?4003gL000NX04001><000010006Ll0237I01IZkP08EMdA0?ooo`03
7O?ak_l0?7Con_[j02?on_[i1000000foo[jn@05oo[jn?oem?;ol>kZo`0l
M3Goool0D`3oool00agclNko03adoo[jnP0Noo[jn@<000000_ojn_T20000
01oon_[i00Gon_[hooGdl_o`k^[o03ad=Oooo`0:0?ooo`037O?ak_l0?7Co
n_[j013on_[i1000000Ooo[jn@8000003oojn_T01Oojn_SomOCboo3^j_l0
?7@eoooo00P0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000m
g0007Z01000CS00000@001W?00Paf@0FJ^h025GM4@3oool01Aobl>co03ad
oogmo?omoOcoo?cl05coo?ck00Cono_jooKdl_l0?7@/ooooD`3oool01Aob
l>co03adoogmo?omoOcoo?cl04?oo?ck00Cono_jooKdl_l0?7@/oooo2P3o
ool01Aobl>co03adoogmo?omoOcoo?cl04?oo?ck00Cono_jooKdl_l0?7@/
oooo203oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000N
X04001><000010006Ll0237I01IZkP08EMdA0?ooo`037O?ak_/UEhCo_lkL
05koo_kn00Coo_kmoko>fo/UEh@<ooooD`3oool00agclNkk9EN4oko>g015
ooknoP04ooknoOnoc]_k9EN43?ooo`X0oooo00<Mlo7^nbEGQ?noc]`0AOon
o_h01?ono_go_lkKnbEGQ0coool80?ooo`030>o_k03no_/0o_kk00d0o_kk
00@0kno/0018l@00?M`001jP0@004h`00004000Ic`08<MT05V[^00QEgA40
oooo00@Mlo7^eWfI[_mEOJ;o`<oMGOooool01?oEgnSoEGfReGjI[`Klo?]C
0?ooo`047O?ak]ImVJkoEGfRol3?gDCooooo00CoeMoXoeEmX]EnVJl6o?ck
2P3oool011gclNkFOIV^oeEmX_o0cme4ooooo`04omGOj?mEOJ;EOYV_1_cl
n`P0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z01
000CS00000@001W?00Paf@0FJ^h025GM4@3oool011Oelo5Ql^oXeWfI[_/U
EhAMo`0lM004oAI=O^=YRZALm?;[3?[ime<0oooo00@GmO?aHO;_j=ImVJkk
9EN4A?l0?7@01?dFCGkSJHZTG?Cbj`cjnOL:0?ooo`045oGclF7bknSFOIV^
nbEGQ4Co03ad00Cm5TenhfV:Y5cdl^/<n_Wg203oool00`3_kn`0o_kk0?kn
n`0=0?knn`040>o_k000B?4003gL000NX04001><000010006Ll0237I01IZ
kP08EMdA0?ooo`031_clnaOelo4Ol_3/02lQlNo[;33[j>838O7_j`047o;`
k1gclNhGmO?a1_clne<0oooo00<6o?ck5oGclAobl>`08b7akn/O<>_XhP<Q
lNo[00@Ol_3/7O?akQOelo46o?ck2P3oool00`Klo?/GmO?a7o;`k00S8O7_
jal`jnSR0b7akn/011obl>`Mlo7^5oGcl@Klo?/80?ooo`030>o_k03no_/0
o_kk00d0o_kk00@0kno/0018l@00?M`001jP0@004h`00004000Ic`08<MT0
5V[^00QEgOl0ooooM03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000
B?4003gL000NX04001><000010006Ll0237I01IZkP08EMgo0?ooog@0oooo
00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z01000CS000
00@001W?00Paf@0FJ^h025GMo`3ooomd0?ooo`030>o_k03no_/0o_kk00d0
o_kk00@0kno/0018l@00?M`001jP0@004h`00004000Ic`08<MT05V[^00QE
gOl0ooooM03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL
000NX04001><000010006Ll01c7H01IZkP08EMgo0?ooog@0oooo00<0kno/
0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z41000CS00000@001W?
00Laf00FJ^h025GMo`3ooomd0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0
kno/0018l@00?M`001jQ0@004h`00004000Ic`07<MP05V[^00QEgOl0oooo
M03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000NX@40
01><000010006Ll01c7H01IZkP08EMgo0?ooog@0oooo00<0kno/0?knn`3n
o_/03@3no_/0103_kn`004Sa000mg0007Z41000CS00000@001W?00Laf00F
J^h025GMo`3ooomd0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018
l@00?M`001jQ0@004h`00004000Ic`07<MP05V[^00QEg@X0ooooo`00001P
000000X0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg000
7Z41000CS00000@001W?00Laf00FJ^h025GMo`3ooomd0?ooo`030>o_k03n
o_/0o_kk00d0o_kk00@0kno/0018l@00?M`001jQ0@004h`00004000Ic`07
<MP05V[^00QEgOl0ooooM03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_
k000B?4003gL000NX@4001><000010006Ll01c7H01IZkP08EMgo0?ooog@0
oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z41000C
S00000@001W?00Laf00FJ^h025GMQ`3oool00`15CYT0oooo0?ooo`3Y0?oo
o`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001jQ0@004h`0
0004000Ic`07<MP05V[^00QEgHL0oooo00<0ADjI0?ooo`3oool0j@3oool0
0`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000NX@4001><0000
10006Ll01c7H01IZkP08EMd>0?ooo`<0ADjI0P3oool304E>V@<0oooo0`15
CYT40?ooo`0404E>V@3oool0oooo04E>V@80oooo00@0ADjI0?ooo`15CYT0
ADjI0`3oool304E>V@040?ooo`15CYT0ADjI04E>V@<0oooo0`15CYT40?oo
o`80ADjI0P3oool204E>V@H0oooo00D0ADjI0?ooo`3oool0oooo04E>V@02
0?ooo`80ADjI0P3oool204E>V@030?ooo`15CYT0ADjI0080ADjI00<0oooo
04E>V@15CYT00P3oool304E>V@@0oooo0P15CYT01@3oool0ADjI0?ooo`3o
ool0ADjI0080oooo0`15CYT60?ooo`<0ADjI0P3oool00`15CYT0oooo0?oo
o`0404E>V@040?ooo`15CYT0ADjI04E>V@80oooo00H0ADjI0?ooo`3oool0
ADjI0?ooo`15CYT20?ooo`80ADjI0P3oool304E>VMP0oooo00<0kno/0?kn
n`3no_/03@3no_/0103_kn`004Sa000mg0007Z41000CS00000@001W?00La
f00FJ^h025GM3@3oool01@15CYT0oooo0?ooo`3oool0ADjI00@0oooo00<0
ADjI0?ooo`15CYT01`3oool01P15CYT0oooo04E>V@3oool0ADjI0?ooo`80
ADjI0P3oool00`15CYT0oooo04E>V@020?ooo`0304E>V@3oool0oooo0080
oooo00<0ADjI0?ooo`15CYT01`3oool01015CYT0oooo0?ooo`15CYT20?oo
o`0304E>V@3oool0oooo00<0oooo00L0ADjI0?ooo`3oool0oooo04E>V@3o
ool0ADjI0080oooo00<0ADjI0?ooo`15CYT00P3oool01P15CYT0oooo0?oo
o`15CYT0oooo04E>V@80oooo00<0ADjI0?ooo`3oool01@3oool01015CYT0
oooo0?ooo`15CYT20?ooo`0304E>V@3oool0ADjI00P0oooo00L0ADjI0?oo
o`3oool0oooo04E>V@3oool0ADjI0080oooo00H0ADjI0?ooo`3oool0ADjI
0?ooo`15CYT20?ooo`0304E>V@3oool0ADjI0080oooo00D0ADjI0?ooo`15
CYT0oooo04E>V@020?ooo`0304E>V@3oool0oooo0080oooo00<0ADjI0?oo
o`3oool0e@3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL
000NX@4001><000010006Ll0237I01IZkP08EMd=0?ooo`0504E>V@3oool0
oooo0?ooo`15CYT00P3oool204E>V@80oooo1015CYT40?ooo`0604E>V@3o
ool0ADjI0?ooo`15CYT0oooo0P15CYT20?ooo`0304E>V@3oool0ADjI0080
oooo00<0ADjI0?ooo`3oool00P15CYT20?ooo`@0ADjI103oool01015CYT0
oooo0?ooo`15CYT20?ooo`0304E>V@3oool0oooo00<0oooo00@0ADjI0?oo
o`3oool0ADjI0P3oool01P15CYT0oooo0?ooo`15CYT0oooo04E>V@<0oooo
0`15CYT0103oool0ADjI0?ooo`3oool404E>V@@0oooo00@0ADjI0?ooo`3o
ool0ADjI0P3oool00`15CYT0oooo04E>V@0304E>V@D0oooo00L0ADjI0?oo
o`3oool0oooo04E>V@3oool0ADjI00<0oooo0`15CYT01`3oool0ADjI0?oo
o`3oool0ADjI0?ooo`15CYT00P3oool01@15CYT0oooo04E>V@3oool0ADjI
00D0oooo0P15CYWH0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018
l@00?]d001fP0@004h`00004000Ic`08<MT05V[^00QEg@d0oooo00L0ADjI
0?ooo`3oool0oooo04E>V@3oool0ADjI00@0oooo00@0ADjI0?ooo`3oool0
ADjI103oool01P15CYT0oooo04E>V@3oool0ADjI0?ooo`80ADjI0P3oool0
0`15CYT0oooo04E>V@020?ooo`0304E>V@3oool0ADjI00@0oooo00@0ADjI
0?ooo`3oool0ADjI103oool01015CYT0oooo0?ooo`15CYT20?ooo`0304E>
V@3oool0oooo00<0oooo1015CYT20?ooo`0604E>V@3oool0oooo04E>V@3o
ool0ADjI1@3oool00`15CYT0oooo04E>V@020?ooo`0404E>V@3oool0oooo
04E>V@@0oooo00@0ADjI0?ooo`3oool0ADjI0P3oool00`15CYT0oooo04E>
V@020?ooo`0304E>V@3oool0oooo00<0oooo00<0ADjI0?ooo`3oool00P15
CYT00`3oool0ADjI0?ooo`040?ooo`0304E>V@3oool0ADjI0080oooo00<0
ADjI0?ooo`15CYT00P3oool01@15CYT0oooo04E>V@3oool0ADjI0080oooo
00<0ADjI0?ooo`15CYT0fP3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_
k000B?4003kM000MX04001><000010006Ll0237I01IZkP08EMd=0?ooo`05
04E>V@3oool0oooo0?ooo`15CYT00P3oool304E>V@80oooo0P15CYT50?oo
o`80ADjI0`3oool204E>V@030?ooo`15CYT0ADjI0080oooo00@0ADjI0?oo
o`3oool0ADjI0P3oool304E>V@80oooo0P15CYT40?ooo`<0ADjI0P3oool2
04E>V@H0oooo00D0ADjI0?ooo`3oool0oooo04E>V@020?ooo`80ADjI00D0
oooo04E>V@15CYT0ADjI0?ooo`0704E>V@80oooo0P15CYT40?ooo`<0ADjI
00@0oooo04E>V@15CYT0ADjI0`3oool204E>V@H0oooo00<0ADjI0?ooo`3o
ool00`3oool704E>V@040?ooo`15CYT0ADjI04E>V@80oooo0`15CYT20?oo
o`0304E>V@3oool0oooo0080ADjI0`3oool304E>VML0oooo00<0kno/0?kn
n`3no_/03@3no_/0103_kn`004Sa000ng@007J01000CS00000@001W?00Pa
f@0FJ^h025GM3@3oool01@15CYT0oooo0?ooo`3oool0ADjI00h0oooo0P15
CYT30?ooo`80ADjI5`3oool00`15CYT0oooo0?ooo`090?ooo`0504E>V@3o
ool0oooo0?ooo`15CYT01P3oool00`15CYT0oooo0?ooo`050?ooo`0304E>
V@3oool0oooo00P0oooo00@0ADjI0?ooo`3oool0ADjI3@3oool01@15CYT0
oooo0?ooo`3oool0ADjI00h0oooo00<0ADjI0?ooo`3oool0i03oool00`3_
kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kM000MX04001><00001000
6Ll0237I01IZkP08EMd=0?ooo`0504E>V@3oool0oooo0?ooo`15CYT03P3o
ool00`15CYT0oooo0?ooo`030?ooo`0304E>V@3oool0oooo0240oooo1015
CYTM0?ooo`0304E>V@3oool0oooo00`0oooo0`15CYT?0?ooo`0304E>V@3o
ool0oooo0080oooo00<0ADjI0?ooo`3oool0g`3oool00`3_kn`0o_kk0?kn
n`0=0?knn`040>o_k000B?4003kM000MX04001><000010006Ll0237I01IZ
kP08EMgo0?ooog@0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa
000ng@007J01000CS00000@001W?00Paf@0FJ^h025GMo`3ooomd0?ooo`03
0>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]d001fP0@004h`00004
000Ic`08<MT05V[^00QEgOl0ooooM03oool00`3_kn`0o_kk0?knn`0=0?kn
n`040>o_k000B?4003kM000MX04001><000010006Ll0237I01IZkP08EMgo
0?ooog@0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng@00
7J01000CS00000@001W?00Paf@0FJ^h025GMo`3ooomd0?ooo`030>o_k03n
o_/0o_kk00d0o_kk00@0kno/0018l@00?]d001fP0@004h`00004000Ic`08
<MT05V[^00QEgOl0ooooM03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_
k000B?4003kM000MX04001><000010006Ll0237I01IZkP08EMg>0?ooo`<0
0000503oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo08H0
oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng@007J01000C
S00000@001W?00Laf@0FJ^h025GMc03oool2000001P0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`250?ooo`030>o_k03no_/0o_kk
00d0o_kk00@0kno/0018l@00?]d001jQ0@004h`00004000Ic`07<MT05V[^
00QEgLX0oooo0P00000J0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0Q03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?40
03kM000NX@4001><000010006Ll01c7I01IZkP08EMg70?ooo`<00000703o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo08@0oooo00<0
kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng@007Z41000CS00000@0
01W?00Laf@0FJ^h025GMa@3oool2000001l0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`230?ooo`030>o_k03no_/0o_kk00d0o_kk
00@0kno/0018l@00?]d001jQ0@004h`00004000Ic`07<MT05V[^00QEgL<0
oooo0P00000Q0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0P`3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kM000N
X@4001><000010006Ll01c7I01IZkP08EMg00?ooo`<000007P3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0PP3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kM
000NX@4001><000010006Ll01c7I01IZkP08EMfn0?ooo`8000009P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0840oooo00<0kno/
0?knn`3no_/03@3no_/0103_kn`004Sa000ng@007Z41000CS00000@001W?
00Laf@0FJ^h025GM_03oool2000002P0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`210?ooo`030>o_k03no_/0o_kk00d0o_kk00@0
kno/0018l@00?]d001jQ0@004h`00004000Ic`07<MT05V[^00QEgKT0oooo
0`00000Z0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
P03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kM000NX@40
01><000010006Ll01c7I01IZkP08EMfg0?ooo`800000;@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo0800oooo00<0kno/0?knn`3n
o_/03@3no_/0103_kn`004Sa000ng@007Z41000CS00000@001W?00Laf@0F
J^h025GM]@3oool2000002l0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`1o0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018
l@00?]d001jQ0@004h`00004000Ic`07<MT05V[^00QEgK80oooo0`00000a
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0O`3oool0
0`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kM000NX@4001><0000
10006Ll01c7I01IZkP08EMf`0?ooo`800000=03oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo07h0oooo00<0kno/0?knn`3no_/03@3n
o_/0103_kn`004Sa000ng@007Z41000CS00000@001W?00Laf@0FJ^h025GM
[P3oool2000003H0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`1m0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`0
01jP0@004h`00004000Ic`07<MT05V[^00QEgJ/0oooo0`00000h0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0O@3oool00`3_kn`0
o_kk0?knn`0=0?knn`040>o_k000B?4003kL000NX04001><000010006Ll0
1c7I01IZkP08EMfY0?ooo`800000?03oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo07`0oooo00<0kno/0?knn`3no_/03@3no_/0103_
kn`004Sa000ng0007Z01000CS00000@001W?00Laf@0FJ^h025GMY`3oool2
000003h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1l
0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jP0@00
4h`00004000Ic`07<MT05V[^00QEgJD0oooo0P0000100?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0N`3oool00`3_kn`0o_kk0?kn
n`0=0?knn`040>o_k000B?4003kL000NX04001><000010006Ll01c7I01IZ
kP08EMfR0?ooo`<00000@P3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo07X0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa
000ng0007Z01000CS00000@001W?00Laf@0FJ^h025GMX03oool2000004D0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1j0?ooo`03
0>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jP0@004h`00004
000Ic`07<MT05V[^00QEgIh0oooo0P0000170?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0N@3oool00`3_kn`0o_kk0?knn`0=0?kn
n`040>o_k000B?4003kL000NX04001><000010006Ll01c7I01IZkP08EMfK
0?ooo`<00000B@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo07T0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng000
7Z01000CS00000@001W?00Laf@0FJ^h025GMV@3oool2000004`0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`1h0?ooo`030>o_k03n
o_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jP0@004h`00004000Ic`07
<MT05V[^00QEgIL0oooo0P00001>0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool0M`3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_
k000B?4003kL000NX04001><000010006Ll01c7I01IZkP08EMfD0?ooo`<0
0000D03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo07L0
oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng0007Z01000C
S00000@001W?00Laf@0FJ^h025GMTP3oool2000005<0oooo00<000000?oo
o`3oool0403oool00`000000oooo0?ooo`1f0?ooo`030>o_k03no_/0o_kk
00d0o_kk00@0kno/0018l@00?Md001jP0@004h`00004000Ic`07<MT05V[^
00QEgI00oooo0P00001E0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool0MP3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?40
03gM000NX04001><000010006Ll01c7I01IZkP08EMf=0?ooo`<00000E`3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo07D0oooo00<0
kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg@007Z01000CS00000@0
01W?00Laf@0FJ^h025GMR`3oool2000005X0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`1d0?ooo`030>o_k03no_/0o_kk00d0o_kk
00@0kno/0018l@00?Md001jP0@004h`00004000Ic`07<MT05V[^00QEgHT0
oooo0P00001L0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3o
ool0M03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gM000N
X04001><000010006Ll01c7I01IZkP08EMf60?ooo`<00000G`3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo07<0oooo00<0kno/0?kn
n`3no_/03@3no_/0103_kn`004Sa000mg@007Z01000CS00000@001W?00La
f@0FJ^h025GMQ03oool200000680oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`1c0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/
0018l@00?Md001jP0@004h`00004000Ic`07<MT05V[^00QEgH80oooo0P00
001N0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3o
ool00`000000oooo0?ooo`1b0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0
kno/0018l@00?Md001jP0@004h`00004000Ic`07<MT05V[^00QEgGl0oooo
0`00001O0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`1b0?ooo`030>o_k03no_/0o_kk00d0o_kk
00@0kno/0018l@00?Md001jP0@004h`00004000Ic`07<MT05V[^00QEgGd0
oooo0P00001P0?ooo`8000000P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0L@3oool00`3_kn`0
o_kk0?knn`0=0?knn`040>o_k000B?4003gM000NX04001><000010006Ll0
1c7I01IZkP08EMek0?ooo`800000H03oool2000000<0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
0700oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg@007Z01
000CS00000@001W?00Laf@0FJ^h025GMN03oool300000640oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool0L03oool00`3_kn`0o_kk0?knn`0=
0?knn`040>o_k000B?4003gM000NX04001><000010006Ll01c7I01IZkP08
EMef0?ooo`800000HP3oool2000000D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo06l0oooo00<0
kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg@007Z01000CS00000@0
01W?00Laf@0FJ^h025GMM03oool2000006<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0K`3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_
k000B?4003gM000MX04001><000010006Ll01c7I01IZkP08EMeb0?ooo`80
0000H`3oool2000000H0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo06h0oooo00<0kno/0?knn`3n
o_/03@3no_/0103_kn`004Sa000mg@007J01000CS00000@001W?00Laf@0F
J^h025GMK`3oool3000006<0oooo0P0000070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1]0?oo
o`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?Md001fP0@004h`0
0004000Ic`07<MT05V[^00QEgFd0oooo0P00001U0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0H
0?ooo`030000003oool0oooo06d0oooo00<0kno/0?knn`3no_/03@3no_/0
103_kn`004Sa000mg@007J01000CS00000@001W?00Laf@0FJ^h025GMJ`3o
ool2000006H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0K03o
ool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gM000MX04001><
000010006Ll01c7I01IZkP08EMeX0?ooo`<00000IP3oool2000000P0oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo06`0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa
000mg@007J01000CS00000@001W?00Laf@0FJ^h025GMIP3oool2000006P0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0J`3oool00`3_kn`0
o_kk0?knn`0=0?knn`040>o_k000B?4003gM000MX04001><000010006Ll0
1c7I01IZkP08EMeT0?ooo`800000J@3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`1Z0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018
l@00?Md001fP0@004h`00004000Ic`07<MT05V[^00QEgF40oooo0`00001Y
0?ooo`8000002@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0JP3oool00`3_kn`0o_kk0?knn`0=
0?knn`040>o_k000B?4003gM000MX04001><000010006Ll01c7I01IZkP08
EMeO0?ooo`800000J`3oool00`000000oooo0?ooo`080?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`1Y0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?Md001fP
0@004h`00004000Ic`07<MT05V[^00QEgEd0oooo0P00001/0?ooo`030000
003oool0oooo00L0oooo0P00000B0?ooo`030000003oool0oooo01/0oooo
00<000000?ooo`3oool0J@3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_
k000B?4003gM000MX04001><000010006Ll01c7I01IZkP08EMeJ0?ooo`<0
0000K03oool2000000T0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0L0?ooo`030000003oool0oooo06P0oooo00<0kno/0?knn`3n
o_/03@3no_/0103_kn`004Sa000mg@007J01000CS00000@001W?00Laf@0F
J^h025GMF03oool2000006h0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0J03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL
000NX@4001><000010006Ll01c7I01IZkP08EMeF0?ooo`800000K`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`1W0?ooo`030>o_k03no_/0
o_kk00d0o_kk00@0kno/0018l@00?M`001jQ0@004h`00004000Ic`07<MT0
5V[^00QEgE<0oooo0`00001_0?ooo`8000002P3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0IP3o
ool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000NX@4001><
000010006Ll01c7I01IZkP08EMeA0?ooo`800000L@3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
7P3oool00`000000oooo0?ooo`1V0?ooo`030>o_k03no_/0o_kk00d0o_kk
00@0kno/0018l@00?M`001jQ0@004h`00004000Ic`07<MT05V[^00QEgDl0
oooo0P00001b0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06D0
oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z41000C
S00000@001W?00Laf@0FJ^h025GMC@3oool200000780oooo0P00000;0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool07`3oool00`00
0000oooo0?ooo`1U0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018
l@00?M`001jQ0@004h`00004000Ic`07<MT05V[^00QEgDd0oooo0P00001a
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo06@0oooo00<0kno/
0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z41000CS00000@001W?
00Laf@0FJ^h025GMC@3oool00`000000oooo0000001_0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo06<0oooo00<0kno/0?knn`3no_/03@3n
o_/0103_kn`004Sa000mg0007Z41000CS00000@001W?00Laf@0FJ^h025GM
C03oool01@000000oooo0?ooo`3oool0000006d0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0240
oooo00<000000?ooo`3oool0H`3oool00`3_kn`0o_kk0?knn`0=0?knn`04
0>o_k000B?4003gL000NX@4001><000010006Ll01c7I01IZkP08EMe<0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0J03oool20000
00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo0680oooo00<0kno/0?knn`3no_/03@3no_/0103_
kn`004Sa000mg0007Z41000CS00000@001W?00Laf@0FJ^h025GMC03oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo06H0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo0280oooo00<000000?ooo`3oool0HP3oool00`3_kn`0o_kk0?knn`0=
0?knn`040>o_k000B?4003gL000NX@4001><000010006Ll01c7I01IZkP08
EMe<0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0I03o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01l0oooo00<0
00000?ooo`3oool08P3oool00`000000oooo0?ooo`1Q0?ooo`030>o_k03n
o_/0o_kk00d0o_kk00@0kno/0018l@00?M`001jQ0@004h`00004000Ic`07
<MT05V[^00QEgD`0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`1R0?ooo`030000003oool0oooo00X0oooo0P00000R0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0H03oool00`3_kn`0o_kk
0?knn`0=0?knn`040>o_k000B?4003gL000NX@4001><000010006Ll0237I
01IZkP08EMe<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`00
0000H03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`1P0?ooo`03
0>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001jQ0@004h`00004
000Ic`08<MT05V[^00QEgD/0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`1N0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
05l0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z41
000CS00000@001W?00Paf@0FJ^h025GMB`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0G`3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?40
03gL000NX@4001><000010006Ll0237I01IZkP08EMe;0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0F@3oool2000000`0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo05h0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000m
g0007Z41000CS00000@001W?00Paf@0FJ^h025GMB`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo02H0oooo
00<000000?ooo`3oool0G@3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_
k000B?4003gL000NX@4001><000010006Ll0237I01IZkP08EMe;0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0E@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`1M0?ooo`030>o_k03no_/0o_kk00d0
o_kk00@0kno/0018l@00?M`001jQ0@004h`00004000Ic`08<MT05V[^00QE
gD/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1C0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo05`0oooo00<0kno/0?kn
n`3no_/03@3no_/0103_kn`004Sa000mg0007Z41000CS00000@001W?00Pa
f@0FJ^h025GMBP3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0540oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0G03oool0
0`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000NX@4001><0000
10006Ll0237I01IZkP08EMe:0?ooo`030000003oool0oooo0100oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`1K0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001jQ
0@004h`00004000Ic`08<MT05V[^00QEgDX0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`1<0?ooo`8000003@3oool00`000000oooo
0?ooo`0[0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
F`3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000NX@40
01><000010006Ll0237I01IZkP08EMe:0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo02`0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`1J0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00
?M`001jQ0@004h`00004000Ic`08<MT05V[^00QEgDX0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo05T0oooo00<0kno/0?knn`3no_/03@3no_/0103_
kn`004Sa000mg0007Z41000CS00000@001W?00Paf@0FJ^h025GMB@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0F@3oool00`3_kn`0o_kk0?knn`0=
0?knn`040>o_k000B?4003kM000MX@4001><000010006Ll0237I01IZkP08
EMe90?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool0:P3oool00`000000oooo0?ooo`1H0?ooo`030>o_k03n
o_/0o_kk00d0o_kk00@0kno/0018l@00?]d001fQ0@004h`00004000Ic`08
<MT05V[^00QEgDT0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`120?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
<@3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo05P0oooo
00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng@007J41000CS000
00@001W?00Paf@0FJ^h025GMB@3oool00`000000oooo0?ooo`0H0?ooo`03
0000003oool0oooo03l0oooo0P00000>0?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`1G0?ooo`03
0>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]d001fQ0@004h`00004
000Ic`08<MT05V[^00QEgDT0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0m0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0403ooolY000002T0oooo00<000000?ooo`3oool0EP3oool00`3_
kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kM000MX@4001><00001000
6Ll0237I01IZkP08EMe90?ooo`030000003oool0oooo01X0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0:0?oooaL000008`3oool0
0`000000oooo0?ooo`030?ooo`X000007`3oool00`000000oooo0?ooo`1F
0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]d001fQ0@00
4h`00004000Ic`08<MT05V[^00QEgDP0oooo00<000000?ooo`3oool0703o
ool00`000000oooo0?ooo`0i0?ooo`h000000P3oool00`000000oooo0?oo
o`0e0?ooo`030000003oool0oooo00d0oooo1P00000J0?ooo`030000003o
ool0oooo05D0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000n
g@007J41000CS00000@001W?00Paf@0FJ^h025GMB03oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo02/0oooo3@00000?0?ooo`030000
003oool0oooo03H0oooo00<000000?ooo`3oool04`3oool6000001@0oooo
00<000000?ooo`3oool0E@3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_
k000B?4003kM000MX@4001><000010006Ll0237I01IZkP08EMe80?ooo`03
0000003oool0oooo01h0oooo00<000000?ooo`3oool07P3oool<000000`0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0g0?ooo`03
0000003oool0oooo01T0oooo1000000A0?ooo`030000003oool0oooo05@0
oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng@007J41000C
S00000@001W?00Paf@0FJ^h025GMB03oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo0180oooo2`00000G0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0M0?oo
o`800000403oool00`000000oooo0?ooo`1C0?ooo`030>o_k03no_/0o_kk
00d0o_kk00@0kno/0018l@00?]d001fQ0@004h`00004000Ic`08<MT05V[^
00QEgDP0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`06
0?ooo`/000008@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo05<0oooo00<0kno/0?knn`3no_/03@3no_/0
103_kn`004Sa000ng@007J41000CS00000@001W?00Paf@0FJ^h025GMB03o
ool00`000000oooo0?ooo`0O0?ooocP00000303oool00`000000oooo0?oo
o`0j0?ooo`030000003oool0oooo0200oooo0P00000>0?ooo`030000003o
ool0oooo0580oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000n
g@007J41000CS00000@001W?00Paf@0FJ^h025GMA`3oool00`000000oooo
0?ooo`0F0?oooa<00000:`3oool010000000oooo0?ooo`3ooolE000003@0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo0580oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`0
04Sa000ng@007J41000CS00000@001W?00Paf@0FJ^h025GMA`3oool00`00
0000oooo0?ooo`0;0?ooo`d00000303oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0203oool80000
02`0oooo00<000000?ooo`3oool08`3oool2000000`0oooo00<000000?oo
o`3oool0D@3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL
000NX@4001><000010006Ll0237I01IZkP08EMe70?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo0140oooo1P00000V0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1A
0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@00
4h`00004000Ic`08<MT05V[^00QEgDL0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0603oool7000001l0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0500oooo00<0
kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng0007Z41000CS00000@0
01W?00Paf@0FJ^h025GMA`3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0P0?ooo`H000006P3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0C`3oool00`3_kn`0o_kk
0?knn`0=0?knn`040>o_k000B?4003kL000NX@4001><000010006Ll0237I
01IZkP08EMe60?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02L0
oooo1`00000C0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`1?0?ooo`030>o_k03no_/0o_kk00d0
o_kk00@0kno/0018l@00?]`001jQ0@004h`00004000Ic`08<MT05V[^00QE
gDH0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0S0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool0;`3oool50000
00h0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo04h0oooo00<0kno/0?knn`3no_/03@3no_/0103_
kn`004Sa000ng0007Z41000CS00000@001W?00Paf@0FJ^h025GMAP3oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0e0?ooo`<000002`3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0CP3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?40
03kL000NX@4001><000010006Ll0237I01IZkP08EMe60?ooo`030000003o
ool0oooo02/0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo03T0oooo0P0000090?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`1=0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ
0@004h`00004000Ic`08<MT05V[^00QEgDH0oooo00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00`0oooo
00<000000?ooo`3oool0?03oool3000000H0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04`0oooo
00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng0007Z41000CS000
00@001W?00Paf@0FJ^h025GMAP3oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0303oool00`000000
oooo0?ooo`100?ooo`<000000`3oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool0C03oool00`3_kn`0
o_kk0?knn`0=0?knn`040>o_k000B?4003kL000NX@4001><000010006Ll0
237I01IZkP08EMe50?ooo`030000003oool0oooo02l0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
04<0oooo0P0000000`3oool000000?ooo`0R0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0B`3oool00`3_kn`0o_kk0?knn`0=0?kn
n`040>o_k000B?4003kL000NX@4001><000010006Ll0237I01IZkP08EMe5
0?ooo`030000003oool0oooo0300oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo04H0oooo0`00000R
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0B`3oool0
0`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL000NX@4001><0000
10006Ll0237I01IZkP08EMe50?ooo`030000003oool0oooo0340oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`0000000P00000M0?ooo`8000004P3o
ool3000000030?ooo`000000oooo04/0oooo00<0kno/0?knn`3no_/03@3n
o_/0103_kn`004Sa000ng0007Z41000CS00000@001W?00Paf@0FJ^h025GM
A@3oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo0080oooo0`00000I0?ooo`030000003oool0oooo00l0oooo
0`0000040?ooo`030000003oool0oooo04X0oooo00<0kno/0?knn`3no_/0
3@3no_/0103_kn`004Sa000ng0007Z41000CS00000@001W?00Paf@0FJ^h0
25GMA@3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo00D0oooo0P00000E0?ooo`8000003`3oool3000000L0
oooo00<000000?ooo`3oool0BP3oool00`3_kn`0o_kk0?knn`0=0?knn`04
0>o_k000B?4003kL000NX@4001><000010006Ll0237I01IZkP08EMe50?oo
o`030000003oool0oooo03@0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`3oool01`3oool300000140oooo00<000000?ooo`3oool0303oool30000
00030?ooo`000000oooo00L0oooo00<000000?ooo`3oool0BP3oool00`3_
kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL000NX@4001><00001000
6Ll0237I01IZkP08EMe40?ooo`030000003oool0oooo03H0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo04/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<
0?ooo`800000303oool3000000d0oooo00<000000?ooo`3oool0BP3oool0
0`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL000NX@4001><0000
10006Ll0237I01IZkP08EMe40?ooo`030000003oool0oooo03L0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo04`0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo00T0oooo0`00000@0?ooo`030000003o
ool0oooo04X0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000n
g0007Z41000CS00000@001W?00Paf@0FJ^h025GMA03oool00`000000oooo
0?ooo`0h0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool01`3oool2000000T0oooo0`00000D0?ooo`030000
003oool0oooo04T0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa
000ng0007Z41000CS00000@001W?00Paf@0FJ^h025GMA03oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`<0
00005`3oool00`000000oooo0?ooo`190?ooo`030>o_k03no_/0o_kk00d0
o_kk00@0kno/0018l@00?]`001jQ0@004h`00004000Ic`08<MT05V[^00QE
gD@0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0C`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo0P0000060?oo
o`<000006P3oool00`000000oooo0?ooo`190?ooo`030>o_k03no_/0o_kk
00d0o_kk00@0kno/0018l@00?]`001jQ0@004h`00004000Ic`08<MT05V[^
00QEgD@0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0D03oool0
0`000000oooo0?ooo`0>0?ooo`040000003oool00000000000D0oooo0`00
000M0?ooo`030000003oool0oooo04T0oooo00<0kno/0?knn`3no_/03@3n
o_/0103_kn`004Sa000ng0007Z41000CS00000@001W?00Paf@0FJ^h025GM
@`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1@0?ooo`030000
003oool0oooo00h0oooo0P0000040?ooo`<00000803oool00`000000oooo
0?ooo`190?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`0
01jQ0@004h`00004000Ic`08<MT05V[^00QEgD<0oooo00<000000?ooo`3o
ool0?P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0<0?ooo`80
00000P3oool4000002<0oooo00<000000?ooo`3oool0B@3oool00`3_kn`0
o_kk0?knn`0=0?knn`040>o_k000B?4003kL000NX@4001><000010006Ll0
237I01IZkP08EMe30?ooo`030000003oool0oooo03l0oooo00@000000?oo
o`3oool000003`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0
oooo00X0oooo0P0000020?ooo`@000009@3oool00`000000oooo0?ooo`19
0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@00
4h`00004000Ic`08<MT05V[^00QEgD<0oooo00<000000?ooo`3oool0@03o
ool200000100oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`080?ooo`80000000@0oooo0000000000000000103oool2000002@0oooo
00<000000?ooo`3oool0B03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_
k000B?4003kL000NX@4001><000010006Ll0237I01IZkP08EMe30?ooo`03
0000003oool0oooo0440oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`1C0?ooo`030000003oool0oooo00D0oooo1P0000090?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool0B03oool00`3_kn`0
o_kk0?knn`0=0?knn`040>o_k000B?4003kL000NX@4001><000010006Ll0
237I01IZkP08EMe20?ooo`030000003oool0oooo0440oooo00<000000?oo
o`0000003P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
00<0oooo1@00000=0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0B03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL
000NX@4001><000010006Ll0237I01IZkP08EMe20?ooo`030000003oool0
oooo0400oooo00D000000?ooo`3oool0oooo0000000=0?ooo`030000003o
ool0oooo05<0oooo00@000000?ooo`3oool0oooo1000000A0?ooo`030000
003oool0oooo01l0oooo00<000000?ooo`3oool0B03oool00`3_kn`0o_kk
0?knn`0=0?knn`040>o_k000B?4003kL000NX@4001><000010006Ll0237I
01IZkP08EMe20?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo05@0
oooo00<000000?ooo`0000000P00000E0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0B03oool00`3_kn`0o_kk0?knn`0=0?knn`04
0>o_k000B?4003kL000NX@4001><000010006Ll0237I01IZkP08EMe20?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo0580oooo1000000I0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0B03oool00`3_
kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL000NX@4001><00001000
6Ll0237I01IZkP08EMe20?ooo`030000003oool0oooo03h0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo04l0oooo100000000`3oool000000?ooo`0J0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0A`3oool00`3_kn`0o_kk0?knn`0=
0?knn`040>o_k000B?4003kL000NX@4001><000010006Ll0237I01IZkP08
EMe20?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04d0oooo1@00
00030?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`170?ooo`030>o_k03no_/0o_kk00d0o_kk00@0
kno/0018l@00?]`001jQ0@004h`00004000Ic`08<MT05V[^00QEgD40oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0BP3oool5000000L0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo04L0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa
000ng0007Z41000CS00000@001W?00Paf@0FJ^h025GM@@3oool00`000000
oooo0?ooo`0m0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`170?ooo`D000002P3oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3o
ool0A`3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL000N
X@4001><000010006Ll0237I01IZkP08EMe10?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool03@3oool01@000000oooo0?ooo`3oool0
000004L0oooo1000000>0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`170?ooo`030>o_k03no_/0
o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@004h`00004000Ic`08<MT0
5V[^00QEgD40oooo00<000000?ooo`3oool0?03oool00`000000oooo0?oo
o`0>0?ooo`040000003oool0oooo000004@0oooo1000000A0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool07@3oool00`000000oooo
0?ooo`170?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`0
01jQ0@004h`00004000Ic`08<MT05V[^00QEgD40oooo00<000000?ooo`3o
ool0>`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool000000440
oooo1000000D0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`170?ooo`030>o_k03no_/0o_kk00d0
o_kk00@0kno/0018l@00?]`001jQ0@004h`00004000Ic`08<MT05V[^00QE
gD40oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0000003d0oooo1000000G0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`160?oo
o`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@004h`0
0004000Ic`08<MT05V[^00QEgD00oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0000003T0oooo1000000J
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`160?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/
0018l@00?]`001jQ0@004h`00004000Ic`08<MT05V[^00QEgD00oooo00<0
00000?ooo`3oool0>P3oool00`000000oooo0?ooo`0E0?ooo`800000=@3o
ool5000001d0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo04H0oooo00<0kno/0?knn`3no_/03@3n
o_/0103_kn`004Sa000ng0007Z41000CS00000@001W?00Paf@0FJ^h025GM
@03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01H0oooo
0P00000`0?ooo`D000008@3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo01h0oooo00<000000?ooo`3oool0AP3oool00`3_kn`0o_kk
0?knn`0=0?knn`040>o_k000B?4003kL000NX@4001><000010006Ll0237I
01IZkP08EMe00?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`0Y0?ooo`L00000903oool00`000000
oooo0?ooo`0H0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0AP3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL000N
X@4001><000010006Ll0237I01IZkP08EMe00?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0T0?oo
o`@0000000@0oooo00000000000000009`3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0AP3oool0
0`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL000NX@4001><0000
10006Ll0237I01IZkP08EMdo0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool06P3oool4000001h0oooo100000020?ooo`<00000:P3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool0AP3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000
B?4003kL000NX@4001><000010006Ll0237I01IZkP08EMdo0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`05000000h0oooo2`0000030?ooo`<00000;@3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
A@3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL000NX@40
01><000010006Ll0237I01IZkP08EMdo0?ooo`030000003oool0oooo03X0
oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`040?ooo`h0
00002`3oool300000300oooo00<000000?ooo`3oool06@3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo04D0oooo00<0kno/0?knn`3n
o_/03@3no_/0103_kn`004Sa000ng0007Z41000CS00000@001W?00Paf@0F
J^h025GM?`3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
01h0oooo00<000000?ooo`3oool06@3oool3000003<0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
04D0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng0007Z41
000CS00000@001W?00Paf@0FJ^h025GM?`3oool00`000000oooo0?ooo`0i
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool05@3oool3
000003L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo04D0oooo00<0kno/0?knn`3no_/03@3no_/0
103_kn`004Sa000ng0007Z41000CS00000@001W?00Paf@0FJ^h025GM?`3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0403oool4000003X0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo04D0oooo00<0
kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng0007Z41000CS00000@0
01W?00Paf@0FJ^h025GM?P3oool00`000000oooo0?ooo`0i0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool0303oool3000003h0oooo
00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo04D0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa
000ng0007Z41000CS00000@001W?00Paf@0FJ^h025GM?P3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0203oool300000440oooo00<000000?ooo`3oool0603oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo04D0oooo00<0kno/0?knn`3n
o_/03@3no_/0103_kn`004Sa000ng0007Z41000CS00000@001W?00Paf@0F
J^h025GM?P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo
02@0oooo00<000000?ooo`3oool0103oool3000004@0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
04@0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng0007Z41
000CS00000@001W?00Paf@0FJ^h025GM?P3oool00`000000oooo0?ooo`0h
0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool00`000017
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`140?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/
0018l@00?]`001jQ0@004h`00004000Ic`08<MT05V[^00QEgCh0oooo00<0
00000?ooo`3oool0>03oool00`000000oooo0?ooo`0W0?ooo`<00000B@3o
ool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool0A03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000
B?4003kL000NX@4001><000010006Ll0237I01IZkP08EMdn0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool09`3oool00`000000oooo
0?ooo`130?ooo`030000003oool0oooo0080oooo0P00000G0?ooo`030000
003oool0oooo0280oooo00<000000?ooo`3oool0A03oool00`3_kn`0o_kk
0?knn`0=0?knn`040>o_k000B?4003kL000NX@4001><000010006Ll0237I
01IZkP08EMdm0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`150?ooo`<000000P3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3o
ool0A03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL000N
X@4001><000010006Ll0237I01IZkP08EMdm0?ooo`030000003oool0oooo
03P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`120?oo
o`<000001@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0A03oool00`3_kn`0o_kk0?knn`0=0?kn
n`040>o_k000B?4003kL000NX@4001><000010006Ll0237I01IZkP08EMdm
0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0:03oool0
0`000000oooo0?ooo`0o0?ooo`<000002@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0@`3oool0
0`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL000NX@4001><0000
10006Ll0237I01IZkP08EMdm0?ooo`030000003oool0oooo03P0oooo00<0
00000?ooo`3oool0:03oool00`000000oooo0?ooo`0k0?ooo`@000003@3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02D0oooo00<0
00000?ooo`3oool0@`3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000
B?4003kL000NX@4001><000010006Ll0237I01IZkP08EMdm0?ooo`030000
003oool0oooo03P0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0h0?ooo`<000004P3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool0@`3oool00`3_kn`0o_kk
0?knn`0=0?knn`040>o_k000B?4003kL000NX@4001><000010006Ll0237I
01IZkP08EMdl0?ooo`030000003oool0oooo03T0oooo00<000000?ooo`3o
ool0:03oool00`000000oooo0?ooo`0e0?ooo`<000005P3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool0@`3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL000N
X@4001><000010006Ll0237H01IZkP08EMdl0?ooo`030000003oool0oooo
03X0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0b0?oo
o`<000006@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool0@`3oool00`3_kn`0o_kk0?knn`0=0?kn
n`040>o_k000B?4003kL000NX@4001><000010006Ll0237H01IZkP08EMdl
0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`0^0?ooo`@000007@3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0@`3oool0
0`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL000NX@4001><0000
10006Ll0237H01IZkP08EMdl0?ooo`030000003oool0oooo03X0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0/0?ooo`<000008P3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool0@`3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000
B?4003kL000NX@4001><000010006Ll0237H01IZkP08EMdl0?ooo`030000
003oool0oooo03X0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`0Y0?ooo`<000009P3oool00`000000oooo0?ooo`080?ooo`030000
003oool0oooo02T0oooo00<000000?ooo`3oool0@P3oool00`3_kn`0o_kk
0?knn`0=0?knn`040>o_k000B?4003kL000NX@4001><000010006Ll0237H
01IZkP08EMdl0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0V0?ooo`<00000:P3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3o
ool0@P3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL000N
X@4001><000010006Ll0237H01IZkP08EMdk0?ooo`030000003oool0oooo
03`0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0R0?oo
o`@00000603oool500000100oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo0480oooo00<0kno/0?kn
n`3no_/03@3no_/0103_kn`004Sa000ng0007Z41000CS00000@001W?00Pa
f00FJ^h025GM>`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool07`3oool300000100oooo30000005
0?ooo`D00000303oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo02X0oooo00<000000?ooo`3oool0@P3oool00`3_kn`0o_kk0?knn`0=
0?knn`040>o_k000B?4003kL000NX@4001><000010006Ll0237H01IZkP08
EMdk0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`0L0?ooo`<000001`3oool<000001H0oooo1@00
00080?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`120?ooo`030>o_k03no_/0o_kk00d0o_kk00@0
kno/0018l@00?]`001jQ0@004h`00004000Ic`08<MP05V[^00QEgC/0oooo
00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0T0?ooo`030000
003oool0oooo01T0oooo0`0000030?ooo`L000009`3oool5000000@0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0[0?ooo`030000
003oool0oooo0480oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa
000ng0007Z41000CS00000@001W?00Paf00FJ^h025GM>`3oool00`000000
oooo0?ooo`0m0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool05@3oool4000000030?ooo`000000000000<00000<`3oool2000000<0
oooo00@000000?ooo`3oool00000;P3oool00`000000oooo0?ooo`120?oo
o`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001jQ0@004h`0
0004000Ic`08<MP05V[^00QEgC/0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo0180oooo2000000j
0?ooo`060000003oool0oooo0000003oool00000<03oool00`000000oooo
0?ooo`110?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`0
01jQ0@004h`00004000Ic`08<MP05V[^00QEgCX0oooo00<000000?ooo`3o
ool0?`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00l0
oooo1P00000o0?ooo`050000003oool0oooo0?ooo`000000<@3oool00`00
0000oooo0?ooo`110?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018
l@00?]`001jQ0@004h`00004000Ic`08<MP05V[^00QEgCX0oooo00<00000
0?ooo`3oool0?`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo00`0oooo1@0000130?ooo`060000003oool0oooo0000003oool00000
<03oool00`000000oooo0?ooo`110?ooo`030>o_k03no_/0o_kk00d0o_kk
00@0kno/0018l@00?]`001jQ0@004h`00004000Ic`07<]T05V[^00QEgCX0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo00L0oooo1@0000190?ooo`8000000`3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo0440oooo00<0kno/0?knn`3n
o_/03@3no_/0103_kn`004Sa000mg0007Z01000CS00000@001W?00Lbf@0F
J^h025GM>P3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
0280oooo00<000000?ooo`3oool00P3oool6000004d0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo
0440oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z01
000CS00000@001W?00Lbf@0FJ^h025GM>P3oool00`000000oooo0?ooo`11
0?ooo`030000003oool0oooo0240oooo2000001?0?ooo`8000001@3oool0
0`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0440oooo00<0kno/
0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z01000CS00000@001W?
00Lbf@0FJ^h025GM>@3oool00`000000oooo0?ooo`130?ooo`030000003o
ool0oooo01d0oooo10000000103oool0000000000000001A0?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`3oool0;03oool00`000000
oooo0?ooo`100?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00
?M`001jP0@004h`00004000Ic`07<]T05V[^00QEgCT0oooo00<000000?oo
o`3oool0A03oool2000001X0oooo0`0000000`3oool00000000000020000
05<0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0
oooo02/0oooo00<000000?ooo`3oool0@03oool00`3_kn`0o_kk0?knn`0=
0?knn`040>o_k000B?4003gL000NX04001><000010006Ll01c;I01IZkP08
EMdi0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0503o
ool3000000040?ooo`000000000000000080oooo00<000000?ooo`3oool0
D@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`100?ooo`030>o_
k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001jP0@004h`00004000I
c`07<]T05V[^00QEgCT0oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`0@0?ooo`<0000000@0oooo00000000000000001@3oool00`00
0000oooo0?ooo`1@0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
0400oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z01
000CS00000@001W?00Lbf@0FJ^h025GM>@3oool00`000000oooo0?ooo`18
0?ooo`030000003oool0oooo00/0oooo10000000103oool0000000000000
00080?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02T0oooo00<0
00000?ooo`3oool0@03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000
B?4003gL000NX04001><000010006Ll01c;I01IZkP08EMdi0?ooo`030000
003oool0oooo04T0oooo0P0000080?ooo`<0000000<0oooo000000000000
0P00000;0?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0@03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_
k000B?4003gL000NX04001><000010006Ll01c;I01IZkP08EMdh0?ooo`03
0000003oool0oooo04`0oooo00<000000?ooo`3oool00P3oool300000004
0?ooo`0000000000000000l0oooo00<000000?ooo`3oool0CP3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`100?ooo`030>o_k03no_/0o_kk
00d0o_kk00@0kno/0018l@00?M`001jP0@004h`00004000Ic`07<]T05V[^
00QEgCP0oooo00<000000?ooo`3oool0C@3oool4000000040?ooo`000000
000000000180oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0o0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0
kno/0018l@00?M`001jP0@004h`00004000Ic`07<]T05V[^00QEgCP0oooo
00<000000?ooo`3oool0BP3oool8000001D0oooo00<000000?ooo`3oool0
C03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0o0?ooo`030>o_
k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001jP0@004h`00004000I
c`08<MP05V[^00QEgCP0oooo00<000000?ooo`3oool0A`3oool300000003
0?ooo`000000000000<000005`3oool00`000000oooo0?ooo`1;0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo03l0oooo00<0kno/0?knn`3n
o_/03@3no_/0103_kn`004Sa000mg0007Z01000CS00000@001W?00Paf00F
J^h025GM>03oool00`000000oooo0?ooo`140?ooo`<0000000@0oooo0000
0000000000001@3oool2000001D0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0o0?ooo`030>o_k03no_/0
o_kk00d0o_kk00@0kno/0018l@00?M`001jP0@004h`00004000Ic`08<MP0
5V[^00QEgCP0oooo00<000000?ooo`3oool0@P3oool2000000040?ooo`00
00000000000000X0oooo0`00000B0?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0?`3oool00`3_kn`0o_kk
0?knn`0=0?knn`040>o_k000B?4003gL000NX04001><000010006Ll0237H
01IZkP08EMdg0?ooo`030000003oool0oooo0400oooo1P00000@0?ooo`<0
00003`3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo03l0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`0
04Sa000mg0007Z01000CS00000@001W?00Paf00FJ^h025GM=`3oool00`00
0000oooo0?ooo`0n0?ooo`D000005P3oool2000000`0oooo00<000000?oo
o`3oool0B03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0o0?oo
o`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001jP0@004h`0
0004000Ic`08<MP05V[^00QEgCL0oooo00<000000?ooo`3oool0?03oool3
000001`0oooo0`0000090?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0?P3oool00`3_kn`0o_kk0?knn`0=
0?knn`040>o_k000B?4003gL000NX04001><000010006Ll0237H01IZkP08
EMdg0?ooo`030000003oool0oooo03T0oooo0`00000R0?ooo`<000001P3o
ool00`000000oooo0?ooo`150?ooo`8000001`3oool00`000000oooo0?oo
o`0H0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0?P3o
ool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000NX04001><
000010006Ll0237H01IZkP08EMdg0?ooo`030000003oool0oooo03H0oooo
0`00000X0?ooo`<000000`3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo03h0oooo00<0kno/0?knn`3no_/0
3@3no_/0103_kn`004Sa000mg0007Z01000CS00000@001W?00Paf00FJ^h0
25GM=`3oool00`000000oooo0?ooo`0b0?ooo`D00000;@3oool4000004D0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0L0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0?P3oool00`3_kn`0
o_kk0?knn`0=0?knn`040>o_k000B?4003gL000NX04001><000010006Ll0
237H01IZkP08EMdf0?ooo`030000003oool0oooo0300oooo0`0000000`3o
ool000000000000b0?ooo`<00000@P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool0803oool00`00
0000oooo0?ooo`0n0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018
l@00?M`001jP0@004h`00004000Ic`08<MP05V[^00QEgCH0oooo00<00000
0?ooo`3oool0;@3oool3000000040?ooo`0000000000000003@0oooo00<0
00000?ooo`3oool01000000m0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo03h0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000m
g0007Z01000CS00000@001W?00Paf00FJ^h025GM=P3oool00`000000oooo
0?ooo`0Z0?ooo`<000000P3oool2000003L0oooo00<000000?ooo`3oool0
103oool5000003H0oooo0P0000070?ooo`8000008`3oool00`000000oooo
0?ooo`0O0?ooo`030000003oool0oooo03d0oooo00<0kno/0?knn`3no_/0
3@3no_/0103_kn`004Sa000mg0007Z01000CS00000@001W?00Paf00FJ^h0
25GM=P3oool00`000000oooo0?ooo`0V0?ooo`@000000`3oool2000003T0
oooo00<000000?ooo`3oool02@3oool6000002l0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0?@3oool00`3_kn`0o_kk0?knn`0=0?knn`04
0>o_k000B?4003gL000NX04001><000010006Ll01c;I01IZkP08EMdf0?oo
o`030000003oool0oooo02<0oooo0`0000050?ooo`800000>`3oool00`00
0000oooo0?ooo`0?0?ooo`H00000:03oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0m0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018
l@00?Md001jP0@004h`00004000Ic`07<]T05V[^00QEgCD0oooo00<00000
0?ooo`3oool08@3oool3000000L0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0E0?ooo`H000008@3oool00`000000oooo0?ooo`05
0?ooo`800000:@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo03d0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg@00
7Z01000CS00000@001W?00Lbf@0FJ^h025GM=@3oool00`000000oooo0?oo
o`0N0?ooo`<00000203oool2000003h0oooo00<000000?ooo`3oool06`3o
ool5000001X0oooo0P0000070?ooo`030000003oool0oooo02X0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0m0?ooo`030>o_k03n
o_/0o_kk00d0o_kk00@0kno/0018l@00?Md001jP0@004h`00004000Ic`07
<]T05V[^00QEgCD0oooo00<000000?ooo`3oool06P3oool4000000X0oooo
00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0P0?ooo``00000
3@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02`0oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0m0?ooo`030>o_
k03no_/0o_kk00d0o_kk00@0kno/0018l@00?Md001jP0@004h`00004000I
c`07<]T05V[^00QEgCD0oooo00<000000?ooo`3oool05`3oool3000000d0
oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0/0?ooo`/0
000000<0oooo0000003oool01`3oool00`000000oooo0?ooo`0^0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0?@3oool00`3_kn`0
o_kk0?knn`0=0?knn`040>o_k000B?4003gM000NX04001><000010006Ll0
1c;I01IZkP08EMde0?ooo`030000003oool0oooo01@0oooo0`00000>0?oo
o`800000@P3oool00`000000oooo0?ooo`0g0?ooo``00000<03oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo03`0oooo00<0kno/0?kn
n`3no_/03@3no_/0103_kn`004Sa000mg@007Z01000CS00000@001W?00Lb
f@0FJ^h025GM=@3oool00`000000oooo0?ooo`0@0?ooo`@00000403oool0
0`000000oooo0?ooo`120?ooo`030000003oool0oooo03D0oooo0P000007
0?ooo`030000003oool0oooo0080oooo5`00000I0?ooo`030000003oool0
oooo01X0oooo00<000000?ooo`3oool0?03oool00`3_kn`0o_kk0?knn`0=
0?knn`040>o_k000B?4003gM000NX04001><000010006Ll01c;I01IZkP08
EMdd0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`00
000C0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0=03o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01X0oooo6`00
000K0?ooo`030000003oool0oooo03`0oooo00<0kno/0?knn`3no_/03@3n
o_/0103_kn`004Sa000mg@007Z01000CS00000@001W?00Lbf@0FJ^h025GM
=03oool00`000000oooo0?ooo`0;0?ooo`<00000503oool2000004H0oooo
00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo03H0oooo3@00000>0?ooo`030000003oool0oooo03`0oooo
00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg@007Z01000CS000
00@001W?00Lbf@0FJ^h025GM=03oool00`000000oooo0?ooo`080?ooo`<0
00005P3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo0380
oooo00<000000?ooo`3oool01@3oool2000003X0oooo00<000000?ooo`3o
ool02@3oool3000000/0oooo00<000000?ooo`3oool0?03oool00`3_kn`0
o_kk0?knn`0=0?knn`040>o_k000B?4003gM000NX04001><000010006Ll0
1c;I01IZkP08EMdd0?ooo`030000003oool0oooo00@0oooo1000000H0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool0<03oool20000
00L0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0?03oool00`3_
kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gM000NX04001><00001000
6Ll01c;I01IZkP08EMdd0?ooo`040000003oool0oooo0?ooo`<00000703o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo02l0oooo00<0
00000?ooo`3oool01@3oool2000003h0oooo00<000000?ooo`3oool0103o
ool5000000d0oooo00<000000?ooo`3oool0?03oool00`3_kn`0o_kk0?kn
n`0=0?knn`040>o_k000B?4003gM000NX04001><000010006Ll0237I01IZ
kP08EMdd0?ooo`@000007`3oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo02d0oooo0P0000060?ooo`800000@@3oool6000001<0oooo
00<000000?ooo`3oool0>`3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_
k000B?4003gL000NX04001><000010006Ll0237I01IZkP08EMdd0?ooo`03
0000003oool0oooo0200oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`0/0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0?03oool5000000030?ooo`000000oooo01H0oooo00<000000?ooo`3o
ool0>`3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000N
X04001><000010006Ll0237I01IZkP08EMde0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0Z0?oo
o`8000001P3oool2000003L0oooo200000070?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0>`3oool00`3_kn`0o_kk0?knn`0=0?kn
n`040>o_k000B?4003gL000NX04001><000010006Ll0237I01IZkP08EMdf
0?ooo`8000007`3oool00`000000oooo0?ooo`170?ooo`030000003oool0
oooo02T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0_
0?ooo`P00000403oool00`000000oooo0?ooo`0C0?ooo`030000003oool0
oooo03/0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg000
7Z01000CS00000@001W?00Paf@0FJ^h025GM>03oool00`000000oooo0?oo
o`0L0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0:03o
ool00`000000oooo0?ooo`040?ooo`800000:P3oool8000001P0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0k0?ooo`030>o_k03n
o_/0o_kk00d0o_kk00@0kno/0018l@00?M`001jP0@004h`00004000Ic`08
<MT05V[^00QEgCT0oooo0P00000M0?ooo`030000003oool0oooo04D0oooo
00<000000?ooo`3oool09`3oool2000000H0oooo00<000000?ooo`3oool0
8P3oool800000240oooo00<000000?ooo`3oool04P3oool00`000000oooo
0?ooo`0k0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`0
01jP0@004h`00004000Ic`08<MT05V[^00QEgC/0oooo00<000000?ooo`3o
ool06P3oool2000004H0oooo00<000000?ooo`3oool09P3oool00`000000
oooo0?ooo`040?ooo`8000006`3oool:000002X0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`0k0?ooo`030>o_k03no_/0o_kk00d0
o_kk00@0kno/0018l@00?M`001jP0@004h`00004000Ic`08<MT05V[^00QE
gC`0oooo0P00000L0?ooo`<00000@`3oool00`000000oooo0?ooo`0T0?oo
o`8000001@3oool200000180oooo2`00000e0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0>P3oool00`3_kn`0o_kk0?knn`0=0?kn
n`040>o_k000B?4003gL000NX04001><000010006Ll0237I01IZkP08EMdn
0?ooo`030000003oool0oooo01`0oooo0`0000100?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`08
0?ooo`X00000@@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0
oooo03X0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg000
7Z01000CS00000@001W?00Paf@0FJ^h025GM?`3oool2000001l0oooo0`00
000m0?ooo`030000003oool0oooo0240oooo0P0000050?ooo`d00000B`3o
ool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03X0oooo00<0
kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z01000CS00000@0
01W?00Paf@0FJ^h025GM@@3oool00`000000oooo0?ooo`0O0?ooo`<00000
>P3oool00`000000oooo0?ooo`0J0?ooo`l00000F03oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo03X0oooo00<0kno/0?knn`3no_/0
3@3no_/0103_kn`004Sa000mg0007Z01000CS00000@001W?00Paf@0FJ^h0
25GM@P3oool200000280oooo2`00000_0?ooo`030000003oool0oooo00/0
oooo3`0000040?ooo`8000001@3oool2000005/0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0j0?ooo`030>o_k03no_/0o_kk00d0
o_kk00@0kno/0018l@00?M`001jP0@004h`00004000Ic`08<MT05V[^00QE
gD@0oooo00<000000?ooo`3oool0:P3oool?000000d0oooo8@00000B0?oo
o`030000003oool0oooo00<0oooo0P00001N0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0>P3oool00`3_kn`0o_kk0?knn`0=0?kn
n`040>o_k000B?4003gL000NX04001><000010006Ll0237H01IZkP08EMe5
0?ooo`800000>@3oool=000001<0oooo00<000000?ooo`3oool06`3oool2
000000@0oooo0P00001P0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0>@3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?40
03gL000MX04001><000010006Ll0237H01IZkP08EMe70?ooo`030000003o
ool0oooo05H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0640oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0i0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0
kno/0018l@00?M`001fP0@004h`00004000Ic`08<MP05V[^00QEgDP0oooo
0P00001F0?ooo`030000003oool0oooo01P0oooo0P0000040?ooo`800000
I@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo03T0oooo
00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007J01000CS000
00@001W?00Paf00FJ^h025GMBP3oool00`000000oooo0?ooo`1C0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool00P3oool2000006P0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0i0?ooo`03
0>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001fP0@004h`00004
000Ic`08<MP05V[^00QEgD/0oooo0P00001C0?ooo`030000003oool0oooo
01D0oooo0P0000030?ooo`800000J`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo03T0oooo00<0kno/0?knn`3no_/03@3no_/0103_
kn`004Sa000mg0007J01000CS00000@001W?00Paf00FJ^h025GMC@3oool0
0`000000oooo0?ooo`1@0?ooo`030000003oool0oooo01<0oooo0P000004
0?ooo`030000003oool0oooo06/0oooo00<000000?ooo`3oool02P3oool0
0`000000oooo0?ooo`0i0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/
0018l@00?M`001fP0@004h`00004000Ic`08<MP05V[^00QEgDh0oooo0P00
001@0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool00P3o
ool2000006l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0i0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001fP
0@004h`00004000Ic`08<MP05V[^00QEgE00oooo00<000000?ooo`3oool0
C@3oool00`000000oooo0?ooo`0@0?ooo`8000000`3oool200000780oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0h0?ooo`030>o_
k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001fP0@004h`00004000I
c`08<MP05V[^00QEgE40oooo0P00001=0?ooo`030000003oool0oooo00l0
oooo00@000000?ooo`3oool0oooo0P00001e0?ooo`030000003oool0oooo
00P0oooo00<000000?ooo`3oool0>03oool00`3_kn`0o_kk0?knn`0=0?kn
n`040>o_k000B?4003gL000MX04001><000010006Ll0237H01IZkP08EMeC
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool03@3oool2
00000080oooo0P00001h0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0>03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?40
03gL000MX04001><000010006Ll0237H01IZkP08EMeD0?ooo`800000BP3o
ool00`000000oooo0?ooo`0<0?ooo`050000003oool0oooo0?ooo`000000
NP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03P0oooo
00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007J01000CS000
00@001W?00Paf00FJ^h025GMEP3oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo00X0oooo0P0000020?ooo`800000O03oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo03P0oooo00<0kno/0?knn`3n
o_/03@3no_/0103_kn`004Sa000mg0007J01000CS00000@001W?00Laf00F
J^h025GME`3oool2000004L0oooo00<000000?ooo`3oool0203oool20000
0080oooo0P00001o0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0>03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gM
000NX@4001><000010006Ll01c7H01IZkP08EMeI0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`02
00000880oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0h
0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?Md001jQ0@00
4h`00004000Ic`07<MP05V[^00QEgEX0oooo0P0000140?ooo`030000003o
ool0oooo00D0oooo0P0000000`3oool00000000000250?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0=`3oool00`3_kn`0o_kk0?kn
n`0=0?knn`040>o_k000B?4003gM000NX@4001><000010006Ll01c7H01IZ
kP08EMeL0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
0`3oool2000000030?ooo`000000000008L0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0g0?ooo`030>o_k03no_/0o_kk00d0o_kk
00@0kno/0018l@00?Md001jQ0@004h`00004000Ic`07<MP05V[^00QEgEd0
oooo0P0000110?ooo`030000003oool0oooo0080oooo00@000000?ooo`00
00000000QP3oool01@000000oooo0?ooo`3oool0000000D0oooo00<00000
0?ooo`3oool0=`3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?40
03gM000NX@4001><000010006Ll01c7H01IZkP08EMeO0?ooo`030000003o
ool0oooo03h0oooo00<000000?ooo`3oool01000002=0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0=`3oool00`3_kn`0o_kk0?kn
n`0=0?knn`040>o_k000B?4003gM000NX@4001><000010006Ll01c7H01IZ
kP08EMeP0?ooo`800000?P3oool00`000000oooo0000000200000900oooo
00D000000?ooo`3oool0oooo0000000i0?ooo`030>o_k03no_/0o_kk00d0
o_kk00@0kno/0018l@00?Md001jQ0@004h`00004000Ic`07<MP05V[^00QE
gF80oooo00<000000?ooo`3oool0>P3oool4000009<0oooo00@000000?oo
o`3oool00000>@3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?40
03gM000NX@4001><000010006Ll01c7H01IZkP08EMeS0?ooo`800000>P3o
ool2000009D0oooo00D000000?ooo`3oool0oooo0000000h0?ooo`030>o_
k03no_/0o_kk00d0o_kk00@0kno/0018l@00?Md001jQ0@004h`00004000I
c`07<MP05V[^00QEgFD0oooo00<000000?ooo`3oool0=`3oool00`000000
oooo0?ooo`2E0?ooo`040000003oool0oooo000003P0oooo00<0kno/0?kn
n`3no_/03@3no_/0103_kn`004Sa000mg@007Z41000CS00000@001W?00La
f00FJ^h025GMIP3oool2000003L0oooo00<000000?ooo`3oool0UP3oool0
0`000000oooo0000000h0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/
0018l@00?Md001jQ0@004h`00004000Ic`07<MP05V[^00QEgFP0oooo00<0
00000?ooo`3oool0=03oool00`000000oooo0?ooo`2G0?ooo`800000>03o
ool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gM000NX@4001><
000010006Ll01c7H01IZkP08EMeY0?ooo`800000=03oool00`000000oooo
0?ooo`2H0?ooo`030000003oool0oooo03H0oooo00<0kno/0?knn`3no_/0
3@3no_/0103_kn`004Sa000mg@007Z41000CS00000@001W?00Paf00FJ^h0
25GMJ`3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo09H0
oooo0`00000h0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00
?]`001fQ0@004h`00004000Ic`08<MP05V[^00QEgF`0oooo0P00000a0?oo
o`030000003oool0oooo0940oooo1@00000k0?ooo`030>o_k03no_/0o_kk
00d0o_kk00@0kno/0018l@00?]`001fQ0@004h`00004000Ic`08<MP05V[^
00QEgFh0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2=
0?ooo`@00000@03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?40
03kL000MX@4001><000010006Ll0237H01IZkP08EMe_0?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool0R03oool5000004@0oooo00<0
kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng0007J41000CS00000@0
01W?00Paf00FJ^h025GML03oool2000002d0oooo00<000000?ooo`3oool0
Q03oool4000004T0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa
000ng0007J41000CS00000@001W?00Paf00FJ^h025GMLP3oool00`000000
oooo0?ooo`0Z0?ooo`030000003oool0oooo07l0oooo1@00001=0?ooo`03
0>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001fQ0@004h`00004
000Ic`08<MP05V[^00QEgG<0oooo0P00000Z0?ooo`030000003oool0oooo
07/0oooo1000001B0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018
l@00?]`001fQ0@004h`00004000Ic`08<MP05V[^00QEgGD0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`1f0?ooo`D00000EP3oool0
0`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003kL000MX@4001><0000
10006Ll0237H01IZkP08EMef0?ooo`8000009`3oool00`000000oooo0?oo
o`1b0?ooo`@00000F`3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000
B?4003kL000MX@4001><000010006Ll0237H01IZkP08EMeh0?ooo`030000
003oool0oooo02@0oooo00<000000?ooo`3oool0K@3oool5000005l0oooo
00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000ng0007J41000CS000
00@001W?00Paf00FJ^h025GMN@3oool2000002@0oooo00<000000?ooo`3o
ool0J@3oool4000006@0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`0
04Sa000ng0007J41000CS00000@001W?00Paf00FJ^h025GMN`3oool00`00
0000oooo0?ooo`0Q0?ooo`030000003oool0oooo06@0oooo1@00001X0?oo
o`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?]`001fQ0@004h`0
0004000Ic`07<MP05V[^00QEgG`0oooo0P00000Q0?ooo`030000003oool0
oooo0600oooo1000001]0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/
0018l@00?M`001jP0@004h`00004000Ic`07<MP05V[^00QEgGh0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`1K0?ooo`D00000L@3o
ool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000NX04001><
000010006Ll01c7H01IZkP08EMeo0?ooo`8000007P3oool00`000000oooo
0?ooo`1F0?ooo`D00000MP3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_
k000B?4003gL000NX04001><000010006Ll01c7H01IZkP08EMf10?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0DP3oool4000007/0
oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z01000C
S00000@001W?00Laf00FJ^h025GMPP3oool2000001/0oooo00<000000?oo
o`3oool0C@3oool5000007l0oooo00<0kno/0?knn`3no_/03@3no_/0103_
kn`004Sa000mg0007Z01000CS00000@001W?00Laf00FJ^h025GMQ03oool0
0`000000oooo0?ooo`0H0?ooo`030000003oool0oooo04T0oooo10000024
0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001jP0@00
4h`00004000Ic`07<MP05V[^00QEgHD0oooo0P00000H0?ooo`030000003o
ool0oooo04@0oooo1@0000280?ooo`030>o_k03no_/0o_kk00d0o_kk00@0
kno/0018l@00?M`001jP0@004h`00004000Ic`07<MP05V[^00QEgHL0oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`100?ooo`@00000
S@3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000NX040
01><000010006Ll01c7H01IZkP08EMf80?ooo`800000503oool00`000000
oooo0?ooo`0l0?ooo`D00000T@3oool00`3_kn`0o_kk0?knn`0=0?knn`04
0>o_k000B?4003gL000NX04001><000010006Ll01c7H01IZkP08EMf:0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0>03oool40000
09H0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z01
000CS00000@001W?00Laf00FJ^h025GMR`3oool200000140oooo00<00000
0?ooo`3oool0<`3oool5000009X0oooo00<0kno/0?knn`3no_/03@3no_/0
103_kn`004Sa000mg0007Z01000CS00000@001W?00Laf00FJ^h025GMS@3o
ool00`000000oooo0?ooo`0>0?ooo`040000003oool0oooo000002h0oooo
1000002O0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`0
01jP0@004h`00004000Ic`07<MP05V[^00QEgHh0oooo0P00000>0?ooo`03
0000003oool0oooo02X0oooo1@00002S0?ooo`030>o_k03no_/0o_kk00d0
o_kk00@0kno/0018l@00?M`001jP0@004h`00004000Ic`07<MP05V[^00QE
gI00oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0V0?oo
o`@00000Z03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL
000NX04001><000010006Ll01c7H01IZkP08EMfA0?ooo`8000002`3oool0
0`000000oooo0?ooo`0Q0?ooo`D00000[03oool00`3_kn`0o_kk0?knn`0=
0?knn`040>o_k000B?4003gL000NX04001><000010006Ll01c7H01IZkP08
EMfC0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0703o
ool500000;40oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000m
g0007Z01000CS00000@001W?00Laf00FJ^h025GMU03oool2000000P0oooo
00<000000?ooo`3oool0603oool400000;H0oooo00<0kno/0?knn`3no_/0
3@3no_/0103_kn`004Sa000mg0007Z01000CS00000@001W?00Laf00FJ^h0
25GMUP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01<0
oooo1@00002j0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00
?M`001jP0@004h`00004000Ic`07<MP05V[^00QEgIL0oooo0P0000050?oo
o`030000003oool0oooo00l0oooo1000002o0?ooo`030>o_k03no_/0o_kk
00d0o_kk00@0kno/0018l@00?M`001jP0@004h`00004000Ic`07<MP05V[^
00QEgIT0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:
0?ooo`D00000``3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?40
03gL000NX04001><000010006Ll01c7H01IZkP08EMfJ0?ooo`8000000P3o
ool00`000000oooo0?ooo`060?ooo`@00000b03oool00`3_kn`0o_kk0?kn
n`0=0?knn`040>o_k000B?4003gL000NX04001><000010006Ll01c7H01IZ
kP08EMfL0?ooo`030000003oool0000000<0oooo1@00003<0?ooo`030>o_
k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001jP0@004h`00004000I
c`07<MP05V[^00QEgId0oooo1@00003A0?ooo`030>o_k03no_/0o_kk00d0
o_kk00@0kno/0018l@00?M`001jP0@004h`00004000Ic`07<MP05V[^00QE
gOl0ooooM03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL
000NX04001><000010006Ll01c7H01IZkP08EMgo0?ooog@0oooo00<0kno/
0?knn`3no_/03@3no_/0103_kn`004Sa000mg0007Z01000CS00000@001W?
00Paf@0FJ^h025GMo`3ooomd0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0
kno/0018l@00?M`001fP0@004h`00004000Ic`08<MT05V[^00QEgOl0oooo
M03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000MX040
01><000010006Ll0237I01IZkP08EMgo0?ooog@0oooo00<0kno/0?knn`3n
o_/03@3no_/0103_kn`004Sa000mg0007J01000CS00000@001W?00Paf@0F
J^h025GMo`3ooomd0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018
l@00?M`001fP0@004h`00004000Ic`08<MT05V[^00QEgOl0ooooM03oool0
0`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000MX04001><0000
10006Ll0237I01IZkP08EMgo0?ooog@0oooo00<0kno/0?knn`3no_/03@3n
o_/0103_kn`004Sa000mg0007J01000CS00000@001W?00Paf@0FJ^h025GM
o`3ooomd0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`0
01fP0@004h`00004000Ic`08<MT05V[^00QEgOl0ooooM03oool00`3_kn`0
o_kk0?knn`0=0?knn`040>o_k000B?4003gL000MX04001><000010006Ll0
237I01IZkP08EMgo0?ooog@0oooo00<0kno/0?knn`3no_/03@3no_/0103_
kn`004Sa000mg0007J01000CS00000@001W?00Paf@0FJ^h025GMo`3ooomd
0?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001fP0@00
4h`00004000Ic`08<MT05V[^00QEgOl0ooooM03oool00`3_kn`0o_kk0?kn
n`0=0?knn`040>o_k000B?4003gL000MX04001><000010006Ll0237I01IZ
kP08EMgo0?ooog@0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa
000mg0007J01000CS00000@001W?00Paf@0FJ^h025GMo`3ooomd0?ooo`03
0>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00?M`001fP0@004h`00004
000Ic`09==X05V[^00QEgOl0ooooM03oool00`3_kn`0o_kk0?knn`0=0?kn
n`040>o_k000B?4003gL000MX04001><000010006Ll02CCJ01IZkP08EMgo
0?ooog@0oooo00<0kno/0?knn`3no_/03@3no_/0103_kn`004Sa000mg000
7J01000CS00000@001W?00TdfP0FJ^h025GMo`3ooomd0?ooo`030>o_k03n
o_/0o_kk00d0o_kk00@0kno/0018l@00?M`001fP0@004h`00004000Ic`09
==X05V[^00QEgOl0ooooM03oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_
k000B?4003gL000MX04001><000010006Ll02CCJ01IZkP08EMgo0?oooe/0
oooo4@0000080?ooo`030>o_k03no_/0o_kk00d0o_kk00@0kno/0018l@00
?M`001fP0@004h`00004000Ic`09==X05V[^00QEgOl0ooooF`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00H0oooo00<0kno/0?kn
n`3no_/03@3no_/0103_kn`004Sa000mg0007J01000CS00000@001W?00Td
fP0FJ^h025GMf`3oool00`000000oooo0?ooo`030?ooo`800000D@3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool01P3oool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?40
03gL000MX04001><000010006Ll02CCJ01IZkP08EMgK0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`0S0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3o
ool00`3_kn`0o_kk0?knn`0=0?knn`040>o_k000B?4003gL000MX04001><
000010006Ll02CCJ01IZkP08EMg@0?ooo`<000000`3oool300000080oooo
100000040?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0
oooo000000030?ooo`@000000`3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool0103oool300000080oooo00@000000?oo
o`3oool000000`3oool010000000oooo0000000000040?ooo`8000000P3o
ool3000000D0oooo0`0000020?ooo`040000003oool0oooo00000080oooo
100000020?ooo`@000000`3oool3000000<0oooo100000000`3oool00000
0?ooo`030?ooo`@000001@3oool00`000000oooo0?ooo`030?ooo`050000
003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`060?ooo`06
0>k]i@3clnh0emO80<c<^P39bKH0aLFa1P34a:l02034a;00a/Jc0=3@_`3e
mO40k>cU0018l@00?M`001fP0@004h`00004000Ic`09==X05V[^00QEgLl0
oooo00L000000?ooo`3oool0oooo0000003oool0000000<0oooo00<00000
0?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000H0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00D0
oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00<0oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo00L0
00000?ooo`3oool0oooo0000003oool0000000D0oooo00@000000?ooo`3o
ool000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo0000
00030?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo
000000050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`000000
1P3oool00`000000oooo0?ooo`060?ooo`030>k]i@3Rh]L0oooo00`0oooo
00D0f][=0>c/i@00B?4003gL000MX001000CS00000@001W?00TdfP0FJ^h0
25GMc`3oool00`000000oooo0?ooo`030?ooo`070000003oool0oooo0?oo
o`000000oooo000000030?ooo`060000003oool0oooo0000003oool00000
1@3oool00`000000oooo000000020?ooo`030000003oool0oooo00D00000
0P3oool01`000000oooo0000003oool000000?ooo`0000000P3oool00`00
0000oooo0?ooo`030?ooo`070000003oool0oooo0?ooo`000000oooo0000
00020?ooo`070000003oool0oooo0?ooo`000000oooo000000050?ooo`04
0000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo00000005
0?ooo`040000003oool0oooo00000080oooo00L000000?ooo`3oool0oooo
0000003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`04000000030?ooo`000000oooo0080oooo00D000000?ooo`3o
ool0oooo000000050?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`0000001P3oool00`000000oooo0?ooo`060?ooo`040>k]i@3oool0l_;]
0>GUf`<0i^KL00@0i^KM0>KVg03Vi]`0i^KL0P3UiM/01`3ShmP0lO7[0?oo
o`3Bd/4004Sa000mg0007J000@004h`00004000Ic`09==X05V[^00QEgLl0
oooo00<000000?ooo`3oool00`3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000D0oooo
00<000000?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool4
00000080oooo00L000000?ooo`3oool0oooo0000003oool000000080oooo
00L000000?ooo`3oool0oooo0000003oool0000000D0oooo00@000000?oo
o`3oool000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`030000
003oool0000000<0oooo00<000000?ooo`0000000`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0
oooo000000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`050>k]i@3oool0h^;G0>[Z
hP3[jn<00P3/k>@20>_[h`0;0>[ZhP3YjN00j>SO0>OWgP3Vi]d0hn?H0?oo
o`3<c;X004Sa000mg0007J000@004h`00004000Ic`07==X05V[^00QEgLl0
oooo00<000000?ooo`3oool0103oool300000080oooo100000020?ooo`05
0000003oool0oooo0?ooo`0000000`3oool01`000000oooo0?ooo`3oool0
00000?ooo`0000000`3oool300000080oooo00D000000?ooo`3oool0oooo
000000030?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
0`0000020?ooo`030000003oool0oooo00@0000000@0oooo000000000000
00000`3oool300000080oooo0`0000050?ooo`<000000P3oool010000000
oooo0?ooo`0000020?ooo`@000000P3oool4000000<0oooo0`0000020?oo
o`@000000P3oool300000080oooo100000050?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`0000001P3oool00`000000oooo0?ooo`060?oo
o`040>k]i@3oool0iNGK0>c/i0@0kNgV00`0k>cU0>_[h`3[jn<0j^[R0>WY
h03Wimh0i>CI0?ooo`3<c;T004Sa000kfP008JT1000CS00000@001W?00Ld
fP0FJ^h025GMc`3oool01@000000oooo0?ooo`3oool0000001D0oooo00D0
00000?ooo`3oool0oooo0000000D0?ooo`050000003oool0oooo0?ooo`00
0000403oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo000000060?ooo`030000003oool0oooo00H0oooo00@0k^gU0?ooo`3U
iM/0kNgV103^k^L0303]kNH0k>cT0>_[h`3Zj^80jNWP0>SXg`3UiM/0oooo
0<c<^@00B?4003_J000QZ@4001><000010006Ll01cCJ01IZkP08EMg@0?oo
o`<000005@3oool00`000000oooo0?ooo`030?ooo`8000004P3oool40000
00P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00h0oooo00@000000?ooo`3oool00000203oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool00`3oool01@000000oooo0?ooo`3oool0000000D0oooo00<0
00000?ooo`3oool01P3oool01`3^kND0oooo0>KVg03^k^L0knoY0<W9`P3_
knT00P3^k^L02`3/k>@0j^[R0<W9`P3Zj^80jNWP0>KVg03oool0c<bi0018
l@00>mX0026Y004001><000010006Ll01cCJ01IZkP08EMgo0?oooe/0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`060?ooo`040>k]
i@3oool0i^KM0>o_j@<0bLW200<0knoY0>k^i`3/k>D00`39bL801`3Zj^80
i^KL0?ooo`3<c;T004Sa000kfP008JT00@004h`00004000Ic`07==X05V[^
00QEgOl0ooooF`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00H0oooo00<0k^gU0?ooo`3Wimh00P3`l>X30<W9`P0<0>g]iP39bL80
bLW20<W9`P3[jn<0j^[R0>KVg@3oool0c<bj0018l@00>mX0026Y0@004h`0
0004000Ic`07==X05V[^00QEgOl0ooooF`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00H0oooo00@0k^gU0?ooo`3Xj=l0l?3Z0P3a
lN/50<W9`P<0jn_S00H0inON0?ooo`3<c;X004Sa000kfP008JT1000CS000
00@001W?00LdfP0FJ^h025GMo`3ooomK0?oooa400000203oool00`3^kND0
oooo0>[ZhP020?7aj`80l?3Z0`39bL802P3/k>@0jn_S0>c/i03[jn<0inON
0?ooo`3=cK`004Sa000kfP008JT1000CS00000@001W?00LdfP0FJ^h025GM
o`3ooomd0?ooo`030>k]i@3oool0j^[R0080lO7/00D0lO7[0?3`jP3`l>X0
bLW20>c/i@040>c/i0060>OWgP3oool0clnn0018l@00>mX0026Y0@004h`0
0004000Ic`07==X05V[^00QEgOl0ooooM03oool01P3^kND0oooo0>c/i@3c
lnh0l_;]0?7aj`<0l?3Z00/0kNgV0>c/i@3/k>D0k>cU0>c/i03Wimh0oooo
0=?C`P00B?4003_J000QZ@01000CS00000@001W?00LdfP0FJ^h025GMo`3o
oomd0?ooo`090>k]i@3oool0k^kW0?Gel@3dm?00l_;]0?7ak03alN/0l?3Z
0080knoY00T0k^kW0>g]iP3/k>@0i^KM0?ooo`3Hf<T004Sa000kfP008JT0
0@004h`00004000Ic`07==X05V[^00QEgOl0ooooM03oool01`3^kND0oooo
0?7aj`3gmo<0mOGa0??ckP3bl^d00P3alN`02`3alN/0l?3Z0>o_j@3^k^L0
k>cT0>KVg@3oool0gmoB0018l@00>mX0026Y004001><000010006Ll01cCJ
01IZkP08EMgo0?ooog@0oooo00P0k^gU0?ooo`3gmo@0lO7[0>k^i`3/k>D0
jn_S0>[ZhP80j>SO0P3Wimh0203Vi]d0i>CI0??ckP3oool0iNGK0018l@00
>mX0026Y0@004h`00004000Ic`07==X05V[^00QEgOoo0000M?l000000`3^
kND0o?cj0?ooo`0=0?ooo`040>c/i@00B?4003_J000QZ@4001><00001000
6/l003_P000kh000Bn020013c`030053c`01A=000DC@00T00TG@0`01A=02
0053c`030054d001@ll00D??07400DC@K`00@lm`0053cah004??00<003_P
000^g000</400@005I800007000Jc`00>n0003_P001;h000?L`004??0054
d0020095d0<004[H0`01CM`00`00D>0004gS001@hP02001@hP03001Ch@00
D>80053R00<0053Rh000CN=_0016h003001;h000Bn<004KP00H004KP00<0
04?L0010g000@=`00`00?M`00`00?]X0043L000mg0030010g003000nfP00
@=`003kJ008003[I00P003SH000jf@00=MP003SH000ef000>n0003SZ000b
`@4001>;00001@006/l003_P001;j`00CN<005CS008005SV00@005S[001L
k000H>h005ob0`03IO4400=Xm00300=XnP01J_X00F[j00@00F[j00<006Gm
005Tn@01I?T0K`00H?U_001Po6l0063i00L005ci001Po000G?T005Wh001J
m@00F?<005Of008005Sg00@005Of001Em000DO@005Gd0P00DO@4001Em005
001Al000C>l0057`001Em000DO@00P00C?<60017k`4003SZ0@00</41000C
R`0000L001[?000kh000Bn/005S^001KlP00F>h005_b00800f3a00<00f7f
00=Xm003J?X00`06J_T300I/o0L00f_k0P02J_i`00=Xn[P006Gm00<?1FKk
SfJKmOooool03oooool00noUkOf?IY_e3`EVn`02001Uo@033`EVnhmVVoGo
oooo00oooooo00O_iNgmSfJIl`l5HOL0063i001Ln@l5G_N?IYKc013ooooo
00S_iNclSfJCl@l5Co8004cc0017k`00A^X003SZ000b`@4001>;00001`00
6/l003_R001;j`00F>h005_b005Pm@03HOH00P02IOT00`03J?X01V[i00I/
o00200M_o@<01g;m1006LOh300=bo`<00fkoo`02J_hY009ZoP0ESfNNm_o@
f_7o:5K3o`do]_lAA;go4TFkoaA5^OlBA;Wo4dFloa=6_Ol@AKko3DG0o`Y5
`Ol8A<?o1T70o`<o`?l1?l?o03^noam>^Oo?f>f?Iikf00800V[n036?Iikf
om3JlOlXE/?o3Cnfoa54_OlBAK_o54Fioa94^OlCAKco4dJmoa15__l=AL3o
2TG1o`Q4`ol6@L3o0co0o`4o`ol0>kko7djioloHkHmVVoD006Gm001Po8mV
VOGok]K@okE4:?nV:`go[30Aoj/a4_nY<QCoZC0Boj`b4on]<Q?o[S4@ok4`
3Onb;P[o]2d8ok4Z1_na:0?o]2L1ojhT0?n/?1ooj]C?SfJCl@00DO@004cc
0017k`00>>X003;1004001>;000010006/l003_R001;j`00F>h2005Pm@04
00=QmP03J?X00fSj00I/o0801fom0P07L_d600MdoP801W7n0`03L_mb00=^
okP00V[n01G_iNkmobQNgolCCmoo6eGOob5Jh_lUG>7o9UgPobALhOlSG^;o
8EkRoaiNh_lKGnGo5UkUoa=Mi_l>FnGo2ESVo`ADi_l1C^;o04GCoam>^?oo
ool00P02J_h0<NoUk_go:5kOoa=?golKEMoo8E[RobELhOlVGN3o95cQob=N
h_lQG^;o7UkRoa]OiOlFG^Go4egVo`iKiOl9F>Ko15CVo`5>h_l0AM?o7djh
ooooo`00IOd0063lknG]oOo=BBSoc3PCol`n6oo?A27ocdLUolm79_o?ARCo
d4LSom568OoBAAkoeDDKomE25_oF@1?oeCd>omHi2OoE=@CodC01ol8Z0?n[
?1oooooo001Am000C?<004O_000hjP00</400@004h/0000;000Jc`00>n80
04_[001HkP01H?D00f7f009Un@03J?X00f_k00I_nP07Kod00P06LOh00`07
L_d01gCn00MdoP0300MdoP801W7n0`03L_l400=^ool00V[n:002J_h05Ooo
oooo3U3]oaaKkolXHo3o;fS`oc=[lOldK?7o<Fcboc5]l_l^Ko;o:W3bobE`
lolOKo?o6Fgdoa=Zm?l=I_Co1f3co`9Jl?l0CN;o03Ziooooo`02009ZoP0E
ooooool>D>go75__obQSl?l_J?3o<f_aocA/lOlaK?;o<Fgbobi_l_lZL?;o
9G3coam_lolIKOCo4f[do`eVm?l7H??o0U[`o`1=h_l0>[Wooooo0080063l
01GoooooomPg3_oK@acogD`XomiB;ooOEC?oh5Ldon1E<OoPES7ohEH^on9E
:_oTDbGoi50OonE<6OoUB1?oiD<=on@n1ooP>0;odBl0ojXS0?ooool00P00
C?<00`00Anl003SZ000b`@01000ETP0000X001oB000khP00Bn/005S^001O
lP01H?D00VGiojNWYonSXZ?oXZ:R0_nQXJ400onPX:3oYIjEojZLR@02oinO
W`;oX:2P0_nQXJ401?nWYjL00fko005/oP01K?h4009ZoP0300MHh`0:68<0
1eSS00@00V[n0P0:68<2009ZoP0500MDgP09<:P02QR300Ti]@05Ho<00P02
J_h01`06H>l02QR300ESl`02J_h01F?c00XHP`06H>l00P02J_h200XHP`L0
0V[n00@024gC00XHP`0:68<0257I0`02J_h200XHP`800V[n0P0:68<2009Z
oP802QR30P02J_h02@07FnL02QR300XHP`02J_h01F?c00U5aP0:68<02C2X
00QAf@03009ZoP0500MDgP09<:P02QR300Ti]@05Ho<00P02J_h02@06GN/0
2C2X00MHh`02J_h01eCN00T`Z00:68<02CVe00ESl`02009ZoP0500MDgP09
>KD02QR300Ti]@05Ho<00P02J_h00`07FnL02QR300XHP`07009ZoP0700Q=
d`0:68<01FGg009ZoP05IOL02QR300Q=d`04009ZoP802QR30P02J_h200XH
P`800V[n0P0:68<3009ZoP0300U5aP0:68<02CVe00802QR30P02J_h01008
CM<02QR300XHP`08DMT3009ZoP0700IPk`0:68<01F?c009ZoP05Ho<02QR3
00IPk`1:009ZoTT006Gm01GooooooaAFlolUH_Co<F_docUam?lmM?Go?GCf
oc]emOliM_Go=gOeoc9hm_l/N?Oo9GOgoamfmolIL_Oo4Fkho`]Xmol5H?Co
0U?Vo`4m__ooool00P00IOd0<Ooooooo55KcobERm?laJoCo>G7docedmOlm
M?Ko>gGeocUfmOlgMoGo<WSfobahmolUMoOo7gKgoaUbmolAK_So2fSgo`EP
m?l2DnKo0Cfnooooo`00H?`005cioooooooM?1Coh4/Uon5D<OoSFcWoi5hm
onAO?OoTGS_oiEhionEN=ooVGC;oie//onQG9OoYE1oojE0IonU:4OoXA0_o
i3d5omHc0_n_9P7ooooo001<l`00Anl004KZ000hjP00<LH00@005I800009
000SeP00>n0004_W001Hj`00Go800F3eI@8kUOnKVi_o[:b/00?ojNWY00_o
j^[Zon?6N_oINQCok>c/ong]kOo^k^kolNOEoo3`l?obl_;oXj>S009ZoP02
005ZnP8006Gm00D00FCi0;?@o@3oool0]K[I00Q6bP03005Tn@80oooo0180
2QR3005Tn@2odOD0n?Sk0?ooo`3amOd0P9CA00Q=e@01I?T0SKWl0?ooo`21
R;l024gE07b_n`3oool0TIO700Q9d001I?T20?ooo`0300XHP`01I?T00FCi
00@00FCi00L0dMkg0?ooo`3oool0b=Wg00XHP`08CMD00FCi0080oooo00H0
2QR3005Tn@3oool0oooo00XHP`01I?T20?ooo`0300XHP`01I?T0YlWl0080
oooo02<00FCi07b_n`3RjOT0oooo0?SjoP38fo/02QR300Q9d001I?T0_m7e
0?Shn`3oool0lOGm082Dd@08CMD00FCi09_2o03hnO`0]K[I005Tn@2odOD0
n?Sk0?ooo`3amOd0P9CA00Q=e@01I?T0_m7e0?7bn03oool0l?Kn082Ph`08
CMD00FCi0:O9o0020?ooo`L00FCi00P0d>;m0?ooo`1^M[D01UKS06VSn`3o
ool0d]CX00Tg/`<00FCi0P3oool01P0:68<00FCi0?ooo`3oool02QR3005T
n@80oooo00H02QR3005Tn@01I?T0h^Wi0?ooo`3amOd20?ooo`0300XHP`01
I?T0dMkg0080oooo00`0b=Wg00XHP`08CMD00FCi08fio03oool0PHRo00Q=
e@1l[o/0oooo096Ga`08BM1:005TnDT0063l00GooooooaQIlol^J?Co>W7d
od9gm@070?ooo`09obYln?lTN_So7GOhoaEcn?l>K?So2F?do`EFiol2?koo
oooo0080063l00GooooooaQIlol^J?Co>W7dod9gm@0;0?ooo`0Lo`i/n?l9
HoCo1EKWo`8o_oooool005ci001In?oooooogT0Hon5A;_oSG3[oi692ooG1
]OooooooiVE3onIU@OoVI3goif8honQP<_oYG2[ojUTTooooooog^:7ojDP>
onE02OoG=PGo/2L2ooooo`8004O_00<0047X000hjP00;<P00@005I800004
000SeP00>n0004KZ001Aj`8005ob00D00F3eoj2PX?oZj^[ojNWYoo[XZ@02
on[ZjP09ooSU6?o=I`3okNg]onk^k_ofZ3?om/j<oo;bl_oclo?oXj>S0080
0VGi0P01I?T2001Pn@040=WWoP3oool0f]c/00XHP`<0063i0P3oool01`0:
68<0_MKm0?ooo`2o`ml0//om0?SjoP37g?d00P00H?T02@3AhO`0oooo0<W<
h`09;JH0amcm0?ooo`3Be>P02QR300AKlP020?ooo`0300XHP`00H?T0063i
00<0063i00P0amcm0?ooo`2Z[m@0//om0?ooo`39c><02BfV001Pn@80oooo
00H02QR3001Pn@3oool0oooo00XHP`00H?T20?ooo`0C00XHP`00H?T0n?[n
0?ooo`0:68<0063i0=3Qo@3YlOh0063i07b]n`3oool0d]CX00XHP`2me_d0
oooo0;o3g`2bcod0n?[n0<OLo@02001Pn@0@0?SjoP3oool02QR30;gFo@3o
ool0_l?O0;;?o@3hn_h0amcm001Pn@2me_d0oooo0;o3g`00H?T0fNOn0<OL
o@80063i00<0n?[n0?ooo`0:68<01`00H?T02@3amOh0oooo0:Z_e008Am00
YlSl0?ooo`3al_P02QR300AKlP02001Pn@80oooo00H02QR3001Pn@3oool0
oooo00XHP`00H?T20?ooo`0600XHP`00H?T0d>7m0?ooo`2e^]T0063i0P3o
ool04P0:68<0amcm0?ooo`2Z[m@0//om0?ooo`39c><02BfV001Pn@3AhO`0
oooo0<W<h`09;JH0amcm0?ooo`3Be>P02QR300AKlY80063i00GooooooaiM
lolfK_Co@WKeodUkm@070?ooo`09obemmolUN_So7WOhoaMcn?lAKOOo3FKd
o`]Iiol6@L3ooooo0080063i01cooooooaiMlolfK_Co@WKeodUkm@3ooooo
BWkgodQnm_m5OoKo@H3foc]om_leOoOo;GggobEjn?lNMoP0oooooa5]mol=
I_Co2eWWo`I1`?ooool005Sc001Em?oooooogdDNon9H=_oTHT;oiFM90ooo
ool01OoVJ4GoifM1onMT>ooXHSGojUh]00?ooooo00[ojDXAonI43OoG>`_o
/B/6ooooo`00Anl004KZ0011j000>n8003;10@005I80000F000OdP00>n00
04KT001EjP00G>`005obE@0oXOn?ShooSXj>onWYjOoAN`3obS40olYfEOoo
m`3ojj/0om^NOooUX7Woed80oo;bl_oclo?om?CdojBTY0<00f7f0`01H?D3
0?ooo`0400XHP`05EnL00F3e005Pm@80oooo00<02QR30?SjoP3oool01@0:
68<01P1YXOT0oooo0?ooo`3hnOd02QR30?Sio@80oooo00@0KWJe00M=e`3o
ool0oooo0`0:68<02`08@lP01EW[005Pm@3hn_h0oooo00XHP`01H?D0oooo
0?Shn`0:68<00F3e0080oooo00H02QR3005Pm@3oool0oooo00XHP`01H?D2
0?ooo`0500XHP`01H?D0oooo0?ooo`0:68<01@01H?D20?ooo`0300T]Y@3h
n_h0oooo00D02QR300H00F3e0?ooo`3oool02QR30?SjoP3oool500XHP`03
0?SjoP3oool02QR300D00F3e0P3oool00`0:68<00F3e005Pm@04005Pm@06
06VQn@3oool0oooo0=7Kl`09=K40d>7m0P3oool0101^M[D01U;P001Jm@00
F_D20?ooo`0600XHP`00F_D0oooo0?ooo`0:68<005[e0P3oool01P0:68<0
05[e0?SjoP3oool02QR3001Jm@80oooo00T02QR30?SjoP3oool02QR3001J
m@3oool0n?Sk00XHP`1XWOT00P3oool00`3hnOd02QR30?Sio@020?ooo`03
06if]@07BML005[e094005[e00GoooooobERlolmLoCoB7_eodj0mP070?oo
o`09obelmolVNOSo87OgoaUcmolFKoOo4fWdoa1Mj?l:A;oooooo008005[e
01GoooooobERlolmLoCoB7_eodj0mP3oooooCX7fod^0m_m7OoKo@Wofocao
m_lfOoOo;GcgobIin?lPMoL0oooooaI_molCJOCo45gXo`Y4_oooool00P00
EO401_ooooooh4/Uon=N?OoUIdSoiVa>onI]D0?ooooo00?oifQ2onMU??oX
HSH00oooool01_oYD1Woj4`FonA74ooH?a3o/Bd:ooooo`80047X00<003_R
000^g000:[L00@005I800009000OdP00?M`004KT001Ei@00F>/005c/GP0l
VOnSXj?oinKV00;oj^[Z00go]``0om1h0?ooi@3onl`0omR80?noBP3o]d@0
okY@>_oIVV7ooM`0okV^NP03HOH00F3e008005[e00L005_b08ben@3oool0
h^C`0?ooo`2AUlL01dWE008005_b0P3oool00`0:68<0oooo0?ooo`040?oo
o`0;00T/Y02me?/0oooo0=;HkP3oool0d]S^0?ooo`3Bf>h0oooo0;o8i`09
;:@0103oool0103Ii_`0P9WK00T/Y004En/20?ooo`0600XHP`00Fo80oooo
0?ooo`09;:@005_b0P3oool01P0:68<005_b0?ooo`3oool02QR3001KlP80
oooo00D02QR3001KlP3oool0oooo00XHP`03001KlP0500AGj`3Afo<0oooo
0?Shn`06C]d01P3oool01@09;:@005_b0?ooo`3oool02QR300H0oooo00@0
2BbT0?ooo`3oool02QR31@00Fo820?ooo`0300XHP`00Fo8005_b00@005_b
00X0YlKj0?ooo`3Ri?00lOGm00XHP`3amOd0h^C`0?ooo`2Z[m@024?;0P00
Fo820?ooo`0600XHP`00Fo80oooo0?ooo`0:68<005_b0P3oool01P0:68<0
05_b0?ooo`3oool02QR3001KlP80oooo00D02QR30?ooo`3oool02QR3001K
lP020?ooo`0;00T/Y02me?/0oooo0=;HkP3oool0d]S^0?ooo`3Bf>h0oooo
0;o8i`09;:@0B@00Fo99001Hl`0Eooooool[I_CoA7Seodiom_mBP_KoDh?f
oe62m_m=POOoB7ofod=om_lmO_Ko=GcfobejmolVMoOo8GCgoa]amolHK_Oo
66[doaIOiol?Al3ooooo008005Sc01koooooob]Vm?m4N?GoCWofoe:2mP3o
ooooDH;fodf1mom8OoKo@gofocenm_leO?Ko;G[gobIgmolQM?L0oooooaQ^
molHJ_Co5UoWo`m7`?ooool005Ga001Al?oooooohDl[onASA?oVJdkoifmB
onM_DooVKU43ooooo`0@onMU?OooooooooooookelOoXE27oj50KonM=6?oT
BQSoed8Fok8a3oooool0047X0010h@00>n0002kL000Z]`4001FB00005`00
8<P003SH0016i000DND005S[001Lk000H>koQXN6okj>E_oigdSonNi2onbf
0?okd03ol;X0onZ`0?oY/P3ofX/0olnE0?oR_`3oo]l0ooK`g?nTYJD00f3a
008005_b0P00F>h01P2me?X0oooo0:Z_e03oool0_l?O00Tg]`8005S^0P3o
ool04P0:68<0n?[n0?ooo`0:68<01dWF0?ooo`3hn?/024;90?Sjo@3hn?/0
1dC>0?SjoP3oool0n?Sk00M4cP3hn_h0n?Wm00XHP`80oooo00h02QR306RL
m03Yl?d0n?[n06if]@08@/T0n?[n0?ooo`0:68<01TcJ0?ooo`3hn?/01dC>
001HkP80oooo00H02QR3001HkP3oool0oooo00XHP`04D^@20?ooo`0500Pk
_P00F>h0oooo0?ooo`0:68<00P00F>h03P1[U^/0h^Kd0?ooo`3oool0ZL;c
001HkP3hn_h0oooo00XHP`07BMH0oooo0?Shn`08@/T005S^0P3oool0400:
68<0n?[n0?ooo`0:68<01dWF0?ooo`3hn?/024;90?3eoP3oool02QR300M4
cP00F>h023k300M7dP00F>h20?ooo`0300XHP`00F>h005S^00@005S^00X0
d>3k0?ooo`2Z[m@0oooo096Ga`3oool0ZZoD0?ooo`3Be>P02C:^0P00F>h2
0?ooo`0600XHP`00F>h0oooo0?ooo`0:68<015;T0P3oool01P08>kh005S^
0?SjoP3oool02QR300M9eP80oooo01<02QR30?SjoP3oool02QR300I<fP3o
ool0n?Sk00M4cP3hn_d0n?Sk00M4cP3hn_h0oooo0?Shn`07A<h0n?[n0?Si
o@0:68<01TcJ094005S^01Gooooooc9[m?m;OOGoE8?foeJ4momEPoOoDX;f
odf0m_m8OOKo@Wcfocajm_ldN?Ko;GKfobIcmolQLOOo76ofoaa]m_lLJ_Co
767Voa98_oooool00P00F>h05Ooooooo<V_dod]mmOmDPoKoEXCg0?oooomB
P_KoCH3fodQmm_m2O?Ko?7[focAhm_l]M_Ko9W?gob5am`3ooooo76gfoaaZ
m?lLHNKo4TRoooooo`02001Aj`08oooooooRE3;oiFU;onM`E?oWLEKoj71E
onM_D_oVK4d5ooooo`0=onME9_oWDR7oiThLonI=7?oSC1coeTHLok0c4_oo
ool003_R000kh000=MP002?F000Z]`01000CR`0001H00238000hf000A^@0
057U001EjP00F>]]03F7oiBDU?nMO4[oag80onNT0?ooj03ojkH0onVZ0?oX
[03odh40okY<0?oR^P3on_9gooKfm_ohn?SoYJBU0P03GN`02@00G>`005S[
001Hj`3Yl?d0oooo00Pk_03oool0jNki00XHP`02001Hj`80oooo01802QR3
0=3Pn`3oool0]LK^09jTcP3oool0dMcd0:O5n03oool0bLcS00ABhP37f_X0
oooo0<W<h`04D^80am[j0?ooo`2Z[m@20?ooo`0<00XHP`00F>/0J9cc0?oo
o`3Be>P02B^R0<OJnP3oool0Z[k[09jTcP3oool0b=Gb0P00F>/20?ooo`0:
00XHP`00F>/0oooo0?ooo`20W=l0T9oE0?ooo`3Rj?L015;R001Hj`80oooo
0P0:68<01@2J_OL0n?Wl0?ooo`3am?/0V[gg008005S[00H0d>3k0?ooo`2e
a^h0WZC>0?ooo`3Ag?@2001Hj`80oooo01002QR30=3Pn`3oool0]LK^09jT
cP3oool0dMcd001Hj`2me?T0oooo0<SFm009<Zd0f]c/0;o:j@06C]/005S[
0P3oool200XHP`D005S[00`0lOGm0?ooo`08>k`0oooo0>;Xm`3oool023^l
0?ooo`3am?/02QR300AAi000ENX20?ooo`0>00XHP`00ENX0oooo0?ooo`20
Vml0T9oE0?ooo`3RioL014oQ001EjP3@go/0oooo0;G3jP0:68<20?ooo`0C
00XHP`37fOX0oooo0:Zmj`2NY<h0oooo0<SElP2Wa?L0oooo0<W<h`04Cn40
amWj0?ooo`39c><014oQ0<OInP3oool0ZZoD00Te]@2A001EjP0Eoooooolg
K_CoDH7foeN5momIQ_OoEhGgoe:1m_m=O_KoAg_fod5im_lkMoGo=7Ceobab
m_lVKoKo8Vgfoai[m_lOJ_Ko8F[cob5Ri_lFBKkooooo008005GZ023ooooo
ocM^m?mAPOKoEhGgoeV6m`3oooooDX7fodenm_m7NoKo@GWfoc]gmOldM?Go
;7;fobI_m_lRKOH0oooooamZm_lQJ_?o8F;VoaI9__ooool0057[001AiOoo
ooooheTgonM]DOoXLUOoj7=IonMaEooVKU;oiVY=onEWA`?ooooo00koiEL/
onEC9_oUD2;oiDdNonE=7ooRCR7oeTTQojle5_ooool003gL000jf@00=MP0
02W@000V[04001>;00006@006[`003KB0010g000D>8005SV001Ij000G>Wo
UiNGokNg]oo/k>cog[InomV80?oba03okK40onRZ0?oDM@3o_VP0oocE0?ok
ggWon?KaooWinOnUYJD00eg/001Lk000F>/00P00FNP01`3oool0h^C`00M5
c`3Qjo`0oooo00XHP`06BmX00`3oool2001EjP0@0=3On`3oool0oooo0=3O
n`00ENX0jO3m0?ooo`1lYo@005GZ07bWm03oool0O:Od001EjP1lYo@0oooo
0>W`o@80oooo00P02QR3001EjP00ENX0oooo0?Shn`09<:d005GZ0=3On`80
oooo00<0d=ok001EjP00ENX00`3oool2001EjP070?ooo`3IiO/0n?[n0?oo
o`3Qjo`0O:Od001EjP040?ooo`04001EjP3`mOd0oooo0=;Dj0D005GZ00@0
d=ok0?ooo`3oool0d=ok0`00ENX20?ooo`0300XHP`00ENX0d=ok0080oooo
00X0d=ok001EjP00ENX005GZ0;gCn@3`mOd0oooo0?3eo@2J_?H005GZ103o
ool5001EjP0<06RJlP3oool0h^C`00M5c`3Qjo`0oooo0>;Tl007ALl0hN_l
0?ooo`1^M[D01TWG0`3oool2001EjP060?ooo`3IiO/0n?[n0?ooo`3Qjo`0
O:Od0`00ENX00`3Qjo`0oooo0?3eo@020?ooo`0300XHP`00ENX0d=ok0080
oooo00d0d=ok001EjP3Yl?d0oooo07bWm000ENX0O:Od0?ooo`1lYo@005GZ
07bWm03oool0jO3m098005GZ01Goooooocabm?mIQoKoGH[goef9momIQ_Oo
Dh7fodinm_m7N_Go@GSeocYdmOldL_Go;6oeobM/mOlSJ_Ko86Wfob9XmOlU
JO;o9F;VoaU;__ooool00P00ENX05Ooooooo?7;doeV7m_mMR_OoGHWg0?oo
oomCPOKoCWkfodMjmOm1N?Go>WCeocAbmOl/KoGo9fceob=ZmP3ooooo8VSe
obEYl_lUH^Ko6D^nooooo`02001=h`08oooooooSGCcoj7AIonQgGOoXMUgo
ig9IonI_DooUJdh5ooooo`0=onAA9ooTCb?ohd`Pon==8_oQCbGoeDXUojlg
6Oooool003SH000ef000=]8002W@000Z]`01000>O@0001P001Zl000fdP00
@=`004[L001Ai@00ENEU03J<oiVIVOnVYjKokNg]onO:R_o7J03ol[T0omb9
0?o:I`3o]S40ok]B0?oobP3ook`0oo^i0?og/P3obZ]P00=Mk000G>T2001I
j00809Zmm@3oool0_l?O00I;eP2mdoP0oooo09jTcP08@<<2001Ei@802CFb
4@00END20?ooo`0600XHP`00END0OZG^0?ooo`3al_P01T_F2@00END200Te
/PT005GU0P3oool02@09<:/005GU0?ooo`3oool02QR300A?g005CMT02BZP
00Pm_P08001Ei@80oooo00<02QR3001Ei@00END03@00END20?ooo`0300T`
Z`00END005GU00<005GU00`0YlCf0?ooo`2o`ml01T_F0;gCn03oool0_l?O
00I;eP2mdoP0oooo0:Z_e008@<<2001Ei@802CFb3@00END20?ooo`0300XH
P`00END005GU0:4005GU01GoooooodIimOmPS?OoHXghof2;momKQoOoE8;g
odilm_m7N?Ko@GCeocYamOldK_Co;F_eobQYmOlTIoGo8VKeobEWmOlYJ?;o
:F?Toa];_Oooool00P00END07_ooooooAWWeof2<momRSOSoH8_g0?oooomD
P_OoCWcfodMhm_m1M?Go>W7eocA^m?l]JoGo:6WeobAWm@3ooooo9FOeobUX
l_lYHnCo6d^mooooo`00Bn<004_PoooooooUIDKoj7YPonQlH_oXNV3oj7AK
onM^E0?ooooo013ohe`jooooooooooooooooon9=9?oRBb;ohTdUon1@:OoD
C2Wo[STKooooo`00>=P003GH000Yd0008<P002J/0@003Wd0000F000J_000
=]80043L001:g000E><005GU001Ij?nNWYgohn?SonbbG_oJV03odW`0omjC
0?oIO03of7T0ok@d0?nP1P3okiX0oon/0?ojm^conoSaokJXQ`<005WX00d0
05SV0=3PnP3oool0WZC>00AAg`2J_?@0oooo0=;Dj009<:/005GU0>W`o03Z
kOP02CFb014005GU0P3oool01@0:68<0KWJe0>[/mP3oool0W;W`00T005GU
00<0jO3l0>[]n009=K802@00END02P37fOT0l?Gm001Ei@00END0hN_k0?oo
o`20WN00T9oD0?Shn`3Jh_D9001Ei@80oooo00<02BZP001Ei@00END03@00
END00`37fOT0l?Gm001Ei@05001Ei@0@0=3OnP3oool0WZC>00AAg`2J_?@0
oooo09jTcP04DMl0V[cd0?ooo`3Be>P02C2[001Ei@3Yl?`0j^gh00Te/Pd0
05GU0P3oool00`09:Z0005GU001Ei@2Q001Ei@0Eoooooom6NOGoJ9;hofZC
n?mUSoSoGXWgoeN3mom@O_KoBWWfod=emOlmLOGo=Vkdobm[mOl[JOGo:6Oe
obMVmOlZJ?Go;6WbobYRi?lLC;gooooo008005GU00GoooooodIimOmXT_So
JY?hofF?n00;0?ooo`0=obYXmOl/JO;o:V;Toaa<_Oooool004gS001;h?oo
ooooiFE6onV1J?oZPf[ojGiUonQgGP03ooooo`03onAQ@ooTGCgohePf00?o
oooo00_ohThWon9@:_oPDBcodddZojdi7?ooool003SH000fdP00:M000238
000V[001000>O@0001H001Zl000gb`00>m8004[L001Ch@00ENED03bKohf=
SOmoMfooh9/0oo3`l?oT_ISok:d0oooO0?ooaP3ojZL0ol9P0?oAM@3on:L]
oo_knoolo?coYZJV0P00F^L2001HiP070?3eo@3oool0J9[_001Ei@1XV^l0
oooo0?3eo@02001Ei@80jO3l4P00END30?ooo`030?SjoP3IiO/0S;;c00X0
05GU0P3Yl?`?001Ei@040=3OnP3hn_h0oooo0=WUn`X005GU00<0hN_k0?Sj
oP00END05`00END02`3`mOd0oooo06RJk`00END0J9[_0?ooo`1XV^l005GU
06RJk`3oool0l?Gm008005GU0P3Yl?`>001Ei@030>7[n`3hn_h005GU05X0
05GUB@00DND05OooooooCGkfofjGn?m`VOSoJY?hof:<n?mKQ_OoE83godek
m_m7MoKo@7;eocY_mOldKOCo<6_dobeYm?l/JOGo;FWeobiYl_l/HnGo7Dbl
ooooo`02001Ai@05oooooom=O_KoKYOhog2In?mZToP02`3oool03?l]JOGo
;VWbobaSiOlMC;cooooo001=h`00Bn3oooooonIZCOo[QfkojhY`onZ3JP?o
oooo00GoiFQ=onATAooTGd3ohe/jon9F=003ooooo`05on9B;OoODRkoddd/
ojdj7Oooool00P00=]800`00;<P00238000TYP01000>O@0001H001R[000a
aP00?m8004[H001@h000E>=404:YoijNW_oEe=Col?3`oo;bl_oXbj_on=80
ooKTQoocdXgolZ80ono9TOoWaJ;ohH40ooclo?omoOgoYZNW0P00F^L2001H
i_l005GU:P00END05OooooooDX;fogVOn?mlXOSoLIWhofNAn?mPRoOoFHGg
oe>1m_m=NoKoAWOeod5cmOljKoCo>6kdocA/m?lbK?Co<F_doc1YlOl/H^Co
7Dblooooo`02001Ei@05oooooomBP_KoNIohogbQn?maVOP02`3oool07?la
JoCo<6WaobaRi?lMC;cooooo001=h`00Bn3oooooonM_D_o/TGWok9=lon^:
LOogc<;oooooonMbFOoWKE?oiFQ=onATA_oTGd7ohe/jon=I>?oooooolk^]
on9E<OoODc3oddh/ojdj7Oooool2000fdP03000/b0008<P002J/004000im
00005P006:/00376000odP00B]P0053P001Dh`00F^OoQXJ6oiBDToobl_;o
lo?conJT0?ohkJkom_Kfoo?K[?oZU`3on_[joo_knooaf[_onKH_ookno_nW
YjL2001Ji`8005SVo`00ENDZ001Ei@0EoooooomHQ_KoRJ[iohf]nOmoXoSo
LIWhofZCn?mTS_OoGX[goeV6momDP_KoDH3fod]lmOm:O?GoA7SeocmemOlj
L_Co=6cbobYQholHB;_ooooo008005GU02cooooooeR6m_n9Z_WoSJgiognS
n?maVOSoJY?hofB>momNR_OoFHKgoeB2m_mAP?KoBgceodYlmOm4N?Go?gGe
ocYbm?ldK?;o:V7SoaQ8^oooool004gS001;h?ooooooj7AHonjMROo_XHgo
kIEoon^:LOoZPf[ojGeTonQhG_oWLeWoifmDonI]DOoUJ4_oiFQ:onASA?oT
H3oohe`jon1F=?oBC2[o[3HHooooo`8003KB00<002c8000Pb0009Z`00@00
3Wd0000C000HZ`00</4003g<0017e`00DmX005[OF00kUOnPX:3ohN3Qoo?c
loo/ilool^cNooKfm_ohn?SonOWionJ;0?okno_oo?cloogmo@02ooknoP03
ojNWY`00F^L005[W00<005SVL000ENE_001DhdT005?Q01GoooooofF@monG
]?WoV[OjohVZnOmjX?SoLY[hoffEn?mXT_SoIHogof:>momQSOOoGH[goeV7
m_mBPoKoC7kfod=gmOlgK_;o:5oSoaE6^Oooool00P00Dn40;?ooooooII3g
oiNdnOnJ]o[oRJ[iogZPn?mbV_SoKIGhofRBn?mUSoOoHXkgof6=momMR_Oo
FHOfoe:3m_m<O_Ko@gOeocM^l_lXGn?o5DJiooooo`00D>0004_PoooooooY
OfGol:VGoo6/V_o^WHWok95jon^;L_oZQFgojH5XonQnIOoYO6;ojG]QonQg
GOoXM5WoiVmBonEZC?oTHd?ohETgom9::?nZ<aGooooo0P00=l/00`00;<P0
0238000TYP01000>O@0000@001R[000b`@00?L`00TG@0P00DmX00`00F]oo
SHf=ojZZZP06ojZZZP03okBVS_nZZZ[oZZZZ00CoZZZZ0P00F^L3001Hi]l0
05CSB@00Dn405OooooooMYchoi2_nOnD/_WoQJOhogFLn?m^UoSoJ9;gofJ@
momRS_OoGhcgoej;momIR?KoEXGfoe22m_m9O?Go?gGeoc9[l_lSG>?o<5c5
knG/n`02001Ch@0EoooooomfW?SoT:oioiBbnOn5YoSoMIchofjGn?mXT_Oo
IY3gof:>momOS?OoGX_goeV8m_mFQOKoD8;fodUlmOloMOGo<V_bob=Lhol`
G<G_iNck0080053P01[oooooonb=M_o_Xi3ol:JDonjJQOo[SGGojXM^onZ1
J?oYOfKojGaRonQiGooXNEkoj7EIonMbE_oVKU3oiFQ9onAP?ooPEC;od4HS
okI;<>oUj_X003O;000aaP00;<P002:i000TYP4000im000010009:H003;1
0011bP01C=02001CfP03001Jg`00F^@005kW008006;Y1P01IN/2001Rj@04
005QjP00G^T005kW001Ni`<005[W0P00F>I_001EiFl005CSB@00Dn402HmV
TnWog>Gmog>Jn?mPS?OoEHCfodenm_m8N_Go@WKeodAhm@02ocicm@;o>g7e
0_lcK?@01_l`J_Co:6CdoamMkoldIn3od]_bSfJCj@8005?Q00V?IY?YomcU
oOmcV_SoH8cgoeF4m_m=O_KoB7[eod9fmOm4N?D00_lnLoD2oc]am@;o<fcd
017o<6[dobQTm?lOGNoo=6OPom;KlXmVTnT0053R001@h8mVTNOon^7Lon^;
LooYNf3oig5EonIZCOoUITSoi652onASA002onAO?P;ohe`k0_oRES<01_oR
Dc3oh4dXoma57oo@DcCokmSBSfJ7g`80037600<003;1000R^@009:H00@00
3Wd0008003;100@0047:005<d000DmX005?J0P00F]l00`00G^L006;Y001R
j@04005Uj`@006O]0P01IN/01@00H^T00F7Z001Nj@00G^T005cY008005[W
o`00F>HX001HiP033`EJiHmVU^__iNgk013ooooo00N?IYK[3`EJi@00F>H0
05SV3`EJiHmVU^__iNgk013ooooo00N?IYC[3`EFh`00E><0053R3`EBh8mV
TNO_iNck013ooooo00N?IXOO3`Dkc000=l/00376000b`@00:[L002J/0040
01FP00000`00</4004[L001;c@03001CfP8005[O00@005kW001Rj@00H^T0
0FG[0`00Ind4001YlP@006O]00@00FG[001PkP00H>h0063^L000G>cO001L
j@H005[W00<005SV001Ei@00E><00P00Dn42001@h0800DgL0`00B]`4001:
f08004OG0P00@m<01@00?m8003g<000mc000?L`003O;008003;10@005J00
00030?ooo`00@LX004_=00@005[O00@005kW001Rj@01IN/006O]0`02K?49
00=^m@03009/l@03J?@00fSd00800fSdo`03IO5D00=Ul@800f?/00D00f7[
005QjP02GNT00UgY001Ji`02001HiP<005GU0`00E><2001Ch@80053P00<0
0DgL001:g000B]P00P00AmL01000B]P004?C000gb`006:/108NVj@0000@0
oooo0011bP00D>8005?J0P01IN/3001Wk@05009/l@03K_D00foj00MdoP00
Lod00P03L_l01`07M?h007?m00MdoP07M?h007?m00=bo`07M?h00P00Lod0
0`07M?h01W7n00Mbo@3N00=bofl00Fcn00@00g;o005/oP00Lod00g;o1000
Lod02@01J_X00VGi00=Xm003IO400F3e001OlP00F_D005ob001KlP02005P
m@08001OlP00H>h0063^001PkP00G>`0063^001OlP00ENX2001Hj`8005c/
00<005CS0013d`00?M`00@0000000080oooo00D00Dc@009Mj@06Io@00Vca
00MdoP0201=jo`806X;o0P0QROl00`0WSOl0:i3o02^@o`0202^@o`<0<ICo
o`0[T?mE02^@o`<09hgo0P0[T?l202N=o`<08hGo00<09hgo0269o`0QROl0
0`0QROl00`0SQOl08HWo0269o`020269o`D06X;o0`0CN_l200M_o@03001H
l`00>m80QJGY0040QJGY00030?ooo`800Dc@00<01VOd00Mbo@0CN_l00P0J
P_l0100SQOl09hgo036<o`0aU?l203ZAo`80?IGo2@0oUom`03fEofl0?iOo
L00mUOl503nGo`0503fEo`0jTOl0?IGo03ZAo`0mUOl02@0jTOl6036<o`80
8hGo00D04g[o00I/o000?m8003760000000208FUj@001@3oool00`00Bld0
0Dc@005<d0020017e`<004[H00/0053P001Ch@00F^@005kW001Ji000G^L0
0F7Z001Nj@00F^L005cY001Nj@03001LjG0005S[K`00F>i_001Ij0@005S[
00<005S^001Hj`00F>/00`00F>/2001Aj`03001Ai@00DN/004_W0080057U
00D004_W001Aj`00Bn/004_W001;h`020016i006001;h`00BnL004_W001;
j`00A^X003oB0`23Y^/100000040QJGY0000\
\>"], "Text",
  ImageSize->{396, 422},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "The main buttons have different meaning  now:\n",
  StyleBox["[Copy]", "MR"],
  " \[Dash] copies the ",
  StyleBox["ViewPoint", "MR"],
  " to the clipboard\n",
  StyleBox["[Ok]", "MR"],
  " \[Dash] insert the chosen ",
  StyleBox["ViewPoint", "MR"],
  " value into the plot expression\n",
  StyleBox["[Cancel]", "MR"],
  " \[Dash] closes ",
  StyleBox["ViewPointSelect", "MR"],
  " window without any additional action"
}], "Text"],

Cell["\<\
The selected option will be placed at the end of expression: \
\>", "Text"],

Cell[BoxData[
    \(ParametricPlot3D[{Cos[5\ t], Sin[3\ t], Sin[t]}, {t, 0, 2\ \[Pi]}, 
      ViewPoint \[Rule] {2.49, \(-1.015\), 2.054}]\)], "Input"],

Cell[TextData[{
  "Note, the menu and shortcut command doesn't work in cells with format type \
",
  StyleBox["InputForm", "SR"],
  "."
}], "Text"],

Cell[TextData[{
  "Shortcut command can be applied directly to ",
  StyleBox["Show[Graphics3D[...]]", "MR"],
  " expression if graphics object is defined in the function ",
  StyleBox["Show", "MR"],
  " or evaluated before the application of the command. For example the ",
  StyleBox["ViewPointSelect", "MR"],
  " command can be applied to selected expression ",
  StyleBox["Show[gr,Boxed\[Rule]False]", "MR"],
  " of the following cell only if ",
  StyleBox["gr", "MR"],
  " has been defined in the current ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session as ",
  StyleBox["Graphics3D", "MR"],
  " object:"
}], "Text"],

Cell[BoxData[
    \(\(gr = 
        Graphics3D[\[IndentingNewLine]{Line[{{0, 0, 0}, {0, 0, 
                  1}}], \[IndentingNewLine]Line[{{0, 0, 0}, {0, 
                  Sin[60  \[Degree]], 0}}], \[IndentingNewLine]Line[{{0, 0, 
                  0}, {1, 0, 0}, {1/2, Cos[30  \[Degree]], 
                  0}, \[IndentingNewLine]{\(-1\)/2, Cos[30  \[Degree]], 
                  0}, {\(-1\)/2, \(-Cos[30  \[Degree]]\), 
                  0}, \[IndentingNewLine]{1/2, \(-Cos[30  \[Degree]]\), 
                  0}, {1, 0, 0}}]}];\)\)], "Input"],

Cell[BoxData[
    \(Show[gr, Boxed \[Rule] False]\)], "Input"],

Cell[BoxData[
    \(Clear[gr]\)], "Input"],

Cell[TextData[{
  "One final remark, in the cases when ",
  StyleBox["Graphics3D", "MR"],
  " primitive ",
  StyleBox["Polygon", "MR"],
  " has two identical points or when some points lay in the area restricted \
by other points the rendering in ",
  StyleBox["RealTime3D", "MR"],
  " mode might lead to crutial error. For more information refer to the \
package ",
  StyleBox["TaggedCells", "MR"],
  " by Ingolf Dahl."
}], "Text"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1400}, {0, 971}},
WindowSize->{496, 740},
WindowMargins->{{448, Automatic}, {Automatic, 101}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 40, 0, 65, "Section"],

Cell[CellGroupData[{
Cell[1841, 57, 27, 0, 39, "Subsection"],
Cell[1871, 59, 1063, 29, 161, "Text"],
Cell[2937, 90, 78, 1, 25, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3052, 96, 29, 0, 39, "Subsection"],
Cell[3084, 98, 112, 3, 42, "Text"],
Cell[3199, 103, 271, 10, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3507, 118, 32, 0, 39, "Subsection"],
Cell[3542, 120, 618, 14, 142, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4197, 139, 51, 0, 39, "Subsection"],
Cell[4251, 141, 165, 5, 42, "Text"],
Cell[4419, 148, 64, 0, 25, "Text"],
Cell[4486, 150, 62, 1, 29, "Input"],
Cell[4551, 153, 153, 4, 42, "Text"],

Cell[CellGroupData[{
Cell[4729, 161, 55, 1, 29, "Input"],
Cell[4787, 164, 647, 9, 70, "Print"]
}, Open  ]],
Cell[5449, 176, 240, 6, 70, "Text"],
Cell[5692, 184, 91, 1, 70, "Input"],
Cell[5786, 187, 149110, 2447, 70, 149018, 2444, "GraphicsData", "Bitmap", \
"Text"],
Cell[154899, 2636, 394, 12, 70, "Text"],
Cell[155296, 2650, 354, 7, 70, "Text"],
Cell[155653, 2659, 363, 7, 70, "Text"],
Cell[156019, 2668, 90, 1, 70, "Input"],
Cell[156112, 2671, 151, 4, 70, "Text"],
Cell[156266, 2677, 193, 6, 70, "Text"],
Cell[156462, 2685, 47, 1, 70, "Input"],
Cell[156512, 2688, 263, 7, 70, "Text"],

Cell[CellGroupData[{
Cell[156800, 2699, 269, 5, 70, "Input"],
Cell[157072, 2706, 84, 1, 70, "Output"],
Cell[157159, 2709, 41086, 1092, 70, 11303, 719, "GraphicsData", "PostScript", \
"Graphics"],
Cell[198248, 3803, 132, 3, 70, "Output"],
Cell[198383, 3808, 72, 1, 70, "Output"]
}, Open  ]],
Cell[198470, 3812, 531, 16, 70, "Text"],
Cell[199004, 3830, 127, 2, 70, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[199168, 3837, 66, 0, 70, "Subsection"],
Cell[199237, 3839, 275, 6, 70, "Text"],
Cell[199515, 3847, 675, 16, 70, "Text"],
Cell[200193, 3865, 108, 2, 70, "Input"],
Cell[200304, 3869, 57, 0, 70, "Text"],
Cell[200364, 3871, 111623, 1832, 70, 111531, 1829, "GraphicsData", "Bitmap", \
"Text"],
Cell[311990, 5705, 450, 14, 70, "Text"],
Cell[312443, 5721, 85, 2, 70, "Text"],
Cell[312531, 5725, 151, 2, 70, "Input"],
Cell[312685, 5729, 147, 5, 70, "Text"],
Cell[312835, 5736, 638, 17, 70, "Text"],
Cell[313476, 5755, 550, 9, 70, "Input"],
Cell[314029, 5766, 62, 1, 70, "Input"],
Cell[314094, 5769, 42, 1, 70, "Input"],
Cell[314139, 5772, 432, 12, 70, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

